#!/bin/sed
s/\bdifer/differ/g
s/\bDIFER/DIFFER/g
s/\bDifer/Differ/g
s/\bwanna\b/want to/g
s/\bWANNA\b/WANT TO/g
s/\bWanna\b/Want to/g
s/addresse\b/address/g
s/ADDRESSE\b/ADDRESS/g
s/Addresse\b/Address/g
s/adres\b/address/g
s/ADRES\b/ADDRESS/g
s/Adres\b/Address/g
s/alot/a lot/g
s/ALOT/A LOT/g
s/Alot/A lot/g
s/buitins/builtin's/g
s/BUITINS/BUILTIN'S/g
s/Buitins/Builtin's/g
s/canot/can't/g
s/CANOT/CAN'T/g
s/Canot/Can't/g
s/decompressions/decompression's/g
s/DECOMPRESSIONS/DECOMPRESSION'S/g
s/Decompressions/Decompression's/g
s/desn't/doesn't/g
s/DESN'T/DOESN'T/g
s/Desn't/Doesn't/g
s/diagnostic's/diagnostics/g
s/DIAGNOSTIC'S/DIAGNOSTICS/g
s/Diagnostic's/Diagnostics/g
s/does't/doesn't/g
s/DOES'T/DOESN'T/g
s/Does't/Doesn't/g
