#!/bin/sed
s/\bceasar\b/caesar/g
s/\bCEASAR\b/CAESAR/g
s/\bCeasar\b/Caesar/g
s/\bfeburary\b/february/g
s/\bFEBURARY\b/FEBRUARY/g
s/\bFeburary\b/February/g
s/\bgameboy\b/game boy/g
s/\bGAMEBOY\b/GAME BOY/g
s/\bGameboy\b/Game Boy/g
s/\baccessable\b/accessible/g
s/\bACCESSABLE\b/ACCESSIBLE/g
s/\bAccessable\b/Accessible/g
s/\bactualy\b/actually/g
s/\bACTUALY\b/ACTUALLY/g
s/\bActualy\b/Actually/g
s/\baddtional\b/additional/g
s/\bADDTIONAL\b/ADDITIONAL/g
s/\bAddtional\b/Additional/g
s/\bagressive\b/aggressive/g
s/\bAGRESSIVE\b/AGGRESSIVE/g
s/\bAgressive\b/Aggressive/g
s/\bahve\b/have/g
s/\bAHVE\b/HAVE/g
s/\bAhve\b/Have/g
s/\balligned\b/aligned/g
s/\bALLIGNED\b/ALIGNED/g
s/\bAlligned\b/Aligned/g
s/\ballready\b/already/g
s/\bALLREADY\b/ALREADY/g
s/\bAllready\b/Already/g
s/\balocation/allocation/g
s/\bALOCATION/ALLOCATION/g
s/\bAlocation/Allocation/g
s/\bammount\b/amount/g
s/\bAMMOUNT\b/AMOUNT/g
s/\bAmmount\b/Amount/g
s/\baproximate\b/approximate/g
s/\bAPROXIMATE\b/APPROXIMATE/g
s/\bAproximate\b/Approximate/g
s/\baquiring\b/acquiring/g
s/\bAQUIRING\b/ACQUIRING/g
s/\bAquiring\b/Acquiring/g
s/\barbitarily\b/arbitrarily/g
s/\bARBITARILY\b/ARBITRARILY/g
s/\bArbitarily\b/Arbitrarily/g
s/\bargment/argument/g
s/\bARGMENT/ARGUMENT/g
s/\bArgment/Argument/g
s/\bartifical\b/artificial/g
s/\bARTIFICAL\b/ARTIFICIAL/g
s/\bArtifical\b/Artificial/g
s/\bartifically\b/artificially/g
s/\bARTIFICALLY\b/ARTIFICIALLY/g
s/\bArtifically\b/Artificially/g
s/\battemp\b/attempt/g
s/\bATTEMP\b/ATTEMPT/g
s/\bAttemp\b/Attempt/g
s/\battemts\b/attempts/g
s/\bATTEMTS\b/ATTEMPTS/g
s/\bAttemts\b/Attempts/g
s/\bauxilary\b/auxiliary/g
s/\bAUXILARY\b/AUXILIARY/g
s/\bAuxilary\b/Auxiliary/g
s/\bauxillary\b/auxiliary/g
s/\bAUXILLARY\b/AUXILIARY/g
s/\bAuxillary\b/Auxiliary/g
s/\bauxilliary\b/auxiliary/g
s/\bAUXILLIARY\b/AUXILIARY/g
s/\bAuxilliary\b/Auxiliary/g
s/\bavailabe\b/available/g
s/\bAVAILABE\b/AVAILABLE/g
s/\bAvailabe\b/Available/g
s/\bavailble\b/available/g
s/\bAVAILBLE\b/AVAILABLE/g
s/\bAvailble\b/Available/g
s/\bavaliable\b/available/g
s/\bAVALIABLE\b/AVAILABLE/g
s/\bAvaliable\b/Available/g
s/\bbeeing\b/being/g
s/\bBEEING\b/BEING/g
s/\bBeeing\b/Being/g
s/\bbetwen\b/between/g
s/\bBETWEN\b/BETWEEN/g
s/\bBetwen\b/Between/g
s/\bbewteen\b/between/g
s/\bBEWTEEN\b/BETWEEN/g
s/\bBewteen\b/Between/g
s/\bcharachters\b/characters/g
s/\bCHARACHTERS\b/CHARACTERS/g
s/\bCharachters\b/Characters/g
s/\bcharactor\b/character/g
s/\bCHARACTOR\b/CHARACTER/g
s/\bCharactor\b/Character/g
s/\bchilden\b/children/g
s/\bCHILDEN\b/CHILDREN/g
s/\bChilden\b/Children/g
s/\bcompatiable\b/compatible/g
s/\bCOMPATIABLE\b/COMPATIBLE/g
s/\bCompatiable\b/Compatible/g
s/\bcomplier\b/compiler/g
s/\bCOMPLIER\b/COMPILER/g
s/\bComplier\b/Compiler/g
s/\bcondidtions\b/conditions/g
s/\bCONDIDTIONS\b/CONDITIONS/g
s/\bCondidtions\b/Conditions/g
s/\bconection\b/connection/g
s/\bCONECTION\b/CONNECTION/g
s/\bConection\b/Connection/g
s/\bconfigureable\b/configurable/g
s/\bCONFIGUREABLE\b/CONFIGURABLE/g
s/\bConfigureable\b/Configurable/g
s/\bconsonent\b/consonant/g
s/\bCONSONENT\b/CONSONANT/g
s/\bConsonent\b/Consonant/g
s/\bconstaints\b/constraints/g
s/\bCONSTAINTS\b/CONSTRAINTS/g
s/\bConstaints\b/Constraints/g
s/\bcontaines\b/contains/g
s/\bCONTAINES\b/CONTAINS/g
s/\bContaines\b/Contains/g
s/\bcontinous\b/continuous/g
s/\bCONTINOUS\b/CONTINUOUS/g
s/\bContinous\b/Continuous/g
s/\bcontroled\b/controlled/g
s/\bCONTROLED\b/CONTROLLED/g
s/\bControled\b/Controlled/g
s/\bdecendents\b/descendants/g
s/\bDECENDENTS\b/DESCENDANTS/g
s/\bDecendents\b/Descendants/g
s/\bdependant\b/dependent/g
s/\bDEPENDANT\b/DEPENDENT/g
s/\bDependant\b/Dependent/g
s/\bdescibed\b/described/g
s/\bDESCIBED\b/DESCRIBED/g
s/\bDescibed\b/Described/g
s/\bdescripton\b/description/g
s/\bDESCRIPTON\b/DESCRIPTION/g
s/\bDescripton\b/Description/g
s/\bdimention\b/dimension/g
s/\bDIMENTION\b/DIMENSION/g
s/\bDimention\b/Dimension/g
s/\bdimentional\b/dimensional/g
s/\bDIMENTIONAL\b/DIMENSIONAL/g
s/\bDimentional\b/Dimensional/g
s/\bdipthongs\b/diphthongs/g
s/\bDIPTHONGS\b/DIPHTHONGS/g
s/\bDipthongs\b/Diphthongs/g
s/\bdivison\b/division/g
s/\bDIVISON\b/DIVISION/g
s/\bDivison\b/Division/g
s/\bdupicate\b/duplicate/g
s/\bDUPICATE\b/DUPLICATE/g
s/\bDupicate\b/Duplicate/g
s/\befficent\b/efficient/g
s/\bEFFICENT\b/EFFICIENT/g
s/\bEfficent\b/Efficient/g
s/\benviromental\b/environmental/g
s/\bENVIROMENTAL\b/ENVIRONMENTAL/g
s/\bEnviromental\b/Environmental/g
s/\bequivelant\b/equivalent/g
s/\bEQUIVELANT\b/EQUIVALENT/g
s/\bEquivelant\b/Equivalent/g
s/\beventhough\b/even though/g
s/\bEVENTHOUGH\b/EVEN THOUGH/g
s/\bEventhough\b/Even though/g
s/\beverytime\b/every time/g
s/\bEVERYTIME\b/EVERY TIME/g
s/\bEverytime\b/Every time/g
s/\bextremly\b/extremely/g
s/\bEXTREMLY\b/EXTREMELY/g
s/\bExtremly\b/Extremely/g
s/\bfinaly\b/finally/g
s/\bFINALY\b/FINALLY/g
s/\bFinaly\b/Finally/g
s/\bfolowing\b/following/g
s/\bFOLOWING\b/FOLLOWING/g
s/\bFolowing\b/Following/g
s/\bfucntion\b/function/g
s/\bFUCNTION\b/FUNCTION/g
s/\bFucntion\b/Function/g
s/\bfuther\b/further/g
s/\bFUTHER\b/FURTHER/g
s/\bFuther\b/Further/g
s/\bgrammer\b/grammar/g
s/\bGRAMMER\b/GRAMMAR/g
s/\bGrammer\b/Grammar/g
s/\bguage\b/gauge/g
s/\bGUAGE\b/GAUGE/g
s/\bGuage\b/Gauge/g
s/\bhasnt\b/hasn't/g
s/\bHASNT\b/HASN'T/g
s/\bHasnt\b/Hasn't/g
s/\bheigher\b/higher/g
s/\bHEIGHER\b/HIGHER/g
s/\bHeigher\b/Higher/g
s/\bidentifers\b/identifiers/g
s/\bIDENTIFERS\b/IDENTIFIERS/g
s/\bIdentifers\b/Identifiers/g
s/\bimcomplete\b/incomplete/g
s/\bIMCOMPLETE\b/INCOMPLETE/g
s/\bImcomplete\b/Incomplete/g
s/\bindependance\b/independence/g
s/\bINDEPENDANCE\b/INDEPENDENCE/g
s/\bIndependance\b/Independence/g
s/\binheritence\b/inheritance/g
s/\bINHERITENCE\b/INHERITANCE/g
s/\bInheritence\b/Inheritance/g
s/\binital\b/initial/g
s/\bINITAL\b/INITIAL/g
s/\bInital\b/Initial/g
s/\bloosing\b/losing/g
s/\bLOOSING\b/LOSING/g
s/\bLoosing\b/Losing/g
s/\bmarkes\b/marks/g
s/\bMARKES\b/MARKS/g
s/\bMarkes\b/Marks/g
s/\bminumum\b/minimum/g
s/\bMINUMUM\b/MINIMUM/g
s/\bMinumum\b/Minimum/g
s/\bocasion\b/occasion/g
s/\bOCASION\b/OCCASION/g
s/\bOcasion\b/Occasion/g
s/\bocasions\b/occasions/g
s/\bOCASIONS\b/OCCASIONS/g
s/\bOcasions\b/Occasions/g
s/\boffical\b/official/g
s/\bOFFICAL\b/OFFICIAL/g
s/\bOffical\b/Official/g
s/\bommited\b/omitted/g
s/\bOMMITED\b/OMITTED/g
s/\bOmmited\b/Omitted/g
s/\bommitted\b/omitted/g
s/\bOMMITTED\b/OMITTED/g
s/\bOmmitted\b/Omitted/g
s/\bonyl\b/only/g
s/\bONYL\b/ONLY/g
s/\bOnyl\b/Only/g
s/\bpallete\b/palette/g
s/\bPALLETE\b/PALETTE/g
s/\bPallete\b/Palette/g
s/\bparticulary\b/particularly/g
s/\bPARTICULARY\b/PARTICULARLY/g
s/\bParticulary\b/Particularly/g
s/\bpased\b/passed/g
s/\bPASED\b/PASSED/g
s/\bPased\b/Passed/g
s/\bpeformed\b/performed/g
s/\bPEFORMED\b/PERFORMED/g
s/\bPeformed\b/Performed/g
s/\bperfomance\b/performance/g
s/\bPERFOMANCE\b/PERFORMANCE/g
s/\bPerfomance\b/Performance/g
s/\bperistent\b/persistent/g
s/\bPERISTENT\b/PERSISTENT/g
s/\bPeristent\b/Persistent/g
s/\bpersistant\b/persistent/g
s/\bPERSISTANT\b/PERSISTENT/g
s/\bPersistant\b/Persistent/g
s/\bpossiblity\b/possibility/g
s/\bPOSSIBLITY\b/POSSIBILITY/g
s/\bPossiblity\b/Possibility/g
s/\bpreceeds\b/precedes/g
s/\bPRECEEDS\b/PRECEDES/g
s/\bPreceeds\b/Precedes/g
s/\bprefered\b/preferred/g
s/\bPREFERED\b/PREFERRED/g
s/\bPrefered\b/Preferred/g
s/\bprocesser\b/processor/g
s/\bPROCESSER\b/PROCESSOR/g
s/\bProcesser\b/Processor/g
s/\bpropogate\b/propagate/g
s/\bPROPOGATE\b/PROPAGATE/g
s/\bPropogate\b/Propagate/g
s/\bpropper\b/proper/g
s/\bPROPPER\b/PROPER/g
s/\bPropper\b/Proper/g
s/\bpsuedo\b/pseudo/g
s/\bPSUEDO\b/PSEUDO/g
s/\bPsuedo\b/Pseudo/g
s/\brecieving\b/receiving/g
s/\bRECIEVING\b/RECEIVING/g
s/\bRecieving\b/Receiving/g
s/\breferece\b/reference/g
s/\bREFERECE\b/REFERENCE/g
s/\bReferece\b/Reference/g
s/\brefereces\b/references/g
s/\bREFERECES\b/REFERENCES/g
s/\bRefereces\b/References/g
s/\breferrence\b/reference/g
s/\bREFERRENCE\b/REFERENCE/g
s/\bReferrence\b/Reference/g
s/\brelevence\b/relevance/g
s/\bRELEVENCE\b/RELEVANCE/g
s/\bRelevence\b/Relevance/g
s/\bremeber\b/remember/g
s/\bREMEBER\b/REMEMBER/g
s/\bRemeber\b/Remember/g
s/\breoccurrence\b/recurrence/g
s/\bREOCCURRENCE\b/RECURRENCE/g
s/\bReoccurrence\b/Recurrence/g
s/\brepetion\b/repetition/g
s/\bREPETION\b/REPETITION/g
s/\bRepetion\b/Repetition/g
s/\breponsible\b/responsible/g
s/\bREPONSIBLE\b/RESPONSIBLE/g
s/\bReponsible\b/Responsible/g
s/\brequred\b/required/g
s/\bREQURED\b/REQUIRED/g
s/\bRequred\b/Required/g
s/\bresistence\b/resistance/g
s/\bRESISTENCE\b/RESISTANCE/g
s/\bResistence\b/Resistance/g
s/\bsegementation\b/segmentation/g
s/\bSEGEMENTATION\b/SEGMENTATION/g
s/\bSegementation\b/Segmentation/g
s/\bshoudl\b/should/g
s/\bSHOUDL\b/SHOULD/g
s/\bShoudl\b/Should/g
s/\bsimplier\b/simpler/g
s/\bSIMPLIER\b/SIMPLER/g
s/\bSimplier\b/Simpler/g
s/\bspecfic\b/specific/g
s/\bSPECFIC\b/SPECIFIC/g
s/\bSpecfic\b/Specific/g
s/\bsubsiduary\b/subsidiary/g
s/\bSUBSIDUARY\b/SUBSIDIARY/g
s/\bSubsiduary\b/Subsidiary/g
s/\bsubstract\b/subtract/g
s/\bSUBSTRACT\b/SUBTRACT/g
s/\bSubstract\b/Subtract/g
s/\bsubstracts\b/subtracts/g
s/\bSUBSTRACTS\b/SUBTRACTS/g
s/\bSubstracts\b/Subtracts/g
s/\bsucceded\b/succeeded/g
s/\bSUCCEDED\b/SUCCEEDED/g
s/\bSucceded\b/Succeeded/g
s/\bsytem\b/system/g
s/\bSYTEM\b/SYSTEM/g
s/\bSytem\b/System/g
s/\btargetted\b/targeted/g
s/\bTARGETTED\b/TARGETED/g
s/\bTargetted\b/Targeted/g
s/\btargetting\b/targeting/g
s/\bTARGETTING\b/TARGETING/g
s/\bTargetting\b/Targeting/g
s/\bteh\b/the/g
s/\bTEH\b/THE/g
s/\bTeh\b/The/g
s/\btheese\b/these/g
s/\bTHEESE\b/THESE/g
s/\bTheese\b/These/g
s/\bthta\b/that/g
s/\bTHTA\b/THAT/g
s/\bThta\b/That/g
s/\btoke\b/took/g
s/\bTOKE\b/TOOK/g
s/\bToke\b/Took/g
s/\btransfering\b/transferring/g
s/\bTRANSFERING\b/TRANSFERRING/g
s/\bTransfering\b/Transferring/g
s/\btransistion\b/transition/g
s/\bTRANSISTION\b/TRANSITION/g
s/\bTransistion\b/Transition/g
s/\buntill\b/until/g
s/\bUNTILL\b/UNTIL/g
s/\bUntill\b/Until/g
s/\bwhic\b/which/g
s/\bWHIC\b/WHICH/g
s/\bWhic\b/Which/g
s/\bwhther\b/whether/g
s/\bWHTHER\b/WHETHER/g
s/\bWhther\b/Whether/g
s/\bwithing\b/within/g
s/\bWITHING\b/WITHIN/g
s/\bWithing\b/Within/g
s/\bwriten\b/written/g
s/\bWRITEN\b/WRITTEN/g
s/\bWriten\b/Written/g
s/absense/absence/g
s/ABSENSE/ABSENCE/g
s/Absense/Absence/g
s/accidentaly/accidentally/g
s/ACCIDENTALY/ACCIDENTALLY/g
s/Accidentaly/Accidentally/g
s/accomodating/accommodating/g
s/ACCOMODATING/ACCOMMODATING/g
s/Accomodating/Accommodating/g
s/accout/account/g
s/ACCOUT/ACCOUNT/g
s/Accout/Account/g
s/acess/access/g
s/ACESS/ACCESS/g
s/Acess/Access/g
s/addreses/addresses/g
s/ADDRESES/ADDRESSES/g
s/Addreses/Addresses/g
s/algorthm/algorithm/g
s/ALGORTHM/ALGORITHM/g
s/Algorthm/Algorithm/g
s/algorythm/algorithm/g
s/ALGORYTHM/ALGORITHM/g
s/Algorythm/Algorithm/g
s/alignement/alignment/g
s/ALIGNEMENT/ALIGNMENT/g
s/Alignement/Alignment/g
s/alltogether/altogether/g
s/ALLTOGETHER/ALTOGETHER/g
s/Alltogether/Altogether/g
s/alogrithm/algorithm/g
s/ALOGRITHM/ALGORITHM/g
s/Alogrithm/Algorithm/g
s/alrady/already/g
s/ALRADY/ALREADY/g
s/Alrady/Already/g
s/alredy/already/g
s/ALREDY/ALREADY/g
s/Alredy/Already/g
s/althought/although/g
s/ALTHOUGHT/ALTHOUGH/g
s/Althought/Although/g
s/alway\b/always/g
s/ALWAY\b/ALWAYS/g
s/Alway\b/Always/g
s/ammend/amend/g
s/AMMEND/AMEND/g
s/Ammend/Amend/g
s/analagous/analogous/g
s/ANALAGOUS/ANALOGOUS/g
s/Analagous/Analogous/g
s/appopriate/appropriate/g
s/APPOPRIATE/APPROPRIATE/g
s/Appopriate/Appropriate/g
s/appplying/applying/g
s/APPPLYING/APPLYING/g
s/Appplying/Applying/g
s/appropiate/appropriate/g
s/APPROPIATE/APPROPRIATE/g
s/Appropiate/Appropriate/g
s/approriate/appropriate/g
s/APPRORIATE/APPROPRIATE/g
s/Approriate/Appropriate/g
s/arbitary/arbitrary/g
s/ARBITARY/ARBITRARY/g
s/Arbitary/Arbitrary/g
s/arguements/arguments/g
s/ARGUEMENTS/ARGUMENTS/g
s/Arguements/Arguments/g
s/arguement/argument/g
s/ARGUEMENT/ARGUMENT/g
s/Arguement/Argument/g
s/arguemnt/argument/g
s/ARGUEMNT/ARGUMENT/g
s/Arguemnt/Argument/g
s/arugment/argument/g
s/ARUGMENT/ARGUMENT/g
s/Arugment/Argument/g
s/arument/argument/g
s/ARUMENT/ARGUMENT/g
s/Arument/Argument/g
s/arument/arum_ent/g
s/ARUMENT/ARUM_ENT/g
s/Arument/Arum_ent/g
s/assigments/assignments/g
s/ASSIGMENTS/ASSIGNMENTS/g
s/Assigments/Assignments/g
s/aswell/as well/g
s/ASWELL/AS WELL/g
s/Aswell/As well/g
s/atomicly/atomically/g
s/ATOMICLY/ATOMICALLY/g
s/Atomicly/Atomically/g
s/atributes/attributes/g
s/ATRIBUTES/ATTRIBUTES/g
s/Atributes/Attributes/g
s/attibute/attribute/g
s/ATTIBUTE/ATTRIBUTE/g
s/Attibute/Attribute/g
s/autmatically/automatically/g
s/AUTMATICALLY/AUTOMATICALLY/g
s/Autmatically/Automatically/g
s/auxilary\b/auxiliary/g
s/AUXILARY\b/AUXILIARY/g
s/Auxilary\b/Auxiliary/g
s/auxillary\b/auxiliary/g
s/AUXILLARY\b/AUXILIARY/g
s/Auxillary\b/Auxiliary/g
s/auxilliary\b/auxiliary/g
s/AUXILLIARY\b/AUXILIARY/g
s/Auxilliary\b/Auxiliary/g
s/avaiable/available/g
s/AVAIABLE/AVAILABLE/g
s/Avaiable/Available/g
s/beacuse/because/g
s/BEACUSE/BECAUSE/g
s/Beacuse/Because/g
s/becase/because/g
s/BECASE/BECAUSE/g
s/Becase/Because/g
s/becasue/because/g
s/BECASUE/BECAUSE/g
s/Becasue/Because/g
s/becaues/because/g
s/BECAUES/BECAUSE/g
s/Becaues/Because/g
s/becaue/because/g
s/BECAUE/BECAUSE/g
s/Becaue/Because/g
s/becaus\b/because/g
s/BECAUS\b/BECAUSE/g
s/Becaus\b/Because/g
s/befor\b/before/g
s/BEFOR\b/BEFORE/g
s/Befor\b/Before/g
s/beforere/before/g
s/BEFORERE/BEFORE/g
s/Beforere/Before/g
s/beging/beginning/g
s/BEGING/BEGINNING/g
s/Beging/Beginning/g
s/beginnig/beginning/g
s/BEGINNIG/BEGINNING/g
s/Beginnig/Beginning/g
s/blatent/blatant/g
s/BLATENT/BLATANT/g
s/Blatent/Blatant/g
s/botton/bottom/g
s/BOTTON/BOTTOM/g
s/Botton/Bottom/g
s/boundery/boundary/g
s/BOUNDERY/BOUNDARY/g
s/Boundery/Boundary/g
s/bulitin/builtin/g
s/BULITIN/BUILTIN/g
s/Bulitin/Builtin/g
s/calcuations/calculations/g
s/CALCUATIONS/CALCULATIONS/g
s/Calcuations/Calculations/g
s/calculcate/calculate/g
s/CALCULCATE/CALCULATE/g
s/Calculcate/Calculate/g
s/cancelation/cancellation/g
s/CANCELATION/CANCELLATION/g
s/Cancelation/Cancellation/g
s/carefull/careful/g
s/CAREFULL/CAREFUL/g
s/Carefull/Careful/g
s/catagori/categori/g
s/CATAGORI/CATEGORI/g
s/Catagori/Categori/g
s/chache/cache/g
s/CHACHE/CACHE/g
s/Chache/Cache/g
s/changable/changeable/g
s/CHANGABLE/CHANGEABLE/g
s/Changable/Changeable/g
s/chaning/changing/g
s/CHANING/CHANGING/g
s/Chaning/Changing/g
s/characeters/characters/g
s/CHARACETERS/CHARACTERS/g
s/Characeters/Characters/g
s/chould/could/g
s/CHOULD/COULD/g
s/Chould/Could/g
s/chracters/characters/g
s/CHRACTERS/CHARACTERS/g
s/Chracters/Characters/g
s/chracter/character/g
s/CHRACTER/CHARACTER/g
s/Chracter/Character/g
s/coalesed/coalesced/g
s/COALESED/COALESCED/g
s/Coalesed/Coalesced/g
s/comming/coming/g
s/COMMING/COMING/g
s/Comming/Coming/g
s/compability/compatibility/g
s/COMPABILITY/COMPATIBILITY/g
s/Compability/Compatibility/g
s/comparsion/comparison/g
s/COMPARSION/COMPARISON/g
s/Comparsion/Comparison/g
s/compatibile/compatible/g
s/COMPATIBILE/COMPATIBLE/g
s/Compatibile/Compatible/g
s/compatibily/compatibility/g
s/COMPATIBILY/COMPATIBILITY/g
s/Compatibily/Compatibility/g
s/complation/compilation/g
s/COMPLATION/COMPILATION/g
s/Complation/Compilation/g
s/complation/completion/g
s/COMPLATION/COMPLETION/g
s/Complation/Completion/g
s/concatented/concatenated/g
s/CONCATENTED/CONCATENATED/g
s/Concatented/Concatenated/g
s/conditonal/conditional/g
s/CONDITONAL/CONDITIONAL/g
s/Conditonal/Conditional/g
s/condtion/condition/g
s/CONDTION/CONDITION/g
s/Condtion/Condition/g
s/confict/conflict/g
s/CONFICT/CONFLICT/g
s/Confict/Conflict/g
s/configiuration/configuration/g
s/CONFIGIURATION/CONFIGURATION/g
s/Configiuration/Configuration/g
s/configury/configure/g
s/CONFIGURY/CONFIGURE/g
s/Configury/Configure/g
s/consistancy/consistency/g
s/CONSISTANCY/CONSISTENCY/g
s/Consistancy/Consistency/g
s/constains/constrains/g
s/CONSTAINS/CONSTRAINS/g
s/Constains/Constrains/g
s/contants/constants/g
s/CONTANTS/CONSTANTS/g
s/Contants/Constants/g
s/continguous/continuous/g
s/CONTINGUOUS/CONTINUOUS/g
s/Continguous/Continuous/g
s/contoller/controller/g
s/CONTOLLER/CONTROLLER/g
s/Contoller/Controller/g
s/contraversy/controversy/g
s/CONTRAVERSY/CONTROVERSY/g
s/Contraversy/Controversy/g
s/controling/controlling/g
s/CONTROLING/CONTROLLING/g
s/Controling/Controlling/g
s/contructors/constructors/g
s/CONTRUCTORS/CONSTRUCTORS/g
s/Contructors/Constructors/g
s/convergance/convergence/g
s/CONVERGANCE/CONVERGENCE/g
s/Convergance/Convergence/g
s/converison/conversion/g
s/CONVERISON/CONVERSION/g
s/Converison/Conversion/g
s/correspondig/corresponding/g
s/CORRESPONDIG/CORRESPONDING/g
s/Correspondig/Corresponding/g
s/coverd/covered/g
s/COVERD/COVERED/g
s/Coverd/Covered/g
s/currenty/currently/g
s/CURRENTY/CURRENTLY/g
s/Currenty/Currently/g
s/debuging/debugging/g
s/DEBUGING/DEBUGGING/g
s/Debuging/Debugging/g
s/decending/descending/g
s/DECENDING/DESCENDING/g
s/Decending/Descending/g
s/defering/deferring/g
s/DEFERING/DEFERRING/g
s/Defering/Deferring/g
s/definate/definite/g
s/DEFINATE/DEFINITE/g
s/Definate/Definite/g
s/definte/definite/g
s/DEFINTE/DEFINITE/g
s/Definte/Definite/g
s/defintions/definitions/g
s/DEFINTIONS/DEFINITIONS/g
s/Defintions/Definitions/g
s/defitions/deviations/g
s/DEFITIONS/DEVIATIONS/g
s/Defitions/Deviations/g
s/depedent/dependent/g
s/DEPEDENT/DEPENDENT/g
s/Depedent/Dependent/g
s/dependecies/dependencies/g
s/DEPENDECIES/DEPENDENCIES/g
s/Dependecies/Dependencies/g
s/depricated/deprecated/g
s/DEPRICATED/DEPRECATED/g
s/Depricated/Deprecated/g
s/derivates/derivatives/g
s/DERIVATES/DERIVATIVES/g
s/Derivates/Derivatives/g
s/derivate/derivative/g
s/DERIVATE/DERIVATIVE/g
s/Derivate/Derivative/g
s/derrived/derived/g
s/DERRIVED/DERIVED/g
s/Derrived/Derived/g
s/derrive/derive/g
s/DERRIVE/DERIVE/g
s/Derrive/Derive/g
s/desination/designation/g
s/DESINATION/DESIGNATION/g
s/Desination/Designation/g
s/desireable/desirable/g
s/DESIREABLE/DESIRABLE/g
s/Desireable/Desirable/g
s/destoyed/destroyed/g
s/DESTOYED/DESTROYED/g
s/Destoyed/Destroyed/g
s/differnt/different/g
s/DIFFERNT/DIFFERENT/g
s/Differnt/Different/g
s/direclty/directly/g
s/DIRECLTY/DIRECTLY/g
s/Direclty/Directly/g
s/distribtution/distributions/g
s/DISTRIBTUTION/DISTRIBUTIONS/g
s/Distribtution/Distributions/g
s/dynamicaly/dynamically/g
s/DYNAMICALY/DYNAMICALLY/g
s/Dynamicaly/Dynamically/g
s/easilly/easily/g
s/EASILLY/EASILY/g
s/Easilly/Easily/g
s/eliminte/eliminate/g
s/ELIMINTE/ELIMINATE/g
s/Eliminte/Eliminate/g
s/elment/element/g
s/ELMENT/ELEMENT/g
s/Elment/Element/g
s/elsewere/elsewhere/g
s/ELSEWERE/ELSEWHERE/g
s/Elsewere/Elsewhere/g
s/emptry/empty/g
s/EMPTRY/EMPTY/g
s/Emptry/Empty/g
s/entirity/entirely/g
s/ENTIRITY/ENTIRELY/g
s/Entirity/Entirely/g
s/epressions/expressions/g
s/EPRESSIONS/EXPRESSIONS/g
s/Epressions/Expressions/g
s/errorneous/erroneous/g
s/ERRORNEOUS/ERRONEOUS/g
s/Errorneous/Erroneous/g
s/erros/errors/g
s/ERROS/ERRORS/g
s/Erros/Errors/g
s/excpetions/exceptions/g
s/EXCPETIONS/EXCEPTIONS/g
s/Excpetions/Exceptions/g
s/exmaple/example/g
s/EXMAPLE/EXAMPLE/g
s/Exmaple/Example/g
s/expession/expression/g
s/EXPESSION/EXPRESSION/g
s/Expession/Expression/g
s/expexted/expected/g
s/EXPEXTED/EXPECTED/g
s/Expexted/Expected/g
s/explicte/explicate/g
s/EXPLICTE/EXPLICATE/g
s/Explicte/Explicate/g
s/expres\b/express/g
s/EXPRES\b/EXPRESS/g
s/Expres\b/Express/g
s/forseeable/foreseeable/g
s/FORSEEABLE/FORESEEABLE/g
s/Forseeable/Foreseeable/g
s/fuction/function/g
s/FUCTION/FUNCTION/g
s/Fuction/Function/g
s/funcion/function/g
s/FUNCION/FUNCTION/g
s/Funcion/Function/g
s/functin/function/g
s/FUNCTIN/FUNCTION/g
s/Functin/Function/g
s/guarenteed/guaranteed/g
s/GUARENTEED/GUARANTEED/g
s/Guarenteed/Guaranteed/g
s/implemenetation/implementation/g
s/IMPLEMENETATION/IMPLEMENTATION/g
s/Implemenetation/Implementation/g
s/langauge/language/g
s/LANGAUGE/LANGUAGE/g
s/Langauge/Language/g
s/libary/library/g
s/LIBARY/LIBRARY/g
s/Libary/Library/g
s/logrithm/logarithm/g
s/LOGRITHM/LOGARITHM/g
s/Logrithm/Logarithm/g
s/mathod/method/g
s/MATHOD/METHOD/g
s/Mathod/Method/g
s/measurments/measurements/g
s/MEASURMENTS/MEASUREMENTS/g
s/Measurments/Measurements/g
s/neccesar/necessar/g
s/NECCESAR/NECESSAR/g
s/Neccesar/Necessar/g
s/ocurred/occurred/g
s/OCURRED/OCCURRED/g
s/Ocurred/Occurred/g
s/origional/original/g
s/ORIGIONAL/ORIGINAL/g
s/Origional/Original/g
s/parantheses/parentheses/g
s/PARANTHESES/PARENTHESES/g
s/Parantheses/Parentheses/g
s/propogating/propagating/g
s/PROPOGATING/PROPAGATING/g
s/Propogating/Propagating/g
s/realy/really/g
s/REALY/REALLY/g
s/Realy/Really/g
s/recived/received/g
s/RECIVED/RECEIVED/g
s/Recived/Received/g
s/relase/release/g
s/RELASE/RELEASE/g
s/Relase/Release/g
s/represenation/representation/g
s/REPRESENATION/REPRESENTATION/g
s/Represenation/Representation/g
s/representaiton/representation/g
s/REPRESENTAITON/REPRESENTATION/g
s/Representaiton/Representation/g
s/seraliz/serializ/g
s/SERALIZ/SERIALIZ/g
s/Seraliz/Serializ/g
s/seriliz/serializ/g
s/SERILIZ/SERIALIZ/g
s/Seriliz/Serializ/g
s/simpliest/simplest/g
s/SIMPLIEST/SIMPLEST/g
s/Simpliest/Simplest/g
s/slighty/slightly/g
s/SLIGHTY/SLIGHTLY/g
s/Slighty/Slightly/g
s/specfied/specified/g
s/SPECFIED/SPECIFIED/g
s/Specfied/Specified/g
s/successfuly/successfully/g
s/SUCCESSFULY/SUCCESSFULLY/g
s/Successfuly/Successfully/g
s/trucate/truncate/g
s/TRUCATE/TRUNCATE/g
s/Trucate/Truncate/g
s/truely/truly/g
s/TRUELY/TRULY/g
s/Truely/Truly/g
s/unecessary/unnecessary/g
s/UNECESSARY/UNNECESSARY/g
s/Unecessary/Unnecessary/g
s/unfortunatly/unfortunately/g
s/UNFORTUNATLY/UNFORTUNATELY/g
s/Unfortunatly/Unfortunately/g
s/unnecssary/unnecessary/g
s/UNNECSSARY/UNNECESSARY/g
s/Unnecssary/Unnecessary/g
s/untill\b/until/g
s/UNTILL\b/UNTIL/g
s/Untill\b/Until/g
s/usualy/usually/g
s/USUALY/USUALLY/g
s/Usualy/Usually/g
s/valud/valid/g
s/VALUD/VALID/g
s/Valud/Valid/g
s/wellformed/well formed/g
s/WELLFORMED/WELL FORMED/g
s/Wellformed/Well formed/g
s/writting/writing/g
s/WRITTING/WRITING/g
s/Writting/Writing/g
