#!/bin/sed
s/\benviroment\b/environment/g
s/\bENVIROMENT\b/ENVIRONMENT/g
s/\bEnviroment\b/Environment/g
s/\bequivelent\b/equivalent/g
s/\bEQUIVELENT\b/EQUIVALENT/g
s/\bEquivelent\b/Equivalent/g
s/\boccuring\b/occurring/g
s/\bOCCURING\b/OCCURRING/g
s/\bOccuring\b/Occurring/g
s/\bommitting\b/omitting/g
s/\bOMMITTING\b/OMITTING/g
s/\bOmmitting\b/Omitting/g
s/\bpersistance\b/persistence/g
s/\bPERSISTANCE\b/PERSISTENCE/g
s/\bPersistance\b/Persistence/g
s/\bpostive\b/positive/g
s/\bPOSTIVE\b/POSITIVE/g
s/\bPostive\b/Positive/g
s/\brefered\b/referred/g
s/\bREFERED\b/REFERRED/g
s/\bRefered\b/Referred/g
s/\brefered/referred/g
s/\bREFERED/REFERRED/g
s/\bRefered/Referred/g
s/\bretreive\b/retrieve/g
s/\bRETREIVE\b/RETRIEVE/g
s/\bRetreive\b/Retrieve/g
s/\bstatment\b/statement/g
s/\bSTATMENT\b/STATEMENT/g
s/\bStatment\b/Statement/g
s/\bupto\b/up to/g
s/\bUPTO\b/UP TO/g
s/\bUpto\b/Up to/g
s/\busefull\b/useful/g
s/\bUSEFULL\b/USEFUL/g
s/\bUsefull\b/Useful/g
s/accesor/accessor/g
s/ACCESOR/ACCESSOR/g
s/Accesor/Accessor/g
s/accidently/accidentally/g
s/ACCIDENTLY/ACCIDENTALLY/g
s/Accidently/Accidentally/g
s/accomodate/accommodate/g
s/ACCOMODATE/ACCOMMODATE/g
s/Accomodate/Accommodate/g
s/accross/across/g
s/ACCROSS/ACROSS/g
s/Accross/Across/g
s/aleady/already/g
s/ALEADY/ALREADY/g
s/Aleady/Already/g
s/alllocation/allocation/g
s/ALLLOCATION/ALLOCATION/g
s/Alllocation/Allocation/g
s/allways/always/g
s/ALLWAYS/ALWAYS/g
s/Allways/Always/g
s/amout/amount/g
s/AMOUT/AMOUNT/g
s/Amout/Amount/g
s/aquired/acquired/g
s/AQUIRED/ACQUIRED/g
s/Aquired/Acquired/g
s/aquires/acquires/g
s/AQUIRES/ACQUIRES/g
s/Aquires/Acquires/g
s/aquire/acquire/g
s/AQUIRE/ACQUIRE/g
s/Aquire/Acquire/g
s/assigment/assignment/g
s/ASSIGMENT/ASSIGNMENT/g
s/Assigment/Assignment/g
s/atleast/at least/g
s/ATLEAST/AT LEAST/g
s/Atleast/At least/g
s/atrribute/attribute/g
s/ATRRIBUTE/ATTRIBUTE/g
s/Atrribute/Attribute/g
s/becuase/because/g
s/BECUASE/BECAUSE/g
s/Becuase/Because/g
s/beggining/beginning/g
s/BEGGINING/BEGINNING/g
s/Beggining/Beginning/g
s/begining/beginning/g
s/BEGINING/BEGINNING/g
s/Begining/Beginning/g
s/boundries/boundaries/g
s/BOUNDRIES/BOUNDARIES/g
s/Boundries/Boundaries/g
s/cachable/cacheable/g
s/CACHABLE/CACHEABLE/g
s/Cachable/Cacheable/g
s/choosen/chosen/g
s/CHOOSEN/CHOSEN/g
s/Choosen/Chosen/g
s/chosing/choosing/g
s/CHOSING/CHOOSING/g
s/Chosing/Choosing/g
s/commited/committed/g
s/COMMITED/COMMITTED/g
s/Commited/Committed/g
s/comparisions/comparisons/g
s/COMPARISIONS/COMPARISONS/g
s/Comparisions/Comparisons/g
s/comparision/comparison/g
s/COMPARISION/COMPARISON/g
s/Comparision/Comparison/g
s/compatability/compatibility/g
s/COMPATABILITY/COMPATIBILITY/g
s/Compatability/Compatibility/g
s/compatibilty/compatibility/g
s/COMPATIBILTY/COMPATIBILITY/g
s/Compatibilty/Compatibility/g
s/compatiblity/compatibility/g
s/COMPATIBLITY/COMPATIBILITY/g
s/Compatiblity/Compatibility/g
s/conjuction/conjunction/g
s/CONJUCTION/CONJUNCTION/g
s/Conjuction/Conjunction/g
s/consistant/consistent/g
s/CONSISTANT/CONSISTENT/g
s/Consistant/Consistent/g
s/contraints/constraints/g
s/CONTRAINTS/CONSTRAINTS/g
s/Contraints/Constraints/g
s/contructor/constructor/g
s/CONTRUCTOR/CONSTRUCTOR/g
s/Contructor/Constructor/g
s/contruct/construct/g
s/CONTRUCT/CONSTRUCT/g
s/Contruct/Construct/g
s/curent/current/g
s/CURENT/CURRENT/g
s/Curent/Current/g
s/defaut/default/g
s/DEFAUT/DEFAULT/g
s/Defaut/Default/g
s/defered/deferred/g
s/DEFERED/DEFERRED/g
s/Defered/Deferred/g
s/defintion/definition/g
s/DEFINTION/DEFINITION/g
s/Defintion/Definition/g
s/delimeter/delimiter/g
s/DELIMETER/DELIMITER/g
s/Delimeter/Delimiter/g
s/dependend/dependent/g
s/DEPENDEND/DEPENDENT/g
s/Dependend/Dependent/g
s/embeded/embedded/g
s/EMBEDED/EMBEDDED/g
s/Embeded/Embedded/g
s/entires/entries/g
s/ENTIRES/ENTRIES/g
s/Entires/Entries/g
s/excercise/exercise/g
s/EXCERCISE/EXERCISE/g
s/Excercise/Exercise/g
s/existance/existence/g
s/EXISTANCE/EXISTENCE/g
s/Existance/Existence/g
s/existant/existent/g
s/EXISTANT/EXISTENT/g
s/Existant/Existent/g
s/explicitely/explicitly/g
s/EXPLICITELY/EXPLICITLY/g
s/Explicitely/Explicitly/g
s/explicity/explicitly/g
s/EXPLICITY/EXPLICITLY/g
s/Explicity/Explicitly/g
s/explictly/explicitly/g
s/EXPLICTLY/EXPLICITLY/g
s/Explictly/Explicitly/g
s/explict/explicit/g
s/EXPLICT/EXPLICIT/g
s/Explict/Explicit/g
s/expresion/expression/g
s/EXPRESION/EXPRESSION/g
s/Expresion/Expression/g
s/expresssion/expressions/g
s/EXPRESSSION/EXPRESSIONS/g
s/Expresssion/Expressions/g
s/extention/extension/g
s/EXTENTION/EXTENSION/g
s/Extention/Extension/g
s/fullfil/fulfil/g
s/FULLFIL/FULFIL/g
s/Fullfil/Fulfil/g
s/funtion/function/g
s/FUNTION/FUNCTION/g
s/Funtion/Function/g
s/greater then/greater than/g
s/GREATER THEN/GREATER THAN/g
s/Greater then/Greater than/g
s/independant/independent/g
s/INDEPENDANT/INDEPENDENT/g
s/Independant/Independent/g
s/instace/instance/g
s/INSTACE/INSTANCE/g
s/Instace/Instance/g
s/intial/initial/g
s/INTIAL/INITIAL/g
s/Intial/Initial/g
s/lenght/length/g
s/LENGHT/LENGTH/g
s/Lenght/Length/g
s/lower then/lower than/g
s/LOWER THEN/LOWER THAN/g
s/Lower then/Lower than/g
s/muliple/multiple/g
s/MULIPLE/MULTIPLE/g
s/Muliple/Multiple/g
s/neccessar/necessar/g
s/NECCESSAR/NECESSAR/g
s/Neccessar/Necessar/g
s/occurance/occurrence/g
s/OCCURANCE/OCCURRENCE/g
s/Occurance/Occurrence/g
s/occured/occurred/g
s/OCCURED/OCCURRED/g
s/Occured/Occurred/g
s/occurence/occurrence/g
s/OCCURENCE/OCCURRENCE/g
s/Occurence/Occurrence/g
s/orginal/original/g
s/ORGINAL/ORIGINAL/g
s/Orginal/Original/g
s/orignal/original/g
s/ORIGNAL/ORIGINAL/g
s/Orignal/Original/g
s/ouput/output/g
s/OUPUT/OUTPUT/g
s/Ouput/Output/g
s/overridding/overriding/g
s/OVERRIDDING/OVERRIDING/g
s/Overridding/Overriding/g
s/paramater/parameter/g
s/PARAMATER/PARAMETER/g
s/Paramater/Parameter/g
s/paramter/parameter/g
s/PARAMTER/PARAMETER/g
s/Paramter/Parameter/g
s/preceed/preced/g
s/PRECEED/PRECED/g
s/Preceed/Preced/g
s/presense/presence/g
s/PRESENSE/PRESENCE/g
s/Presense/Presence/g
s/recieve/receive/g
s/RECIEVE/RECEIVE/g
s/Recieve/Receive/g
s/refrence/reference/g
s/REFRENCE/REFERENCE/g
s/Refrence/Reference/g
s/retreiving/retrieving/g
s/RETREIVING/RETRIEVING/g
s/Retreiving/Retrieving/g
s/seperat/separat/g
s/SEPERAT/SEPARAT/g
s/Seperat/Separat/g
s/succesful/successful/g
s/SUCCESFUL/SUCCESSFUL/g
s/Succesful/Successful/g
s/successfull\b/successful/g
s/SUCCESSFULL\b/SUCCESSFUL/g
s/Successfull\b/Successful/g
s/sucess/success/g
s/SUCESS/SUCCESS/g
s/Sucess/Success/g
s/supercede/supersede/g
s/SUPERCEDE/SUPERSEDE/g
s/Supercede/Supersede/g
s/supress/suppress/g
s/SUPRESS/SUPPRESS/g
s/Supress/Suppress/g
s/threshhold/threshold/g
s/THRESHHOLD/THRESHOLD/g
s/Threshhold/Threshold/g
s/transfered/transferred/g
s/TRANSFERED/TRANSFERRED/g
s/Transfered/Transferred/g
s/unkown/unknown/g
s/UNKOWN/UNKNOWN/g
s/Unkown/Unknown/g
s/usefull\b/useful/g
s/USEFULL\b/USEFUL/g
s/Usefull\b/Useful/g
s/wether/whether/g
s/WETHER/WHETHER/g
s/Wether/Whether/g
s/wierd/weird/g
s/WIERD/WEIRD/g
s/Wierd/Weird/g
