#!/bin/sed
s/amortised/amortized/g
s/AMORTISED/AMORTIZED/g
s/Amortised/Amortized/g
s/analysed/analyzed/g
s/ANALYSED/ANALYZED/g
s/Analysed/Analyzed/g
s/analysers/analyzers/g
s/ANALYSERS/ANALYZERS/g
s/Analysers/Analyzers/g
s/analyser/analyzer/g
s/ANALYSER/ANALYZER/g
s/Analyser/Analyzer/g
s/characterised/characterized/g
s/CHARACTERISED/CHARACTERIZED/g
s/Characterised/Characterized/g
s/colouring/coloring/g
s/COLOURING/COLORING/g
s/Colouring/Coloring/g
s/counsellor/counselor/g
s/COUNSELLOR/COUNSELOR/g
s/Counsellor/Counselor/g
s/criticised/criticized/g
s/CRITICISED/CRITICIZED/g
s/Criticised/Criticized/g
s/emphasised/emphasized/g
s/EMPHASISED/EMPHASIZED/g
s/Emphasised/Emphasized/g
s/minimise/minimize/g
s/MINIMISE/MINIMIZE/g
s/Minimise/Minimize/g
s/organisation/organization/g
s/ORGANISATION/ORGANIZATION/g
s/Organisation/Organization/g
s/specialised/specialized/g
s/SPECIALISED/SPECIALIZED/g
s/Specialised/Specialized/g
s/utilised/utilized/g
s/UTILISED/UTILIZED/g
s/Utilised/Utilized/g
