#!/bin/sed
s/\bamercia\b/america/g
s/\bAMERCIA\b/AMERICA/g
s/\bAmercia\b/America/g
s/\bbernouilli\b/bernoulli/g
s/\bBERNOUILLI\b/BERNOULLI/g
s/\bBernouilli\b/Bernoulli/g
s/\bblitzkreig\b/blitzkrieg/g
s/\bBLITZKREIG\b/BLITZKRIEG/g
s/\bBlitzkreig\b/Blitzkrieg/g
s/\bbonnano\b/bonanno/g
s/\bBONNANO\b/BONANNO/g
s/\bBonnano\b/Bonanno/g
s/\bbrasillian\b/brazilian/g
s/\bBRASILLIAN\b/BRAZILIAN/g
s/\bBrasillian\b/Brazilian/g
s/\bbritian\b/britain/g
s/\bBRITIAN\b/BRITAIN/g
s/\bBritian\b/Britain/g
s/\bbrittish\b/british/g
s/\bBRITTISH\b/BRITISH/g
s/\bBrittish\b/British/g
s/\bbuddah\b/buddha/g
s/\bBUDDAH\b/BUDDHA/g
s/\bBuddah\b/Buddha/g
s/\bbuddist\b/buddhist/g
s/\bBUDDIST\b/BUDDHIST/g
s/\bBuddist\b/Buddhist/g
s/\bcambrige\b/cambridge/g
s/\bCAMBRIGE\b/CAMBRIDGE/g
s/\bCambrige\b/Cambridge/g
s/\bcapetown\b/cape town/g
s/\bCAPETOWN\b/CAPE TOWN/g
s/\bCapetown\b/Cape Town/g
s/\bcarmalite\b/carmelite/g
s/\bCARMALITE\b/CARMELITE/g
s/\bCarmalite\b/Carmelite/g
s/\bcarnagie-mellon\b/carnegie-mellon/g
s/\bCARNAGIE-MELLON\b/CARNEGIE-MELLON/g
s/\bCarnagie-Mellon\b/Carnegie-Mellon/g
s/\bcarnagie\b/carnegie/g
s/\bCARNAGIE\b/CARNEGIE/g
s/\bCarnagie\b/Carnegie/g
s/\bcarnigie-mellon\b/carnegie-mellon/g
s/\bCARNIGIE-MELLON\b/CARNEGIE-MELLON/g
s/\bCarnigie-Mellon\b/Carnegie-Mellon/g
s/\bcarnigie\b/carnegie/g
s/\bCARNIGIE\b/CARNEGIE/g
s/\bCarnigie\b/Carnegie/g
s/\bcarribbean\b/caribbean/g
s/\bCARRIBBEAN\b/CARIBBEAN/g
s/\bCarribbean\b/Caribbean/g
s/\bcarribean\b/caribbean/g
s/\bCARRIBEAN\b/CARIBBEAN/g
s/\bCarribean\b/Caribbean/g
s/\bcarthagian\b/carthaginian/g
s/\bCARTHAGIAN\b/CARTHAGINIAN/g
s/\bCarthagian\b/Carthaginian/g
s/\bcelcius\b/celsius/g
s/\bCELCIUS\b/CELSIUS/g
s/\bCelcius\b/Celsius/g
s/\bchampange\b/champagne/g
s/\bCHAMPANGE\b/CHAMPAGNE/g
s/\bChampange\b/Champagne/g
s/\bcincinatti\b/cincinnati/g
s/\bCINCINATTI\b/CINCINNATI/g
s/\bCincinatti\b/Cincinnati/g
s/\bcincinnatti\b/cincinnati/g
s/\bCINCINNATTI\b/CINCINNATI/g
s/\bCincinnatti\b/Cincinnati/g
s/\bcoca cola\b/coca-cola/g
s/\bCOCA COLA\b/COCA-COLA/g
s/\bCoca Cola\b/Coca-Cola/g
s/\bconneticut\b/connecticut/g
s/\bCONNETICUT\b/CONNECTICUT/g
s/\bConneticut\b/Connecticut/g
s/\bdardenelles\b/dardanelles/g
s/\bDARDENELLES\b/DARDANELLES/g
s/\bDardenelles\b/Dardanelles/g
s/\bdravadian\b/dravidian/g
s/\bDRAVADIAN\b/DRAVIDIAN/g
s/\bDravadian\b/Dravidian/g
s/\beuropian\b/european/g
s/\bEUROPIAN\b/EUROPEAN/g
s/\bEuropian\b/European/g
s/\beuropians\b/europeans/g
s/\bEUROPIANS\b/EUROPEANS/g
s/\bEuropians\b/Europeans/g
s/\beurpean\b/european/g
s/\bEURPEAN\b/EUROPEAN/g
s/\bEurpean\b/European/g
s/\beurpoean\b/european/g
s/\bEURPOEAN\b/EUROPEAN/g
s/\bEurpoean\b/European/g
s/\bfarenheit\b/fahrenheit/g
s/\bFARENHEIT\b/FAHRENHEIT/g
s/\bFarenheit\b/Fahrenheit/g
s/\bfebuary\b/february/g
s/\bFEBUARY\b/FEBRUARY/g
s/\bFebuary\b/February/g
s/\bflemmish\b/flemish/g
s/\bFLEMMISH\b/FLEMISH/g
s/\bFlemmish\b/Flemish/g
s/\bformalhaut\b/fomalhaut/g
s/\bFORMALHAUT\b/FOMALHAUT/g
s/\bFormalhaut\b/Fomalhaut/g
s/\bfoundland\b/newfoundland/g
s/\bFOUNDLAND\b/NEWFOUNDLAND/g
s/\bFoundland\b/Newfoundland/g
s/\bfransiscan\b/franciscan/g
s/\bFRANSISCAN\b/FRANCISCAN/g
s/\bFransiscan\b/Franciscan/g
s/\bfransiscans\b/franciscans/g
s/\bFRANSISCANS\b/FRANCISCANS/g
s/\bFransiscans\b/Franciscans/g
s/\bgalations\b/galatians/g
s/\bGALATIONS\b/GALATIANS/g
s/\bGalations\b/Galatians/g
s/\bghandi\b/gandhi/g
s/\bGHANDI\b/GANDHI/g
s/\bGhandi\b/Gandhi/g
s/\bgodounov\b/godunov/g
s/\bGODOUNOV\b/GODUNOV/g
s/\bGodounov\b/Godunov/g
s/\bgothenberg\b/gothenburg/g
s/\bGOTHENBERG\b/GOTHENBURG/g
s/\bGothenberg\b/Gothenburg/g
s/\bgottleib\b/gottlieb/g
s/\bGOTTLEIB\b/GOTTLIEB/g
s/\bGottleib\b/Gottlieb/g
s/\bguatamala\b/guatemala/g
s/\bGUATAMALA\b/GUATEMALA/g
s/\bGuatamala\b/Guatemala/g
s/\bguatamalan\b/guatemalan/g
s/\bGUATAMALAN\b/GUATEMALAN/g
s/\bGuatamalan\b/Guatemalan/g
s/\bguilia\b/giulia/g
s/\bGUILIA\b/GIULIA/g
s/\bGuilia\b/Giulia/g
s/\bguilio\b/giulio/g
s/\bGUILIO\b/GIULIO/g
s/\bGuilio\b/Giulio/g
s/\bguiness\b/guinness/g
s/\bGUINESS\b/GUINNESS/g
s/\bGuiness\b/Guinness/g
s/\bguiseppe\b/giuseppe/g
s/\bGUISEPPE\b/GIUSEPPE/g
s/\bGuiseppe\b/Giuseppe/g
s/\bhabsbourg\b/habsburg/g
s/\bHABSBOURG\b/HABSBURG/g
s/\bHabsbourg\b/Habsburg/g
s/\bhatian\b/haitian/g
s/\bHATIAN\b/HAITIAN/g
s/\bHatian\b/Haitian/g
s/\bheidelburg\b/heidelberg/g
s/\bHEIDELBURG\b/HEIDELBERG/g
s/\bHeidelburg\b/Heidelberg/g
s/\bihaca\b/ithaca/g
s/\bIHACA\b/ITHACA/g
s/\bIhaca\b/Ithaca/g
s/\bisraelies\b/israelis/g
s/\bISRAELIES\b/ISRAELIS/g
s/\bIsraelies\b/Israelis/g
s/\bjanurary\b/january/g
s/\bJANURARY\b/JANUARY/g
s/\bJanurary\b/January/g
s/\bjanuray\b/january/g
s/\bJANURAY\b/JANUARY/g
s/\bJanuray\b/January/g
s/\bjapanes\b/japanese/g
s/\bJAPANES\b/JAPANESE/g
s/\bJapanes\b/Japanese/g
s/\bjohanine\b/johannine/g
s/\bJOHANINE\b/JOHANNINE/g
s/\bJohanine\b/Johannine/g
s/\bjospeh\b/joseph/g
s/\bJOSPEH\b/JOSEPH/g
s/\bJospeh\b/Joseph/g
s/\bjuadaism\b/judaism/g
s/\bJUADAISM\b/JUDAISM/g
s/\bJuadaism\b/Judaism/g
s/\bjuadism\b/judaism/g
s/\bJUADISM\b/JUDAISM/g
s/\bJuadism\b/Judaism/g
s/\blybia\b/libya/g
s/\bLYBIA\b/LIBYA/g
s/\bLybia\b/Libya/g
s/\bmalcom\b/malcolm/g
s/\bMALCOM\b/MALCOLM/g
s/\bMalcom\b/Malcolm/g
s/\bmassachussets\b/massachusetts/g
s/\bMASSACHUSSETS\b/MASSACHUSETTS/g
s/\bMassachussets\b/Massachusetts/g
s/\bmassachussetts\b/massachusetts/g
s/\bMASSACHUSSETTS\b/MASSACHUSETTS/g
s/\bMassachussetts\b/Massachusetts/g
s/\bmediteranean\b/mediterranean/g
s/\bMEDITERANEAN\b/MEDITERRANEAN/g
s/\bMediteranean\b/Mediterranean/g
s/\bmichagan\b/michigan/g
s/\bMICHAGAN\b/MICHIGAN/g
s/\bMichagan\b/Michigan/g
s/\bmisouri\b/missouri/g
s/\bMISOURI\b/MISSOURI/g
s/\bMisouri\b/Missouri/g
s/\bmissisipi\b/mississippi/g
s/\bMISSISIPI\b/MISSISSIPPI/g
s/\bMissisipi\b/Mississippi/g
s/\bmissisippi\b/mississippi/g
s/\bMISSISIPPI\b/MISSISSIPPI/g
s/\bMissisippi\b/Mississippi/g
s/\bmonserrat\b/montserrat/g
s/\bMONSERRAT\b/MONTSERRAT/g
s/\bMonserrat\b/Montserrat/g
s/\bmontnana\b/montana/g
s/\bMONTNANA\b/MONTANA/g
s/\bMontnana\b/Montana/g
s/\bmorisette\b/morissette/g
s/\bMORISETTE\b/MORISSETTE/g
s/\bMorisette\b/Morissette/g
s/\bmorrisette\b/morissette/g
s/\bMORRISETTE\b/MORISSETTE/g
s/\bMorrisette\b/Morissette/g
s/\bmythraic\b/mithraic/g
s/\bMYTHRAIC\b/MITHRAIC/g
s/\bMythraic\b/Mithraic/g
s/\bnaploeon\b/napoleon/g
s/\bNAPLOEON\b/NAPOLEON/g
s/\bNaploeon\b/Napoleon/g
s/\bnapolean\b/napoleon/g
s/\bNAPOLEAN\b/NAPOLEON/g
s/\bNapolean\b/Napoleon/g
s/\bnapoleonian\b/napoleonic/g
s/\bNAPOLEONIAN\b/NAPOLEONIC/g
s/\bNapoleonian\b/Napoleonic/g
s/\bnazereth\b/nazareth/g
s/\bNAZERETH\b/NAZARETH/g
s/\bNazereth\b/Nazareth/g
s/\bnovermber\b/november/g
s/\bNOVERMBER\b/NOVEMBER/g
s/\bNovermber\b/November/g
s/\bnullabour\b/nullarbor/g
s/\bNULLABOUR\b/NULLARBOR/g
s/\bNullabour\b/Nullarbor/g
s/\bnuremburg\b/nuremberg/g
s/\bNUREMBURG\b/NUREMBERG/g
s/\bNuremburg\b/Nuremberg/g
s/\bpalistian\b/palestinian/g
s/\bPALISTIAN\b/PALESTINIAN/g
s/\bPalistian\b/Palestinian/g
s/\bpalistinian\b/palestinian/g
s/\bPALISTINIAN\b/PALESTINIAN/g
s/\bPalistinian\b/Palestinian/g
s/\bpalistinians\b/palestinians/g
s/\bPALISTINIANS\b/PALESTINIANS/g
s/\bPalistinians\b/Palestinians/g
s/\bpapanicalou\b/papanicolaou/g
s/\bPAPANICALOU\b/PAPANICOLAOU/g
s/\bPapanicalou\b/Papanicolaou/g
s/\bpeloponnes\b/peloponnesus/g
s/\bPELOPONNES\b/PELOPONNESUS/g
s/\bPeloponnes\b/Peloponnesus/g
s/\bpennyslvania\b/pennsylvania/g
s/\bPENNYSLVANIA\b/PENNSYLVANIA/g
s/\bPennyslvania\b/Pennsylvania/g
s/\bpharoah\b/pharaoh/g
s/\bPHAROAH\b/PHARAOH/g
s/\bPharoah\b/Pharaoh/g
s/\bphilipines\b/philippines/g
s/\bPHILIPINES\b/PHILIPPINES/g
s/\bPhilipines\b/Philippines/g
s/\bphillipine\b/philippine/g
s/\bPHILLIPINE\b/PHILIPPINE/g
s/\bPhillipine\b/Philippine/g
s/\bphillipines\b/philippines/g
s/\bPHILLIPINES\b/PHILIPPINES/g
s/\bPhillipines\b/Philippines/g
s/\bphillippines\b/philippines/g
s/\bPHILLIPPINES\b/PHILIPPINES/g
s/\bPhillippines\b/Philippines/g
s/\bphonecian\b/phoenecian/g
s/\bPHONECIAN\b/PHOENECIAN/g
s/\bPhonecian\b/Phoenecian/g
s/\bportugese\b/portuguese/g
s/\bPORTUGESE\b/PORTUGUESE/g
s/\bPortugese\b/Portuguese/g
s/\bpostdam\b/potsdam/g
s/\bPOSTDAM\b/POTSDAM/g
s/\bPostdam\b/Potsdam/g
s/\bpremonasterians\b/premonstratensians/g
s/\bPREMONASTERIANS\b/PREMONSTRATENSIANS/g
s/\bPremonasterians\b/Premonstratensians/g
s/\bpucini\b/puccini/g
s/\bPUCINI\b/PUCCINI/g
s/\bPucini\b/Puccini/g
s/\bpuertorrican\b/puerto rican/g
s/\bPUERTORRICAN\b/PUERTO RICAN/g
s/\bPuertorrican\b/Puerto Rican/g
s/\bpuertorricans\b/puerto ricans/g
s/\bPUERTORRICANS\b/PUERTO RICANS/g
s/\bPuertorricans\b/Puerto Ricans/g
s/\bqueenland\b/queensland/g
s/\bQUEENLAND\b/QUEENSLAND/g
s/\bQueenland\b/Queensland/g
s/\brockerfeller\b/rockefeller/g
s/\bROCKERFELLER\b/ROCKEFELLER/g
s/\bRockerfeller\b/Rockefeller/g
s/\brussion\b/russian/g
s/\bRUSSION\b/RUSSIAN/g
s/\bRussion\b/Russian/g
s/\bsacremento\b/sacramento/g
s/\bSACREMENTO\b/SACRAMENTO/g
s/\bSacremento\b/Sacramento/g
s/\bsanhedrim\b/sanhedrin/g
s/\bSANHEDRIM\b/SANHEDRIN/g
s/\bSanhedrim\b/Sanhedrin/g
s/\bsaterday\b/saturday/g
s/\bSATERDAY\b/SATURDAY/g
s/\bSaterday\b/Saturday/g
s/\bsaterdays\b/saturdays/g
s/\bSATERDAYS\b/SATURDAYS/g
s/\bSaterdays\b/Saturdays/g
s/\bsionist\b/zionist/g
s/\bSIONIST\b/ZIONIST/g
s/\bSionist\b/Zionist/g
s/\bsionists\b/zionists/g
s/\bSIONISTS\b/ZIONISTS/g
s/\bSionists\b/Zionists/g
s/\bsixtin\b/sistine/g
s/\bSIXTIN\b/SISTINE/g
s/\bSixtin\b/Sistine/g
s/\bskagerak\b/skagerrak/g
s/\bSKAGERAK\b/SKAGERRAK/g
s/\bSkagerak\b/Skagerrak/g
s/\btolkein\b/tolkien/g
s/\bTOLKEIN\b/TOLKIEN/g
s/\bTolkein\b/Tolkien/g
s/\btuscon\b/tucson/g
s/\bTUSCON\b/TUCSON/g
s/\bTuscon\b/Tucson/g
s/\bukranian\b/ukrainian/g
s/\bUKRANIAN\b/UKRAINIAN/g
s/\bUkranian\b/Ukrainian/g
s/\bunitesstates\b/unitedstates/g
s/\bUNITESSTATES\b/UNITEDSTATES/g
s/\bUnitesStates\b/UnitedStates/g
s/\babandonned\b/abandoned/g
s/\bABANDONNED\b/ABANDONED/g
s/\bAbandonned\b/Abandoned/g
s/\babbout\b/about/g
s/\bABBOUT\b/ABOUT/g
s/\bAbbout\b/About/g
s/\baberation\b/aberration/g
s/\bABERATION\b/ABERRATION/g
s/\bAberation\b/Aberration/g
s/\babilties\b/abilities/g
s/\bABILTIES\b/ABILITIES/g
s/\bAbilties\b/Abilities/g
s/\babilty\b/ability/g
s/\bABILTY\b/ABILITY/g
s/\bAbilty\b/Ability/g
s/\babondon\b/abandon/g
s/\bABONDON\b/ABANDON/g
s/\bAbondon\b/Abandon/g
s/\babondoned\b/abandoned/g
s/\bABONDONED\b/ABANDONED/g
s/\bAbondoned\b/Abandoned/g
s/\babondoning\b/abandoning/g
s/\bABONDONING\b/ABANDONING/g
s/\bAbondoning\b/Abandoning/g
s/\babondons\b/abandons/g
s/\bABONDONS\b/ABANDONS/g
s/\bAbondons\b/Abandons/g
s/\baborigene\b/aborigine/g
s/\bABORIGENE\b/ABORIGINE/g
s/\bAborigene\b/Aborigine/g
s/\babortificant\b/abortifacient/g
s/\bABORTIFICANT\b/ABORTIFACIENT/g
s/\bAbortificant\b/Abortifacient/g
s/\babotu\b/about/g
s/\bABOTU\b/ABOUT/g
s/\bAbotu\b/About/g
s/\babouta\b/about a/g
s/\bABOUTA\b/ABOUT A/g
s/\bAbouta\b/About a/g
s/\baboutit\b/about it/g
s/\bABOUTIT\b/ABOUT IT/g
s/\bAboutit\b/About it/g
s/\baboutthe\b/about the/g
s/\bABOUTTHE\b/ABOUT THE/g
s/\bAboutthe\b/About the/g
s/\babreviate\b/abbreviate/g
s/\bABREVIATE\b/ABBREVIATE/g
s/\bAbreviate\b/Abbreviate/g
s/\babreviated\b/abbreviated/g
s/\bABREVIATED\b/ABBREVIATED/g
s/\bAbreviated\b/Abbreviated/g
s/\babreviation\b/abbreviation/g
s/\bABREVIATION\b/ABBREVIATION/g
s/\bAbreviation\b/Abbreviation/g
s/\babritrary\b/arbitrary/g
s/\bABRITRARY\b/ARBITRARY/g
s/\bAbritrary\b/Arbitrary/g
s/\babsail\b/abseil/g
s/\bABSAIL\b/ABSEIL/g
s/\bAbsail\b/Abseil/g
s/\babsailing\b/abseiling/g
s/\bABSAILING\b/ABSEILING/g
s/\bAbsailing\b/Abseiling/g
s/\babscence\b/absence/g
s/\bABSCENCE\b/ABSENCE/g
s/\bAbscence\b/Absence/g
s/\babsolutly\b/absolutely/g
s/\bABSOLUTLY\b/ABSOLUTELY/g
s/\bAbsolutly\b/Absolutely/g
s/\babsorbsion\b/absorption/g
s/\bABSORBSION\b/ABSORPTION/g
s/\bAbsorbsion\b/Absorption/g
s/\babsorbtion\b/absorption/g
s/\bABSORBTION\b/ABSORPTION/g
s/\bAbsorbtion\b/Absorption/g
s/\babudance\b/abundance/g
s/\bABUDANCE\b/ABUNDANCE/g
s/\bAbudance\b/Abundance/g
s/\babundacies\b/abundances/g
s/\bABUNDACIES\b/ABUNDANCES/g
s/\bAbundacies\b/Abundances/g
s/\babundancies\b/abundances/g
s/\bABUNDANCIES\b/ABUNDANCES/g
s/\bAbundancies\b/Abundances/g
s/\babundunt\b/abundant/g
s/\bABUNDUNT\b/ABUNDANT/g
s/\bAbundunt\b/Abundant/g
s/\babutts\b/abuts/g
s/\bABUTTS\b/ABUTS/g
s/\bAbutts\b/Abuts/g
s/\bacadamy\b/academy/g
s/\bACADAMY\b/ACADEMY/g
s/\bAcadamy\b/Academy/g
s/\bacadmic\b/academic/g
s/\bACADMIC\b/ACADEMIC/g
s/\bAcadmic\b/Academic/g
s/\baccademic\b/academic/g
s/\bACCADEMIC\b/ACADEMIC/g
s/\bAccademic\b/Academic/g
s/\baccademy\b/academy/g
s/\bACCADEMY\b/ACADEMY/g
s/\bAccademy\b/Academy/g
s/\bacccused\b/accused/g
s/\bACCCUSED\b/ACCUSED/g
s/\bAcccused\b/Accused/g
s/\baccelleration\b/acceleration/g
s/\bACCELLERATION\b/ACCELERATION/g
s/\bAccelleration\b/Acceleration/g
s/\bacceptence\b/acceptance/g
s/\bACCEPTENCE\b/ACCEPTANCE/g
s/\bAcceptence\b/Acceptance/g
s/\baccidant\b/accident/g
s/\bACCIDANT\b/ACCIDENT/g
s/\bAccidant\b/Accident/g
s/\bacclimitization\b/acclimatization/g
s/\bACCLIMITIZATION\b/ACCLIMATIZATION/g
s/\bAcclimitization\b/Acclimatization/g
s/\baccomadating\b/accommodating/g
s/\bACCOMADATING\b/ACCOMMODATING/g
s/\bAccomadating\b/Accommodating/g
s/\baccomadation\b/accommodation/g
s/\bACCOMADATION\b/ACCOMMODATION/g
s/\bAccomadation\b/Accommodation/g
s/\baccomadations\b/accommodations/g
s/\bACCOMADATIONS\b/ACCOMMODATIONS/g
s/\bAccomadations\b/Accommodations/g
s/\baccomdate\b/accommodate/g
s/\bACCOMDATE\b/ACCOMMODATE/g
s/\bAccomdate\b/Accommodate/g
s/\baccomodation\b/accommodation/g
s/\bACCOMODATION\b/ACCOMMODATION/g
s/\bAccomodation\b/Accommodation/g
s/\baccomodations\b/accommodations/g
s/\bACCOMODATIONS\b/ACCOMMODATIONS/g
s/\bAccomodations\b/Accommodations/g
s/\baccompanyed\b/accompanied/g
s/\bACCOMPANYED\b/ACCOMPANIED/g
s/\bAccompanyed\b/Accompanied/g
s/\baccordeon\b/accordion/g
s/\bACCORDEON\b/ACCORDION/g
s/\bAccordeon\b/Accordion/g
s/\baccordian\b/accordion/g
s/\bACCORDIAN\b/ACCORDION/g
s/\bAccordian\b/Accordion/g
s/\baccoring\b/according/g
s/\bACCORING\b/ACCORDING/g
s/\bAccoring\b/According/g
s/\baccoustic\b/acoustic/g
s/\bACCOUSTIC\b/ACOUSTIC/g
s/\bAccoustic\b/Acoustic/g
s/\baccquainted\b/acquainted/g
s/\bACCQUAINTED\b/ACQUAINTED/g
s/\bAccquainted\b/Acquainted/g
s/\baccrediation\b/accreditation/g
s/\bACCREDIATION\b/ACCREDITATION/g
s/\bAccrediation\b/Accreditation/g
s/\baccredidation\b/accreditation/g
s/\bACCREDIDATION\b/ACCREDITATION/g
s/\bAccredidation\b/Accreditation/g
s/\baccussed\b/accused/g
s/\bACCUSSED\b/ACCUSED/g
s/\bAccussed\b/Accused/g
s/\bacedemic\b/academic/g
s/\bACEDEMIC\b/ACADEMIC/g
s/\bAcedemic\b/Academic/g
s/\bacheive\b/achieve/g
s/\bACHEIVE\b/ACHIEVE/g
s/\bAcheive\b/Achieve/g
s/\bacheived\b/achieved/g
s/\bACHEIVED\b/ACHIEVED/g
s/\bAcheived\b/Achieved/g
s/\bacheivement\b/achievement/g
s/\bACHEIVEMENT\b/ACHIEVEMENT/g
s/\bAcheivement\b/Achievement/g
s/\bacheivements\b/achievements/g
s/\bACHEIVEMENTS\b/ACHIEVEMENTS/g
s/\bAcheivements\b/Achievements/g
s/\bacheives\b/achieves/g
s/\bACHEIVES\b/ACHIEVES/g
s/\bAcheives\b/Achieves/g
s/\bacheiving\b/achieving/g
s/\bACHEIVING\b/ACHIEVING/g
s/\bAcheiving\b/Achieving/g
s/\bacheivment\b/achievement/g
s/\bACHEIVMENT\b/ACHIEVEMENT/g
s/\bAcheivment\b/Achievement/g
s/\bacheivments\b/achievements/g
s/\bACHEIVMENTS\b/ACHIEVEMENTS/g
s/\bAcheivments\b/Achievements/g
s/\bachievment\b/achievement/g
s/\bACHIEVMENT\b/ACHIEVEMENT/g
s/\bAchievment\b/Achievement/g
s/\bachievments\b/achievements/g
s/\bACHIEVMENTS\b/ACHIEVEMENTS/g
s/\bAchievments\b/Achievements/g
s/\bacident\b/accident/g
s/\bACIDENT\b/ACCIDENT/g
s/\bAcident\b/Accident/g
s/\backnowldeged\b/acknowledged/g
s/\bACKNOWLDEGED\b/ACKNOWLEDGED/g
s/\bAcknowldeged\b/Acknowledged/g
s/\backnowledgeing\b/acknowledging/g
s/\bACKNOWLEDGEING\b/ACKNOWLEDGING/g
s/\bAcknowledgeing\b/Acknowledging/g
s/\bacommodate\b/accommodate/g
s/\bACOMMODATE\b/ACCOMMODATE/g
s/\bAcommodate\b/Accommodate/g
s/\bacomplish\b/accomplish/g
s/\bACOMPLISH\b/ACCOMPLISH/g
s/\bAcomplish\b/Accomplish/g
s/\bacomplished\b/accomplished/g
s/\bACOMPLISHED\b/ACCOMPLISHED/g
s/\bAcomplished\b/Accomplished/g
s/\bacomplishment\b/accomplishment/g
s/\bACOMPLISHMENT\b/ACCOMPLISHMENT/g
s/\bAcomplishment\b/Accomplishment/g
s/\bacomplishments\b/accomplishments/g
s/\bACOMPLISHMENTS\b/ACCOMPLISHMENTS/g
s/\bAcomplishments\b/Accomplishments/g
s/\bacording\b/according/g
s/\bACORDING\b/ACCORDING/g
s/\bAcording\b/According/g
s/\bacordingly\b/accordingly/g
s/\bACORDINGLY\b/ACCORDINGLY/g
s/\bAcordingly\b/Accordingly/g
s/\bacquaintence\b/acquaintance/g
s/\bACQUAINTENCE\b/ACQUAINTANCE/g
s/\bAcquaintence\b/Acquaintance/g
s/\bacquaintences\b/acquaintances/g
s/\bACQUAINTENCES\b/ACQUAINTANCES/g
s/\bAcquaintences\b/Acquaintances/g
s/\bacquiantence\b/acquaintance/g
s/\bACQUIANTENCE\b/ACQUAINTANCE/g
s/\bAcquiantence\b/Acquaintance/g
s/\bacquiantences\b/acquaintances/g
s/\bACQUIANTENCES\b/ACQUAINTANCES/g
s/\bAcquiantences\b/Acquaintances/g
s/\bacquited\b/acquitted/g
s/\bACQUITED\b/ACQUITTED/g
s/\bAcquited\b/Acquitted/g
s/\bactivites\b/activities/g
s/\bACTIVITES\b/ACTIVITIES/g
s/\bActivites\b/Activities/g
s/\bactivly\b/actively/g
s/\bACTIVLY\b/ACTIVELY/g
s/\bActivly\b/Actively/g
s/\bacuracy\b/accuracy/g
s/\bACURACY\b/ACCURACY/g
s/\bAcuracy\b/Accuracy/g
s/\bacused\b/accused/g
s/\bACUSED\b/ACCUSED/g
s/\bAcused\b/Accused/g
s/\bacustom\b/accustom/g
s/\bACUSTOM\b/ACCUSTOM/g
s/\bAcustom\b/Accustom/g
s/\bacustommed\b/accustomed/g
s/\bACUSTOMMED\b/ACCUSTOMED/g
s/\bAcustommed\b/Accustomed/g
s/\badavanced\b/advanced/g
s/\bADAVANCED\b/ADVANCED/g
s/\bAdavanced\b/Advanced/g
s/\badbandon\b/abandon/g
s/\bADBANDON\b/ABANDON/g
s/\bAdbandon\b/Abandon/g
s/\baddional\b/additional/g
s/\bADDIONAL\b/ADDITIONAL/g
s/\bAddional\b/Additional/g
s/\baddionally\b/additionally/g
s/\bADDIONALLY\b/ADDITIONALLY/g
s/\bAddionally\b/Additionally/g
s/\badditinally\b/additionally/g
s/\bADDITINALLY\b/ADDITIONALLY/g
s/\bAdditinally\b/Additionally/g
s/\badditionaly\b/additionally/g
s/\bADDITIONALY\b/ADDITIONALLY/g
s/\bAdditionaly\b/Additionally/g
s/\badditonal\b/additional/g
s/\bADDITONAL\b/ADDITIONAL/g
s/\bAdditonal\b/Additional/g
s/\badditonally\b/additionally/g
s/\bADDITONALLY\b/ADDITIONALLY/g
s/\bAdditonally\b/Additionally/g
s/\baddmission\b/admission/g
s/\bADDMISSION\b/ADMISSION/g
s/\bAddmission\b/Admission/g
s/\baddopt\b/adopt/g
s/\bADDOPT\b/ADOPT/g
s/\bAddopt\b/Adopt/g
s/\baddopted\b/adopted/g
s/\bADDOPTED\b/ADOPTED/g
s/\bAddopted\b/Adopted/g
s/\baddoptive\b/adoptive/g
s/\bADDOPTIVE\b/ADOPTIVE/g
s/\bAddoptive\b/Adoptive/g
s/\baddresable\b/addressable/g
s/\bADDRESABLE\b/ADDRESSABLE/g
s/\bAddresable\b/Addressable/g
s/\baddresed\b/addressed/g
s/\bADDRESED\b/ADDRESSED/g
s/\bAddresed\b/Addressed/g
s/\baddresing\b/addressing/g
s/\bADDRESING\b/ADDRESSING/g
s/\bAddresing\b/Addressing/g
s/\baddressess\b/addresses/g
s/\bADDRESSESS\b/ADDRESSES/g
s/\bAddressess\b/Addresses/g
s/\baddtion\b/addition/g
s/\bADDTION\b/ADDITION/g
s/\bAddtion\b/Addition/g
s/\badecuate\b/adequate/g
s/\bADECUATE\b/ADEQUATE/g
s/\bAdecuate\b/Adequate/g
s/\badequit\b/adequate/g
s/\bADEQUIT\b/ADEQUATE/g
s/\bAdequit\b/Adequate/g
s/\badhearing\b/adhering/g
s/\bADHEARING\b/ADHERING/g
s/\bAdhearing\b/Adhering/g
s/\badherance\b/adherence/g
s/\bADHERANCE\b/ADHERENCE/g
s/\bAdherance\b/Adherence/g
s/\badmendment\b/amendment/g
s/\bADMENDMENT\b/AMENDMENT/g
s/\bAdmendment\b/Amendment/g
s/\badmininistrative\b/administrative/g
s/\bADMININISTRATIVE\b/ADMINISTRATIVE/g
s/\bAdmininistrative\b/Administrative/g
s/\badminstered\b/administered/g
s/\bADMINSTERED\b/ADMINISTERED/g
s/\bAdminstered\b/Administered/g
s/\badminstrate\b/administrate/g
s/\bADMINSTRATE\b/ADMINISTRATE/g
s/\bAdminstrate\b/Administrate/g
s/\badminstration\b/administration/g
s/\bADMINSTRATION\b/ADMINISTRATION/g
s/\bAdminstration\b/Administration/g
s/\badminstrative\b/administrative/g
s/\bADMINSTRATIVE\b/ADMINISTRATIVE/g
s/\bAdminstrative\b/Administrative/g
s/\badminstrator\b/administrator/g
s/\bADMINSTRATOR\b/ADMINISTRATOR/g
s/\bAdminstrator\b/Administrator/g
s/\badmissability\b/admissibility/g
s/\bADMISSABILITY\b/ADMISSIBILITY/g
s/\bAdmissability\b/Admissibility/g
s/\badmissable\b/admissible/g
s/\bADMISSABLE\b/ADMISSIBLE/g
s/\bAdmissable\b/Admissible/g
s/\badmited\b/admitted/g
s/\bADMITED\b/ADMITTED/g
s/\bAdmited\b/Admitted/g
s/\badmitedly\b/admittedly/g
s/\bADMITEDLY\b/ADMITTEDLY/g
s/\bAdmitedly\b/Admittedly/g
s/\badn\b/and/g
s/\bADN\b/AND/g
s/\bAdn\b/And/g
s/\badolecent\b/adolescent/g
s/\bADOLECENT\b/ADOLESCENT/g
s/\bAdolecent\b/Adolescent/g
s/\badquire\b/acquire/g
s/\bADQUIRE\b/ACQUIRE/g
s/\bAdquire\b/Acquire/g
s/\badquired\b/acquired/g
s/\bADQUIRED\b/ACQUIRED/g
s/\bAdquired\b/Acquired/g
s/\badquires\b/acquires/g
s/\bADQUIRES\b/ACQUIRES/g
s/\bAdquires\b/Acquires/g
s/\badquiring\b/acquiring/g
s/\bADQUIRING\b/ACQUIRING/g
s/\bAdquiring\b/Acquiring/g
s/\badres\b/address/g
s/\bADRES\b/ADDRESS/g
s/\bAdres\b/Address/g
s/\badresable\b/addressable/g
s/\bADRESABLE\b/ADDRESSABLE/g
s/\bAdresable\b/Addressable/g
s/\badresing\b/addressing/g
s/\bADRESING\b/ADDRESSING/g
s/\bAdresing\b/Addressing/g
s/\badress\b/address/g
s/\bADRESS\b/ADDRESS/g
s/\bAdress\b/Address/g
s/\badressable\b/addressable/g
s/\bADRESSABLE\b/ADDRESSABLE/g
s/\bAdressable\b/Addressable/g
s/\badressed\b/addressed/g
s/\bADRESSED\b/ADDRESSED/g
s/\bAdressed\b/Addressed/g
s/\badventrous\b/adventurous/g
s/\bADVENTROUS\b/ADVENTUROUS/g
s/\bAdventrous\b/Adventurous/g
s/\badvertisment\b/advertisement/g
s/\bADVERTISMENT\b/ADVERTISEMENT/g
s/\bAdvertisment\b/Advertisement/g
s/\badvertisments\b/advertisements/g
s/\bADVERTISMENTS\b/ADVERTISEMENTS/g
s/\bAdvertisments\b/Advertisements/g
s/\badvesary\b/adversary/g
s/\bADVESARY\b/ADVERSARY/g
s/\bAdvesary\b/Adversary/g
s/\badviced\b/advised/g
s/\bADVICED\b/ADVISED/g
s/\bAdviced\b/Advised/g
s/\baeriel\b/aerial/g
s/\bAERIEL\b/AERIAL/g
s/\bAeriel\b/Aerial/g
s/\baeriels\b/aerials/g
s/\bAERIELS\b/AERIALS/g
s/\bAeriels\b/Aerials/g
s/\bafair\b/affair/g
s/\bAFAIR\b/AFFAIR/g
s/\bAfair\b/Affair/g
s/\bafficianados\b/aficionados/g
s/\bAFFICIANADOS\b/AFICIONADOS/g
s/\bAfficianados\b/Aficionados/g
s/\bafficionado\b/aficionado/g
s/\bAFFICIONADO\b/AFICIONADO/g
s/\bAfficionado\b/Aficionado/g
s/\bafficionados\b/aficionados/g
s/\bAFFICIONADOS\b/AFICIONADOS/g
s/\bAfficionados\b/Aficionados/g
s/\baffilate\b/affiliate/g
s/\bAFFILATE\b/AFFILIATE/g
s/\bAffilate\b/Affiliate/g
s/\baffilliate\b/affiliate/g
s/\bAFFILLIATE\b/AFFILIATE/g
s/\bAffilliate\b/Affiliate/g
s/\baforememtioned\b/aforementioned/g
s/\bAFOREMEMTIONED\b/AFOREMENTIONED/g
s/\bAforememtioned\b/Aforementioned/g
s/\bagainnst\b/against/g
s/\bAGAINNST\b/AGAINST/g
s/\bAgainnst\b/Against/g
s/\bagains\b/against/g
s/\bAGAINS\b/AGAINST/g
s/\bAgains\b/Against/g
s/\bagaisnt\b/against/g
s/\bAGAISNT\b/AGAINST/g
s/\bAgaisnt\b/Against/g
s/\baganist\b/against/g
s/\bAGANIST\b/AGAINST/g
s/\bAganist\b/Against/g
s/\baggaravates\b/aggravates/g
s/\bAGGARAVATES\b/AGGRAVATES/g
s/\bAggaravates\b/Aggravates/g
s/\baggreed\b/agreed/g
s/\bAGGREED\b/AGREED/g
s/\bAggreed\b/Agreed/g
s/\baggreement\b/agreement/g
s/\bAGGREEMENT\b/AGREEMENT/g
s/\bAggreement\b/Agreement/g
s/\baggregious\b/egregious/g
s/\bAGGREGIOUS\b/EGREGIOUS/g
s/\bAggregious\b/Egregious/g
s/\baggresive\b/aggressive/g
s/\bAGGRESIVE\b/AGGRESSIVE/g
s/\bAggresive\b/Aggressive/g
s/\bagian\b/again/g
s/\bAGIAN\b/AGAIN/g
s/\bAgian\b/Again/g
s/\bagianst\b/against/g
s/\bAGIANST\b/AGAINST/g
s/\bAgianst\b/Against/g
s/\bagin\b/again/g
s/\bAGIN\b/AGAIN/g
s/\bAgin\b/Again/g
s/\baginst\b/against/g
s/\bAGINST\b/AGAINST/g
s/\bAginst\b/Against/g
s/\bagravate\b/aggravate/g
s/\bAGRAVATE\b/AGGRAVATE/g
s/\bAgravate\b/Aggravate/g
s/\bagre\b/agree/g
s/\bAGRE\b/AGREE/g
s/\bAgre\b/Agree/g
s/\bagred\b/agreed/g
s/\bAGRED\b/AGREED/g
s/\bAgred\b/Agreed/g
s/\bagreeement\b/agreement/g
s/\bAGREEEMENT\b/AGREEMENT/g
s/\bAgreeement\b/Agreement/g
s/\bagreemnt\b/agreement/g
s/\bAGREEMNT\b/AGREEMENT/g
s/\bAgreemnt\b/Agreement/g
s/\bagregate\b/aggregate/g
s/\bAGREGATE\b/AGGREGATE/g
s/\bAgregate\b/Aggregate/g
s/\bagregates\b/aggregates/g
s/\bAGREGATES\b/AGGREGATES/g
s/\bAgregates\b/Aggregates/g
s/\bagreing\b/agreeing/g
s/\bAGREING\b/AGREEING/g
s/\bAgreing\b/Agreeing/g
s/\bagressively\b/aggressively/g
s/\bAGRESSIVELY\b/AGGRESSIVELY/g
s/\bAgressively\b/Aggressively/g
s/\bagressor\b/aggressor/g
s/\bAGRESSOR\b/AGGRESSOR/g
s/\bAgressor\b/Aggressor/g
s/\bagricultue\b/agriculture/g
s/\bAGRICULTUE\b/AGRICULTURE/g
s/\bAgricultue\b/Agriculture/g
s/\bagriculure\b/agriculture/g
s/\bAGRICULURE\b/AGRICULTURE/g
s/\bAgriculure\b/Agriculture/g
s/\bagricuture\b/agriculture/g
s/\bAGRICUTURE\b/AGRICULTURE/g
s/\bAgricuture\b/Agriculture/g
s/\bagrieved\b/aggrieved/g
s/\bAGRIEVED\b/AGGRIEVED/g
s/\bAgrieved\b/Aggrieved/g
s/\bahev\b/have/g
s/\bAHEV\b/HAVE/g
s/\bAhev\b/Have/g
s/\bahppen\b/happen/g
s/\bAHPPEN\b/HAPPEN/g
s/\bAhppen\b/Happen/g
s/\baicraft\b/aircraft/g
s/\bAICRAFT\b/AIRCRAFT/g
s/\bAicraft\b/Aircraft/g
s/\baiport\b/airport/g
s/\bAIPORT\b/AIRPORT/g
s/\bAiport\b/Airport/g
s/\bairbourne\b/airborne/g
s/\bAIRBOURNE\b/AIRBORNE/g
s/\bAirbourne\b/Airborne/g
s/\baircaft\b/aircraft/g
s/\bAIRCAFT\b/AIRCRAFT/g
s/\bAircaft\b/Aircraft/g
s/\baircrafts'\b/aircraft's/g
s/\bAIRCRAFTS'\b/AIRCRAFT'S/g
s/\bAircrafts'\b/Aircraft's/g
s/\baircrafts\b/aircraft/g
s/\bAIRCRAFTS\b/AIRCRAFT/g
s/\bAircrafts\b/Aircraft/g
s/\bairporta\b/airports/g
s/\bAIRPORTA\b/AIRPORTS/g
s/\bAirporta\b/Airports/g
s/\bairrcraft\b/aircraft/g
s/\bAIRRCRAFT\b/AIRCRAFT/g
s/\bAirrcraft\b/Aircraft/g
s/\baisian\b/asian/g
s/\bAISIAN\b/ASIAN/g
s/\bAisian\b/Asian/g
s/\balbiet\b/albeit/g
s/\bALBIET\b/ALBEIT/g
s/\bAlbiet\b/Albeit/g
s/\balchohol\b/alcohol/g
s/\bALCHOHOL\b/ALCOHOL/g
s/\bAlchohol\b/Alcohol/g
s/\balchoholic\b/alcoholic/g
s/\bALCHOHOLIC\b/ALCOHOLIC/g
s/\bAlchoholic\b/Alcoholic/g
s/\balchol\b/alcohol/g
s/\bALCHOL\b/ALCOHOL/g
s/\bAlchol\b/Alcohol/g
s/\balcholic\b/alcoholic/g
s/\bALCHOLIC\b/ALCOHOLIC/g
s/\bAlcholic\b/Alcoholic/g
s/\balcohal\b/alcohol/g
s/\bALCOHAL\b/ALCOHOL/g
s/\bAlcohal\b/Alcohol/g
s/\balcoholical\b/alcoholic/g
s/\bALCOHOLICAL\b/ALCOHOLIC/g
s/\bAlcoholical\b/Alcoholic/g
s/\baledge\b/allege/g
s/\bALEDGE\b/ALLEGE/g
s/\bAledge\b/Allege/g
s/\baledged\b/alleged/g
s/\bALEDGED\b/ALLEGED/g
s/\bAledged\b/Alleged/g
s/\baledges\b/alleges/g
s/\bALEDGES\b/ALLEGES/g
s/\bAledges\b/Alleges/g
s/\balege\b/allege/g
s/\bALEGE\b/ALLEGE/g
s/\bAlege\b/Allege/g
s/\baleged\b/alleged/g
s/\bALEGED\b/ALLEGED/g
s/\bAleged\b/Alleged/g
s/\balegience\b/allegiance/g
s/\bALEGIENCE\b/ALLEGIANCE/g
s/\bAlegience\b/Allegiance/g
s/\balgebraical\b/algebraic/g
s/\bALGEBRAICAL\b/ALGEBRAIC/g
s/\bAlgebraical\b/Algebraic/g
s/\balgorhitms\b/algorithms/g
s/\bALGORHITMS\b/ALGORITHMS/g
s/\bAlgorhitms\b/Algorithms/g
s/\balgoritm\b/algorithm/g
s/\bALGORITM\b/ALGORITHM/g
s/\bAlgoritm\b/Algorithm/g
s/\balientating\b/alienating/g
s/\bALIENTATING\b/ALIENATING/g
s/\bAlientating\b/Alienating/g
s/\balledge\b/allege/g
s/\bALLEDGE\b/ALLEGE/g
s/\bAlledge\b/Allege/g
s/\balledged\b/alleged/g
s/\bALLEDGED\b/ALLEGED/g
s/\bAlledged\b/Alleged/g
s/\balledgedly\b/allegedly/g
s/\bALLEDGEDLY\b/ALLEGEDLY/g
s/\bAlledgedly\b/Allegedly/g
s/\balledges\b/alleges/g
s/\bALLEDGES\b/ALLEGES/g
s/\bAlledges\b/Alleges/g
s/\ballegedely\b/allegedly/g
s/\bALLEGEDELY\b/ALLEGEDLY/g
s/\bAllegedely\b/Allegedly/g
s/\ballegedy\b/allegedly/g
s/\bALLEGEDY\b/ALLEGEDLY/g
s/\bAllegedy\b/Allegedly/g
s/\ballegely\b/allegedly/g
s/\bALLEGELY\b/ALLEGEDLY/g
s/\bAllegely\b/Allegedly/g
s/\ballegence\b/allegiance/g
s/\bALLEGENCE\b/ALLEGIANCE/g
s/\bAllegence\b/Allegiance/g
s/\ballegience\b/allegiance/g
s/\bALLEGIENCE\b/ALLEGIANCE/g
s/\bAllegience\b/Allegiance/g
s/\ballign\b/align/g
s/\bALLIGN\b/ALIGN/g
s/\bAllign\b/Align/g
s/\balliviate\b/alleviate/g
s/\bALLIVIATE\b/ALLEVIATE/g
s/\bAlliviate\b/Alleviate/g
s/\ballopone\b/allophone/g
s/\bALLOPONE\b/ALLOPHONE/g
s/\bAllopone\b/Allophone/g
s/\ballopones\b/allophones/g
s/\bALLOPONES\b/ALLOPHONES/g
s/\bAllopones\b/Allophones/g
s/\ballthough\b/although/g
s/\bALLTHOUGH\b/ALTHOUGH/g
s/\bAllthough\b/Although/g
s/\balltime\b/all-time/g
s/\bALLTIME\b/ALL-TIME/g
s/\bAlltime\b/All-time/g
s/\balmsot\b/almost/g
s/\bALMSOT\b/ALMOST/g
s/\bAlmsot\b/Almost/g
s/\balochol\b/alcohol/g
s/\bALOCHOL\b/ALCOHOL/g
s/\bAlochol\b/Alcohol/g
s/\balomst\b/almost/g
s/\bALOMST\b/ALMOST/g
s/\bAlomst\b/Almost/g
s/\balotted\b/allotted/g
s/\bALOTTED\b/ALLOTTED/g
s/\bAlotted\b/Allotted/g
s/\balowed\b/allowed/g
s/\bALOWED\b/ALLOWED/g
s/\bAlowed\b/Allowed/g
s/\balowing\b/allowing/g
s/\bALOWING\b/ALLOWING/g
s/\bAlowing\b/Allowing/g
s/\balreayd\b/already/g
s/\bALREAYD\b/ALREADY/g
s/\bAlreayd\b/Already/g
s/\balse\b/else/g
s/\bALSE\b/ELSE/g
s/\bAlse\b/Else/g
s/\balsot\b/also/g
s/\bALSOT\b/ALSO/g
s/\bAlsot\b/Also/g
s/\balternitives\b/alternatives/g
s/\bALTERNITIVES\b/ALTERNATIVES/g
s/\bAlternitives\b/Alternatives/g
s/\baltho\b/although/g
s/\bALTHO\b/ALTHOUGH/g
s/\bAltho\b/Although/g
s/\baltough\b/although/g
s/\bALTOUGH\b/ALTHOUGH/g
s/\bAltough\b/Although/g
s/\balwasy\b/always/g
s/\bALWASY\b/ALWAYS/g
s/\bAlwasy\b/Always/g
s/\balwyas\b/always/g
s/\bALWYAS\b/ALWAYS/g
s/\bAlwyas\b/Always/g
s/\bamalgomated\b/amalgamated/g
s/\bAMALGOMATED\b/AMALGAMATED/g
s/\bAmalgomated\b/Amalgamated/g
s/\bamatuer\b/amateur/g
s/\bAMATUER\b/AMATEUR/g
s/\bAmatuer\b/Amateur/g
s/\bamendmant\b/amendment/g
s/\bAMENDMANT\b/AMENDMENT/g
s/\bAmendmant\b/Amendment/g
s/\bamerliorate\b/ameliorate/g
s/\bAMERLIORATE\b/AMELIORATE/g
s/\bAmerliorate\b/Ameliorate/g
s/\bamke\b/make/g
s/\bAMKE\b/MAKE/g
s/\bAmke\b/Make/g
s/\bamking\b/making/g
s/\bAMKING\b/MAKING/g
s/\bAmking\b/Making/g
s/\bammused\b/amused/g
s/\bAMMUSED\b/AMUSED/g
s/\bAmmused\b/Amused/g
s/\bamoung\b/among/g
s/\bAMOUNG\b/AMONG/g
s/\bAmoung\b/Among/g
s/\bamoungst\b/amongst/g
s/\bAMOUNGST\b/AMONGST/g
s/\bAmoungst\b/Amongst/g
s/\bamung\b/among/g
s/\bAMUNG\b/AMONG/g
s/\bAmung\b/Among/g
s/\bamunition\b/ammunition/g
s/\bAMUNITION\b/AMMUNITION/g
s/\bAmunition\b/Ammunition/g
s/\banalitic\b/analytic/g
s/\bANALITIC\b/ANALYTIC/g
s/\bAnalitic\b/Analytic/g
s/\banalogeous\b/analogous/g
s/\bANALOGEOUS\b/ANALOGOUS/g
s/\bAnalogeous\b/Analogous/g
s/\banarchim\b/anarchism/g
s/\bANARCHIM\b/ANARCHISM/g
s/\bAnarchim\b/Anarchism/g
s/\banarchistm\b/anarchism/g
s/\bANARCHISTM\b/ANARCHISM/g
s/\bAnarchistm\b/Anarchism/g
s/\banbd\b/and/g
s/\bANBD\b/AND/g
s/\bAnbd\b/And/g
s/\bancestory\b/ancestry/g
s/\bANCESTORY\b/ANCESTRY/g
s/\bAncestory\b/Ancestry/g
s/\bandd\b/and/g
s/\bANDD\b/AND/g
s/\bAndd\b/And/g
s/\bandrogenous\b/androgynous/g
s/\bANDROGENOUS\b/ANDROGYNOUS/g
s/\bAndrogenous\b/Androgynous/g
s/\bandrogeny\b/androgyny/g
s/\bANDROGENY\b/ANDROGYNY/g
s/\bAndrogeny\b/Androgyny/g
s/\banihilation\b/annihilation/g
s/\bANIHILATION\b/ANNIHILATION/g
s/\bAnihilation\b/Annihilation/g
s/\baniversary\b/anniversary/g
s/\bANIVERSARY\b/ANNIVERSARY/g
s/\bAniversary\b/Anniversary/g
s/\bannoint\b/anoint/g
s/\bANNOINT\b/ANOINT/g
s/\bAnnoint\b/Anoint/g
s/\bannointed\b/anointed/g
s/\bANNOINTED\b/ANOINTED/g
s/\bAnnointed\b/Anointed/g
s/\bannointing\b/anointing/g
s/\bANNOINTING\b/ANOINTING/g
s/\bAnnointing\b/Anointing/g
s/\bannoints\b/anoints/g
s/\bANNOINTS\b/ANOINTS/g
s/\bAnnoints\b/Anoints/g
s/\bannouced\b/announced/g
s/\bANNOUCED\b/ANNOUNCED/g
s/\bAnnouced\b/Announced/g
s/\bannualy\b/annually/g
s/\bANNUALY\b/ANNUALLY/g
s/\bAnnualy\b/Annually/g
s/\bannuled\b/annulled/g
s/\bANNULED\b/ANNULLED/g
s/\bAnnuled\b/Annulled/g
s/\banohter\b/another/g
s/\bANOHTER\b/ANOTHER/g
s/\bAnohter\b/Another/g
s/\banomolies\b/anomalies/g
s/\bANOMOLIES\b/ANOMALIES/g
s/\bAnomolies\b/Anomalies/g
s/\banomolous\b/anomalous/g
s/\bANOMOLOUS\b/ANOMALOUS/g
s/\bAnomolous\b/Anomalous/g
s/\banomoly\b/anomaly/g
s/\bANOMOLY\b/ANOMALY/g
s/\bAnomoly\b/Anomaly/g
s/\banonimity\b/anonymity/g
s/\bANONIMITY\b/ANONYMITY/g
s/\bAnonimity\b/Anonymity/g
s/\banounced\b/announced/g
s/\bANOUNCED\b/ANNOUNCED/g
s/\bAnounced\b/Announced/g
s/\banouncement\b/announcement/g
s/\bANOUNCEMENT\b/ANNOUNCEMENT/g
s/\bAnouncement\b/Announcement/g
s/\bansalisation\b/nasalisation/g
s/\bANSALISATION\b/NASALISATION/g
s/\bAnsalisation\b/Nasalisation/g
s/\bansalization\b/nasalization/g
s/\bANSALIZATION\b/NASALIZATION/g
s/\bAnsalization\b/Nasalization/g
s/\bansestors\b/ancestors/g
s/\bANSESTORS\b/ANCESTORS/g
s/\bAnsestors\b/Ancestors/g
s/\bantartic\b/antarctic/g
s/\bANTARTIC\b/ANTARCTIC/g
s/\bAntartic\b/Antarctic/g
s/\banthromorphization\b/anthropomorphization/g
s/\bANTHROMORPHIZATION\b/ANTHROPOMORPHIZATION/g
s/\bAnthromorphization\b/Anthropomorphization/g
s/\banthropolgist\b/anthropologist/g
s/\bANTHROPOLGIST\b/ANTHROPOLOGIST/g
s/\bAnthropolgist\b/Anthropologist/g
s/\banthropolgy\b/anthropology/g
s/\bANTHROPOLGY\b/ANTHROPOLOGY/g
s/\bAnthropolgy\b/Anthropology/g
s/\banual\b/annual/g
s/\bANUAL\b/ANNUAL/g
s/\bAnual\b/Annual/g
s/\banulled\b/annulled/g
s/\bANULLED\b/ANNULLED/g
s/\bAnulled\b/Annulled/g
s/\banwsered\b/answered/g
s/\bANWSERED\b/ANSWERED/g
s/\bAnwsered\b/Answered/g
s/\banyhwere\b/anywhere/g
s/\bANYHWERE\b/ANYWHERE/g
s/\bAnyhwere\b/Anywhere/g
s/\banyother\b/any other/g
s/\bANYOTHER\b/ANY OTHER/g
s/\bAnyother\b/Any other/g
s/\banytying\b/anything/g
s/\bANYTYING\b/ANYTHING/g
s/\bAnytying\b/Anything/g
s/\baparent\b/apparent/g
s/\bAPARENT\b/APPARENT/g
s/\bAparent\b/Apparent/g
s/\baparment\b/apartment/g
s/\bAPARMENT\b/APARTMENT/g
s/\bAparment\b/Apartment/g
s/\baplication\b/application/g
s/\bAPLICATION\b/APPLICATION/g
s/\bAplication\b/Application/g
s/\baplied\b/applied/g
s/\bAPLIED\b/APPLIED/g
s/\bAplied\b/Applied/g
s/\baply/apply/g
s/\bAPLY/APPLY/g
s/\bAply/Apply/g
s/\bapolegetics\b/apologetics/g
s/\bAPOLEGETICS\b/APOLOGETICS/g
s/\bApolegetics\b/Apologetics/g
s/\bapparant\b/apparent/g
s/\bAPPARANT\b/APPARENT/g
s/\bApparant\b/Apparent/g
s/\bapparantly\b/apparently/g
s/\bAPPARANTLY\b/APPARENTLY/g
s/\bApparantly\b/Apparently/g
s/\bappart\b/apart/g
s/\bAPPART\b/APART/g
s/\bAppart\b/Apart/g
s/\bappartment\b/apartment/g
s/\bAPPARTMENT\b/APARTMENT/g
s/\bAppartment\b/Apartment/g
s/\bappartments\b/apartments/g
s/\bAPPARTMENTS\b/APARTMENTS/g
s/\bAppartments\b/Apartments/g
s/\bappeareance\b/appearance/g
s/\bAPPEAREANCE\b/APPEARANCE/g
s/\bAppeareance\b/Appearance/g
s/\bapperance\b/appearance/g
s/\bAPPERANCE\b/APPEARANCE/g
s/\bApperance\b/Appearance/g
s/\bapplicaiton\b/application/g
s/\bAPPLICAITON\b/APPLICATION/g
s/\bApplicaiton\b/Application/g
s/\bapplicaitons\b/applications/g
s/\bAPPLICAITONS\b/APPLICATIONS/g
s/\bApplicaitons\b/Applications/g
s/\bappologies\b/apologies/g
s/\bAPPOLOGIES\b/APOLOGIES/g
s/\bAppologies\b/Apologies/g
s/\bappology\b/apology/g
s/\bAPPOLOGY\b/APOLOGY/g
s/\bAppology\b/Apology/g
s/\bapprearance\b/appearance/g
s/\bAPPREARANCE\b/APPEARANCE/g
s/\bApprearance\b/Appearance/g
s/\bapprieciate\b/appreciate/g
s/\bAPPRIECIATE\b/APPRECIATE/g
s/\bApprieciate\b/Appreciate/g
s/\bapproachs\b/approaches/g
s/\bAPPROACHS\b/APPROACHES/g
s/\bApproachs\b/Approaches/g
s/\bappropraite\b/appropriate/g
s/\bAPPROPRAITE\b/APPROPRIATE/g
s/\bAppropraite\b/Appropriate/g
s/\bappropropiate\b/appropriate/g
s/\bAPPROPROPIATE\b/APPROPRIATE/g
s/\bAppropropiate\b/Appropriate/g
s/\bapproproximate\b/approximate/g
s/\bAPPROPROXIMATE\b/APPROXIMATE/g
s/\bApproproximate\b/Approximate/g
s/\bapproxamately\b/approximately/g
s/\bAPPROXAMATELY\b/APPROXIMATELY/g
s/\bApproxamately\b/Approximately/g
s/\bapproxiately\b/approximately/g
s/\bAPPROXIATELY\b/APPROXIMATELY/g
s/\bApproxiately\b/Approximately/g
s/\bapproximitely\b/approximately/g
s/\bAPPROXIMITELY\b/APPROXIMATELY/g
s/\bApproximitely\b/Approximately/g
s/\baprehensive\b/apprehensive/g
s/\bAPREHENSIVE\b/APPREHENSIVE/g
s/\bAprehensive\b/Apprehensive/g
s/\bapropriate\b/appropriate/g
s/\bAPROPRIATE\b/APPROPRIATE/g
s/\bApropriate\b/Appropriate/g
s/\baproval\b/approval/g
s/\bAPROVAL\b/APPROVAL/g
s/\bAproval\b/Approval/g
s/\baproximately\b/approximately/g
s/\bAPROXIMATELY\b/APPROXIMATELY/g
s/\bAproximately\b/Approximately/g
s/\baquaduct\b/aqueduct/g
s/\bAQUADUCT\b/AQUEDUCT/g
s/\bAquaduct\b/Aqueduct/g
s/\baquaintance\b/acquaintance/g
s/\bAQUAINTANCE\b/ACQUAINTANCE/g
s/\bAquaintance\b/Acquaintance/g
s/\baquainted\b/acquainted/g
s/\bAQUAINTED\b/ACQUAINTED/g
s/\bAquainted\b/Acquainted/g
s/\baquiantance\b/acquaintance/g
s/\bAQUIANTANCE\b/ACQUAINTANCE/g
s/\bAquiantance\b/Acquaintance/g
s/\baquisition\b/acquisition/g
s/\bAQUISITION\b/ACQUISITION/g
s/\bAquisition\b/Acquisition/g
s/\baquitted\b/acquitted/g
s/\bAQUITTED\b/ACQUITTED/g
s/\bAquitted\b/Acquitted/g
s/\baranged\b/arranged/g
s/\bARANGED\b/ARRANGED/g
s/\bAranged\b/Arranged/g
s/\barangement\b/arrangement/g
s/\bARANGEMENT\b/ARRANGEMENT/g
s/\bArangement\b/Arrangement/g
s/\barchaelogical\b/archaeological/g
s/\bARCHAELOGICAL\b/ARCHAEOLOGICAL/g
s/\bArchaelogical\b/Archaeological/g
s/\barchaelogists\b/archaeologists/g
s/\bARCHAELOGISTS\b/ARCHAEOLOGISTS/g
s/\bArchaelogists\b/Archaeologists/g
s/\barchaelogy\b/archaeology/g
s/\bARCHAELOGY\b/ARCHAEOLOGY/g
s/\bArchaelogy\b/Archaeology/g
s/\barchetect\b/architect/g
s/\bARCHETECT\b/ARCHITECT/g
s/\bArchetect\b/Architect/g
s/\barchetects\b/architects/g
s/\bARCHETECTS\b/ARCHITECTS/g
s/\bArchetects\b/Architects/g
s/\barchetectural\b/architectural/g
s/\bARCHETECTURAL\b/ARCHITECTURAL/g
s/\bArchetectural\b/Architectural/g
s/\barchetecturally\b/architecturally/g
s/\bARCHETECTURALLY\b/ARCHITECTURALLY/g
s/\bArchetecturally\b/Architecturally/g
s/\barchetecture\b/architecture/g
s/\bARCHETECTURE\b/ARCHITECTURE/g
s/\bArchetecture\b/Architecture/g
s/\barchiac\b/archaic/g
s/\bARCHIAC\b/ARCHAIC/g
s/\bArchiac\b/Archaic/g
s/\barchictect\b/architect/g
s/\bARCHICTECT\b/ARCHITECT/g
s/\bArchictect\b/Architect/g
s/\barchimedian\b/archimedean/g
s/\bARCHIMEDIAN\b/ARCHIMEDEAN/g
s/\bArchimedian\b/Archimedean/g
s/\barchitecht\b/architect/g
s/\bARCHITECHT\b/ARCHITECT/g
s/\bArchitecht\b/Architect/g
s/\barchitechturally\b/architecturally/g
s/\bARCHITECHTURALLY\b/ARCHITECTURALLY/g
s/\bArchitechturally\b/Architecturally/g
s/\barchitechture\b/architecture/g
s/\bARCHITECHTURE\b/ARCHITECTURE/g
s/\bArchitechture\b/Architecture/g
s/\barchitechtures\b/architectures/g
s/\bARCHITECHTURES\b/ARCHITECTURES/g
s/\bArchitechtures\b/Architectures/g
s/\barchitectual\b/architectural/g
s/\bARCHITECTUAL\b/ARCHITECTURAL/g
s/\bArchitectual\b/Architectural/g
s/\barchtype\b/archetype/g
s/\bARCHTYPE\b/ARCHETYPE/g
s/\bArchtype\b/Archetype/g
s/\barchtypes\b/archetypes/g
s/\bARCHTYPES\b/ARCHETYPES/g
s/\bArchtypes\b/Archetypes/g
s/\baready\b/already/g
s/\bAREADY\b/ALREADY/g
s/\bAready\b/Already/g
s/\bareodynamics\b/aerodynamics/g
s/\bAREODYNAMICS\b/AERODYNAMICS/g
s/\bAreodynamics\b/Aerodynamics/g
s/\bargubly\b/arguably/g
s/\bARGUBLY\b/ARGUABLY/g
s/\bArgubly\b/Arguably/g
s/\barised\b/arose/g
s/\bARISED\b/AROSE/g
s/\bArised\b/Arose/g
s/\barival\b/arrival/g
s/\bARIVAL\b/ARRIVAL/g
s/\bArival\b/Arrival/g
s/\barmamant\b/armament/g
s/\bARMAMANT\b/ARMAMENT/g
s/\bArmamant\b/Armament/g
s/\barmistace\b/armistice/g
s/\bARMISTACE\b/ARMISTICE/g
s/\bArmistace\b/Armistice/g
s/\barogant\b/arrogant/g
s/\bAROGANT\b/ARROGANT/g
s/\bArogant\b/Arrogant/g
s/\barogent\b/arrogant/g
s/\bAROGENT\b/ARROGANT/g
s/\bArogent\b/Arrogant/g
s/\baroud\b/around/g
s/\bAROUD\b/AROUND/g
s/\bAroud\b/Around/g
s/\barrangment\b/arrangement/g
s/\bARRANGMENT\b/ARRANGEMENT/g
s/\bArrangment\b/Arrangement/g
s/\barrangments\b/arrangements/g
s/\bARRANGMENTS\b/ARRANGEMENTS/g
s/\bArrangments\b/Arrangements/g
s/\barrengement\b/arrangement/g
s/\bARRENGEMENT\b/ARRANGEMENT/g
s/\bArrengement\b/Arrangement/g
s/\barrengements\b/arrangements/g
s/\bARRENGEMENTS\b/ARRANGEMENTS/g
s/\bArrengements\b/Arrangements/g
s/\barround\b/around/g
s/\bARROUND\b/AROUND/g
s/\bArround\b/Around/g
s/\bartcile\b/article/g
s/\bARTCILE\b/ARTICLE/g
s/\bArtcile\b/Article/g
s/\bartical\b/article/g
s/\bARTICAL\b/ARTICLE/g
s/\bArtical\b/Article/g
s/\bartice\b/article/g
s/\bARTICE\b/ARTICLE/g
s/\bArtice\b/Article/g
s/\barticel\b/article/g
s/\bARTICEL\b/ARTICLE/g
s/\bArticel\b/Article/g
s/\bartillary\b/artillery/g
s/\bARTILLARY\b/ARTILLERY/g
s/\bArtillary\b/Artillery/g
s/\barund\b/around/g
s/\bARUND\b/AROUND/g
s/\bArund\b/Around/g
s/\basetic\b/ascetic/g
s/\bASETIC\b/ASCETIC/g
s/\bAsetic\b/Ascetic/g
s/\basfar\b/as far/g
s/\bASFAR\b/AS FAR/g
s/\bAsfar\b/As far/g
s/\basign\b/assign/g
s/\bASIGN\b/ASSIGN/g
s/\bAsign\b/Assign/g
s/\baslo\b/also/g
s/\bASLO\b/ALSO/g
s/\bAslo\b/Also/g
s/\basociated\b/associated/g
s/\bASOCIATED\b/ASSOCIATED/g
s/\bAsociated\b/Associated/g
s/\basorbed\b/absorbed/g
s/\bASORBED\b/ABSORBED/g
s/\bAsorbed\b/Absorbed/g
s/\basphyxation\b/asphyxiation/g
s/\bASPHYXATION\b/ASPHYXIATION/g
s/\bAsphyxation\b/Asphyxiation/g
s/\bassasin\b/assassin/g
s/\bASSASIN\b/ASSASSIN/g
s/\bAssasin\b/Assassin/g
s/\bassasinate\b/assassinate/g
s/\bASSASINATE\b/ASSASSINATE/g
s/\bAssasinate\b/Assassinate/g
s/\bassasinated\b/assassinated/g
s/\bASSASINATED\b/ASSASSINATED/g
s/\bAssasinated\b/Assassinated/g
s/\bassasinates\b/assassinates/g
s/\bASSASINATES\b/ASSASSINATES/g
s/\bAssasinates\b/Assassinates/g
s/\bassasination\b/assassination/g
s/\bASSASINATION\b/ASSASSINATION/g
s/\bAssasination\b/Assassination/g
s/\bassasinations\b/assassinations/g
s/\bASSASINATIONS\b/ASSASSINATIONS/g
s/\bAssasinations\b/Assassinations/g
s/\bassasined\b/assassinated/g
s/\bASSASINED\b/ASSASSINATED/g
s/\bAssasined\b/Assassinated/g
s/\bassasins\b/assassins/g
s/\bASSASINS\b/ASSASSINS/g
s/\bAssasins\b/Assassins/g
s/\bassassintation\b/assassination/g
s/\bASSASSINTATION\b/ASSASSINATION/g
s/\bAssassintation\b/Assassination/g
s/\bassemple\b/assemble/g
s/\bASSEMPLE\b/ASSEMBLE/g
s/\bAssemple\b/Assemble/g
s/\bassertation\b/assertion/g
s/\bASSERTATION\b/ASSERTION/g
s/\bAssertation\b/Assertion/g
s/\basside\b/aside/g
s/\bASSIDE\b/ASIDE/g
s/\bAsside\b/Aside/g
s/\bassisnate\b/assassinate/g
s/\bASSISNATE\b/ASSASSINATE/g
s/\bAssisnate\b/Assassinate/g
s/\bassit\b/assist/g
s/\bASSIT\b/ASSIST/g
s/\bAssit\b/Assist/g
s/\bassitant\b/assistant/g
s/\bASSITANT\b/ASSISTANT/g
s/\bAssitant\b/Assistant/g
s/\bassocation\b/association/g
s/\bASSOCATION\b/ASSOCIATION/g
s/\bAssocation\b/Association/g
s/\bassoicate\b/associate/g
s/\bASSOICATE\b/ASSOCIATE/g
s/\bAssoicate\b/Associate/g
s/\bassoicated\b/associated/g
s/\bASSOICATED\b/ASSOCIATED/g
s/\bAssoicated\b/Associated/g
s/\bassoicates\b/associates/g
s/\bASSOICATES\b/ASSOCIATES/g
s/\bAssoicates\b/Associates/g
s/\bassosication\b/assassination/g
s/\bASSOSICATION\b/ASSASSINATION/g
s/\bAssosication\b/Assassination/g
s/\basssassans\b/assassins/g
s/\bASSSASSANS\b/ASSASSINS/g
s/\bAsssassans\b/Assassins/g
s/\bassualt\b/assault/g
s/\bASSUALT\b/ASSAULT/g
s/\bAssualt\b/Assault/g
s/\bassualted\b/assaulted/g
s/\bASSUALTED\b/ASSAULTED/g
s/\bAssualted\b/Assaulted/g
s/\bassymetric\b/asymmetric/g
s/\bASSYMETRIC\b/ASYMMETRIC/g
s/\bAssymetric\b/Asymmetric/g
s/\bassymetrical\b/asymmetrical/g
s/\bASSYMETRICAL\b/ASYMMETRICAL/g
s/\bAssymetrical\b/Asymmetrical/g
s/\basteriod\b/asteroid/g
s/\bASTERIOD\b/ASTEROID/g
s/\bAsteriod\b/Asteroid/g
s/\basthetic\b/aesthetic/g
s/\bASTHETIC\b/AESTHETIC/g
s/\bAsthetic\b/Aesthetic/g
s/\basthetical\b/aesthetical/g
s/\bASTHETICAL\b/AESTHETICAL/g
s/\bAsthetical\b/Aesthetical/g
s/\basthetically\b/aesthetically/g
s/\bASTHETICALLY\b/AESTHETICALLY/g
s/\bAsthetically\b/Aesthetically/g
s/\basume\b/assume/g
s/\bASUME\b/ASSUME/g
s/\bAsume\b/Assume/g
s/\batain\b/attain/g
s/\bATAIN\b/ATTAIN/g
s/\bAtain\b/Attain/g
s/\batempting\b/attempting/g
s/\bATEMPTING\b/ATTEMPTING/g
s/\bAtempting\b/Attempting/g
s/\batheistical\b/atheistic/g
s/\bATHEISTICAL\b/ATHEISTIC/g
s/\bAtheistical\b/Atheistic/g
s/\bathenean\b/athenian/g
s/\bATHENEAN\b/ATHENIAN/g
s/\bAthenean\b/Athenian/g
s/\batheneans\b/athenians/g
s/\bATHENEANS\b/ATHENIANS/g
s/\bAtheneans\b/Athenians/g
s/\bathiesm\b/atheism/g
s/\bATHIESM\b/ATHEISM/g
s/\bAthiesm\b/Atheism/g
s/\bathiest\b/atheist/g
s/\bATHIEST\b/ATHEIST/g
s/\bAthiest\b/Atheist/g
s/\batorney\b/attorney/g
s/\bATORNEY\b/ATTORNEY/g
s/\bAtorney\b/Attorney/g
s/\batribute\b/attribute/g
s/\bATRIBUTE\b/ATTRIBUTE/g
s/\bAtribute\b/Attribute/g
s/\batributed\b/attributed/g
s/\bATRIBUTED\b/ATTRIBUTED/g
s/\bAtributed\b/Attributed/g
s/\battemped\b/attempted/g
s/\bATTEMPED\b/ATTEMPTED/g
s/\bAttemped\b/Attempted/g
s/\battemt\b/attempt/g
s/\bATTEMT\b/ATTEMPT/g
s/\bAttemt\b/Attempt/g
s/\battemted\b/attempted/g
s/\bATTEMTED\b/ATTEMPTED/g
s/\bAttemted\b/Attempted/g
s/\battemting\b/attempting/g
s/\bATTEMTING\b/ATTEMPTING/g
s/\bAttemting\b/Attempting/g
s/\battendence\b/attendance/g
s/\bATTENDENCE\b/ATTENDANCE/g
s/\bAttendence\b/Attendance/g
s/\battendent\b/attendant/g
s/\bATTENDENT\b/ATTENDANT/g
s/\bAttendent\b/Attendant/g
s/\battendents\b/attendants/g
s/\bATTENDENTS\b/ATTENDANTS/g
s/\bAttendents\b/Attendants/g
s/\battened\b/attended/g
s/\bATTENED\b/ATTENDED/g
s/\bAttened\b/Attended/g
s/\battension\b/attention/g
s/\bATTENSION\b/ATTENTION/g
s/\bAttension\b/Attention/g
s/\battitide\b/attitude/g
s/\bATTITIDE\b/ATTITUDE/g
s/\bAttitide\b/Attitude/g
s/\battributred\b/attributed/g
s/\bATTRIBUTRED\b/ATTRIBUTED/g
s/\bAttributred\b/Attributed/g
s/\battrocities\b/atrocities/g
s/\bATTROCITIES\b/ATROCITIES/g
s/\bAttrocities\b/Atrocities/g
s/\baudeince\b/audience/g
s/\bAUDEINCE\b/AUDIENCE/g
s/\bAudeince\b/Audience/g
s/\bauromated\b/automated/g
s/\bAUROMATED\b/AUTOMATED/g
s/\bAuromated\b/Automated/g
s/\baustrailia\b/australia/g
s/\bAUSTRAILIA\b/AUSTRALIA/g
s/\bAustrailia\b/Australia/g
s/\baustrailian\b/australian/g
s/\bAUSTRAILIAN\b/AUSTRALIAN/g
s/\bAustrailian\b/Australian/g
s/\bauther\b/author/g
s/\bAUTHER\b/AUTHOR/g
s/\bAuther\b/Author/g
s/\bauthobiographic\b/autobiographic/g
s/\bAUTHOBIOGRAPHIC\b/AUTOBIOGRAPHIC/g
s/\bAuthobiographic\b/Autobiographic/g
s/\bauthobiography\b/autobiography/g
s/\bAUTHOBIOGRAPHY\b/AUTOBIOGRAPHY/g
s/\bAuthobiography\b/Autobiography/g
s/\bauthorative\b/authoritative/g
s/\bAUTHORATIVE\b/AUTHORITATIVE/g
s/\bAuthorative\b/Authoritative/g
s/\bauthorites\b/authorities/g
s/\bAUTHORITES\b/AUTHORITIES/g
s/\bAuthorites\b/Authorities/g
s/\bauthorithy\b/authority/g
s/\bAUTHORITHY\b/AUTHORITY/g
s/\bAuthorithy\b/Authority/g
s/\bauthoritiers\b/authorities/g
s/\bAUTHORITIERS\b/AUTHORITIES/g
s/\bAuthoritiers\b/Authorities/g
s/\bauthoritive\b/authoritative/g
s/\bAUTHORITIVE\b/AUTHORITATIVE/g
s/\bAuthoritive\b/Authoritative/g
s/\bauthrorities\b/authorities/g
s/\bAUTHRORITIES\b/AUTHORITIES/g
s/\bAuthrorities\b/Authorities/g
s/\bautochtonous\b/autochthonous/g
s/\bAUTOCHTONOUS\b/AUTOCHTHONOUS/g
s/\bAutochtonous\b/Autochthonous/g
s/\bautoctonous\b/autochthonous/g
s/\bAUTOCTONOUS\b/AUTOCHTHONOUS/g
s/\bAutoctonous\b/Autochthonous/g
s/\bautomaticly\b/automatically/g
s/\bAUTOMATICLY\b/AUTOMATICALLY/g
s/\bAutomaticly\b/Automatically/g
s/\bautomibile\b/automobile/g
s/\bAUTOMIBILE\b/AUTOMOBILE/g
s/\bAutomibile\b/Automobile/g
s/\bautomonomous\b/autonomous/g
s/\bAUTOMONOMOUS\b/AUTONOMOUS/g
s/\bAutomonomous\b/Autonomous/g
s/\bautor\b/author/g
s/\bAUTOR\b/AUTHOR/g
s/\bAutor\b/Author/g
s/\bautority\b/authority/g
s/\bAUTORITY\b/AUTHORITY/g
s/\bAutority\b/Authority/g
s/\bauxillaries\b/auxiliaries/g
s/\bAUXILLARIES\b/AUXILIARIES/g
s/\bAuxillaries\b/Auxiliaries/g
s/\bauxilliaries\b/auxiliaries/g
s/\bAUXILLIARIES\b/AUXILIARIES/g
s/\bAuxilliaries\b/Auxiliaries/g
s/\bavailaible\b/available/g
s/\bAVAILAIBLE\b/AVAILABLE/g
s/\bAvailaible\b/Available/g
s/\bavailiable\b/available/g
s/\bAVAILIABLE\b/AVAILABLE/g
s/\bAvailiable\b/Available/g
s/\bavailible\b/available/g
s/\bAVAILIBLE\b/AVAILABLE/g
s/\bAvailible\b/Available/g
s/\bavalable\b/available/g
s/\bAVALABLE\b/AVAILABLE/g
s/\bAvalable\b/Available/g
s/\bavalance\b/avalanche/g
s/\bAVALANCE\b/AVALANCHE/g
s/\bAvalance\b/Avalanche/g
s/\bavation\b/aviation/g
s/\bAVATION\b/AVIATION/g
s/\bAvation\b/Aviation/g
s/\bavengence\b/a vengeance/g
s/\bAVENGENCE\b/A VENGEANCE/g
s/\bAvengence\b/A vengeance/g
s/\baverageed\b/averaged/g
s/\bAVERAGEED\b/AVERAGED/g
s/\bAverageed\b/Averaged/g
s/\bavilable\b/available/g
s/\bAVILABLE\b/AVAILABLE/g
s/\bAvilable\b/Available/g
s/\bawared\b/awarded/g
s/\bAWARED\b/AWARDED/g
s/\bAwared\b/Awarded/g
s/\bawya\b/away/g
s/\bAWYA\b/AWAY/g
s/\bAwya\b/Away/g
s/\bbaceause\b/because/g
s/\bBACEAUSE\b/BECAUSE/g
s/\bBaceause\b/Because/g
s/\bbackgorund\b/background/g
s/\bBACKGORUND\b/BACKGROUND/g
s/\bBackgorund\b/Background/g
s/\bbackrounds\b/backgrounds/g
s/\bBACKROUNDS\b/BACKGROUNDS/g
s/\bBackrounds\b/Backgrounds/g
s/\bbakc\b/back/g
s/\bBAKC\b/BACK/g
s/\bBakc\b/Back/g
s/\bbanannas\b/bananas/g
s/\bBANANNAS\b/BANANAS/g
s/\bBanannas\b/Bananas/g
s/\bbandwith\b/bandwidth/g
s/\bBANDWITH\b/BANDWIDTH/g
s/\bBandwith\b/Bandwidth/g
s/\bbankrupcy\b/bankruptcy/g
s/\bBANKRUPCY\b/BANKRUPTCY/g
s/\bBankrupcy\b/Bankruptcy/g
s/\bbanruptcy\b/bankruptcy/g
s/\bBANRUPTCY\b/BANKRUPTCY/g
s/\bBanruptcy\b/Bankruptcy/g
s/\bbasicaly\b/basically/g
s/\bBASICALY\b/BASICALLY/g
s/\bBasicaly\b/Basically/g
s/\bbasicly\b/basically/g
s/\bBASICLY\b/BASICALLY/g
s/\bBasicly\b/Basically/g
s/\bbcak\b/back/g
s/\bBCAK\b/BACK/g
s/\bBcak\b/Back/g
s/\bbeachead\b/beachhead/g
s/\bBEACHEAD\b/BEACHHEAD/g
s/\bBeachead\b/Beachhead/g
s/\bbeastiality\b/bestiality/g
s/\bBEASTIALITY\b/BESTIALITY/g
s/\bBeastiality\b/Bestiality/g
s/\bbeatiful\b/beautiful/g
s/\bBEATIFUL\b/BEAUTIFUL/g
s/\bBeatiful\b/Beautiful/g
s/\bbeaurocracy\b/bureaucracy/g
s/\bBEAUROCRACY\b/BUREAUCRACY/g
s/\bBeaurocracy\b/Bureaucracy/g
s/\bbeaurocratic\b/bureaucratic/g
s/\bBEAUROCRATIC\b/BUREAUCRATIC/g
s/\bBeaurocratic\b/Bureaucratic/g
s/\bbeautyfull\b/beautiful/g
s/\bBEAUTYFULL\b/BEAUTIFUL/g
s/\bBeautyfull\b/Beautiful/g
s/\bbecamae\b/became/g
s/\bBECAMAE\b/BECAME/g
s/\bBecamae\b/Became/g
s/\bbeccause\b/because/g
s/\bBECCAUSE\b/BECAUSE/g
s/\bBeccause\b/Because/g
s/\bbecomeing\b/becoming/g
s/\bBECOMEING\b/BECOMING/g
s/\bBecomeing\b/Becoming/g
s/\bbecouse\b/because/g
s/\bBECOUSE\b/BECAUSE/g
s/\bBecouse\b/Because/g
s/\bbedore\b/before/g
s/\bBEDORE\b/BEFORE/g
s/\bBedore\b/Before/g
s/\bbefoer\b/before/g
s/\bBEFOER\b/BEFORE/g
s/\bBefoer\b/Before/g
s/\bbegginer\b/beginner/g
s/\bBEGGINER\b/BEGINNER/g
s/\bBegginer\b/Beginner/g
s/\bbegginers\b/beginners/g
s/\bBEGGINERS\b/BEGINNERS/g
s/\bBegginers\b/Beginners/g
s/\bbeggins\b/begins/g
s/\bBEGGINS\b/BEGINS/g
s/\bBeggins\b/Begins/g
s/\bbeleagured\b/beleaguered/g
s/\bBELEAGURED\b/BELEAGUERED/g
s/\bBeleagured\b/Beleaguered/g
s/\bbeleif\b/belief/g
s/\bBELEIF\b/BELIEF/g
s/\bBeleif\b/Belief/g
s/\bbeleive\b/believe/g
s/\bBELEIVE\b/BELIEVE/g
s/\bBeleive\b/Believe/g
s/\bbeleived\b/believed/g
s/\bBELEIVED\b/BELIEVED/g
s/\bBeleived\b/Believed/g
s/\bbeleives\b/believes/g
s/\bBELEIVES\b/BELIEVES/g
s/\bBeleives\b/Believes/g
s/\bbeleiving\b/believing/g
s/\bBELEIVING\b/BELIEVING/g
s/\bBeleiving\b/Believing/g
s/\bbeligum\b/belgium/g
s/\bBELIGUM\b/BELGIUM/g
s/\bBeligum\b/Belgium/g
s/\bbelive\b/believe/g
s/\bBELIVE\b/BELIEVE/g
s/\bBelive\b/Believe/g
s/\bbelligerant\b/belligerent/g
s/\bBELLIGERANT\b/BELLIGERENT/g
s/\bBelligerant\b/Belligerent/g
s/\bbellweather\b/bellwether/g
s/\bBELLWEATHER\b/BELLWETHER/g
s/\bBellweather\b/Bellwether/g
s/\bbemusemnt\b/bemusement/g
s/\bBEMUSEMNT\b/BEMUSEMENT/g
s/\bBemusemnt\b/Bemusement/g
s/\bbeneficary\b/beneficiary/g
s/\bBENEFICARY\b/BENEFICIARY/g
s/\bBeneficary\b/Beneficiary/g
s/\bbeng\b/being/g
s/\bBENG\b/BEING/g
s/\bBeng\b/Being/g
s/\bbenifit\b/benefit/g
s/\bBENIFIT\b/BENEFIT/g
s/\bBenifit\b/Benefit/g
s/\bbenifits\b/benefits/g
s/\bBENIFITS\b/BENEFITS/g
s/\bBenifits\b/Benefits/g
s/\bbergamont\b/bergamot/g
s/\bBERGAMONT\b/BERGAMOT/g
s/\bBergamont\b/Bergamot/g
s/\bbeseige\b/besiege/g
s/\bBESEIGE\b/BESIEGE/g
s/\bBeseige\b/Besiege/g
s/\bbeseiged\b/besieged/g
s/\bBESEIGED\b/BESIEGED/g
s/\bBeseiged\b/Besieged/g
s/\bbeseiging\b/besieging/g
s/\bBESEIGING\b/BESIEGING/g
s/\bBeseiging\b/Besieging/g
s/\bbeteen\b/between/g
s/\bBETEEN\b/BETWEEN/g
s/\bBeteen\b/Between/g
s/\bbeween\b/between/g
s/\bBEWEEN\b/BETWEEN/g
s/\bBeween\b/Between/g
s/\bbigining\b/beginning/g
s/\bBIGINING\b/BEGINNING/g
s/\bBigining\b/Beginning/g
s/\bbiginning\b/beginning/g
s/\bBIGINNING\b/BEGINNING/g
s/\bBiginning\b/Beginning/g
s/\bbilateraly\b/bilaterally/g
s/\bBILATERALY\b/BILATERALLY/g
s/\bBilateraly\b/Bilaterally/g
s/\bbillingualism\b/bilingualism/g
s/\bBILLINGUALISM\b/BILINGUALISM/g
s/\bBillingualism\b/Bilingualism/g
s/\bbinominal\b/binomial/g
s/\bBINOMINAL\b/BINOMIAL/g
s/\bBinominal\b/Binomial/g
s/\bbizzare\b/bizarre/g
s/\bBIZZARE\b/BIZARRE/g
s/\bBizzare\b/Bizarre/g
s/\bblaim\b/blame/g
s/\bBLAIM\b/BLAME/g
s/\bBlaim\b/Blame/g
s/\bblaimed\b/blamed/g
s/\bBLAIMED\b/BLAMED/g
s/\bBlaimed\b/Blamed/g
s/\bblessure\b/blessing/g
s/\bBLESSURE\b/BLESSING/g
s/\bBlessure\b/Blessing/g
s/\bbodydbuilder\b/bodybuilder/g
s/\bBODYDBUILDER\b/BODYBUILDER/g
s/\bBodydbuilder\b/Bodybuilder/g
s/\bbombardement\b/bombardment/g
s/\bBOMBARDEMENT\b/BOMBARDMENT/g
s/\bBombardement\b/Bombardment/g
s/\bbombarment\b/bombardment/g
s/\bBOMBARMENT\b/BOMBARDMENT/g
s/\bBombarment\b/Bombardment/g
s/\bbondary\b/boundary/g
s/\bBONDARY\b/BOUNDARY/g
s/\bBondary\b/Boundary/g
s/\bboook\b/book/g
s/\bBOOOK\b/BOOK/g
s/\bBoook\b/Book/g
s/\bborke\b/broke/g
s/\bBORKE\b/BROKE/g
s/\bBorke\b/Broke/g
s/\bboundry\b/boundary/g
s/\bBOUNDRY\b/BOUNDARY/g
s/\bBoundry\b/Boundary/g
s/\bbouyancy\b/buoyancy/g
s/\bBOUYANCY\b/BUOYANCY/g
s/\bBouyancy\b/Buoyancy/g
s/\bbouyant\b/buoyant/g
s/\bBOUYANT\b/BUOYANT/g
s/\bBouyant\b/Buoyant/g
s/\bboyant\b/buoyant/g
s/\bBOYANT\b/BUOYANT/g
s/\bBoyant\b/Buoyant/g
s/\bbreakthough\b/breakthrough/g
s/\bBREAKTHOUGH\b/BREAKTHROUGH/g
s/\bBreakthough\b/Breakthrough/g
s/\bbreakthroughts\b/breakthroughs/g
s/\bBREAKTHROUGHTS\b/BREAKTHROUGHS/g
s/\bBreakthroughts\b/Breakthroughs/g
s/\bbreif\b/brief/g
s/\bBREIF\b/BRIEF/g
s/\bBreif\b/Brief/g
s/\bbreifly\b/briefly/g
s/\bBREIFLY\b/BRIEFLY/g
s/\bBreifly\b/Briefly/g
s/\bbrethen\b/brethren/g
s/\bBRETHEN\b/BRETHREN/g
s/\bBrethen\b/Brethren/g
s/\bbretheren\b/brethren/g
s/\bBRETHEREN\b/BRETHREN/g
s/\bBretheren\b/Brethren/g
s/\bbriliant\b/brilliant/g
s/\bBRILIANT\b/BRILLIANT/g
s/\bBriliant\b/Brilliant/g
s/\bbrillant\b/brilliant/g
s/\bBRILLANT\b/BRILLIANT/g
s/\bBrillant\b/Brilliant/g
s/\bbrimestone\b/brimstone/g
s/\bBRIMESTONE\b/BRIMSTONE/g
s/\bBrimestone\b/Brimstone/g
s/\bbroacasted\b/broadcast/g
s/\bBROACASTED\b/BROADCAST/g
s/\bBroacasted\b/Broadcast/g
s/\bbroadacasting\b/broadcasting/g
s/\bBROADACASTING\b/BROADCASTING/g
s/\bBroadacasting\b/Broadcasting/g
s/\bbroady\b/broadly/g
s/\bBROADY\b/BROADLY/g
s/\bBroady\b/Broadly/g
s/\bbuisness\b/business/g
s/\bBUISNESS\b/BUSINESS/g
s/\bBuisness\b/Business/g
s/\bbuisnessman\b/businessman/g
s/\bBUISNESSMAN\b/BUSINESSMAN/g
s/\bBuisnessman\b/Businessman/g
s/\bbuoancy\b/buoyancy/g
s/\bBUOANCY\b/BUOYANCY/g
s/\bBuoancy\b/Buoyancy/g
s/\bburried\b/buried/g
s/\bBURRIED\b/BURIED/g
s/\bBurried\b/Buried/g
s/\bbusines\b/business/g
s/\bBUSINES\b/BUSINESS/g
s/\bBusines\b/Business/g
s/\bbusness\b/business/g
s/\bBUSNESS\b/BUSINESS/g
s/\bBusness\b/Business/g
s/\bbussiness\b/business/g
s/\bBUSSINESS\b/BUSINESS/g
s/\bBussiness\b/Business/g
s/\bcaculater\b/calculator/g
s/\bCACULATER\b/CALCULATOR/g
s/\bCaculater\b/Calculator/g
s/\bcacuses\b/caucuses/g
s/\bCACUSES\b/CAUCUSES/g
s/\bCacuses\b/Caucuses/g
s/\bcahracters\b/characters/g
s/\bCAHRACTERS\b/CHARACTERS/g
s/\bCahracters\b/Characters/g
s/\bcalaber\b/caliber/g
s/\bCALABER\b/CALIBER/g
s/\bCalaber\b/Caliber/g
s/\bcalculater\b/calculator/g
s/\bCALCULATER\b/CALCULATOR/g
s/\bCalculater\b/Calculator/g
s/\bcalculs\b/calculus/g
s/\bCALCULS\b/CALCULUS/g
s/\bCalculs\b/Calculus/g
s/\bcalenders\b/calendars/g
s/\bCALENDERS\b/CALENDARS/g
s/\bCalenders\b/Calendars/g
s/\bcaligraphy\b/calligraphy/g
s/\bCALIGRAPHY\b/CALLIGRAPHY/g
s/\bCaligraphy\b/Calligraphy/g
s/\bcaling/calling/g
s/\bCALING/CALLING/g
s/\bCaling/Calling/g
s/\bcaluclate\b/calculate/g
s/\bCALUCLATE\b/CALCULATE/g
s/\bCaluclate\b/Calculate/g
s/\bcaluclated\b/calculated/g
s/\bCALUCLATED\b/CALCULATED/g
s/\bCaluclated\b/Calculated/g
s/\bcaluculate\b/calculate/g
s/\bCALUCULATE\b/CALCULATE/g
s/\bCaluculate\b/Calculate/g
s/\bcaluculated\b/calculated/g
s/\bCALUCULATED\b/CALCULATED/g
s/\bCaluculated\b/Calculated/g
s/\bcalulate\b/calculate/g
s/\bCALULATE\b/CALCULATE/g
s/\bCalulate\b/Calculate/g
s/\bcalulated\b/calculated/g
s/\bCALULATED\b/CALCULATED/g
s/\bCalulated\b/Calculated/g
s/\bcalulater\b/calculator/g
s/\bCALULATER\b/CALCULATOR/g
s/\bCalulater\b/Calculator/g
s/\bcamoflage\b/camouflage/g
s/\bCAMOFLAGE\b/CAMOUFLAGE/g
s/\bCamoflage\b/Camouflage/g
s/\bcampagin\b/campaign/g
s/\bCAMPAGIN\b/CAMPAIGN/g
s/\bCampagin\b/Campaign/g
s/\bcampain\b/campaign/g
s/\bCAMPAIN\b/CAMPAIGN/g
s/\bCampain\b/Campaign/g
s/\bcampains\b/campaigns/g
s/\bCAMPAINS\b/CAMPAIGNS/g
s/\bCampains\b/Campaigns/g
s/\bcandadate\b/candidate/g
s/\bCANDADATE\b/CANDIDATE/g
s/\bCandadate\b/Candidate/g
s/\bcandiate\b/candidate/g
s/\bCANDIATE\b/CANDIDATE/g
s/\bCandiate\b/Candidate/g
s/\bcandidiate\b/candidate/g
s/\bCANDIDIATE\b/CANDIDATE/g
s/\bCandidiate\b/Candidate/g
s/\bcannister\b/canister/g
s/\bCANNISTER\b/CANISTER/g
s/\bCannister\b/Canister/g
s/\bcannisters\b/canisters/g
s/\bCANNISTERS\b/CANISTERS/g
s/\bCannisters\b/Canisters/g
s/\bcannnot\b/cannot/g
s/\bCANNNOT\b/CANNOT/g
s/\bCannnot\b/Cannot/g
s/\bcannonical\b/canonical/g
s/\bCANNONICAL\b/CANONICAL/g
s/\bCannonical\b/Canonical/g
s/\bcannotation\b/connotation/g
s/\bCANNOTATION\b/CONNOTATION/g
s/\bCannotation\b/Connotation/g
s/\bcannotations\b/connotations/g
s/\bCANNOTATIONS\b/CONNOTATIONS/g
s/\bCannotations\b/Connotations/g
s/\bcaost\b/coast/g
s/\bCAOST\b/COAST/g
s/\bCaost\b/Coast/g
s/\bcaperbility\b/capability/g
s/\bCAPERBILITY\b/CAPABILITY/g
s/\bCaperbility\b/Capability/g
s/\bcapible\b/capable/g
s/\bCAPIBLE\b/CAPABLE/g
s/\bCapible\b/Capable/g
s/\bcaptial\b/capital/g
s/\bCAPTIAL\b/CAPITAL/g
s/\bCaptial\b/Capital/g
s/\bcaptued\b/captured/g
s/\bCAPTUED\b/CAPTURED/g
s/\bCaptued\b/Captured/g
s/\bcapturd\b/captured/g
s/\bCAPTURD\b/CAPTURED/g
s/\bCapturd\b/Captured/g
s/\bcarachter\b/character/g
s/\bCARACHTER\b/CHARACTER/g
s/\bCarachter\b/Character/g
s/\bcaracterized\b/characterized/g
s/\bCARACTERIZED\b/CHARACTERIZED/g
s/\bCaracterized\b/Characterized/g
s/\bcareing\b/caring/g
s/\bCAREING\b/CARING/g
s/\bCareing\b/Caring/g
s/\bcarismatic\b/charismatic/g
s/\bCARISMATIC\b/CHARISMATIC/g
s/\bCarismatic\b/Charismatic/g
s/\bcarniverous\b/carnivorous/g
s/\bCARNIVEROUS\b/CARNIVOROUS/g
s/\bCarniverous\b/Carnivorous/g
s/\bcarreer\b/career/g
s/\bCARREER\b/CAREER/g
s/\bCarreer\b/Career/g
s/\bcarrers\b/careers/g
s/\bCARRERS\b/CAREERS/g
s/\bCarrers\b/Careers/g
s/\bcartdridge\b/cartridge/g
s/\bCARTDRIDGE\b/CARTRIDGE/g
s/\bCartdridge\b/Cartridge/g
s/\bcarthographer\b/cartographer/g
s/\bCARTHOGRAPHER\b/CARTOGRAPHER/g
s/\bCarthographer\b/Cartographer/g
s/\bcartilege\b/cartilage/g
s/\bCARTILEGE\b/CARTILAGE/g
s/\bCartilege\b/Cartilage/g
s/\bcartilidge\b/cartilage/g
s/\bCARTILIDGE\b/CARTILAGE/g
s/\bCartilidge\b/Cartilage/g
s/\bcartrige\b/cartridge/g
s/\bCARTRIGE\b/CARTRIDGE/g
s/\bCartrige\b/Cartridge/g
s/\bcasette\b/cassette/g
s/\bCASETTE\b/CASSETTE/g
s/\bCasette\b/Cassette/g
s/\bcasion\b/caisson/g
s/\bCASION\b/CAISSON/g
s/\bCasion\b/Caisson/g
s/\bcassawory\b/cassowary/g
s/\bCASSAWORY\b/CASSOWARY/g
s/\bCassawory\b/Cassowary/g
s/\bcassowarry\b/cassowary/g
s/\bCASSOWARRY\b/CASSOWARY/g
s/\bCassowarry\b/Cassowary/g
s/\bcasue\b/cause/g
s/\bCASUE\b/CAUSE/g
s/\bCasue\b/Cause/g
s/\bcasued\b/caused/g
s/\bCASUED\b/CAUSED/g
s/\bCasued\b/Caused/g
s/\bcasues\b/causes/g
s/\bCASUES\b/CAUSES/g
s/\bCasues\b/Causes/g
s/\bcasuing\b/causing/g
s/\bCASUING\b/CAUSING/g
s/\bCasuing\b/Causing/g
s/\bcasulaties\b/casualties/g
s/\bCASULATIES\b/CASUALTIES/g
s/\bCasulaties\b/Casualties/g
s/\bcasulaty\b/casualty/g
s/\bCASULATY\b/CASUALTY/g
s/\bCasulaty\b/Casualty/g
s/\bcatapillar\b/caterpillar/g
s/\bCATAPILLAR\b/CATERPILLAR/g
s/\bCatapillar\b/Caterpillar/g
s/\bcatapillars\b/caterpillars/g
s/\bCATAPILLARS\b/CATERPILLARS/g
s/\bCatapillars\b/Caterpillars/g
s/\bcatapiller\b/caterpillar/g
s/\bCATAPILLER\b/CATERPILLAR/g
s/\bCatapiller\b/Caterpillar/g
s/\bcatapillers\b/caterpillars/g
s/\bCATAPILLERS\b/CATERPILLARS/g
s/\bCatapillers\b/Caterpillars/g
s/\bcatepillar\b/caterpillar/g
s/\bCATEPILLAR\b/CATERPILLAR/g
s/\bCatepillar\b/Caterpillar/g
s/\bcatepillars\b/caterpillars/g
s/\bCATEPILLARS\b/CATERPILLARS/g
s/\bCatepillars\b/Caterpillars/g
s/\bcatergorize\b/categorize/g
s/\bCATERGORIZE\b/CATEGORIZE/g
s/\bCatergorize\b/Categorize/g
s/\bcatergorized\b/categorized/g
s/\bCATERGORIZED\b/CATEGORIZED/g
s/\bCatergorized\b/Categorized/g
s/\bcaterpilar\b/caterpillar/g
s/\bCATERPILAR\b/CATERPILLAR/g
s/\bCaterpilar\b/Caterpillar/g
s/\bcaterpilars\b/caterpillars/g
s/\bCATERPILARS\b/CATERPILLARS/g
s/\bCaterpilars\b/Caterpillars/g
s/\bcaterpiller\b/caterpillar/g
s/\bCATERPILLER\b/CATERPILLAR/g
s/\bCaterpiller\b/Caterpillar/g
s/\bcaterpillers\b/caterpillars/g
s/\bCATERPILLERS\b/CATERPILLARS/g
s/\bCaterpillers\b/Caterpillars/g
s/\bcathlic\b/catholic/g
s/\bCATHLIC\b/CATHOLIC/g
s/\bCathlic\b/Catholic/g
s/\bcatholocism\b/catholicism/g
s/\bCATHOLOCISM\b/CATHOLICISM/g
s/\bCatholocism\b/Catholicism/g
s/\bcatterpilar\b/caterpillar/g
s/\bCATTERPILAR\b/CATERPILLAR/g
s/\bCatterpilar\b/Caterpillar/g
s/\bcatterpilars\b/caterpillars/g
s/\bCATTERPILARS\b/CATERPILLARS/g
s/\bCatterpilars\b/Caterpillars/g
s/\bcatterpillar\b/caterpillar/g
s/\bCATTERPILLAR\b/CATERPILLAR/g
s/\bCatterpillar\b/Caterpillar/g
s/\bcatterpillars\b/caterpillars/g
s/\bCATTERPILLARS\b/CATERPILLARS/g
s/\bCatterpillars\b/Caterpillars/g
s/\bcattleship\b/battleship/g
s/\bCATTLESHIP\b/BATTLESHIP/g
s/\bCattleship\b/Battleship/g
s/\bcellpading\b/cellpadding/g
s/\bCELLPADING\b/CELLPADDING/g
s/\bCellpading\b/Cellpadding/g
s/\bcementary\b/cemetery/g
s/\bCEMENTARY\b/CEMETERY/g
s/\bCementary\b/Cemetery/g
s/\bcemetarey\b/cemetery/g
s/\bCEMETAREY\b/CEMETERY/g
s/\bCemetarey\b/Cemetery/g
s/\bcemetaries\b/cemeteries/g
s/\bCEMETARIES\b/CEMETERIES/g
s/\bCemetaries\b/Cemeteries/g
s/\bcemetary\b/cemetery/g
s/\bCEMETARY\b/CEMETERY/g
s/\bCemetary\b/Cemetery/g
s/\bcencus\b/census/g
s/\bCENCUS\b/CENSUS/g
s/\bCencus\b/Census/g
s/\bcententenial\b/centennial/g
s/\bCENTENTENIAL\b/CENTENNIAL/g
s/\bCententenial\b/Centennial/g
s/\bcentruies\b/centuries/g
s/\bCENTRUIES\b/CENTURIES/g
s/\bCentruies\b/Centuries/g
s/\bcentruy\b/century/g
s/\bCENTRUY\b/CENTURY/g
s/\bCentruy\b/Century/g
s/\bcentuties\b/centuries/g
s/\bCENTUTIES\b/CENTURIES/g
s/\bCentuties\b/Centuries/g
s/\bcentuty\b/century/g
s/\bCENTUTY\b/CENTURY/g
s/\bCentuty\b/Century/g
s/\bcerimonial\b/ceremonial/g
s/\bCERIMONIAL\b/CEREMONIAL/g
s/\bCerimonial\b/Ceremonial/g
s/\bcerimonies\b/ceremonies/g
s/\bCERIMONIES\b/CEREMONIES/g
s/\bCerimonies\b/Ceremonies/g
s/\bcerimonious\b/ceremonious/g
s/\bCERIMONIOUS\b/CEREMONIOUS/g
s/\bCerimonious\b/Ceremonious/g
s/\bcerimony\b/ceremony/g
s/\bCERIMONY\b/CEREMONY/g
s/\bCerimony\b/Ceremony/g
s/\bceromony\b/ceremony/g
s/\bCEROMONY\b/CEREMONY/g
s/\bCeromony\b/Ceremony/g
s/\bcertainity\b/certainty/g
s/\bCERTAINITY\b/CERTAINTY/g
s/\bCertainity\b/Certainty/g
s/\bcertian\b/certain/g
s/\bCERTIAN\b/CERTAIN/g
s/\bCertian\b/Certain/g
s/\bchalenging\b/challenging/g
s/\bCHALENGING\b/CHALLENGING/g
s/\bChalenging\b/Challenging/g
s/\bchallange\b/challenge/g
s/\bCHALLANGE\b/CHALLENGE/g
s/\bChallange\b/Challenge/g
s/\bchallanged\b/challenged/g
s/\bCHALLANGED\b/CHALLENGED/g
s/\bChallanged\b/Challenged/g
s/\bchallege\b/challenge/g
s/\bCHALLEGE\b/CHALLENGE/g
s/\bChallege\b/Challenge/g
s/\bcharachter\b/character/g
s/\bCHARACHTER\b/CHARACTER/g
s/\bCharachter\b/Character/g
s/\bcharactersistic\b/characteristic/g
s/\bCHARACTERSISTIC\b/CHARACTERISTIC/g
s/\bCharactersistic\b/Characteristic/g
s/\bcharactors\b/characters/g
s/\bCHARACTORS\b/CHARACTERS/g
s/\bCharactors\b/Characters/g
s/\bcharasmatic\b/charismatic/g
s/\bCHARASMATIC\b/CHARISMATIC/g
s/\bCharasmatic\b/Charismatic/g
s/\bcharaterized\b/characterized/g
s/\bCHARATERIZED\b/CHARACTERIZED/g
s/\bCharaterized\b/Characterized/g
s/\bchariman\b/chairman/g
s/\bCHARIMAN\b/CHAIRMAN/g
s/\bChariman\b/Chairman/g
s/\bcharistics\b/characteristics/g
s/\bCHARISTICS\b/CHARACTERISTICS/g
s/\bCharistics\b/Characteristics/g
s/\bcheif\b/chief/g
s/\bCHEIF\b/CHIEF/g
s/\bCheif\b/Chief/g
s/\bcheifs\b/chiefs/g
s/\bCHEIFS\b/CHIEFS/g
s/\bCheifs\b/Chiefs/g
s/\bchemcial\b/chemical/g
s/\bCHEMCIAL\b/CHEMICAL/g
s/\bChemcial\b/Chemical/g
s/\bchemcially\b/chemically/g
s/\bCHEMCIALLY\b/CHEMICALLY/g
s/\bChemcially\b/Chemically/g
s/\bchemestry\b/chemistry/g
s/\bCHEMESTRY\b/CHEMISTRY/g
s/\bChemestry\b/Chemistry/g
s/\bchemicaly\b/chemically/g
s/\bCHEMICALY\b/CHEMICALLY/g
s/\bChemicaly\b/Chemically/g
s/\bchildbird\b/childbirth/g
s/\bCHILDBIRD\b/CHILDBIRTH/g
s/\bChildbird\b/Childbirth/g
s/\bchuch\b/church/g
s/\bCHUCH\b/CHURCH/g
s/\bChuch\b/Church/g
s/\bchurchs\b/churches/g
s/\bCHURCHS\b/CHURCHES/g
s/\bChurchs\b/Churches/g
s/\bcirculaton\b/circulation/g
s/\bCIRCULATON\b/CIRCULATION/g
s/\bCirculaton\b/Circulation/g
s/\bcircumsicion\b/circumcision/g
s/\bCIRCUMSICION\b/CIRCUMCISION/g
s/\bCircumsicion\b/Circumcision/g
s/\bcircut\b/circuit/g
s/\bCIRCUT\b/CIRCUIT/g
s/\bCircut\b/Circuit/g
s/\bciricuit\b/circuit/g
s/\bCIRICUIT\b/CIRCUIT/g
s/\bCiricuit\b/Circuit/g
s/\bciriculum\b/curriculum/g
s/\bCIRICULUM\b/CURRICULUM/g
s/\bCiriculum\b/Curriculum/g
s/\bcivillian\b/civilian/g
s/\bCIVILLIAN\b/CIVILIAN/g
s/\bCivillian\b/Civilian/g
s/\bclaer\b/clear/g
s/\bCLAER\b/CLEAR/g
s/\bClaer\b/Clear/g
s/\bclaerer\b/clearer/g
s/\bCLAERER\b/CLEARER/g
s/\bClaerer\b/Clearer/g
s/\bclaerly\b/clearly/g
s/\bCLAERLY\b/CLEARLY/g
s/\bClaerly\b/Clearly/g
s/\bclaimes\b/claims/g
s/\bCLAIMES\b/CLAIMS/g
s/\bClaimes\b/Claims/g
s/\bclas\b/class/g
s/\bCLAS\b/CLASS/g
s/\bClas\b/Class/g
s/\bclasic\b/classic/g
s/\bCLASIC\b/CLASSIC/g
s/\bClasic\b/Classic/g
s/\bclasical\b/classical/g
s/\bCLASICAL\b/CLASSICAL/g
s/\bClasical\b/Classical/g
s/\bclasically\b/classically/g
s/\bCLASICALLY\b/CLASSICALLY/g
s/\bClasically\b/Classically/g
s/\bcleareance\b/clearance/g
s/\bCLEAREANCE\b/CLEARANCE/g
s/\bCleareance\b/Clearance/g
s/\bclincial\b/clinical/g
s/\bCLINCIAL\b/CLINICAL/g
s/\bClincial\b/Clinical/g
s/\bclinicaly\b/clinically/g
s/\bCLINICALY\b/CLINICALLY/g
s/\bClinicaly\b/Clinically/g
s/\bcmo\b/com/g
s/\bCMO\b/COM/g
s/\bCmo\b/Com/g
s/\bcmoputer\b/computer/g
s/\bCMOPUTER\b/COMPUTER/g
s/\bCmoputer\b/Computer/g
s/\bco-incided\b/coincided/g
s/\bCO-INCIDED\b/COINCIDED/g
s/\bCo-incided\b/Coincided/g
s/\bcoctail\b/cocktail/g
s/\bCOCTAIL\b/COCKTAIL/g
s/\bCoctail\b/Cocktail/g
s/\bcoform\b/conform/g
s/\bCOFORM\b/CONFORM/g
s/\bCoform\b/Conform/g
s/\bcognizent\b/cognizant/g
s/\bCOGNIZENT\b/COGNIZANT/g
s/\bCognizent\b/Cognizant/g
s/\bcoincedentally\b/coincidentally/g
s/\bCOINCEDENTALLY\b/COINCIDENTALLY/g
s/\bCoincedentally\b/Coincidentally/g
s/\bcolaborations\b/collaborations/g
s/\bCOLABORATIONS\b/COLLABORATIONS/g
s/\bColaborations\b/Collaborations/g
s/\bcolateral\b/collateral/g
s/\bCOLATERAL\b/COLLATERAL/g
s/\bColateral\b/Collateral/g
s/\bcolelctive\b/collective/g
s/\bCOLELCTIVE\b/COLLECTIVE/g
s/\bColelctive\b/Collective/g
s/\bcollaberative\b/collaborative/g
s/\bCOLLABERATIVE\b/COLLABORATIVE/g
s/\bCollaberative\b/Collaborative/g
s/\bcollecton\b/collection/g
s/\bCOLLECTON\b/COLLECTION/g
s/\bCollecton\b/Collection/g
s/\bcollegue\b/colleague/g
s/\bCOLLEGUE\b/COLLEAGUE/g
s/\bCollegue\b/Colleague/g
s/\bcollegues\b/colleagues/g
s/\bCOLLEGUES\b/COLLEAGUES/g
s/\bCollegues\b/Colleagues/g
s/\bcollonade\b/colonnade/g
s/\bCOLLONADE\b/COLONNADE/g
s/\bCollonade\b/Colonnade/g
s/\bcollonies\b/colonies/g
s/\bCOLLONIES\b/COLONIES/g
s/\bCollonies\b/Colonies/g
s/\bcollony\b/colony/g
s/\bCOLLONY\b/COLONY/g
s/\bCollony\b/Colony/g
s/\bcollosal\b/colossal/g
s/\bCOLLOSAL\b/COLOSSAL/g
s/\bCollosal\b/Colossal/g
s/\bcolonizators\b/colonizers/g
s/\bCOLONIZATORS\b/COLONIZERS/g
s/\bColonizators\b/Colonizers/g
s/\bcomando\b/commando/g
s/\bCOMANDO\b/COMMANDO/g
s/\bComando\b/Commando/g
s/\bcomandos\b/commandos/g
s/\bCOMANDOS\b/COMMANDOS/g
s/\bComandos\b/Commandos/g
s/\bcomany\b/company/g
s/\bCOMANY\b/COMPANY/g
s/\bComany\b/Company/g
s/\bcomapany\b/company/g
s/\bCOMAPANY\b/COMPANY/g
s/\bComapany\b/Company/g
s/\bcomback\b/comeback/g
s/\bCOMBACK\b/COMEBACK/g
s/\bComback\b/Comeback/g
s/\bcombanations\b/combinations/g
s/\bCOMBANATIONS\b/COMBINATIONS/g
s/\bCombanations\b/Combinations/g
s/\bcombinatins\b/combinations/g
s/\bCOMBINATINS\b/COMBINATIONS/g
s/\bCombinatins\b/Combinations/g
s/\bcombusion\b/combustion/g
s/\bCOMBUSION\b/COMBUSTION/g
s/\bCombusion\b/Combustion/g
s/\bcomdemnation\b/condemnation/g
s/\bCOMDEMNATION\b/CONDEMNATION/g
s/\bComdemnation\b/Condemnation/g
s/\bcomemmorates\b/commemorates/g
s/\bCOMEMMORATES\b/COMMEMORATES/g
s/\bComemmorates\b/Commemorates/g
s/\bcomemoretion\b/commemoration/g
s/\bCOMEMORETION\b/COMMEMORATION/g
s/\bComemoretion\b/Commemoration/g
s/\bcomision\b/commission/g
s/\bCOMISION\b/COMMISSION/g
s/\bComision\b/Commission/g
s/\bcomisioned\b/commissioned/g
s/\bCOMISIONED\b/COMMISSIONED/g
s/\bComisioned\b/Commissioned/g
s/\bcomisioner\b/commissioner/g
s/\bCOMISIONER\b/COMMISSIONER/g
s/\bComisioner\b/Commissioner/g
s/\bcomisioning\b/commissioning/g
s/\bCOMISIONING\b/COMMISSIONING/g
s/\bComisioning\b/Commissioning/g
s/\bcomisions\b/commissions/g
s/\bCOMISIONS\b/COMMISSIONS/g
s/\bComisions\b/Commissions/g
s/\bcomission\b/commission/g
s/\bCOMISSION\b/COMMISSION/g
s/\bComission\b/Commission/g
s/\bcomissioned\b/commissioned/g
s/\bCOMISSIONED\b/COMMISSIONED/g
s/\bComissioned\b/Commissioned/g
s/\bcomissioner\b/commissioner/g
s/\bCOMISSIONER\b/COMMISSIONER/g
s/\bComissioner\b/Commissioner/g
s/\bcomissioning\b/commissioning/g
s/\bCOMISSIONING\b/COMMISSIONING/g
s/\bComissioning\b/Commissioning/g
s/\bcomissions\b/commissions/g
s/\bCOMISSIONS\b/COMMISSIONS/g
s/\bComissions\b/Commissions/g
s/\bcomited\b/committed/g
s/\bCOMITED\b/COMMITTED/g
s/\bComited\b/Committed/g
s/\bcomiting\b/committing/g
s/\bCOMITING\b/COMMITTING/g
s/\bComiting\b/Committing/g
s/\bcomitted\b/committed/g
s/\bCOMITTED\b/COMMITTED/g
s/\bComitted\b/Committed/g
s/\bcomittee\b/committee/g
s/\bCOMITTEE\b/COMMITTEE/g
s/\bComittee\b/Committee/g
s/\bcomitting\b/committing/g
s/\bCOMITTING\b/COMMITTING/g
s/\bComitting\b/Committing/g
s/\bcommandoes\b/commandos/g
s/\bCOMMANDOES\b/COMMANDOS/g
s/\bCommandoes\b/Commandos/g
s/\bcommedic\b/comedic/g
s/\bCOMMEDIC\b/COMEDIC/g
s/\bCommedic\b/Comedic/g
s/\bcommemerative\b/commemorative/g
s/\bCOMMEMERATIVE\b/COMMEMORATIVE/g
s/\bCommemerative\b/Commemorative/g
s/\bcommemmorate\b/commemorate/g
s/\bCOMMEMMORATE\b/COMMEMORATE/g
s/\bCommemmorate\b/Commemorate/g
s/\bcommemmorating\b/commemorating/g
s/\bCOMMEMMORATING\b/COMMEMORATING/g
s/\bCommemmorating\b/Commemorating/g
s/\bcommerical\b/commercial/g
s/\bCOMMERICAL\b/COMMERCIAL/g
s/\bCommerical\b/Commercial/g
s/\bcommerically\b/commercially/g
s/\bCOMMERICALLY\b/COMMERCIALLY/g
s/\bCommerically\b/Commercially/g
s/\bcommericial\b/commercial/g
s/\bCOMMERICIAL\b/COMMERCIAL/g
s/\bCommericial\b/Commercial/g
s/\bcommericially\b/commercially/g
s/\bCOMMERICIALLY\b/COMMERCIALLY/g
s/\bCommericially\b/Commercially/g
s/\bcommerorative\b/commemorative/g
s/\bCOMMERORATIVE\b/COMMEMORATIVE/g
s/\bCommerorative\b/Commemorative/g
s/\bcomminication\b/communication/g
s/\bCOMMINICATION\b/COMMUNICATION/g
s/\bComminication\b/Communication/g
s/\bcommision\b/commission/g
s/\bCOMMISION\b/COMMISSION/g
s/\bCommision\b/Commission/g
s/\bcommisioned\b/commissioned/g
s/\bCOMMISIONED\b/COMMISSIONED/g
s/\bCommisioned\b/Commissioned/g
s/\bcommisioner\b/commissioner/g
s/\bCOMMISIONER\b/COMMISSIONER/g
s/\bCommisioner\b/Commissioner/g
s/\bcommisioning\b/commissioning/g
s/\bCOMMISIONING\b/COMMISSIONING/g
s/\bCommisioning\b/Commissioning/g
s/\bcommisions\b/commissions/g
s/\bCOMMISIONS\b/COMMISSIONS/g
s/\bCommisions\b/Commissions/g
s/\bcommitee\b/committee/g
s/\bCOMMITEE\b/COMMITTEE/g
s/\bCommitee\b/Committee/g
s/\bcommiting\b/committing/g
s/\bCOMMITING\b/COMMITTING/g
s/\bCommiting\b/Committing/g
s/\bcommitte\b/committee/g
s/\bCOMMITTE\b/COMMITTEE/g
s/\bCommitte\b/Committee/g
s/\bcommittment\b/commitment/g
s/\bCOMMITTMENT\b/COMMITMENT/g
s/\bCommittment\b/Commitment/g
s/\bcommittments\b/commitments/g
s/\bCOMMITTMENTS\b/COMMITMENTS/g
s/\bCommittments\b/Commitments/g
s/\bcommmemorated\b/commemorated/g
s/\bCOMMMEMORATED\b/COMMEMORATED/g
s/\bCommmemorated\b/Commemorated/g
s/\bcommongly\b/commonly/g
s/\bCOMMONGLY\b/COMMONLY/g
s/\bCommongly\b/Commonly/g
s/\bcommonweath\b/commonwealth/g
s/\bCOMMONWEATH\b/COMMONWEALTH/g
s/\bCommonweath\b/Commonwealth/g
s/\bcommuications\b/communications/g
s/\bCOMMUICATIONS\b/COMMUNICATIONS/g
s/\bCommuications\b/Communications/g
s/\bcommuinications\b/communications/g
s/\bCOMMUINICATIONS\b/COMMUNICATIONS/g
s/\bCommuinications\b/Communications/g
s/\bcommunciation\b/communication/g
s/\bCOMMUNCIATION\b/COMMUNICATION/g
s/\bCommunciation\b/Communication/g
s/\bcommuniation\b/communication/g
s/\bCOMMUNIATION\b/COMMUNICATION/g
s/\bCommuniation\b/Communication/g
s/\bcommunites\b/communities/g
s/\bCOMMUNITES\b/COMMUNITIES/g
s/\bCommunites\b/Communities/g
s/\bcomparitive\b/comparative/g
s/\bCOMPARITIVE\b/COMPARATIVE/g
s/\bComparitive\b/Comparative/g
s/\bcomparitively\b/comparatively/g
s/\bCOMPARITIVELY\b/COMPARATIVELY/g
s/\bComparitively\b/Comparatively/g
s/\bcompatabilities\b/compatibilities/g
s/\bCOMPATABILITIES\b/COMPATIBILITIES/g
s/\bCompatabilities\b/Compatibilities/g
s/\bcompatable\b/compatible/g
s/\bCOMPATABLE\b/COMPATIBLE/g
s/\bCompatable\b/Compatible/g
s/\bcompatablities\b/compatibilities/g
s/\bCOMPATABLITIES\b/COMPATIBILITIES/g
s/\bCompatablities\b/Compatibilities/g
s/\bcompatablity\b/compatibility/g
s/\bCOMPATABLITY\b/COMPATIBILITY/g
s/\bCompatablity\b/Compatibility/g
s/\bcompatiblities\b/compatibilities/g
s/\bCOMPATIBLITIES\b/COMPATIBILITIES/g
s/\bCompatiblities\b/Compatibilities/g
s/\bcompeitions\b/competitions/g
s/\bCOMPEITIONS\b/COMPETITIONS/g
s/\bCompeitions\b/Competitions/g
s/\bcompensantion\b/compensation/g
s/\bCOMPENSANTION\b/COMPENSATION/g
s/\bCompensantion\b/Compensation/g
s/\bcompetance\b/competence/g
s/\bCOMPETANCE\b/COMPETENCE/g
s/\bCompetance\b/Competence/g
s/\bcompetant\b/competent/g
s/\bCOMPETANT\b/COMPETENT/g
s/\bCompetant\b/Competent/g
s/\bcompetative\b/competitive/g
s/\bCOMPETATIVE\b/COMPETITIVE/g
s/\bCompetative\b/Competitive/g
s/\bcompetitiion\b/competition/g
s/\bCOMPETITIION\b/COMPETITION/g
s/\bCompetitiion\b/Competition/g
s/\bcompetive\b/competitive/g
s/\bCOMPETIVE\b/COMPETITIVE/g
s/\bCompetive\b/Competitive/g
s/\bcompetiveness\b/competitiveness/g
s/\bCOMPETIVENESS\b/COMPETITIVENESS/g
s/\bCompetiveness\b/Competitiveness/g
s/\bcomphrehensive\b/comprehensive/g
s/\bCOMPHREHENSIVE\b/COMPREHENSIVE/g
s/\bComphrehensive\b/Comprehensive/g
s/\bcompitent\b/competent/g
s/\bCOMPITENT\b/COMPETENT/g
s/\bCompitent\b/Competent/g
s/\bcompletedthe\b/completed the/g
s/\bCOMPLETEDTHE\b/COMPLETED THE/g
s/\bCompletedthe\b/Completed the/g
s/\bcompletelyl\b/completely/g
s/\bCOMPLETELYL\b/COMPLETELY/g
s/\bCompletelyl\b/Completely/g
s/\bcompletetion\b/completion/g
s/\bCOMPLETETION\b/COMPLETION/g
s/\bCompletetion\b/Completion/g
s/\bcomponant\b/component/g
s/\bCOMPONANT\b/COMPONENT/g
s/\bComponant\b/Component/g
s/\bcomprable\b/comparable/g
s/\bCOMPRABLE\b/COMPARABLE/g
s/\bComprable\b/Comparable/g
s/\bcomprimise\b/compromise/g
s/\bCOMPRIMISE\b/COMPROMISE/g
s/\bComprimise\b/Compromise/g
s/\bcompulsary\b/compulsory/g
s/\bCOMPULSARY\b/COMPULSORY/g
s/\bCompulsary\b/Compulsory/g
s/\bcompulsery\b/compulsory/g
s/\bCOMPULSERY\b/COMPULSORY/g
s/\bCompulsery\b/Compulsory/g
s/\bcomputarized\b/computerized/g
s/\bCOMPUTARIZED\b/COMPUTERIZED/g
s/\bComputarized\b/Computerized/g
s/\bconcider\b/consider/g
s/\bCONCIDER\b/CONSIDER/g
s/\bConcider\b/Consider/g
s/\bconcidered\b/considered/g
s/\bCONCIDERED\b/CONSIDERED/g
s/\bConcidered\b/Considered/g
s/\bconcidering\b/considering/g
s/\bCONCIDERING\b/CONSIDERING/g
s/\bConcidering\b/Considering/g
s/\bconciders\b/considers/g
s/\bCONCIDERS\b/CONSIDERS/g
s/\bConciders\b/Considers/g
s/\bconcieted\b/conceited/g
s/\bCONCIETED\b/CONCEITED/g
s/\bConcieted\b/Conceited/g
s/\bconcieved\b/conceived/g
s/\bCONCIEVED\b/CONCEIVED/g
s/\bConcieved\b/Conceived/g
s/\bconcious\b/conscious/g
s/\bCONCIOUS\b/CONSCIOUS/g
s/\bConcious\b/Conscious/g
s/\bconciously\b/consciously/g
s/\bCONCIOUSLY\b/CONSCIOUSLY/g
s/\bConciously\b/Consciously/g
s/\bconciousness\b/consciousness/g
s/\bCONCIOUSNESS\b/CONSCIOUSNESS/g
s/\bConciousness\b/Consciousness/g
s/\bcondamned\b/condemned/g
s/\bCONDAMNED\b/CONDEMNED/g
s/\bCondamned\b/Condemned/g
s/\bcondemmed\b/condemned/g
s/\bCONDEMMED\b/CONDEMNED/g
s/\bCondemmed\b/Condemned/g
s/\bcondidtion\b/condition/g
s/\bCONDIDTION\b/CONDITION/g
s/\bCondidtion\b/Condition/g
s/\bconditionsof\b/conditions of/g
s/\bCONDITIONSOF\b/CONDITIONS OF/g
s/\bConditionsof\b/Conditions of/g
s/\bconected\b/connected/g
s/\bCONECTED\b/CONNECTED/g
s/\bConected\b/Connected/g
s/\bconesencus\b/consensus/g
s/\bCONESENCUS\b/CONSENSUS/g
s/\bConesencus\b/Consensus/g
s/\bconfidental\b/confidential/g
s/\bCONFIDENTAL\b/CONFIDENTIAL/g
s/\bConfidental\b/Confidential/g
s/\bconfidentally\b/confidentially/g
s/\bCONFIDENTALLY\b/CONFIDENTIALLY/g
s/\bConfidentally\b/Confidentially/g
s/\bconfids\b/confides/g
s/\bCONFIDS\b/CONFIDES/g
s/\bConfids\b/Confides/g
s/\bconfortable\b/comfortable/g
s/\bCONFORTABLE\b/COMFORTABLE/g
s/\bConfortable\b/Comfortable/g
s/\bcongradulations\b/congratulations/g
s/\bCONGRADULATIONS\b/CONGRATULATIONS/g
s/\bCongradulations\b/Congratulations/g
s/\bcongresional\b/congressional/g
s/\bCONGRESIONAL\b/CONGRESSIONAL/g
s/\bCongresional\b/Congressional/g
s/\bconived\b/connived/g
s/\bCONIVED\b/CONNIVED/g
s/\bConived\b/Connived/g
s/\bconjecutre\b/conjecture/g
s/\bCONJECUTRE\b/CONJECTURE/g
s/\bConjecutre\b/Conjecture/g
s/\bconotations\b/connotations/g
s/\bCONOTATIONS\b/CONNOTATIONS/g
s/\bConotations\b/Connotations/g
s/\bconquerd\b/conquered/g
s/\bCONQUERD\b/CONQUERED/g
s/\bConquerd\b/Conquered/g
s/\bconquerer\b/conqueror/g
s/\bCONQUERER\b/CONQUEROR/g
s/\bConquerer\b/Conqueror/g
s/\bconquerers\b/conquerors/g
s/\bCONQUERERS\b/CONQUERORS/g
s/\bConquerers\b/Conquerors/g
s/\bconqured\b/conquered/g
s/\bCONQURED\b/CONQUERED/g
s/\bConqured\b/Conquered/g
s/\bconscent\b/consent/g
s/\bCONSCENT\b/CONSENT/g
s/\bConscent\b/Consent/g
s/\bconsciouness\b/consciousness/g
s/\bCONSCIOUNESS\b/CONSCIOUSNESS/g
s/\bConsciouness\b/Consciousness/g
s/\bconsdider\b/consider/g
s/\bCONSDIDER\b/CONSIDER/g
s/\bConsdider\b/Consider/g
s/\bconsdidered\b/considered/g
s/\bCONSDIDERED\b/CONSIDERED/g
s/\bConsdidered\b/Considered/g
s/\bconsdiered\b/considered/g
s/\bCONSDIERED\b/CONSIDERED/g
s/\bConsdiered\b/Considered/g
s/\bconsectutive\b/consecutive/g
s/\bCONSECTUTIVE\b/CONSECUTIVE/g
s/\bConsectutive\b/Consecutive/g
s/\bconsenquently\b/consequently/g
s/\bCONSENQUENTLY\b/CONSEQUENTLY/g
s/\bConsenquently\b/Consequently/g
s/\bconsentrate\b/concentrate/g
s/\bCONSENTRATE\b/CONCENTRATE/g
s/\bConsentrate\b/Concentrate/g
s/\bconsentrated\b/concentrated/g
s/\bCONSENTRATED\b/CONCENTRATED/g
s/\bConsentrated\b/Concentrated/g
s/\bconsentrates\b/concentrates/g
s/\bCONSENTRATES\b/CONCENTRATES/g
s/\bConsentrates\b/Concentrates/g
s/\bconsept\b/concept/g
s/\bCONSEPT\b/CONCEPT/g
s/\bConsept\b/Concept/g
s/\bconsequentually\b/consequently/g
s/\bCONSEQUENTUALLY\b/CONSEQUENTLY/g
s/\bConsequentually\b/Consequently/g
s/\bconsequeseces\b/consequences/g
s/\bCONSEQUESECES\b/CONSEQUENCES/g
s/\bConsequeseces\b/Consequences/g
s/\bconsern\b/concern/g
s/\bCONSERN\b/CONCERN/g
s/\bConsern\b/Concern/g
s/\bconserned\b/concerned/g
s/\bCONSERNED\b/CONCERNED/g
s/\bConserned\b/Concerned/g
s/\bconserning\b/concerning/g
s/\bCONSERNING\b/CONCERNING/g
s/\bConserning\b/Concerning/g
s/\bconservitive\b/conservative/g
s/\bCONSERVITIVE\b/CONSERVATIVE/g
s/\bConservitive\b/Conservative/g
s/\bconsiciousness\b/consciousness/g
s/\bCONSICIOUSNESS\b/CONSCIOUSNESS/g
s/\bConsiciousness\b/Consciousness/g
s/\bconsicousness\b/consciousness/g
s/\bCONSICOUSNESS\b/CONSCIOUSNESS/g
s/\bConsicousness\b/Consciousness/g
s/\bconsiderd\b/considered/g
s/\bCONSIDERD\b/CONSIDERED/g
s/\bConsiderd\b/Considered/g
s/\bconsideres\b/considered/g
s/\bCONSIDERES\b/CONSIDERED/g
s/\bConsideres\b/Considered/g
s/\bconsious\b/conscious/g
s/\bCONSIOUS\b/CONSCIOUS/g
s/\bConsious\b/Conscious/g
s/\bconsituencies\b/constituencies/g
s/\bCONSITUENCIES\b/CONSTITUENCIES/g
s/\bConsituencies\b/Constituencies/g
s/\bconsituency\b/constituency/g
s/\bCONSITUENCY\b/CONSTITUENCY/g
s/\bConsituency\b/Constituency/g
s/\bconsituted\b/constituted/g
s/\bCONSITUTED\b/CONSTITUTED/g
s/\bConsituted\b/Constituted/g
s/\bconsitution\b/constitution/g
s/\bCONSITUTION\b/CONSTITUTION/g
s/\bConsitution\b/Constitution/g
s/\bconsitutional\b/constitutional/g
s/\bCONSITUTIONAL\b/CONSTITUTIONAL/g
s/\bConsitutional\b/Constitutional/g
s/\bconsolodate\b/consolidate/g
s/\bCONSOLODATE\b/CONSOLIDATE/g
s/\bConsolodate\b/Consolidate/g
s/\bconsolodated\b/consolidated/g
s/\bCONSOLODATED\b/CONSOLIDATED/g
s/\bConsolodated\b/Consolidated/g
s/\bconsonents\b/consonants/g
s/\bCONSONENTS\b/CONSONANTS/g
s/\bConsonents\b/Consonants/g
s/\bconsorcium\b/consortium/g
s/\bCONSORCIUM\b/CONSORTIUM/g
s/\bConsorcium\b/Consortium/g
s/\bconspiracys\b/conspiracies/g
s/\bCONSPIRACYS\b/CONSPIRACIES/g
s/\bConspiracys\b/Conspiracies/g
s/\bconspiriator\b/conspirator/g
s/\bCONSPIRIATOR\b/CONSPIRATOR/g
s/\bConspiriator\b/Conspirator/g
s/\bconstanly\b/constantly/g
s/\bCONSTANLY\b/CONSTANTLY/g
s/\bConstanly\b/Constantly/g
s/\bconstarnation\b/consternation/g
s/\bCONSTARNATION\b/CONSTERNATION/g
s/\bConstarnation\b/Consternation/g
s/\bconstatn\b/constant/g
s/\bCONSTATN\b/CONSTANT/g
s/\bConstatn\b/Constant/g
s/\bconstinually\b/continually/g
s/\bCONSTINUALLY\b/CONTINUALLY/g
s/\bConstinually\b/Continually/g
s/\bconstituant\b/constituent/g
s/\bCONSTITUANT\b/CONSTITUENT/g
s/\bConstituant\b/Constituent/g
s/\bconstituants\b/constituents/g
s/\bCONSTITUANTS\b/CONSTITUENTS/g
s/\bConstituants\b/Constituents/g
s/\bconstituion\b/constitution/g
s/\bCONSTITUION\b/CONSTITUTION/g
s/\bConstituion\b/Constitution/g
s/\bconstituional\b/constitutional/g
s/\bCONSTITUIONAL\b/CONSTITUTIONAL/g
s/\bConstituional\b/Constitutional/g
s/\bconsttruction\b/construction/g
s/\bCONSTTRUCTION\b/CONSTRUCTION/g
s/\bConsttruction\b/Construction/g
s/\bconsulant\b/consultant/g
s/\bCONSULANT\b/CONSULTANT/g
s/\bConsulant\b/Consultant/g
s/\bconsumate\b/consummate/g
s/\bCONSUMATE\b/CONSUMMATE/g
s/\bConsumate\b/Consummate/g
s/\bconsumated\b/consummated/g
s/\bCONSUMATED\b/CONSUMMATED/g
s/\bConsumated\b/Consummated/g
s/\bcontaiminate\b/contaminate/g
s/\bCONTAIMINATE\b/CONTAMINATE/g
s/\bContaiminate\b/Contaminate/g
s/\bcontamporaries\b/contemporaries/g
s/\bCONTAMPORARIES\b/CONTEMPORARIES/g
s/\bContamporaries\b/Contemporaries/g
s/\bcontamporary\b/contemporary/g
s/\bCONTAMPORARY\b/CONTEMPORARY/g
s/\bContamporary\b/Contemporary/g
s/\bcontempoary\b/contemporary/g
s/\bCONTEMPOARY\b/CONTEMPORARY/g
s/\bContempoary\b/Contemporary/g
s/\bcontemporaneus\b/contemporaneous/g
s/\bCONTEMPORANEUS\b/CONTEMPORANEOUS/g
s/\bContemporaneus\b/Contemporaneous/g
s/\bcontempory\b/contemporary/g
s/\bCONTEMPORY\b/CONTEMPORARY/g
s/\bContempory\b/Contemporary/g
s/\bcontendor\b/contender/g
s/\bCONTENDOR\b/CONTENDER/g
s/\bContendor\b/Contender/g
s/\bcontian\b/contain/g
s/\bCONTIAN\b/CONTAIN/g
s/\bContian\b/Contain/g
s/\bcontians\b/contains/g
s/\bCONTIANS\b/CONTAINS/g
s/\bContians\b/Contains/g
s/\bcontibute\b/contribute/g
s/\bCONTIBUTE\b/CONTRIBUTE/g
s/\bContibute\b/Contribute/g
s/\bcontibuted\b/contributed/g
s/\bCONTIBUTED\b/CONTRIBUTED/g
s/\bContibuted\b/Contributed/g
s/\bcontibutes\b/contributes/g
s/\bCONTIBUTES\b/CONTRIBUTES/g
s/\bContibutes\b/Contributes/g
s/\bcontigent\b/contingent/g
s/\bCONTIGENT\b/CONTINGENT/g
s/\bContigent\b/Contingent/g
s/\bcontined\b/continued/g
s/\bCONTINED\b/CONTINUED/g
s/\bContined\b/Continued/g
s/\bcontinential\b/continental/g
s/\bCONTINENTIAL\b/CONTINENTAL/g
s/\bContinential\b/Continental/g
s/\bcontinously\b/continuously/g
s/\bCONTINOUSLY\b/CONTINUOUSLY/g
s/\bContinously\b/Continuously/g
s/\bcontinueing\b/continuing/g
s/\bCONTINUEING\b/CONTINUING/g
s/\bContinueing\b/Continuing/g
s/\bcontravercial\b/controversial/g
s/\bCONTRAVERCIAL\b/CONTROVERSIAL/g
s/\bContravercial\b/Controversial/g
s/\bcontributer\b/contributor/g
s/\bCONTRIBUTER\b/CONTRIBUTOR/g
s/\bContributer\b/Contributor/g
s/\bcontributers\b/contributors/g
s/\bCONTRIBUTERS\b/CONTRIBUTORS/g
s/\bContributers\b/Contributors/g
s/\bcontritutions\b/contributions/g
s/\bCONTRITUTIONS\b/CONTRIBUTIONS/g
s/\bContritutions\b/Contributions/g
s/\bcontroll\b/control/g
s/\bCONTROLL\b/CONTROL/g
s/\bControll\b/Control/g
s/\bcontrolls\b/controls/g
s/\bCONTROLLS\b/CONTROLS/g
s/\bControlls\b/Controls/g
s/\bcontrovercial\b/controversial/g
s/\bCONTROVERCIAL\b/CONTROVERSIAL/g
s/\bControvercial\b/Controversial/g
s/\bcontrovercy\b/controversy/g
s/\bCONTROVERCY\b/CONTROVERSY/g
s/\bControvercy\b/Controversy/g
s/\bcontroveries\b/controversies/g
s/\bCONTROVERIES\b/CONTROVERSIES/g
s/\bControveries\b/Controversies/g
s/\bcontroversal\b/controversial/g
s/\bCONTROVERSAL\b/CONTROVERSIAL/g
s/\bControversal\b/Controversial/g
s/\bcontroversey\b/controversy/g
s/\bCONTROVERSEY\b/CONTROVERSY/g
s/\bControversey\b/Controversy/g
s/\bcontrovertial\b/controversial/g
s/\bCONTROVERTIAL\b/CONTROVERSIAL/g
s/\bControvertial\b/Controversial/g
s/\bcontrovery\b/controversy/g
s/\bCONTROVERY\b/CONTROVERSY/g
s/\bControvery\b/Controversy/g
s/\bcontstruction\b/construction/g
s/\bCONTSTRUCTION\b/CONSTRUCTION/g
s/\bContstruction\b/Construction/g
s/\bconveinent\b/convenient/g
s/\bCONVEINENT\b/CONVENIENT/g
s/\bConveinent\b/Convenient/g
s/\bconvenant\b/covenant/g
s/\bCONVENANT\b/COVENANT/g
s/\bConvenant\b/Covenant/g
s/\bconvential\b/conventional/g
s/\bCONVENTIAL\b/CONVENTIONAL/g
s/\bConvential\b/Conventional/g
s/\bconvertables\b/convertibles/g
s/\bCONVERTABLES\b/CONVERTIBLES/g
s/\bConvertables\b/Convertibles/g
s/\bconvertion\b/conversion/g
s/\bCONVERTION\b/CONVERSION/g
s/\bConvertion\b/Conversion/g
s/\bconviced\b/convinced/g
s/\bCONVICED\b/CONVINCED/g
s/\bConviced\b/Convinced/g
s/\bconvienient\b/convenient/g
s/\bCONVIENIENT\b/CONVENIENT/g
s/\bConvienient\b/Convenient/g
s/\bcoordiantion\b/coordination/g
s/\bCOORDIANTION\b/COORDINATION/g
s/\bCoordiantion\b/Coordination/g
s/\bcoorperations\b/corporations/g
s/\bCOORPERATIONS\b/CORPORATIONS/g
s/\bCoorperations\b/Corporations/g
s/\bcopmetitors\b/competitors/g
s/\bCOPMETITORS\b/COMPETITORS/g
s/\bCopmetitors\b/Competitors/g
s/\bcoputer\b/computer/g
s/\bCOPUTER\b/COMPUTER/g
s/\bCoputer\b/Computer/g
s/\bcopywrite\b/copyright/g
s/\bCOPYWRITE\b/COPYRIGHT/g
s/\bCopywrite\b/Copyright/g
s/\bcoridal\b/cordial/g
s/\bCORIDAL\b/CORDIAL/g
s/\bCoridal\b/Cordial/g
s/\bcornmitted\b/committed/g
s/\bCORNMITTED\b/COMMITTED/g
s/\bCornmitted\b/Committed/g
s/\bcorosion\b/corrosion/g
s/\bCOROSION\b/CORROSION/g
s/\bCorosion\b/Corrosion/g
s/\bcorparate\b/corporate/g
s/\bCORPARATE\b/CORPORATE/g
s/\bCorparate\b/Corporate/g
s/\bcorperations\b/corporations/g
s/\bCORPERATIONS\b/CORPORATIONS/g
s/\bCorperations\b/Corporations/g
s/\bcorrecters\b/correctors/g
s/\bCORRECTERS\b/CORRECTORS/g
s/\bCorrecters\b/Correctors/g
s/\bcorreponding\b/corresponding/g
s/\bCORREPONDING\b/CORRESPONDING/g
s/\bCorreponding\b/Corresponding/g
s/\bcorreposding\b/corresponding/g
s/\bCORREPOSDING\b/CORRESPONDING/g
s/\bCorreposding\b/Corresponding/g
s/\bcorrespondant\b/correspondent/g
s/\bCORRESPONDANT\b/CORRESPONDENT/g
s/\bCorrespondant\b/Correspondent/g
s/\bcorrespondants\b/correspondents/g
s/\bCORRESPONDANTS\b/CORRESPONDENTS/g
s/\bCorrespondants\b/Correspondents/g
s/\bcorridoors\b/corridors/g
s/\bCORRIDOORS\b/CORRIDORS/g
s/\bCorridoors\b/Corridors/g
s/\bcorrispond\b/correspond/g
s/\bCORRISPOND\b/CORRESPOND/g
s/\bCorrispond\b/Correspond/g
s/\bcorrispondant\b/correspondent/g
s/\bCORRISPONDANT\b/CORRESPONDENT/g
s/\bCorrispondant\b/Correspondent/g
s/\bcorrispondants\b/correspondents/g
s/\bCORRISPONDANTS\b/CORRESPONDENTS/g
s/\bCorrispondants\b/Correspondents/g
s/\bcorrisponded\b/corresponded/g
s/\bCORRISPONDED\b/CORRESPONDED/g
s/\bCorrisponded\b/Corresponded/g
s/\bcorrisponding\b/corresponding/g
s/\bCORRISPONDING\b/CORRESPONDING/g
s/\bCorrisponding\b/Corresponding/g
s/\bcorrisponds\b/corresponds/g
s/\bCORRISPONDS\b/CORRESPONDS/g
s/\bCorrisponds\b/Corresponds/g
s/\bcostitution\b/constitution/g
s/\bCOSTITUTION\b/CONSTITUTION/g
s/\bCostitution\b/Constitution/g
s/\bcoucil\b/council/g
s/\bCOUCIL\b/COUNCIL/g
s/\bCoucil\b/Council/g
s/\bcounries\b/countries/g
s/\bCOUNRIES\b/COUNTRIES/g
s/\bCounries\b/Countries/g
s/\bcountains\b/contains/g
s/\bCOUNTAINS\b/CONTAINS/g
s/\bCountains\b/Contains/g
s/\bcountires\b/countries/g
s/\bCOUNTIRES\b/COUNTRIES/g
s/\bCountires\b/Countries/g
s/\bcreaeted\b/created/g
s/\bCREAETED\b/CREATED/g
s/\bCreaeted\b/Created/g
s/\bcreche\b/crèche/g
s/\bCRECHE\b/CRèCHE/g
s/\bCreche\b/Crèche/g
s/\bcreedence\b/credence/g
s/\bCREEDENCE\b/CREDENCE/g
s/\bCreedence\b/Credence/g
s/\bcritereon\b/criterion/g
s/\bCRITEREON\b/CRITERION/g
s/\bCritereon\b/Criterion/g
s/\bcriterias\b/criteria/g
s/\bCRITERIAS\b/CRITERIA/g
s/\bCriterias\b/Criteria/g
s/\bcriticists\b/critics/g
s/\bCRITICISTS\b/CRITICS/g
s/\bCriticists\b/Critics/g
s/\bcritisising\b/criticising/g
s/\bCRITISISING\b/CRITICISING/g
s/\bCritisising\b/Criticising/g
s/\bcritisism\b/criticism/g
s/\bCRITISISM\b/CRITICISM/g
s/\bCritisism\b/Criticism/g
s/\bcritisisms\b/criticisms/g
s/\bCRITISISMS\b/CRITICISMS/g
s/\bCritisisms\b/Criticisms/g
s/\bcritized\b/criticized/g
s/\bCRITIZED\b/CRITICIZED/g
s/\bCritized\b/Criticized/g
s/\bcritizing\b/criticizing/g
s/\bCRITIZING\b/CRITICIZING/g
s/\bCritizing\b/Criticizing/g
s/\bcrockodiles\b/crocodiles/g
s/\bCROCKODILES\b/CROCODILES/g
s/\bCrockodiles\b/Crocodiles/g
s/\bcrowm\b/crown/g
s/\bCROWM\b/CROWN/g
s/\bCrowm\b/Crown/g
s/\bcrtical\b/critical/g
s/\bCRTICAL\b/CRITICAL/g
s/\bCrtical\b/Critical/g
s/\bcrticised\b/criticised/g
s/\bCRTICISED\b/CRITICISED/g
s/\bCrticised\b/Criticised/g
s/\bcrucifiction\b/crucifixion/g
s/\bCRUCIFICTION\b/CRUCIFIXION/g
s/\bCrucifiction\b/Crucifixion/g
s/\bcrusies\b/cruises/g
s/\bCRUSIES\b/CRUISES/g
s/\bCrusies\b/Cruises/g
s/\bcrystalisation\b/crystallisation/g
s/\bCRYSTALISATION\b/CRYSTALLISATION/g
s/\bCrystalisation\b/Crystallisation/g
s/\bculiminating\b/culminating/g
s/\bCULIMINATING\b/CULMINATING/g
s/\bCuliminating\b/Culminating/g
s/\bcumulatative\b/cumulative/g
s/\bCUMULATATIVE\b/CUMULATIVE/g
s/\bCumulatative\b/Cumulative/g
s/\bcurch\b/church/g
s/\bCURCH\b/CHURCH/g
s/\bCurch\b/Church/g
s/\bcurcuit\b/circuit/g
s/\bCURCUIT\b/CIRCUIT/g
s/\bCurcuit\b/Circuit/g
s/\bcurrenly\b/currently/g
s/\bCURRENLY\b/CURRENTLY/g
s/\bCurrenly\b/Currently/g
s/\bcurriculem\b/curriculum/g
s/\bCURRICULEM\b/CURRICULUM/g
s/\bCurriculem\b/Curriculum/g
s/\bcxan\b/cyan/g
s/\bCXAN\b/CYAN/g
s/\bCxan\b/Cyan/g
s/\bcyclinder\b/cylinder/g
s/\bCYCLINDER\b/CYLINDER/g
s/\bCyclinder\b/Cylinder/g
s/\bdacquiri\b/daiquiri/g
s/\bDACQUIRI\b/DAIQUIRI/g
s/\bDacquiri\b/Daiquiri/g
s/\bdaed\b/dead/g
s/\bDAED\b/DEAD/g
s/\bDaed\b/Dead/g
s/\bdalmation\b/dalmatian/g
s/\bDALMATION\b/DALMATIAN/g
s/\bDalmation\b/Dalmatian/g
s/\bdamenor\b/demeanor/g
s/\bDAMENOR\b/DEMEANOR/g
s/\bDamenor\b/Demeanor/g
s/\bdammage\b/damage/g
s/\bDAMMAGE\b/DAMAGE/g
s/\bDammage\b/Damage/g
s/\bdaugher\b/daughter/g
s/\bDAUGHER\b/DAUGHTER/g
s/\bDaugher\b/Daughter/g
s/\bdebateable\b/debatable/g
s/\bDEBATEABLE\b/DEBATABLE/g
s/\bDebateable\b/Debatable/g
s/\bdecendant\b/descendant/g
s/\bDECENDANT\b/DESCENDANT/g
s/\bDecendant\b/Descendant/g
s/\bdecendants\b/descendants/g
s/\bDECENDANTS\b/DESCENDANTS/g
s/\bDecendants\b/Descendants/g
s/\bdecendent\b/descendant/g
s/\bDECENDENT\b/DESCENDANT/g
s/\bDecendent\b/Descendant/g
s/\bdecideable\b/decidable/g
s/\bDECIDEABLE\b/DECIDABLE/g
s/\bDecideable\b/Decidable/g
s/\bdecidely\b/decidedly/g
s/\bDECIDELY\b/DECIDEDLY/g
s/\bDecidely\b/Decidedly/g
s/\bdecieved\b/deceived/g
s/\bDECIEVED\b/DECEIVED/g
s/\bDecieved\b/Deceived/g
s/\bdecison\b/decision/g
s/\bDECISON\b/DECISION/g
s/\bDecison\b/Decision/g
s/\bdecomissioned\b/decommissioned/g
s/\bDECOMISSIONED\b/DECOMMISSIONED/g
s/\bDecomissioned\b/Decommissioned/g
s/\bdecomposit\b/decompose/g
s/\bDECOMPOSIT\b/DECOMPOSE/g
s/\bDecomposit\b/Decompose/g
s/\bdecomposited\b/decomposed/g
s/\bDECOMPOSITED\b/DECOMPOSED/g
s/\bDecomposited\b/Decomposed/g
s/\bdecompositing\b/decomposing/g
s/\bDECOMPOSITING\b/DECOMPOSING/g
s/\bDecompositing\b/Decomposing/g
s/\bdecomposits\b/decomposes/g
s/\bDECOMPOSITS\b/DECOMPOSES/g
s/\bDecomposits\b/Decomposes/g
s/\bdecress\b/decrees/g
s/\bDECRESS\b/DECREES/g
s/\bDecress\b/Decrees/g
s/\bdecribe\b/describe/g
s/\bDECRIBE\b/DESCRIBE/g
s/\bDecribe\b/Describe/g
s/\bdecribes\b/describes/g
s/\bDECRIBES\b/DESCRIBES/g
s/\bDecribes\b/Describes/g
s/\bdectect\b/detect/g
s/\bDECTECT\b/DETECT/g
s/\bDectect\b/Detect/g
s/\bdefendent\b/defendant/g
s/\bDEFENDENT\b/DEFENDANT/g
s/\bDefendent\b/Defendant/g
s/\bdefendents\b/defendants/g
s/\bDEFENDENTS\b/DEFENDANTS/g
s/\bDefendents\b/Defendants/g
s/\bdeffensively\b/defensively/g
s/\bDEFFENSIVELY\b/DEFENSIVELY/g
s/\bDeffensively\b/Defensively/g
s/\bdeffine\b/define/g
s/\bDEFFINE\b/DEFINE/g
s/\bDeffine\b/Define/g
s/\bdeffined\b/defined/g
s/\bDEFFINED\b/DEFINED/g
s/\bDeffined\b/Defined/g
s/\bdefinance\b/defiance/g
s/\bDEFINANCE\b/DEFIANCE/g
s/\bDefinance\b/Defiance/g
s/\bdefinatly\b/definitely/g
s/\bDEFINATLY\b/DEFINITELY/g
s/\bDefinatly\b/Definitely/g
s/\bdefinetly\b/definitely/g
s/\bDEFINETLY\b/DEFINITELY/g
s/\bDefinetly\b/Definitely/g
s/\bdefinining\b/defining/g
s/\bDEFININING\b/DEFINING/g
s/\bDefinining\b/Defining/g
s/\bdefinit\b/definite/g
s/\bDEFINIT\b/DEFINITE/g
s/\bDefinit\b/Definite/g
s/\bdefinitly\b/definitely/g
s/\bDEFINITLY\b/DEFINITELY/g
s/\bDefinitly\b/Definitely/g
s/\bdefiniton\b/definition/g
s/\bDEFINITON\b/DEFINITION/g
s/\bDefiniton\b/Definition/g
s/\bdegrate\b/degrade/g
s/\bDEGRATE\b/DEGRADE/g
s/\bDegrate\b/Degrade/g
s/\bdelagates\b/delegates/g
s/\bDELAGATES\b/DELEGATES/g
s/\bDelagates\b/Delegates/g
s/\bdelapidated\b/dilapidated/g
s/\bDELAPIDATED\b/DILAPIDATED/g
s/\bDelapidated\b/Dilapidated/g
s/\bdelerious\b/delirious/g
s/\bDELERIOUS\b/DELIRIOUS/g
s/\bDelerious\b/Delirious/g
s/\bdelevopment\b/development/g
s/\bDELEVOPMENT\b/DEVELOPMENT/g
s/\bDelevopment\b/Development/g
s/\bdeliberatly\b/deliberately/g
s/\bDELIBERATLY\b/DELIBERATELY/g
s/\bDeliberatly\b/Deliberately/g
s/\bdelusionally\b/delusively/g
s/\bDELUSIONALLY\b/DELUSIVELY/g
s/\bDelusionally\b/Delusively/g
s/\bdemenor\b/demeanor/g
s/\bDEMENOR\b/DEMEANOR/g
s/\bDemenor\b/Demeanor/g
s/\bdemographical\b/demographic/g
s/\bDEMOGRAPHICAL\b/DEMOGRAPHIC/g
s/\bDemographical\b/Demographic/g
s/\bdemolision\b/demolition/g
s/\bDEMOLISION\b/DEMOLITION/g
s/\bDemolision\b/Demolition/g
s/\bdemorcracy\b/democracy/g
s/\bDEMORCRACY\b/DEMOCRACY/g
s/\bDemorcracy\b/Democracy/g
s/\bdemostration\b/demonstration/g
s/\bDEMOSTRATION\b/DEMONSTRATION/g
s/\bDemostration\b/Demonstration/g
s/\bdenegrating\b/denigrating/g
s/\bDENEGRATING\b/DENIGRATING/g
s/\bDenegrating\b/Denigrating/g
s/\bdensly\b/densely/g
s/\bDENSLY\b/DENSELY/g
s/\bDensly\b/Densely/g
s/\bdentifier/identifier/g
s/\bDENTIFIER/IDENTIFIER/g
s/\bDentifier/Identifier/g
s/\bdeparment\b/department/g
s/\bDEPARMENT\b/DEPARTMENT/g
s/\bDeparment\b/Department/g
s/\bdeparmental\b/departmental/g
s/\bDEPARMENTAL\b/DEPARTMENTAL/g
s/\bDeparmental\b/Departmental/g
s/\bdeparments\b/departments/g
s/\bDEPARMENTS\b/DEPARTMENTS/g
s/\bDeparments\b/Departments/g
s/\bdependance\b/dependence/g
s/\bDEPENDANCE\b/DEPENDENCE/g
s/\bDependance\b/Dependence/g
s/\bdependancy\b/dependency/g
s/\bDEPENDANCY\b/DEPENDENCY/g
s/\bDependancy\b/Dependency/g
s/\bderiviated\b/derived/g
s/\bDERIVIATED\b/DERIVED/g
s/\bDeriviated\b/Derived/g
s/\bderivitive\b/derivative/g
s/\bDERIVITIVE\b/DERIVATIVE/g
s/\bDerivitive\b/Derivative/g
s/\bderogitory\b/derogatory/g
s/\bDEROGITORY\b/DEROGATORY/g
s/\bDerogitory\b/Derogatory/g
s/\bdescendands\b/descendants/g
s/\bDESCENDANDS\b/DESCENDANTS/g
s/\bDescendands\b/Descendants/g
s/\bdescision\b/decision/g
s/\bDESCISION\b/DECISION/g
s/\bDescision\b/Decision/g
s/\bdescisions\b/decisions/g
s/\bDESCISIONS\b/DECISIONS/g
s/\bDescisions\b/Decisions/g
s/\bdescriibes\b/describes/g
s/\bDESCRIIBES\b/DESCRIBES/g
s/\bDescriibes\b/Describes/g
s/\bdescripters\b/descriptors/g
s/\bDESCRIPTERS\b/DESCRIPTORS/g
s/\bDescripters\b/Descriptors/g
s/\bdesctruction\b/destruction/g
s/\bDESCTRUCTION\b/DESTRUCTION/g
s/\bDesctruction\b/Destruction/g
s/\bdescuss\b/discuss/g
s/\bDESCUSS\b/DISCUSS/g
s/\bDescuss\b/Discuss/g
s/\bdesgined\b/designed/g
s/\bDESGINED\b/DESIGNED/g
s/\bDesgined\b/Designed/g
s/\bdeside\b/decide/g
s/\bDESIDE\b/DECIDE/g
s/\bDeside\b/Decide/g
s/\bdesigining\b/designing/g
s/\bDESIGINING\b/DESIGNING/g
s/\bDesigining\b/Designing/g
s/\bdesintegrated\b/disintegrated/g
s/\bDESINTEGRATED\b/DISINTEGRATED/g
s/\bDesintegrated\b/Disintegrated/g
s/\bdesintegration\b/disintegration/g
s/\bDESINTEGRATION\b/DISINTEGRATION/g
s/\bDesintegration\b/Disintegration/g
s/\bdesitned\b/destined/g
s/\bDESITNED\b/DESTINED/g
s/\bDesitned\b/Destined/g
s/\bdesktiop\b/desktop/g
s/\bDESKTIOP\b/DESKTOP/g
s/\bDesktiop\b/Desktop/g
s/\bdesorder\b/disorder/g
s/\bDESORDER\b/DISORDER/g
s/\bDesorder\b/Disorder/g
s/\bdesoriented\b/disoriented/g
s/\bDESORIENTED\b/DISORIENTED/g
s/\bDesoriented\b/Disoriented/g
s/\bdespict\b/depict/g
s/\bDESPICT\b/DEPICT/g
s/\bDespict\b/Depict/g
s/\bdespiration\b/desperation/g
s/\bDESPIRATION\b/DESPERATION/g
s/\bDespiration\b/Desperation/g
s/\bdessicated\b/desiccated/g
s/\bDESSICATED\b/DESICCATED/g
s/\bDessicated\b/Desiccated/g
s/\bdessigned\b/designed/g
s/\bDESSIGNED\b/DESIGNED/g
s/\bDessigned\b/Designed/g
s/\bdestablized\b/destabilized/g
s/\bDESTABLIZED\b/DESTABILIZED/g
s/\bDestablized\b/Destabilized/g
s/\bdestory\b/destroy/g
s/\bDESTORY\b/DESTROY/g
s/\bDestory\b/Destroy/g
s/\bdetailled\b/detailed/g
s/\bDETAILLED\b/DETAILED/g
s/\bDetailled\b/Detailed/g
s/\bdetatched\b/detached/g
s/\bDETATCHED\b/DETACHED/g
s/\bDetatched\b/Detached/g
s/\bdeteoriated\b/deteriorated/g
s/\bDETEORIATED\b/DETERIORATED/g
s/\bDeteoriated\b/Deteriorated/g
s/\bdeteriate\b/deteriorate/g
s/\bDETERIATE\b/DETERIORATE/g
s/\bDeteriate\b/Deteriorate/g
s/\bdeterioriating\b/deteriorating/g
s/\bDETERIORIATING\b/DETERIORATING/g
s/\bDeterioriating\b/Deteriorating/g
s/\bdeterminining\b/determining/g
s/\bDETERMININING\b/DETERMINING/g
s/\bDeterminining\b/Determining/g
s/\bdetremental\b/detrimental/g
s/\bDETREMENTAL\b/DETRIMENTAL/g
s/\bDetremental\b/Detrimental/g
s/\bdevasted\b/devastated/g
s/\bDEVASTED\b/DEVASTATED/g
s/\bDevasted\b/Devastated/g
s/\bdevelope\b/develop/g
s/\bDEVELOPE\b/DEVELOP/g
s/\bDevelope\b/Develop/g
s/\bdevelopement\b/development/g
s/\bDEVELOPEMENT\b/DEVELOPMENT/g
s/\bDevelopement\b/Development/g
s/\bdevelopped\b/developed/g
s/\bDEVELOPPED\b/DEVELOPED/g
s/\bDevelopped\b/Developed/g
s/\bdevelpment\b/development/g
s/\bDEVELPMENT\b/DEVELOPMENT/g
s/\bDevelpment\b/Development/g
s/\bdevels\b/delves/g
s/\bDEVELS\b/DELVES/g
s/\bDevels\b/Delves/g
s/\bdevestated\b/devastated/g
s/\bDEVESTATED\b/DEVASTATED/g
s/\bDevestated\b/Devastated/g
s/\bdevestating\b/devastating/g
s/\bDEVESTATING\b/DEVASTATING/g
s/\bDevestating\b/Devastating/g
s/\bdevide\b/divide/g
s/\bDEVIDE\b/DIVIDE/g
s/\bDevide\b/Divide/g
s/\bdevided\b/divided/g
s/\bDEVIDED\b/DIVIDED/g
s/\bDevided\b/Divided/g
s/\bdevistating\b/devastating/g
s/\bDEVISTATING\b/DEVASTATING/g
s/\bDevistating\b/Devastating/g
s/\bdevolopement\b/development/g
s/\bDEVOLOPEMENT\b/DEVELOPMENT/g
s/\bDevolopement\b/Development/g
s/\bdiablical\b/diabolical/g
s/\bDIABLICAL\b/DIABOLICAL/g
s/\bDiablical\b/Diabolical/g
s/\bdiamons\b/diamonds/g
s/\bDIAMONS\b/DIAMONDS/g
s/\bDiamons\b/Diamonds/g
s/\bdiaster\b/disaster/g
s/\bDIASTER\b/DISASTER/g
s/\bDiaster\b/Disaster/g
s/\bdichtomy\b/dichotomy/g
s/\bDICHTOMY\b/DICHOTOMY/g
s/\bDichtomy\b/Dichotomy/g
s/\bdiconnects\b/disconnects/g
s/\bDICONNECTS\b/DISCONNECTS/g
s/\bDiconnects\b/Disconnects/g
s/\bdicover\b/discover/g
s/\bDICOVER\b/DISCOVER/g
s/\bDicover\b/Discover/g
s/\bdicovered\b/discovered/g
s/\bDICOVERED\b/DISCOVERED/g
s/\bDicovered\b/Discovered/g
s/\bdicovering\b/discovering/g
s/\bDICOVERING\b/DISCOVERING/g
s/\bDicovering\b/Discovering/g
s/\bdicovers\b/discovers/g
s/\bDICOVERS\b/DISCOVERS/g
s/\bDicovers\b/Discovers/g
s/\bdicovery\b/discovery/g
s/\bDICOVERY\b/DISCOVERY/g
s/\bDicovery\b/Discovery/g
s/\bdictionarys\b/dictionaries/g
s/\bDICTIONARYS\b/DICTIONARIES/g
s/\bDictionarys\b/Dictionaries/g
s/\bdicussed\b/discussed/g
s/\bDICUSSED\b/DISCUSSED/g
s/\bDicussed\b/Discussed/g
s/\bdieties\b/deities/g
s/\bDIETIES\b/DEITIES/g
s/\bDieties\b/Deities/g
s/\bdiety\b/deity/g
s/\bDIETY\b/DEITY/g
s/\bDiety\b/Deity/g
s/\bdiferent\b/different/g
s/\bDIFERENT\b/DIFFERENT/g
s/\bDiferent\b/Different/g
s/\bdiferrent\b/different/g
s/\bDIFERRENT\b/DIFFERENT/g
s/\bDiferrent\b/Different/g
s/\bdifferentiatiations\b/differentiations/g
s/\bDIFFERENTIATIATIONS\b/DIFFERENTIATIONS/g
s/\bDifferentiatiations\b/Differentiations/g
s/\bdifficulity\b/difficulty/g
s/\bDIFFICULITY\b/DIFFICULTY/g
s/\bDifficulity\b/Difficulty/g
s/\bdiffrent\b/different/g
s/\bDIFFRENT\b/DIFFERENT/g
s/\bDiffrent\b/Different/g
s/\bdificulties\b/difficulties/g
s/\bDIFICULTIES\b/DIFFICULTIES/g
s/\bDificulties\b/Difficulties/g
s/\bdificulty\b/difficulty/g
s/\bDIFICULTY\b/DIFFICULTY/g
s/\bDificulty\b/Difficulty/g
s/\bdimenions\b/dimensions/g
s/\bDIMENIONS\b/DIMENSIONS/g
s/\bDimenions\b/Dimensions/g
s/\bdimentions\b/dimensions/g
s/\bDIMENTIONS\b/DIMENSIONS/g
s/\bDimentions\b/Dimensions/g
s/\bdimesnional\b/dimensional/g
s/\bDIMESNIONAL\b/DIMENSIONAL/g
s/\bDimesnional\b/Dimensional/g
s/\bdiminuitive\b/diminutive/g
s/\bDIMINUITIVE\b/DIMINUTIVE/g
s/\bDiminuitive\b/Diminutive/g
s/\bdimunitive\b/diminutive/g
s/\bDIMUNITIVE\b/DIMINUTIVE/g
s/\bDimunitive\b/Diminutive/g
s/\bdiosese\b/diocese/g
s/\bDIOSESE\b/DIOCESE/g
s/\bDiosese\b/Diocese/g
s/\bdiphtong\b/diphthong/g
s/\bDIPHTONG\b/DIPHTHONG/g
s/\bDiphtong\b/Diphthong/g
s/\bdiphtongs\b/diphthongs/g
s/\bDIPHTONGS\b/DIPHTHONGS/g
s/\bDiphtongs\b/Diphthongs/g
s/\bdiplomancy\b/diplomacy/g
s/\bDIPLOMANCY\b/DIPLOMACY/g
s/\bDiplomancy\b/Diplomacy/g
s/\bdipthong\b/diphthong/g
s/\bDIPTHONG\b/DIPHTHONG/g
s/\bDipthong\b/Diphthong/g
s/\bdirectoty\b/directory/g
s/\bDIRECTOTY\b/DIRECTORY/g
s/\bDirectoty\b/Directory/g
s/\bdirived\b/derived/g
s/\bDIRIVED\b/DERIVED/g
s/\bDirived\b/Derived/g
s/\bdisagreeed\b/disagreed/g
s/\bDISAGREEED\b/DISAGREED/g
s/\bDisagreeed\b/Disagreed/g
s/\bdisapeared\b/disappeared/g
s/\bDISAPEARED\b/DISAPPEARED/g
s/\bDisapeared\b/Disappeared/g
s/\bdisapointing\b/disappointing/g
s/\bDISAPOINTING\b/DISAPPOINTING/g
s/\bDisapointing\b/Disappointing/g
s/\bdisappearred\b/disappeared/g
s/\bDISAPPEARRED\b/DISAPPEARED/g
s/\bDisappearred\b/Disappeared/g
s/\bdisaproval\b/disapproval/g
s/\bDISAPROVAL\b/DISAPPROVAL/g
s/\bDisaproval\b/Disapproval/g
s/\bdisasterous\b/disastrous/g
s/\bDISASTEROUS\b/DISASTROUS/g
s/\bDisasterous\b/Disastrous/g
s/\bdisatisfaction\b/dissatisfaction/g
s/\bDISATISFACTION\b/DISSATISFACTION/g
s/\bDisatisfaction\b/Dissatisfaction/g
s/\bdisatisfied\b/dissatisfied/g
s/\bDISATISFIED\b/DISSATISFIED/g
s/\bDisatisfied\b/Dissatisfied/g
s/\bdisatrous\b/disastrous/g
s/\bDISATROUS\b/DISASTROUS/g
s/\bDisatrous\b/Disastrous/g
s/\bdiscontentment\b/discontent/g
s/\bDISCONTENTMENT\b/DISCONTENT/g
s/\bDiscontentment\b/Discontent/g
s/\bdiscribe\b/describe/g
s/\bDISCRIBE\b/DESCRIBE/g
s/\bDiscribe\b/Describe/g
s/\bdiscribed\b/described/g
s/\bDISCRIBED\b/DESCRIBED/g
s/\bDiscribed\b/Described/g
s/\bdiscribes\b/describes/g
s/\bDISCRIBES\b/DESCRIBES/g
s/\bDiscribes\b/Describes/g
s/\bdiscribing\b/describing/g
s/\bDISCRIBING\b/DESCRIBING/g
s/\bDiscribing\b/Describing/g
s/\bdisctinction\b/distinction/g
s/\bDISCTINCTION\b/DISTINCTION/g
s/\bDisctinction\b/Distinction/g
s/\bdisctinctive\b/distinctive/g
s/\bDISCTINCTIVE\b/DISTINCTIVE/g
s/\bDisctinctive\b/Distinctive/g
s/\bdisemination\b/dissemination/g
s/\bDISEMINATION\b/DISSEMINATION/g
s/\bDisemination\b/Dissemination/g
s/\bdisenchanged\b/disenchanted/g
s/\bDISENCHANGED\b/DISENCHANTED/g
s/\bDisenchanged\b/Disenchanted/g
s/\bdisiplined\b/disciplined/g
s/\bDISIPLINED\b/DISCIPLINED/g
s/\bDisiplined\b/Disciplined/g
s/\bdisobediance\b/disobedience/g
s/\bDISOBEDIANCE\b/DISOBEDIENCE/g
s/\bDisobediance\b/Disobedience/g
s/\bdisobediant\b/disobedient/g
s/\bDISOBEDIANT\b/DISOBEDIENT/g
s/\bDisobediant\b/Disobedient/g
s/\bdisolved\b/dissolved/g
s/\bDISOLVED\b/DISSOLVED/g
s/\bDisolved\b/Dissolved/g
s/\bdisover\b/discover/g
s/\bDISOVER\b/DISCOVER/g
s/\bDisover\b/Discover/g
s/\bdispair\b/despair/g
s/\bDISPAIR\b/DESPAIR/g
s/\bDispair\b/Despair/g
s/\bdisparingly\b/disparagingly/g
s/\bDISPARINGLY\b/DISPARAGINGLY/g
s/\bDisparingly\b/Disparagingly/g
s/\bdispence\b/dispense/g
s/\bDISPENCE\b/DISPENSE/g
s/\bDispence\b/Dispense/g
s/\bdispenced\b/dispensed/g
s/\bDISPENCED\b/DISPENSED/g
s/\bDispenced\b/Dispensed/g
s/\bdispencing\b/dispensing/g
s/\bDISPENCING\b/DISPENSING/g
s/\bDispencing\b/Dispensing/g
s/\bdispicable\b/despicable/g
s/\bDISPICABLE\b/DESPICABLE/g
s/\bDispicable\b/Despicable/g
s/\bdispite\b/despite/g
s/\bDISPITE\b/DESPITE/g
s/\bDispite\b/Despite/g
s/\bdispostion\b/disposition/g
s/\bDISPOSTION\b/DISPOSITION/g
s/\bDispostion\b/Disposition/g
s/\bdisproportiate\b/disproportionate/g
s/\bDISPROPORTIATE\b/DISPROPORTIONATE/g
s/\bDisproportiate\b/Disproportionate/g
s/\bdisputandem\b/disputandum/g
s/\bDISPUTANDEM\b/DISPUTANDUM/g
s/\bDisputandem\b/Disputandum/g
s/\bdisricts\b/districts/g
s/\bDISRICTS\b/DISTRICTS/g
s/\bDisricts\b/Districts/g
s/\bdissagreement\b/disagreement/g
s/\bDISSAGREEMENT\b/DISAGREEMENT/g
s/\bDissagreement\b/Disagreement/g
s/\bdissapear\b/disappear/g
s/\bDISSAPEAR\b/DISAPPEAR/g
s/\bDissapear\b/Disappear/g
s/\bdissapearance\b/disappearance/g
s/\bDISSAPEARANCE\b/DISAPPEARANCE/g
s/\bDissapearance\b/Disappearance/g
s/\bdissapeared\b/disappeared/g
s/\bDISSAPEARED\b/DISAPPEARED/g
s/\bDissapeared\b/Disappeared/g
s/\bdissapearing\b/disappearing/g
s/\bDISSAPEARING\b/DISAPPEARING/g
s/\bDissapearing\b/Disappearing/g
s/\bdissapears\b/disappears/g
s/\bDISSAPEARS\b/DISAPPEARS/g
s/\bDissapears\b/Disappears/g
s/\bdissappear\b/disappear/g
s/\bDISSAPPEAR\b/DISAPPEAR/g
s/\bDissappear\b/Disappear/g
s/\bdissappointed\b/disappointed/g
s/\bDISSAPPOINTED\b/DISAPPOINTED/g
s/\bDissappointed\b/Disappointed/g
s/\bdissarray\b/disarray/g
s/\bDISSARRAY\b/DISARRAY/g
s/\bDissarray\b/Disarray/g
s/\bdissobediance\b/disobedience/g
s/\bDISSOBEDIANCE\b/DISOBEDIENCE/g
s/\bDissobediance\b/Disobedience/g
s/\bdissobediant\b/disobedient/g
s/\bDISSOBEDIANT\b/DISOBEDIENT/g
s/\bDissobediant\b/Disobedient/g
s/\bdissobedience\b/disobedience/g
s/\bDISSOBEDIENCE\b/DISOBEDIENCE/g
s/\bDissobedience\b/Disobedience/g
s/\bdissobedient\b/disobedient/g
s/\bDISSOBEDIENT\b/DISOBEDIENT/g
s/\bDissobedient\b/Disobedient/g
s/\bdistiction\b/distinction/g
s/\bDISTICTION\b/DISTINCTION/g
s/\bDistiction\b/Distinction/g
s/\bdistingish\b/distinguish/g
s/\bDISTINGISH\b/DISTINGUISH/g
s/\bDistingish\b/Distinguish/g
s/\bdistingished\b/distinguished/g
s/\bDISTINGISHED\b/DISTINGUISHED/g
s/\bDistingished\b/Distinguished/g
s/\bdistingishes\b/distinguishes/g
s/\bDISTINGISHES\b/DISTINGUISHES/g
s/\bDistingishes\b/Distinguishes/g
s/\bdistingishing\b/distinguishing/g
s/\bDISTINGISHING\b/DISTINGUISHING/g
s/\bDistingishing\b/Distinguishing/g
s/\bdistingquished\b/distinguished/g
s/\bDISTINGQUISHED\b/DISTINGUISHED/g
s/\bDistingquished\b/Distinguished/g
s/\bdistrubution\b/distribution/g
s/\bDISTRUBUTION\b/DISTRIBUTION/g
s/\bDistrubution\b/Distribution/g
s/\bdistruction\b/destruction/g
s/\bDISTRUCTION\b/DESTRUCTION/g
s/\bDistruction\b/Destruction/g
s/\bdistructive\b/destructive/g
s/\bDISTRUCTIVE\b/DESTRUCTIVE/g
s/\bDistructive\b/Destructive/g
s/\bditributed\b/distributed/g
s/\bDITRIBUTED\b/DISTRIBUTED/g
s/\bDitributed\b/Distributed/g
s/\bdivice\b/device/g
s/\bDIVICE\b/DEVICE/g
s/\bDivice\b/Device/g
s/\bdivinition\b/divination/g
s/\bDIVINITION\b/DIVINATION/g
s/\bDivinition\b/Divination/g
s/\bdivisons\b/divisions/g
s/\bDIVISONS\b/DIVISIONS/g
s/\bDivisons\b/Divisions/g
s/\bdoccument\b/document/g
s/\bDOCCUMENT\b/DOCUMENT/g
s/\bDoccument\b/Document/g
s/\bdoccumented\b/documented/g
s/\bDOCCUMENTED\b/DOCUMENTED/g
s/\bDoccumented\b/Documented/g
s/\bdoccuments\b/documents/g
s/\bDOCCUMENTS\b/DOCUMENTS/g
s/\bDoccuments\b/Documents/g
s/\bdocrines\b/doctrines/g
s/\bDOCRINES\b/DOCTRINES/g
s/\bDocrines\b/Doctrines/g
s/\bdoctines\b/doctrines/g
s/\bDOCTINES\b/DOCTRINES/g
s/\bDoctines\b/Doctrines/g
s/\bdocumenatry\b/documentary/g
s/\bDOCUMENATRY\b/DOCUMENTARY/g
s/\bDocumenatry\b/Documentary/g
s/\bdoens\b/does/g
s/\bDOENS\b/DOES/g
s/\bDoens\b/Does/g
s/\bdoign\b/doing/g
s/\bDOIGN\b/DOING/g
s/\bDoign\b/Doing/g
s/\bdominaton\b/domination/g
s/\bDOMINATON\b/DOMINATION/g
s/\bDominaton\b/Domination/g
s/\bdominent\b/dominant/g
s/\bDOMINENT\b/DOMINANT/g
s/\bDominent\b/Dominant/g
s/\bdominiant\b/dominant/g
s/\bDOMINIANT\b/DOMINANT/g
s/\bDominiant\b/Dominant/g
s/\bdonig\b/doing/g
s/\bDONIG\b/DOING/g
s/\bDonig\b/Doing/g
s/\bdosen't\b/doesn't/g
s/\bDOSEN'T\b/DOESN'T/g
s/\bDosen't\b/Doesn't/g
s/\bdoulbe\b/double/g
s/\bDOULBE\b/DOUBLE/g
s/\bDoulbe\b/Double/g
s/\bdowloads\b/downloads/g
s/\bDOWLOADS\b/DOWNLOADS/g
s/\bDowloads\b/Downloads/g
s/\bdramtic\b/dramatic/g
s/\bDRAMTIC\b/DRAMATIC/g
s/\bDramtic\b/Dramatic/g
s/\bdraughtman\b/draughtsman/g
s/\bDRAUGHTMAN\b/DRAUGHTSMAN/g
s/\bDraughtman\b/Draughtsman/g
s/\bdreasm\b/dreams/g
s/\bDREASM\b/DREAMS/g
s/\bDreasm\b/Dreams/g
s/\bdriectly\b/directly/g
s/\bDRIECTLY\b/DIRECTLY/g
s/\bDriectly\b/Directly/g
s/\bdrnik\b/drink/g
s/\bDRNIK\b/DRINK/g
s/\bDrnik\b/Drink/g
s/\bdruming\b/drumming/g
s/\bDRUMING\b/DRUMMING/g
s/\bDruming\b/Drumming/g
s/\bdrummless\b/drumless/g
s/\bDRUMMLESS\b/DRUMLESS/g
s/\bDrummless\b/Drumless/g
s/\bdum\b/dumb/g
s/\bDUM\b/DUMB/g
s/\bDum\b/Dumb/g
s/\bdurig\b/during/g
s/\bDURIG\b/DURING/g
s/\bDurig\b/During/g
s/\bdurring\b/during/g
s/\bDURRING\b/DURING/g
s/\bDurring\b/During/g
s/\bduting\b/during/g
s/\bDUTING\b/DURING/g
s/\bDuting\b/During/g
s/\bdyas\b/dryas/g
s/\bDYAS\b/DRYAS/g
s/\bDyas\b/Dryas/g
s/\beahc\b/each/g
s/\bEAHC\b/EACH/g
s/\bEahc\b/Each/g
s/\bealier\b/earlier/g
s/\bEALIER\b/EARLIER/g
s/\bEalier\b/Earlier/g
s/\bearlies\b/earliest/g
s/\bEARLIES\b/EARLIEST/g
s/\bEarlies\b/Earliest/g
s/\bearnt\b/earned/g
s/\bEARNT\b/EARNED/g
s/\bEarnt\b/Earned/g
s/\becclectic\b/eclectic/g
s/\bECCLECTIC\b/ECLECTIC/g
s/\bEcclectic\b/Eclectic/g
s/\beceonomy\b/economy/g
s/\bECEONOMY\b/ECONOMY/g
s/\bEceonomy\b/Economy/g
s/\becidious\b/deciduous/g
s/\bECIDIOUS\b/DECIDUOUS/g
s/\bEcidious\b/Deciduous/g
s/\beclispe\b/eclipse/g
s/\bECLISPE\b/ECLIPSE/g
s/\bEclispe\b/Eclipse/g
s/\becomonic\b/economic/g
s/\bECOMONIC\b/ECONOMIC/g
s/\bEcomonic\b/Economic/g
s/\bect\b/etc/g
s/\bECT\b/ETC/g
s/\bEct\b/Etc/g
s/\beearly\b/early/g
s/\bEEARLY\b/EARLY/g
s/\bEearly\b/Early/g
s/\befel\b/evil/g
s/\bEFEL\b/EVIL/g
s/\bEfel\b/Evil/g
s/\beffeciency\b/efficiency/g
s/\bEFFECIENCY\b/EFFICIENCY/g
s/\bEffeciency\b/Efficiency/g
s/\beffecient\b/efficient/g
s/\bEFFECIENT\b/EFFICIENT/g
s/\bEffecient\b/Efficient/g
s/\beffeciently\b/efficiently/g
s/\bEFFECIENTLY\b/EFFICIENTLY/g
s/\bEffeciently\b/Efficiently/g
s/\befficency\b/efficiency/g
s/\bEFFICENCY\b/EFFICIENCY/g
s/\bEfficency\b/Efficiency/g
s/\befficently\b/efficiently/g
s/\bEFFICENTLY\b/EFFICIENTLY/g
s/\bEfficently\b/Efficiently/g
s/\beffulence\b/effluence/g
s/\bEFFULENCE\b/EFFLUENCE/g
s/\bEffulence\b/Effluence/g
s/\beiter\b/either/g
s/\bEITER\b/EITHER/g
s/\bEiter\b/Either/g
s/\belction\b/election/g
s/\bELCTION\b/ELECTION/g
s/\bElction\b/Election/g
s/\belectrial\b/electrical/g
s/\bELECTRIAL\b/ELECTRICAL/g
s/\bElectrial\b/Electrical/g
s/\belectricly\b/electrically/g
s/\bELECTRICLY\b/ELECTRICALLY/g
s/\bElectricly\b/Electrically/g
s/\belectricty\b/electricity/g
s/\bELECTRICTY\b/ELECTRICITY/g
s/\bElectricty\b/Electricity/g
s/\belementay\b/elementary/g
s/\bELEMENTAY\b/ELEMENTARY/g
s/\bElementay\b/Elementary/g
s/\beleminated\b/eliminated/g
s/\bELEMINATED\b/ELIMINATED/g
s/\bEleminated\b/Eliminated/g
s/\beleminating\b/eliminating/g
s/\bELEMINATING\b/ELIMINATING/g
s/\bEleminating\b/Eliminating/g
s/\beles\b/eels/g
s/\bELES\b/EELS/g
s/\bEles\b/Eels/g
s/\beletricity\b/electricity/g
s/\bELETRICITY\b/ELECTRICITY/g
s/\bEletricity\b/Electricity/g
s/\belicided\b/elicited/g
s/\bELICIDED\b/ELICITED/g
s/\bElicided\b/Elicited/g
s/\beligable\b/eligible/g
s/\bELIGABLE\b/ELIGIBLE/g
s/\bEligable\b/Eligible/g
s/\belimentary\b/elementary/g
s/\bELIMENTARY\b/ELEMENTARY/g
s/\bElimentary\b/Elementary/g
s/\bellected\b/elected/g
s/\bELLECTED\b/ELECTED/g
s/\bEllected\b/Elected/g
s/\belphant\b/elephant/g
s/\bELPHANT\b/ELEPHANT/g
s/\bElphant\b/Elephant/g
s/\bembarass\b/embarrass/g
s/\bEMBARASS\b/EMBARRASS/g
s/\bEmbarass\b/Embarrass/g
s/\bembarassed\b/embarrassed/g
s/\bEMBARASSED\b/EMBARRASSED/g
s/\bEmbarassed\b/Embarrassed/g
s/\bembarassing\b/embarrassing/g
s/\bEMBARASSING\b/EMBARRASSING/g
s/\bEmbarassing\b/Embarrassing/g
s/\bembarassment\b/embarrassment/g
s/\bEMBARASSMENT\b/EMBARRASSMENT/g
s/\bEmbarassment\b/Embarrassment/g
s/\bembargos\b/embargoes/g
s/\bEMBARGOS\b/EMBARGOES/g
s/\bEmbargos\b/Embargoes/g
s/\bembarras\b/embarrass/g
s/\bEMBARRAS\b/EMBARRASS/g
s/\bEmbarras\b/Embarrass/g
s/\bembarrased\b/embarrassed/g
s/\bEMBARRASED\b/EMBARRASSED/g
s/\bEmbarrased\b/Embarrassed/g
s/\bembarrasing\b/embarrassing/g
s/\bEMBARRASING\b/EMBARRASSING/g
s/\bEmbarrasing\b/Embarrassing/g
s/\bembarrasment\b/embarrassment/g
s/\bEMBARRASMENT\b/EMBARRASSMENT/g
s/\bEmbarrasment\b/Embarrassment/g
s/\bembezelled\b/embezzled/g
s/\bEMBEZELLED\b/EMBEZZLED/g
s/\bEmbezelled\b/Embezzled/g
s/\bemblamatic\b/emblematic/g
s/\bEMBLAMATIC\b/EMBLEMATIC/g
s/\bEmblamatic\b/Emblematic/g
s/\beminate\b/emanate/g
s/\bEMINATE\b/EMANATE/g
s/\bEminate\b/Emanate/g
s/\beminated\b/emanated/g
s/\bEMINATED\b/EMANATED/g
s/\bEminated\b/Emanated/g
s/\bemision\b/emission/g
s/\bEMISION\b/EMISSION/g
s/\bEmision\b/Emission/g
s/\bemited\b/emitted/g
s/\bEMITED\b/EMITTED/g
s/\bEmited\b/Emitted/g
s/\bemiting\b/emitting/g
s/\bEMITING\b/EMITTING/g
s/\bEmiting\b/Emitting/g
s/\bemmediately\b/immediately/g
s/\bEMMEDIATELY\b/IMMEDIATELY/g
s/\bEmmediately\b/Immediately/g
s/\bemminently\b/eminently/g
s/\bEMMINENTLY\b/EMINENTLY/g
s/\bEmminently\b/Eminently/g
s/\bemmisaries\b/emissaries/g
s/\bEMMISARIES\b/EMISSARIES/g
s/\bEmmisaries\b/Emissaries/g
s/\bemmisarries\b/emissaries/g
s/\bEMMISARRIES\b/EMISSARIES/g
s/\bEmmisarries\b/Emissaries/g
s/\bemmisarry\b/emissary/g
s/\bEMMISARRY\b/EMISSARY/g
s/\bEmmisarry\b/Emissary/g
s/\bemmisary\b/emissary/g
s/\bEMMISARY\b/EMISSARY/g
s/\bEmmisary\b/Emissary/g
s/\bemmision\b/emission/g
s/\bEMMISION\b/EMISSION/g
s/\bEmmision\b/Emission/g
s/\bemmisions\b/emissions/g
s/\bEMMISIONS\b/EMISSIONS/g
s/\bEmmisions\b/Emissions/g
s/\bemmited\b/emitted/g
s/\bEMMITED\b/EMITTED/g
s/\bEmmited\b/Emitted/g
s/\bemmiting\b/emitting/g
s/\bEMMITING\b/EMITTING/g
s/\bEmmiting\b/Emitting/g
s/\bemmitted\b/emitted/g
s/\bEMMITTED\b/EMITTED/g
s/\bEmmitted\b/Emitted/g
s/\bemmitting\b/emitting/g
s/\bEMMITTING\b/EMITTING/g
s/\bEmmitting\b/Emitting/g
s/\bemnity\b/enmity/g
s/\bEMNITY\b/ENMITY/g
s/\bEmnity\b/Enmity/g
s/\bemperical\b/empirical/g
s/\bEMPERICAL\b/EMPIRICAL/g
s/\bEmperical\b/Empirical/g
s/\bemphaised\b/emphasised/g
s/\bEMPHAISED\b/EMPHASISED/g
s/\bEmphaised\b/Emphasised/g
s/\bemphsis\b/emphasis/g
s/\bEMPHSIS\b/EMPHASIS/g
s/\bEmphsis\b/Emphasis/g
s/\bemphysyma\b/emphysema/g
s/\bEMPHYSYMA\b/EMPHYSEMA/g
s/\bEmphysyma\b/Emphysema/g
s/\bemporer\b/emperor/g
s/\bEMPORER\b/EMPEROR/g
s/\bEmporer\b/Emperor/g
s/\bemprisoned\b/imprisoned/g
s/\bEMPRISONED\b/IMPRISONED/g
s/\bEmprisoned\b/Imprisoned/g
s/\bempted/emptied/g
s/\bEMPTED/EMPTIED/g
s/\bEmpted/Emptied/g
s/\benameld\b/enameled/g
s/\bENAMELD\b/ENAMELED/g
s/\bEnameld\b/Enameled/g
s/\benchancement\b/enhancement/g
s/\bENCHANCEMENT\b/ENHANCEMENT/g
s/\bEnchancement\b/Enhancement/g
s/\bencouraing\b/encouraging/g
s/\bENCOURAING\b/ENCOURAGING/g
s/\bEncouraing\b/Encouraging/g
s/\bencryptiion\b/encryption/g
s/\bENCRYPTIION\b/ENCRYPTION/g
s/\bEncryptiion\b/Encryption/g
s/\bencylopedia\b/encyclopedia/g
s/\bENCYLOPEDIA\b/ENCYCLOPEDIA/g
s/\bEncylopedia\b/Encyclopedia/g
s/\bendevors\b/endeavors/g
s/\bENDEVORS\b/ENDEAVORS/g
s/\bEndevors\b/Endeavors/g
s/\bendevour\b/endeavour/g
s/\bENDEVOUR\b/ENDEAVOUR/g
s/\bEndevour\b/Endeavour/g
s/\bendig\b/ending/g
s/\bENDIG\b/ENDING/g
s/\bEndig\b/Ending/g
s/\bendolithes\b/endoliths/g
s/\bENDOLITHES\b/ENDOLITHS/g
s/\bEndolithes\b/Endoliths/g
s/\benduce\b/induce/g
s/\bENDUCE\b/INDUCE/g
s/\bEnduce\b/Induce/g
s/\bened\b/need/g
s/\bENED\b/NEED/g
s/\bEned\b/Need/g
s/\benforceing\b/enforcing/g
s/\bENFORCEING\b/ENFORCING/g
s/\bEnforceing\b/Enforcing/g
s/\bengagment\b/engagement/g
s/\bENGAGMENT\b/ENGAGEMENT/g
s/\bEngagment\b/Engagement/g
s/\bengeneer\b/engineer/g
s/\bENGENEER\b/ENGINEER/g
s/\bEngeneer\b/Engineer/g
s/\bengeneering\b/engineering/g
s/\bENGENEERING\b/ENGINEERING/g
s/\bEngeneering\b/Engineering/g
s/\bengieneer\b/engineer/g
s/\bENGIENEER\b/ENGINEER/g
s/\bEngieneer\b/Engineer/g
s/\bengieneers\b/engineers/g
s/\bENGIENEERS\b/ENGINEERS/g
s/\bEngieneers\b/Engineers/g
s/\benlargment\b/enlargement/g
s/\bENLARGMENT\b/ENLARGEMENT/g
s/\bEnlargment\b/Enlargement/g
s/\benlargments\b/enlargements/g
s/\bENLARGMENTS\b/ENLARGEMENTS/g
s/\bEnlargments\b/Enlargements/g
s/\benourmous\b/enormous/g
s/\bENOURMOUS\b/ENORMOUS/g
s/\bEnourmous\b/Enormous/g
s/\benourmously\b/enormously/g
s/\bENOURMOUSLY\b/ENORMOUSLY/g
s/\bEnourmously\b/Enormously/g
s/\bensconsed\b/ensconced/g
s/\bENSCONSED\b/ENSCONCED/g
s/\bEnsconsed\b/Ensconced/g
s/\bentaglements\b/entanglements/g
s/\bENTAGLEMENTS\b/ENTANGLEMENTS/g
s/\bEntaglements\b/Entanglements/g
s/\benteratinment\b/entertainment/g
s/\bENTERATINMENT\b/ENTERTAINMENT/g
s/\bEnteratinment\b/Entertainment/g
s/\benthusiatic\b/enthusiastic/g
s/\bENTHUSIATIC\b/ENTHUSIASTIC/g
s/\bEnthusiatic\b/Enthusiastic/g
s/\bentitity\b/entity/g
s/\bENTITITY\b/ENTITY/g
s/\bEntitity\b/Entity/g
s/\bentitlied\b/entitled/g
s/\bENTITLIED\b/ENTITLED/g
s/\bEntitlied\b/Entitled/g
s/\bentrepeneur\b/entrepreneur/g
s/\bENTREPENEUR\b/ENTREPRENEUR/g
s/\bEntrepeneur\b/Entrepreneur/g
s/\bentrepeneurs\b/entrepreneurs/g
s/\bENTREPENEURS\b/ENTREPRENEURS/g
s/\bEntrepeneurs\b/Entrepreneurs/g
s/\benviorment\b/environment/g
s/\bENVIORMENT\b/ENVIRONMENT/g
s/\bEnviorment\b/Environment/g
s/\benviormental\b/environmental/g
s/\bENVIORMENTAL\b/ENVIRONMENTAL/g
s/\bEnviormental\b/Environmental/g
s/\benviormentally\b/environmentally/g
s/\bENVIORMENTALLY\b/ENVIRONMENTALLY/g
s/\bEnviormentally\b/Environmentally/g
s/\benviorments\b/environments/g
s/\bENVIORMENTS\b/ENVIRONMENTS/g
s/\bEnviorments\b/Environments/g
s/\benviornment\b/environment/g
s/\bENVIORNMENT\b/ENVIRONMENT/g
s/\bEnviornment\b/Environment/g
s/\benviornmental\b/environmental/g
s/\bENVIORNMENTAL\b/ENVIRONMENTAL/g
s/\bEnviornmental\b/Environmental/g
s/\benviornmentalist\b/environmentalist/g
s/\bENVIORNMENTALIST\b/ENVIRONMENTALIST/g
s/\bEnviornmentalist\b/Environmentalist/g
s/\benviornmentally\b/environmentally/g
s/\bENVIORNMENTALLY\b/ENVIRONMENTALLY/g
s/\bEnviornmentally\b/Environmentally/g
s/\benviornments\b/environments/g
s/\bENVIORNMENTS\b/ENVIRONMENTS/g
s/\bEnviornments\b/Environments/g
s/\benviromentalist\b/environmentalist/g
s/\bENVIROMENTALIST\b/ENVIRONMENTALIST/g
s/\bEnviromentalist\b/Environmentalist/g
s/\benviromentally\b/environmentally/g
s/\bENVIROMENTALLY\b/ENVIRONMENTALLY/g
s/\bEnviromentally\b/Environmentally/g
s/\benviroments\b/environments/g
s/\bENVIROMENTS\b/ENVIRONMENTS/g
s/\bEnviroments\b/Environments/g
s/\benvolutionary\b/evolutionary/g
s/\bENVOLUTIONARY\b/EVOLUTIONARY/g
s/\bEnvolutionary\b/Evolutionary/g
s/\benvrionments\b/environments/g
s/\bENVRIONMENTS\b/ENVIRONMENTS/g
s/\bEnvrionments\b/Environments/g
s/\benxt\b/next/g
s/\bENXT\b/NEXT/g
s/\bEnxt\b/Next/g
s/\bepidsodes\b/episodes/g
s/\bEPIDSODES\b/EPISODES/g
s/\bEpidsodes\b/Episodes/g
s/\bepsiode\b/episode/g
s/\bEPSIODE\b/EPISODE/g
s/\bEpsiode\b/Episode/g
s/\bequialent\b/equivalent/g
s/\bEQUIALENT\b/EQUIVALENT/g
s/\bEquialent\b/Equivalent/g
s/\bequilibium\b/equilibrium/g
s/\bEQUILIBIUM\b/EQUILIBRIUM/g
s/\bEquilibium\b/Equilibrium/g
s/\bequilibrum\b/equilibrium/g
s/\bEQUILIBRUM\b/EQUILIBRIUM/g
s/\bEquilibrum\b/Equilibrium/g
s/\bequiped\b/equipped/g
s/\bEQUIPED\b/EQUIPPED/g
s/\bEquiped\b/Equipped/g
s/\bequippment\b/equipment/g
s/\bEQUIPPMENT\b/EQUIPMENT/g
s/\bEquippment\b/Equipment/g
s/\bequitorial\b/equatorial/g
s/\bEQUITORIAL\b/EQUATORIAL/g
s/\bEquitorial\b/Equatorial/g
s/\bequivilant\b/equivalent/g
s/\bEQUIVILANT\b/EQUIVALENT/g
s/\bEquivilant\b/Equivalent/g
s/\bequivilent\b/equivalent/g
s/\bEQUIVILENT\b/EQUIVALENT/g
s/\bEquivilent\b/Equivalent/g
s/\bequivlalent\b/equivalent/g
s/\bEQUIVLALENT\b/EQUIVALENT/g
s/\bEquivlalent\b/Equivalent/g
s/\beratic\b/erratic/g
s/\bERATIC\b/ERRATIC/g
s/\bEratic\b/Erratic/g
s/\beratically\b/erratically/g
s/\bERATICALLY\b/ERRATICALLY/g
s/\bEratically\b/Erratically/g
s/\beraticly\b/erratically/g
s/\bERATICLY\b/ERRATICALLY/g
s/\bEraticly\b/Erratically/g
s/\berrupted\b/erupted/g
s/\bERRUPTED\b/ERUPTED/g
s/\bErrupted\b/Erupted/g
s/\besential\b/essential/g
s/\bESENTIAL\b/ESSENTIAL/g
s/\bEsential\b/Essential/g
s/\besle\b/else/g
s/\bESLE\b/ELSE/g
s/\bEsle\b/Else/g
s/\bespaced/escaped/g
s/\bESPACED/ESCAPED/g
s/\bEspaced/Escaped/g
s/\bespecialy\b/especially/g
s/\bESPECIALY\b/ESPECIALLY/g
s/\bEspecialy\b/Especially/g
s/\bessencial\b/essential/g
s/\bESSENCIAL\b/ESSENTIAL/g
s/\bEssencial\b/Essential/g
s/\bessense\b/essence/g
s/\bESSENSE\b/ESSENCE/g
s/\bEssense\b/Essence/g
s/\bessentail\b/essential/g
s/\bESSENTAIL\b/ESSENTIAL/g
s/\bEssentail\b/Essential/g
s/\bessentual\b/essential/g
s/\bESSENTUAL\b/ESSENTIAL/g
s/\bEssentual\b/Essential/g
s/\bessesital\b/essential/g
s/\bESSESITAL\b/ESSENTIAL/g
s/\bEssesital\b/Essential/g
s/\bestablising\b/establishing/g
s/\bESTABLISING\b/ESTABLISHING/g
s/\bEstablising\b/Establishing/g
s/\bethnocentricm\b/ethnocentrism/g
s/\bETHNOCENTRICM\b/ETHNOCENTRISM/g
s/\bEthnocentricm\b/Ethnocentrism/g
s/\bevenhtually\b/eventually/g
s/\bEVENHTUALLY\b/EVENTUALLY/g
s/\bEvenhtually\b/Eventually/g
s/\beventally\b/eventually/g
s/\bEVENTALLY\b/EVENTUALLY/g
s/\bEventally\b/Eventually/g
s/\beventially\b/eventually/g
s/\bEVENTIALLY\b/EVENTUALLY/g
s/\bEventially\b/Eventually/g
s/\beventualy\b/eventually/g
s/\bEVENTUALY\b/EVENTUALLY/g
s/\bEventualy\b/Eventually/g
s/\beverthing\b/everything/g
s/\bEVERTHING\b/EVERYTHING/g
s/\bEverthing\b/Everything/g
s/\beveryting\b/everything/g
s/\bEVERYTING\b/EVERYTHING/g
s/\bEveryting\b/Everything/g
s/\beveyr\b/every/g
s/\bEVEYR\b/EVERY/g
s/\bEveyr\b/Every/g
s/\bevidentally\b/evidently/g
s/\bEVIDENTALLY\b/EVIDENTLY/g
s/\bEvidentally\b/Evidently/g
s/\bexagerate\b/exaggerate/g
s/\bEXAGERATE\b/EXAGGERATE/g
s/\bExagerate\b/Exaggerate/g
s/\bexagerated\b/exaggerated/g
s/\bEXAGERATED\b/EXAGGERATED/g
s/\bExagerated\b/Exaggerated/g
s/\bexagerates\b/exaggerates/g
s/\bEXAGERATES\b/EXAGGERATES/g
s/\bExagerates\b/Exaggerates/g
s/\bexagerating\b/exaggerating/g
s/\bEXAGERATING\b/EXAGGERATING/g
s/\bExagerating\b/Exaggerating/g
s/\bexagerrate\b/exaggerate/g
s/\bEXAGERRATE\b/EXAGGERATE/g
s/\bExagerrate\b/Exaggerate/g
s/\bexagerrated\b/exaggerated/g
s/\bEXAGERRATED\b/EXAGGERATED/g
s/\bExagerrated\b/Exaggerated/g
s/\bexagerrates\b/exaggerates/g
s/\bEXAGERRATES\b/EXAGGERATES/g
s/\bExagerrates\b/Exaggerates/g
s/\bexagerrating\b/exaggerating/g
s/\bEXAGERRATING\b/EXAGGERATING/g
s/\bExagerrating\b/Exaggerating/g
s/\bexaminated\b/examined/g
s/\bEXAMINATED\b/EXAMINED/g
s/\bExaminated\b/Examined/g
s/\bexampt\b/exempt/g
s/\bEXAMPT\b/EXEMPT/g
s/\bExampt\b/Exempt/g
s/\bexapansion\b/expansion/g
s/\bEXAPANSION\b/EXPANSION/g
s/\bExapansion\b/Expansion/g
s/\bexcact\b/exact/g
s/\bEXCACT\b/EXACT/g
s/\bExcact\b/Exact/g
s/\bexcange\b/exchange/g
s/\bEXCANGE\b/EXCHANGE/g
s/\bExcange\b/Exchange/g
s/\bexcecute\b/execute/g
s/\bEXCECUTE\b/EXECUTE/g
s/\bExcecute\b/Execute/g
s/\bexcecuted\b/executed/g
s/\bEXCECUTED\b/EXECUTED/g
s/\bExcecuted\b/Executed/g
s/\bexcecutes\b/executes/g
s/\bEXCECUTES\b/EXECUTES/g
s/\bExcecutes\b/Executes/g
s/\bexcecuting\b/executing/g
s/\bEXCECUTING\b/EXECUTING/g
s/\bExcecuting\b/Executing/g
s/\bexcecution\b/execution/g
s/\bEXCECUTION\b/EXECUTION/g
s/\bExcecution\b/Execution/g
s/\bexcedded\b/exceeded/g
s/\bEXCEDDED\b/EXCEEDED/g
s/\bExcedded\b/Exceeded/g
s/\bexcelent\b/excellent/g
s/\bEXCELENT\b/EXCELLENT/g
s/\bExcelent\b/Excellent/g
s/\bexcell\b/excel/g
s/\bEXCELL\b/EXCEL/g
s/\bExcell\b/Excel/g
s/\bexcellance\b/excellence/g
s/\bEXCELLANCE\b/EXCELLENCE/g
s/\bExcellance\b/Excellence/g
s/\bexcellant\b/excellent/g
s/\bEXCELLANT\b/EXCELLENT/g
s/\bExcellant\b/Excellent/g
s/\bexcells\b/excels/g
s/\bEXCELLS\b/EXCELS/g
s/\bExcells\b/Excels/g
s/\bexchanching\b/exchanging/g
s/\bEXCHANCHING\b/EXCHANGING/g
s/\bExchanching\b/Exchanging/g
s/\bexcisted\b/existed/g
s/\bEXCISTED\b/EXISTED/g
s/\bExcisted\b/Existed/g
s/\bexculsivly\b/exclusively/g
s/\bEXCULSIVLY\b/EXCLUSIVELY/g
s/\bExculsivly\b/Exclusively/g
s/\bexecising\b/exercising/g
s/\bEXECISING\b/EXERCISING/g
s/\bExecising\b/Exercising/g
s/\bexection\b/execution/g
s/\bEXECTION\b/EXECUTION/g
s/\bExection\b/Execution/g
s/\bexectued\b/executed/g
s/\bEXECTUED\b/EXECUTED/g
s/\bExectued\b/Executed/g
s/\bexeedingly\b/exceedingly/g
s/\bEXEEDINGLY\b/EXCEEDINGLY/g
s/\bExeedingly\b/Exceedingly/g
s/\bexelent\b/excellent/g
s/\bEXELENT\b/EXCELLENT/g
s/\bExelent\b/Excellent/g
s/\bexellent\b/excellent/g
s/\bEXELLENT\b/EXCELLENT/g
s/\bExellent\b/Excellent/g
s/\bexemple\b/example/g
s/\bEXEMPLE\b/EXAMPLE/g
s/\bExemple\b/Example/g
s/\bexept\b/except/g
s/\bEXEPT\b/EXCEPT/g
s/\bExept\b/Except/g
s/\bexeptional\b/exceptional/g
s/\bEXEPTIONAL\b/EXCEPTIONAL/g
s/\bExeptional\b/Exceptional/g
s/\bexerbate\b/exacerbate/g
s/\bEXERBATE\b/EXACERBATE/g
s/\bExerbate\b/Exacerbate/g
s/\bexerbated\b/exacerbated/g
s/\bEXERBATED\b/EXACERBATED/g
s/\bExerbated\b/Exacerbated/g
s/\bexerciese\b/exercises/g
s/\bEXERCIESE\b/EXERCISES/g
s/\bExerciese\b/Exercises/g
s/\bexerpt\b/excerpt/g
s/\bEXERPT\b/EXCERPT/g
s/\bExerpt\b/Excerpt/g
s/\bexerpts\b/excerpts/g
s/\bEXERPTS\b/EXCERPTS/g
s/\bExerpts\b/Excerpts/g
s/\bexersize\b/exercise/g
s/\bEXERSIZE\b/EXERCISE/g
s/\bExersize\b/Exercise/g
s/\bexerternal\b/external/g
s/\bEXERTERNAL\b/EXTERNAL/g
s/\bExerternal\b/External/g
s/\bexhalted\b/exalted/g
s/\bEXHALTED\b/EXALTED/g
s/\bExhalted\b/Exalted/g
s/\bexhibtion\b/exhibition/g
s/\bEXHIBTION\b/EXHIBITION/g
s/\bExhibtion\b/Exhibition/g
s/\bexibition\b/exhibition/g
s/\bEXIBITION\b/EXHIBITION/g
s/\bExibition\b/Exhibition/g
s/\bexibitions\b/exhibitions/g
s/\bEXIBITIONS\b/EXHIBITIONS/g
s/\bExibitions\b/Exhibitions/g
s/\bexicting\b/exciting/g
s/\bEXICTING\b/EXCITING/g
s/\bExicting\b/Exciting/g
s/\bexinct\b/extinct/g
s/\bEXINCT\b/EXTINCT/g
s/\bExinct\b/Extinct/g
s/\bexistince\b/existence/g
s/\bEXISTINCE\b/EXISTENCE/g
s/\bExistince\b/Existence/g
s/\bexliled\b/exiled/g
s/\bEXLILED\b/EXILED/g
s/\bExliled\b/Exiled/g
s/\bexludes\b/excludes/g
s/\bEXLUDES\b/EXCLUDES/g
s/\bExludes\b/Excludes/g
s/\bexonorate\b/exonerate/g
s/\bEXONORATE\b/EXONERATE/g
s/\bExonorate\b/Exonerate/g
s/\bexoskelaton\b/exoskeleton/g
s/\bEXOSKELATON\b/EXOSKELETON/g
s/\bExoskelaton\b/Exoskeleton/g
s/\bexpalin\b/explain/g
s/\bEXPALIN\b/EXPLAIN/g
s/\bExpalin\b/Explain/g
s/\bexpatriot\b/expatriate/g
s/\bEXPATRIOT\b/EXPATRIATE/g
s/\bExpatriot\b/Expatriate/g
s/\bexpeced\b/expected/g
s/\bEXPECED\b/EXPECTED/g
s/\bExpeced\b/Expected/g
s/\bexpecially\b/especially/g
s/\bEXPECIALLY\b/ESPECIALLY/g
s/\bExpecially\b/Especially/g
s/\bexpeditonary\b/expeditionary/g
s/\bEXPEDITONARY\b/EXPEDITIONARY/g
s/\bExpeditonary\b/Expeditionary/g
s/\bexpeiments\b/experiments/g
s/\bEXPEIMENTS\b/EXPERIMENTS/g
s/\bExpeiments\b/Experiments/g
s/\bexpell\b/expel/g
s/\bEXPELL\b/EXPEL/g
s/\bExpell\b/Expel/g
s/\bexpells\b/expels/g
s/\bEXPELLS\b/EXPELS/g
s/\bExpells\b/Expels/g
s/\bexperiance\b/experience/g
s/\bEXPERIANCE\b/EXPERIENCE/g
s/\bExperiance\b/Experience/g
s/\bexperianced\b/experienced/g
s/\bEXPERIANCED\b/EXPERIENCED/g
s/\bExperianced\b/Experienced/g
s/\bexpiditions\b/expeditions/g
s/\bEXPIDITIONS\b/EXPEDITIONS/g
s/\bExpiditions\b/Expeditions/g
s/\bexpierence\b/experience/g
s/\bEXPIERENCE\b/EXPERIENCE/g
s/\bExpierence\b/Experience/g
s/\bexplaination\b/explanation/g
s/\bEXPLAINATION\b/EXPLANATION/g
s/\bExplaination\b/Explanation/g
s/\bexplaning\b/explaining/g
s/\bEXPLANING\b/EXPLAINING/g
s/\bExplaning\b/Explaining/g
s/\bexploititive\b/exploitative/g
s/\bEXPLOITITIVE\b/EXPLOITATIVE/g
s/\bExploititive\b/Exploitative/g
s/\bexplotation\b/exploitation/g
s/\bEXPLOTATION\b/EXPLOITATION/g
s/\bExplotation\b/Exploitation/g
s/\bexpropiated\b/expropriated/g
s/\bEXPROPIATED\b/EXPROPRIATED/g
s/\bExpropiated\b/Expropriated/g
s/\bexpropiation\b/expropriation/g
s/\bEXPROPIATION\b/EXPROPRIATION/g
s/\bExpropiation\b/Expropriation/g
s/\bexressed\b/expressed/g
s/\bEXRESSED\b/EXPRESSED/g
s/\bExressed\b/Expressed/g
s/\bextemely\b/extremely/g
s/\bEXTEMELY\b/EXTREMELY/g
s/\bExtemely\b/Extremely/g
s/\bextered\b/exerted/g
s/\bEXTERED\b/EXERTED/g
s/\bExtered\b/Exerted/g
s/\bextermist\b/extremist/g
s/\bEXTERMIST\b/EXTREMIST/g
s/\bExtermist\b/Extremist/g
s/\bextradiction\b/extradition/g
s/\bEXTRADICTION\b/EXTRADITION/g
s/\bExtradiction\b/Extradition/g
s/\bextraterrestial\b/extraterrestrial/g
s/\bEXTRATERRESTIAL\b/EXTRATERRESTRIAL/g
s/\bExtraterrestial\b/Extraterrestrial/g
s/\bextraterrestials\b/extraterrestrials/g
s/\bEXTRATERRESTIALS\b/EXTRATERRESTRIALS/g
s/\bExtraterrestials\b/Extraterrestrials/g
s/\bextravagent\b/extravagant/g
s/\bEXTRAVAGENT\b/EXTRAVAGANT/g
s/\bExtravagent\b/Extravagant/g
s/\bextrememly\b/extremely/g
s/\bEXTREMEMLY\b/EXTREMELY/g
s/\bExtrememly\b/Extremely/g
s/\bextremeophile\b/extremophile/g
s/\bEXTREMEOPHILE\b/EXTREMOPHILE/g
s/\bExtremeophile\b/Extremophile/g
s/\bextrordinarily\b/extraordinarily/g
s/\bEXTRORDINARILY\b/EXTRAORDINARILY/g
s/\bExtrordinarily\b/Extraordinarily/g
s/\bextrordinary\b/extraordinary/g
s/\bEXTRORDINARY\b/EXTRAORDINARY/g
s/\bExtrordinary\b/Extraordinary/g
s/\bfaciliate\b/facilitate/g
s/\bFACILIATE\b/FACILITATE/g
s/\bFaciliate\b/Facilitate/g
s/\bfaciliated\b/facilitated/g
s/\bFACILIATED\b/FACILITATED/g
s/\bFaciliated\b/Facilitated/g
s/\bfaciliates\b/facilitates/g
s/\bFACILIATES\b/FACILITATES/g
s/\bFaciliates\b/Facilitates/g
s/\bfacilites\b/facilities/g
s/\bFACILITES\b/FACILITIES/g
s/\bFacilites\b/Facilities/g
s/\bfacillitate\b/facilitate/g
s/\bFACILLITATE\b/FACILITATE/g
s/\bFacillitate\b/Facilitate/g
s/\bfacinated\b/fascinated/g
s/\bFACINATED\b/FASCINATED/g
s/\bFacinated\b/Fascinated/g
s/\bfacist\b/fascist/g
s/\bFACIST\b/FASCIST/g
s/\bFacist\b/Fascist/g
s/\bfamiles\b/families/g
s/\bFAMILES\b/FAMILIES/g
s/\bFamiles\b/Families/g
s/\bfamilliar\b/familiar/g
s/\bFAMILLIAR\b/FAMILIAR/g
s/\bFamilliar\b/Familiar/g
s/\bfamoust\b/famous/g
s/\bFAMOUST\b/FAMOUS/g
s/\bFamoust\b/Famous/g
s/\bfanatism\b/fanaticism/g
s/\bFANATISM\b/FANATICISM/g
s/\bFanatism\b/Fanaticism/g
s/\bfatc\b/fact/g
s/\bFATC\b/FACT/g
s/\bFatc\b/Fact/g
s/\bfaught\b/fought/g
s/\bFAUGHT\b/FOUGHT/g
s/\bFaught\b/Fought/g
s/\bfavoutrable\b/favourable/g
s/\bFAVOUTRABLE\b/FAVOURABLE/g
s/\bFavoutrable\b/Favourable/g
s/\bfeasable\b/feasible/g
s/\bFEASABLE\b/FEASIBLE/g
s/\bFeasable\b/Feasible/g
s/\bfedreally\b/federally/g
s/\bFEDREALLY\b/FEDERALLY/g
s/\bFedreally\b/Federally/g
s/\bfemminist\b/feminist/g
s/\bFEMMINIST\b/FEMINIST/g
s/\bFemminist\b/Feminist/g
s/\bferomone\b/pheromone/g
s/\bFEROMONE\b/PHEROMONE/g
s/\bFeromone\b/Pheromone/g
s/\bfertily\b/fertility/g
s/\bFERTILY\b/FERTILITY/g
s/\bFertily\b/Fertility/g
s/\bfianite\b/finite/g
s/\bFIANITE\b/FINITE/g
s/\bFianite\b/Finite/g
s/\bfianlly\b/finally/g
s/\bFIANLLY\b/FINALLY/g
s/\bFianlly\b/Finally/g
s/\bficticious\b/fictitious/g
s/\bFICTICIOUS\b/FICTITIOUS/g
s/\bFicticious\b/Fictitious/g
s/\bfictious\b/fictitious/g
s/\bFICTIOUS\b/FICTITIOUS/g
s/\bFictious\b/Fictitious/g
s/\bfidn\b/find/g
s/\bFIDN\b/FIND/g
s/\bFidn\b/Find/g
s/\bfiercly\b/fiercely/g
s/\bFIERCLY\b/FIERCELY/g
s/\bFiercly\b/Fiercely/g
s/\bfightings\b/fighting/g
s/\bFIGHTINGS\b/FIGHTING/g
s/\bFightings\b/Fighting/g
s/\bfiliament\b/filament/g
s/\bFILIAMENT\b/FILAMENT/g
s/\bFiliament\b/Filament/g
s/\bfimilies\b/families/g
s/\bFIMILIES\b/FAMILIES/g
s/\bFimilies\b/Families/g
s/\bfinacial\b/financial/g
s/\bFINACIAL\b/FINANCIAL/g
s/\bFinacial\b/Financial/g
s/\bfinancialy\b/financially/g
s/\bFINANCIALY\b/FINANCIALLY/g
s/\bFinancialy\b/Financially/g
s/\bfirends\b/friends/g
s/\bFIRENDS\b/FRIENDS/g
s/\bFirends\b/Friends/g
s/\bfisionable\b/fissionable/g
s/\bFISIONABLE\b/FISSIONABLE/g
s/\bFisionable\b/Fissionable/g
s/\bflamable\b/flammable/g
s/\bFLAMABLE\b/FLAMMABLE/g
s/\bFlamable\b/Flammable/g
s/\bflawess\b/flawless/g
s/\bFLAWESS\b/FLAWLESS/g
s/\bFlawess\b/Flawless/g
s/\bflorescent\b/fluorescent/g
s/\bFLORESCENT\b/FLUORESCENT/g
s/\bFlorescent\b/Fluorescent/g
s/\bflourescent\b/fluorescent/g
s/\bFLOURESCENT\b/FLUORESCENT/g
s/\bFlourescent\b/Fluorescent/g
s/\bflourine\b/fluorine/g
s/\bFLOURINE\b/FLUORINE/g
s/\bFlourine\b/Fluorine/g
s/\bflourishment\b/flourishing/g
s/\bFLOURISHMENT\b/FLOURISHING/g
s/\bFlourishment\b/Flourishing/g
s/\bfluorish\b/flourish/g
s/\bFLUORISH\b/FLOURISH/g
s/\bFluorish\b/Flourish/g
s/\bfollwoing\b/following/g
s/\bFOLLWOING\b/FOLLOWING/g
s/\bFollwoing\b/Following/g
s/\bfomed\b/formed/g
s/\bFOMED\b/FORMED/g
s/\bFomed\b/Formed/g
s/\bfonetic\b/phonetic/g
s/\bFONETIC\b/PHONETIC/g
s/\bFonetic\b/Phonetic/g
s/\bfontrier\b/fontier/g
s/\bFONTRIER\b/FONTIER/g
s/\bFontrier\b/Fontier/g
s/\bfoootball\b/football/g
s/\bFOOOTBALL\b/FOOTBALL/g
s/\bFoootball\b/Football/g
s/\bforbad\b/forbade/g
s/\bFORBAD\b/FORBADE/g
s/\bForbad\b/Forbade/g
s/\bforbiden\b/forbidden/g
s/\bFORBIDEN\b/FORBIDDEN/g
s/\bForbiden\b/Forbidden/g
s/\bforeward\b/foreword/g
s/\bFOREWARD\b/FOREWORD/g
s/\bForeward\b/Foreword/g
s/\bforfiet\b/forfeit/g
s/\bFORFIET\b/FORFEIT/g
s/\bForfiet\b/Forfeit/g
s/\bforhead\b/forehead/g
s/\bFORHEAD\b/FOREHEAD/g
s/\bForhead\b/Forehead/g
s/\bforiegn\b/foreign/g
s/\bFORIEGN\b/FOREIGN/g
s/\bForiegn\b/Foreign/g
s/\bformallize\b/formalize/g
s/\bFORMALLIZE\b/FORMALIZE/g
s/\bFormallize\b/Formalize/g
s/\bformallized\b/formalized/g
s/\bFORMALLIZED\b/FORMALIZED/g
s/\bFormallized\b/Formalized/g
s/\bformelly\b/formerly/g
s/\bFORMELLY\b/FORMERLY/g
s/\bFormelly\b/Formerly/g
s/\bformidible\b/formidable/g
s/\bFORMIDIBLE\b/FORMIDABLE/g
s/\bFormidible\b/Formidable/g
s/\bformost\b/foremost/g
s/\bFORMOST\b/FOREMOST/g
s/\bFormost\b/Foremost/g
s/\bforsaw\b/foresaw/g
s/\bFORSAW\b/FORESAW/g
s/\bForsaw\b/Foresaw/g
s/\bfortelling\b/foretelling/g
s/\bFORTELLING\b/FORETELLING/g
s/\bFortelling\b/Foretelling/g
s/\bforunner\b/forerunner/g
s/\bFORUNNER\b/FORERUNNER/g
s/\bForunner\b/Forerunner/g
s/\bfoucs\b/focus/g
s/\bFOUCS\b/FOCUS/g
s/\bFoucs\b/Focus/g
s/\bfoudn\b/found/g
s/\bFOUDN\b/FOUND/g
s/\bFoudn\b/Found/g
s/\bfougth\b/fought/g
s/\bFOUGTH\b/FOUGHT/g
s/\bFougth\b/Fought/g
s/\bfoundaries\b/foundries/g
s/\bFOUNDARIES\b/FOUNDRIES/g
s/\bFoundaries\b/Foundries/g
s/\bfoundary\b/foundry/g
s/\bFOUNDARY\b/FOUNDRY/g
s/\bFoundary\b/Foundry/g
s/\bfourties\b/forties/g
s/\bFOURTIES\b/FORTIES/g
s/\bFourties\b/Forties/g
s/\bfourty\b/forty/g
s/\bFOURTY\b/FORTY/g
s/\bFourty\b/Forty/g
s/\bfouth\b/fourth/g
s/\bFOUTH\b/FOURTH/g
s/\bFouth\b/Fourth/g
s/\bfoward\b/forward/g
s/\bFOWARD\b/FORWARD/g
s/\bFoward\b/Forward/g
s/\bfreind\b/friend/g
s/\bFREIND\b/FRIEND/g
s/\bFreind\b/Friend/g
s/\bfreindly\b/friendly/g
s/\bFREINDLY\b/FRIENDLY/g
s/\bFreindly\b/Friendly/g
s/\bfrequentily\b/frequently/g
s/\bFREQUENTILY\b/FREQUENTLY/g
s/\bFrequentily\b/Frequently/g
s/\bfrome\b/from/g
s/\bFROME\b/FROM/g
s/\bFrome\b/From/g
s/\bfromed\b/formed/g
s/\bFROMED\b/FORMED/g
s/\bFromed\b/Formed/g
s/\bfroniter\b/frontier/g
s/\bFRONITER\b/FRONTIER/g
s/\bFroniter\b/Frontier/g
s/\bfucntioning\b/functioning/g
s/\bFUCNTIONING\b/FUNCTIONING/g
s/\bFucntioning\b/Functioning/g
s/\bfufill\b/fulfill/g
s/\bFUFILL\b/FULFILL/g
s/\bFufill\b/Fulfill/g
s/\bfufilled\b/fulfilled/g
s/\bFUFILLED\b/FULFILLED/g
s/\bFufilled\b/Fulfilled/g
s/\bfulfiled\b/fulfilled/g
s/\bFULFILED\b/FULFILLED/g
s/\bFulfiled\b/Fulfilled/g
s/\bfundametal\b/fundamental/g
s/\bFUNDAMETAL\b/FUNDAMENTAL/g
s/\bFundametal\b/Fundamental/g
s/\bfundametals\b/fundamentals/g
s/\bFUNDAMETALS\b/FUNDAMENTALS/g
s/\bFundametals\b/Fundamentals/g
s/\bfunguses\b/fungi/g
s/\bFUNGUSES\b/FUNGI/g
s/\bFunguses\b/Fungi/g
s/\bfuruther\b/further/g
s/\bFURUTHER\b/FURTHER/g
s/\bFuruther\b/Further/g
s/\bfuthermore\b/furthermore/g
s/\bFUTHERMORE\b/FURTHERMORE/g
s/\bFuthermore\b/Furthermore/g
s/\bgalatic\b/galactic/g
s/\bGALATIC\b/GALACTIC/g
s/\bGalatic\b/Galactic/g
s/\bgallaxies\b/galaxies/g
s/\bGALLAXIES\b/GALAXIES/g
s/\bGallaxies\b/Galaxies/g
s/\bgalvinized\b/galvanized/g
s/\bGALVINIZED\b/GALVANIZED/g
s/\bGalvinized\b/Galvanized/g
s/\bganerate\b/generate/g
s/\bGANERATE\b/GENERATE/g
s/\bGanerate\b/Generate/g
s/\bganes\b/games/g
s/\bGANES\b/GAMES/g
s/\bGanes\b/Games/g
s/\bganster\b/gangster/g
s/\bGANSTER\b/GANGSTER/g
s/\bGanster\b/Gangster/g
s/\bgarantee\b/guarantee/g
s/\bGARANTEE\b/GUARANTEE/g
s/\bGarantee\b/Guarantee/g
s/\bgaranteed\b/guaranteed/g
s/\bGARANTEED\b/GUARANTEED/g
s/\bGaranteed\b/Guaranteed/g
s/\bgarantees\b/guarantees/g
s/\bGARANTEES\b/GUARANTEES/g
s/\bGarantees\b/Guarantees/g
s/\bgardai\b/gardaí/g
s/\bGARDAI\b/GARDAí/g
s/\bGardai\b/Gardaí/g
s/\bgarnison\b/garrison/g
s/\bGARNISON\b/GARRISON/g
s/\bGarnison\b/Garrison/g
s/\bgauarana\b/guaraná/g
s/\bGAUARANA\b/GUARANá/g
s/\bGauarana\b/Guaraná/g
s/\bgaurantee\b/guarantee/g
s/\bGAURANTEE\b/GUARANTEE/g
s/\bGaurantee\b/Guarantee/g
s/\bgauranteed\b/guaranteed/g
s/\bGAURANTEED\b/GUARANTEED/g
s/\bGauranteed\b/Guaranteed/g
s/\bgaurantees\b/guarantees/g
s/\bGAURANTEES\b/GUARANTEES/g
s/\bGaurantees\b/Guarantees/g
s/\bgaurentee\b/guarantee/g
s/\bGAURENTEE\b/GUARANTEE/g
s/\bGaurentee\b/Guarantee/g
s/\bgaurenteed\b/guaranteed/g
s/\bGAURENTEED\b/GUARANTEED/g
s/\bGaurenteed\b/Guaranteed/g
s/\bgaurentees\b/guarantees/g
s/\bGAURENTEES\b/GUARANTEES/g
s/\bGaurentees\b/Guarantees/g
s/\bgeneological\b/genealogical/g
s/\bGENEOLOGICAL\b/GENEALOGICAL/g
s/\bGeneological\b/Genealogical/g
s/\bgeneologies\b/genealogies/g
s/\bGENEOLOGIES\b/GENEALOGIES/g
s/\bGeneologies\b/Genealogies/g
s/\bgeneology\b/genealogy/g
s/\bGENEOLOGY\b/GENEALOGY/g
s/\bGeneology\b/Genealogy/g
s/\bgeneraly\b/generally/g
s/\bGENERALY\b/GENERALLY/g
s/\bGeneraly\b/Generally/g
s/\bgeneratting\b/generating/g
s/\bGENERATTING\b/GENERATING/g
s/\bGeneratting\b/Generating/g
s/\bgenialia\b/genitalia/g
s/\bGENIALIA\b/GENITALIA/g
s/\bGenialia\b/Genitalia/g
s/\bgeographicial\b/geographical/g
s/\bGEOGRAPHICIAL\b/GEOGRAPHICAL/g
s/\bGeographicial\b/Geographical/g
s/\bgeometrician\b/geometer/g
s/\bGEOMETRICIAN\b/GEOMETER/g
s/\bGeometrician\b/Geometer/g
s/\bgeometricians\b/geometers/g
s/\bGEOMETRICIANS\b/GEOMETERS/g
s/\bGeometricians\b/Geometers/g
s/\bgerat\b/great/g
s/\bGERAT\b/GREAT/g
s/\bGerat\b/Great/g
s/\bglight\b/flight/g
s/\bGLIGHT\b/FLIGHT/g
s/\bGlight\b/Flight/g
s/\bgnawwed\b/gnawed/g
s/\bGNAWWED\b/GNAWED/g
s/\bGnawwed\b/Gnawed/g
s/\bgodess\b/goddess/g
s/\bGODESS\b/GODDESS/g
s/\bGodess\b/Goddess/g
s/\bgodesses\b/goddesses/g
s/\bGODESSES\b/GODDESSES/g
s/\bGodesses\b/Goddesses/g
s/\bgoign\b/going/g
s/\bGOIGN\b/GOING/g
s/\bGoign\b/Going/g
s/\bgonig\b/going/g
s/\bGONIG\b/GOING/g
s/\bGonig\b/Going/g
s/\bgouvener\b/governor/g
s/\bGOUVENER\b/GOVERNOR/g
s/\bGouvener\b/Governor/g
s/\bgovement\b/government/g
s/\bGOVEMENT\b/GOVERNMENT/g
s/\bGovement\b/Government/g
s/\bgovenment\b/government/g
s/\bGOVENMENT\b/GOVERNMENT/g
s/\bGovenment\b/Government/g
s/\bgovenrment\b/government/g
s/\bGOVENRMENT\b/GOVERNMENT/g
s/\bGovenrment\b/Government/g
s/\bgoverance\b/governance/g
s/\bGOVERANCE\b/GOVERNANCE/g
s/\bGoverance\b/Governance/g
s/\bgoverment\b/government/g
s/\bGOVERMENT\b/GOVERNMENT/g
s/\bGoverment\b/Government/g
s/\bgovermental\b/governmental/g
s/\bGOVERMENTAL\b/GOVERNMENTAL/g
s/\bGovermental\b/Governmental/g
s/\bgoverner\b/governor/g
s/\bGOVERNER\b/GOVERNOR/g
s/\bGoverner\b/Governor/g
s/\bgovernmnet\b/government/g
s/\bGOVERNMNET\b/GOVERNMENT/g
s/\bGovernmnet\b/Government/g
s/\bgovorment\b/government/g
s/\bGOVORMENT\b/GOVERNMENT/g
s/\bGovorment\b/Government/g
s/\bgovormental\b/governmental/g
s/\bGOVORMENTAL\b/GOVERNMENTAL/g
s/\bGovormental\b/Governmental/g
s/\bgovornment\b/government/g
s/\bGOVORNMENT\b/GOVERNMENT/g
s/\bGovornment\b/Government/g
s/\bgracefull\b/graceful/g
s/\bGRACEFULL\b/GRACEFUL/g
s/\bGracefull\b/Graceful/g
s/\bgraet\b/great/g
s/\bGRAET\b/GREAT/g
s/\bGraet\b/Great/g
s/\bgrafitti\b/graffiti/g
s/\bGRAFITTI\b/GRAFFITI/g
s/\bGrafitti\b/Graffiti/g
s/\bgramatically\b/grammatically/g
s/\bGRAMATICALLY\b/GRAMMATICALLY/g
s/\bGramatically\b/Grammatically/g
s/\bgrammaticaly\b/grammatically/g
s/\bGRAMMATICALY\b/GRAMMATICALLY/g
s/\bGrammaticaly\b/Grammatically/g
s/\bgrat\b/great/g
s/\bGRAT\b/GREAT/g
s/\bGrat\b/Great/g
s/\bgratuitious\b/gratuitous/g
s/\bGRATUITIOUS\b/GRATUITOUS/g
s/\bGratuitious\b/Gratuitous/g
s/\bgreatful\b/grateful/g
s/\bGREATFUL\b/GRATEFUL/g
s/\bGreatful\b/Grateful/g
s/\bgreatfully\b/gratefully/g
s/\bGREATFULLY\b/GRATEFULLY/g
s/\bGreatfully\b/Gratefully/g
s/\bgreif\b/grief/g
s/\bGREIF\b/GRIEF/g
s/\bGreif\b/Grief/g
s/\bgridles\b/griddles/g
s/\bGRIDLES\b/GRIDDLES/g
s/\bGridles\b/Griddles/g
s/\bgropu\b/group/g
s/\bGROPU\b/GROUP/g
s/\bGropu\b/Group/g
s/\bgrwo\b/grow/g
s/\bGRWO\b/GROW/g
s/\bGrwo\b/Grow/g
s/\bguarentee\b/guarantee/g
s/\bGUARENTEE\b/GUARANTEE/g
s/\bGuarentee\b/Guarantee/g
s/\bguarentees\b/guarantees/g
s/\bGUARENTEES\b/GUARANTEES/g
s/\bGuarentees\b/Guarantees/g
s/\bguerrila\b/guerrilla/g
s/\bGUERRILA\b/GUERRILLA/g
s/\bGuerrila\b/Guerrilla/g
s/\bguerrilas\b/guerrillas/g
s/\bGUERRILAS\b/GUERRILLAS/g
s/\bGuerrilas\b/Guerrillas/g
s/\bguidence\b/guidance/g
s/\bGUIDENCE\b/GUIDANCE/g
s/\bGuidence\b/Guidance/g
s/\bgunanine\b/guanine/g
s/\bGUNANINE\b/GUANINE/g
s/\bGunanine\b/Guanine/g
s/\bgurantee\b/guarantee/g
s/\bGURANTEE\b/GUARANTEE/g
s/\bGurantee\b/Guarantee/g
s/\bguranteed\b/guaranteed/g
s/\bGURANTEED\b/GUARANTEED/g
s/\bGuranteed\b/Guaranteed/g
s/\bgurantees\b/guarantees/g
s/\bGURANTEES\b/GUARANTEES/g
s/\bGurantees\b/Guarantees/g
s/\bguttaral\b/guttural/g
s/\bGUTTARAL\b/GUTTURAL/g
s/\bGuttaral\b/Guttural/g
s/\bgutteral\b/guttural/g
s/\bGUTTERAL\b/GUTTURAL/g
s/\bGutteral\b/Guttural/g
s/\bhabaeus\b/habeas/g
s/\bHABAEUS\b/HABEAS/g
s/\bHabaeus\b/Habeas/g
s/\bhabeus\b/habeas/g
s/\bHABEUS\b/HABEAS/g
s/\bHabeus\b/Habeas/g
s/\bhaemorrage\b/haemorrhage/g
s/\bHAEMORRAGE\b/HAEMORRHAGE/g
s/\bHaemorrage\b/Haemorrhage/g
s/\bhalarious\b/hilarious/g
s/\bHALARIOUS\b/HILARIOUS/g
s/\bHalarious\b/Hilarious/g
s/\bhalp\b/help/g
s/\bHALP\b/HELP/g
s/\bHalp\b/Help/g
s/\bhapen\b/happen/g
s/\bHAPEN\b/HAPPEN/g
s/\bHapen\b/Happen/g
s/\bhapened\b/happened/g
s/\bHAPENED\b/HAPPENED/g
s/\bHapened\b/Happened/g
s/\bhapening\b/happening/g
s/\bHAPENING\b/HAPPENING/g
s/\bHapening\b/Happening/g
s/\bhappend\b/happened/g
s/\bHAPPEND\b/HAPPENED/g
s/\bHappend\b/Happened/g
s/\bhappended\b/happened/g
s/\bHAPPENDED\b/HAPPENED/g
s/\bHappended\b/Happened/g
s/\bhappenned\b/happened/g
s/\bHAPPENNED\b/HAPPENED/g
s/\bHappenned\b/Happened/g
s/\bharased\b/harassed/g
s/\bHARASED\b/HARASSED/g
s/\bHarased\b/Harassed/g
s/\bharases\b/harasses/g
s/\bHARASES\b/HARASSES/g
s/\bHarases\b/Harasses/g
s/\bharasment\b/harassment/g
s/\bHARASMENT\b/HARASSMENT/g
s/\bHarasment\b/Harassment/g
s/\bharasments\b/harassments/g
s/\bHARASMENTS\b/HARASSMENTS/g
s/\bHarasments\b/Harassments/g
s/\bharassement\b/harassment/g
s/\bHARASSEMENT\b/HARASSMENT/g
s/\bHarassement\b/Harassment/g
s/\bharras\b/harass/g
s/\bHARRAS\b/HARASS/g
s/\bHarras\b/Harass/g
s/\bharrased\b/harassed/g
s/\bHARRASED\b/HARASSED/g
s/\bHarrased\b/Harassed/g
s/\bharrases\b/harasses/g
s/\bHARRASES\b/HARASSES/g
s/\bHarrases\b/Harasses/g
s/\bharrasing\b/harassing/g
s/\bHARRASING\b/HARASSING/g
s/\bHarrasing\b/Harassing/g
s/\bharrasment\b/harassment/g
s/\bHARRASMENT\b/HARASSMENT/g
s/\bHarrasment\b/Harassment/g
s/\bharrasments\b/harassments/g
s/\bHARRASMENTS\b/HARASSMENTS/g
s/\bHarrasments\b/Harassments/g
s/\bharrassed\b/harassed/g
s/\bHARRASSED\b/HARASSED/g
s/\bHarrassed\b/Harassed/g
s/\bharrasses\b/harassed/g
s/\bHARRASSES\b/HARASSED/g
s/\bHarrasses\b/Harassed/g
s/\bharrassing\b/harassing/g
s/\bHARRASSING\b/HARASSING/g
s/\bHarrassing\b/Harassing/g
s/\bharrassment\b/harassment/g
s/\bHARRASSMENT\b/HARASSMENT/g
s/\bHarrassment\b/Harassment/g
s/\bharrassments\b/harassments/g
s/\bHARRASSMENTS\b/HARASSMENTS/g
s/\bHarrassments\b/Harassments/g
s/\bhaviest\b/heaviest/g
s/\bHAVIEST\b/HEAVIEST/g
s/\bHaviest\b/Heaviest/g
s/\bheadquarer\b/headquarter/g
s/\bHEADQUARER\b/HEADQUARTER/g
s/\bHeadquarer\b/Headquarter/g
s/\bheadquater\b/headquarter/g
s/\bHEADQUATER\b/HEADQUARTER/g
s/\bHeadquater\b/Headquarter/g
s/\bheadquatered\b/headquartered/g
s/\bHEADQUATERED\b/HEADQUARTERED/g
s/\bHeadquatered\b/Headquartered/g
s/\bheadquaters\b/headquarters/g
s/\bHEADQUATERS\b/HEADQUARTERS/g
s/\bHeadquaters\b/Headquarters/g
s/\bhealthercare\b/healthcare/g
s/\bHEALTHERCARE\b/HEALTHCARE/g
s/\bHealthercare\b/Healthcare/g
s/\bheared\b/heard/g
s/\bHEARED\b/HEARD/g
s/\bHeared\b/Heard/g
s/\bheathy\b/healthy/g
s/\bHEATHY\b/HEALTHY/g
s/\bHeathy\b/Healthy/g
s/\bheirarchy\b/hierarchy/g
s/\bHEIRARCHY\b/HIERARCHY/g
s/\bHeirarchy\b/Hierarchy/g
s/\bheiroglyphics\b/hieroglyphics/g
s/\bHEIROGLYPHICS\b/HIEROGLYPHICS/g
s/\bHeiroglyphics\b/Hieroglyphics/g
s/\bhelment\b/helmet/g
s/\bHELMENT\b/HELMET/g
s/\bHelment\b/Helmet/g
s/\bhelpfull\b/helpful/g
s/\bHELPFULL\b/HELPFUL/g
s/\bHelpfull\b/Helpful/g
s/\bhelpped\b/helped/g
s/\bHELPPED\b/HELPED/g
s/\bHelpped\b/Helped/g
s/\bhemmorhage\b/hemorrhage/g
s/\bHEMMORHAGE\b/HEMORRHAGE/g
s/\bHemmorhage\b/Hemorrhage/g
s/\bheridity\b/heredity/g
s/\bHERIDITY\b/HEREDITY/g
s/\bHeridity\b/Heredity/g
s/\bheroe\b/hero/g
s/\bHEROE\b/HERO/g
s/\bHeroe\b/Hero/g
s/\bheros\b/heroes/g
s/\bHEROS\b/HEROES/g
s/\bHeros\b/Heroes/g
s/\bhertiage\b/heritage/g
s/\bHERTIAGE\b/HERITAGE/g
s/\bHertiage\b/Heritage/g
s/\bhertzs\b/hertz/g
s/\bHERTZS\b/HERTZ/g
s/\bHertzs\b/Hertz/g
s/\bhesistant\b/hesitant/g
s/\bHESISTANT\b/HESITANT/g
s/\bHesistant\b/Hesitant/g
s/\bheterogenous\b/heterogeneous/g
s/\bHETEROGENOUS\b/HETEROGENEOUS/g
s/\bHeterogenous\b/Heterogeneous/g
s/\bhieght\b/height/g
s/\bHIEGHT\b/HEIGHT/g
s/\bHieght\b/Height/g
s/\bhierachical\b/hierarchical/g
s/\bHIERACHICAL\b/HIERARCHICAL/g
s/\bHierachical\b/Hierarchical/g
s/\bhierachies\b/hierarchies/g
s/\bHIERACHIES\b/HIERARCHIES/g
s/\bHierachies\b/Hierarchies/g
s/\bhierachy\b/hierarchy/g
s/\bHIERACHY\b/HIERARCHY/g
s/\bHierachy\b/Hierarchy/g
s/\bhierarcical\b/hierarchical/g
s/\bHIERARCICAL\b/HIERARCHICAL/g
s/\bHierarcical\b/Hierarchical/g
s/\bhierarcy\b/hierarchy/g
s/\bHIERARCY\b/HIERARCHY/g
s/\bHierarcy\b/Hierarchy/g
s/\bhieroglph\b/hieroglyph/g
s/\bHIEROGLPH\b/HIEROGLYPH/g
s/\bHieroglph\b/Hieroglyph/g
s/\bhieroglphs\b/hieroglyphs/g
s/\bHIEROGLPHS\b/HIEROGLYPHS/g
s/\bHieroglphs\b/Hieroglyphs/g
s/\bhiger\b/higher/g
s/\bHIGER\b/HIGHER/g
s/\bHiger\b/Higher/g
s/\bhigest\b/highest/g
s/\bHIGEST\b/HIGHEST/g
s/\bHigest\b/Highest/g
s/\bhigway\b/highway/g
s/\bHIGWAY\b/HIGHWAY/g
s/\bHigway\b/Highway/g
s/\bhillarious\b/hilarious/g
s/\bHILLARIOUS\b/HILARIOUS/g
s/\bHillarious\b/Hilarious/g
s/\bhimselv\b/himself/g
s/\bHIMSELV\b/HIMSELF/g
s/\bHimselv\b/Himself/g
s/\bhinderance\b/hindrance/g
s/\bHINDERANCE\b/HINDRANCE/g
s/\bHinderance\b/Hindrance/g
s/\bhinderence\b/hindrance/g
s/\bHINDERENCE\b/HINDRANCE/g
s/\bHinderence\b/Hindrance/g
s/\bhindrence\b/hindrance/g
s/\bHINDRENCE\b/HINDRANCE/g
s/\bHindrence\b/Hindrance/g
s/\bhipopotamus\b/hippopotamus/g
s/\bHIPOPOTAMUS\b/HIPPOPOTAMUS/g
s/\bHipopotamus\b/Hippopotamus/g
s/\bhismelf\b/himself/g
s/\bHISMELF\b/HIMSELF/g
s/\bHismelf\b/Himself/g
s/\bhistoricians\b/historians/g
s/\bHISTORICIANS\b/HISTORIANS/g
s/\bHistoricians\b/Historians/g
s/\bhitsingles\b/hit singles/g
s/\bHITSINGLES\b/HIT SINGLES/g
s/\bHitsingles\b/Hit singles/g
s/\bholf\b/hold/g
s/\bHOLF\b/HOLD/g
s/\bHolf\b/Hold/g
s/\bholliday\b/holiday/g
s/\bHOLLIDAY\b/HOLIDAY/g
s/\bHolliday\b/Holiday/g
s/\bhomestate\b/home state/g
s/\bHOMESTATE\b/HOME STATE/g
s/\bHomestate\b/Home state/g
s/\bhomogeneize\b/homogenize/g
s/\bHOMOGENEIZE\b/HOMOGENIZE/g
s/\bHomogeneize\b/Homogenize/g
s/\bhomogeneized\b/homogenized/g
s/\bHOMOGENEIZED\b/HOMOGENIZED/g
s/\bHomogeneized\b/Homogenized/g
s/\bhonory\b/honorary/g
s/\bHONORY\b/HONORARY/g
s/\bHonory\b/Honorary/g
s/\bhorrifing\b/horrifying/g
s/\bHORRIFING\b/HORRIFYING/g
s/\bHorrifing\b/Horrifying/g
s/\bhosited\b/hoisted/g
s/\bHOSITED\b/HOISTED/g
s/\bHosited\b/Hoisted/g
s/\bhospitible\b/hospitable/g
s/\bHOSPITIBLE\b/HOSPITABLE/g
s/\bHospitible\b/Hospitable/g
s/\bhounour\b/honour/g
s/\bHOUNOUR\b/HONOUR/g
s/\bHounour\b/Honour/g
s/\bhowver\b/however/g
s/\bHOWVER\b/HOWEVER/g
s/\bHowver\b/However/g
s/\bhsitorians\b/historians/g
s/\bHSITORIANS\b/HISTORIANS/g
s/\bHsitorians\b/Historians/g
s/\bhstory\b/history/g
s/\bHSTORY\b/HISTORY/g
s/\bHstory\b/History/g
s/\bhtey\b/they/g
s/\bHTEY\b/THEY/g
s/\bHtey\b/They/g
s/\bhtikn\b/think/g
s/\bHTIKN\b/THINK/g
s/\bHtikn\b/Think/g
s/\bhting\b/thing/g
s/\bHTING\b/THING/g
s/\bHting\b/Thing/g
s/\bhtink\b/think/g
s/\bHTINK\b/THINK/g
s/\bHtink\b/Think/g
s/\bhtis\b/this/g
s/\bHTIS\b/THIS/g
s/\bHtis\b/This/g
s/\bhuminoid\b/humanoid/g
s/\bHUMINOID\b/HUMANOID/g
s/\bHuminoid\b/Humanoid/g
s/\bhumoural\b/humoral/g
s/\bHUMOURAL\b/HUMORAL/g
s/\bHumoural\b/Humoral/g
s/\bhumurous\b/humorous/g
s/\bHUMUROUS\b/HUMOROUS/g
s/\bHumurous\b/Humorous/g
s/\bhusban\b/husband/g
s/\bHUSBAN\b/HUSBAND/g
s/\bHusban\b/Husband/g
s/\bhvae\b/have/g
s/\bHVAE\b/HAVE/g
s/\bHvae\b/Have/g
s/\bhvaing\b/having/g
s/\bHVAING\b/HAVING/g
s/\bHvaing\b/Having/g
s/\bhwihc\b/which/g
s/\bHWIHC\b/WHICH/g
s/\bHwihc\b/Which/g
s/\bhwile\b/while/g
s/\bHWILE\b/WHILE/g
s/\bHwile\b/While/g
s/\bhwole\b/whole/g
s/\bHWOLE\b/WHOLE/g
s/\bHwole\b/Whole/g
s/\bhydogen\b/hydrogen/g
s/\bHYDOGEN\b/HYDROGEN/g
s/\bHydogen\b/Hydrogen/g
s/\bhydropile\b/hydrophile/g
s/\bHYDROPILE\b/HYDROPHILE/g
s/\bHydropile\b/Hydrophile/g
s/\bhydropilic\b/hydrophilic/g
s/\bHYDROPILIC\b/HYDROPHILIC/g
s/\bHydropilic\b/Hydrophilic/g
s/\bhydropobe\b/hydrophobe/g
s/\bHYDROPOBE\b/HYDROPHOBE/g
s/\bHydropobe\b/Hydrophobe/g
s/\bhydropobic\b/hydrophobic/g
s/\bHYDROPOBIC\b/HYDROPHOBIC/g
s/\bHydropobic\b/Hydrophobic/g
s/\bhygeine\b/hygiene/g
s/\bHYGEINE\b/HYGIENE/g
s/\bHygeine\b/Hygiene/g
s/\bhypocracy\b/hypocrisy/g
s/\bHYPOCRACY\b/HYPOCRISY/g
s/\bHypocracy\b/Hypocrisy/g
s/\bhypocrasy\b/hypocrisy/g
s/\bHYPOCRASY\b/HYPOCRISY/g
s/\bHypocrasy\b/Hypocrisy/g
s/\bhypocricy\b/hypocrisy/g
s/\bHYPOCRICY\b/HYPOCRISY/g
s/\bHypocricy\b/Hypocrisy/g
s/\bhypocrit\b/hypocrite/g
s/\bHYPOCRIT\b/HYPOCRITE/g
s/\bHypocrit\b/Hypocrite/g
s/\bhypocrits\b/hypocrites/g
s/\bHYPOCRITS\b/HYPOCRITES/g
s/\bHypocrits\b/Hypocrites/g
s/\biconclastic\b/iconoclastic/g
s/\bICONCLASTIC\b/ICONOCLASTIC/g
s/\bIconclastic\b/Iconoclastic/g
s/\bidaeidae\b/idea/g
s/\bIDAEIDAE\b/IDEA/g
s/\bIdaeidae\b/Idea/g
s/\bidaes\b/ideas/g
s/\bIDAES\b/IDEAS/g
s/\bIdaes\b/Ideas/g
s/\bidealogies\b/ideologies/g
s/\bIDEALOGIES\b/IDEOLOGIES/g
s/\bIdealogies\b/Ideologies/g
s/\bidealogy\b/ideology/g
s/\bIDEALOGY\b/IDEOLOGY/g
s/\bIdealogy\b/Ideology/g
s/\bidenticial\b/identical/g
s/\bIDENTICIAL\b/IDENTICAL/g
s/\bIdenticial\b/Identical/g
s/\bideosyncratic\b/idiosyncratic/g
s/\bIDEOSYNCRATIC\b/IDIOSYNCRATIC/g
s/\bIdeosyncratic\b/Idiosyncratic/g
s/\bidiosyncracy\b/idiosyncrasy/g
s/\bIDIOSYNCRACY\b/IDIOSYNCRASY/g
s/\bIdiosyncracy\b/Idiosyncrasy/g
s/\billegimacy\b/illegitimacy/g
s/\bILLEGIMACY\b/ILLEGITIMACY/g
s/\bIllegimacy\b/Illegitimacy/g
s/\billegitmate\b/illegitimate/g
s/\bILLEGITMATE\b/ILLEGITIMATE/g
s/\bIllegitmate\b/Illegitimate/g
s/\billess\b/illness/g
s/\bILLESS\b/ILLNESS/g
s/\bIlless\b/Illness/g
s/\billiegal\b/illegal/g
s/\bILLIEGAL\b/ILLEGAL/g
s/\bIlliegal\b/Illegal/g
s/\billution\b/illusion/g
s/\bILLUTION\b/ILLUSION/g
s/\bIllution\b/Illusion/g
s/\bilness\b/illness/g
s/\bILNESS\b/ILLNESS/g
s/\bIlness\b/Illness/g
s/\bilogical\b/illogical/g
s/\bILOGICAL\b/ILLOGICAL/g
s/\bIlogical\b/Illogical/g
s/\bimagenary\b/imaginary/g
s/\bIMAGENARY\b/IMAGINARY/g
s/\bImagenary\b/Imaginary/g
s/\bimagin\b/imagine/g
s/\bIMAGIN\b/IMAGINE/g
s/\bImagin\b/Imagine/g
s/\bimediately\b/immediately/g
s/\bIMEDIATELY\b/IMMEDIATELY/g
s/\bImediately\b/Immediately/g
s/\bimense\b/immense/g
s/\bIMENSE\b/IMMENSE/g
s/\bImense\b/Immense/g
s/\bimmediatley\b/immediately/g
s/\bIMMEDIATLEY\b/IMMEDIATELY/g
s/\bImmediatley\b/Immediately/g
s/\bimmediatly\b/immediately/g
s/\bIMMEDIATLY\b/IMMEDIATELY/g
s/\bImmediatly\b/Immediately/g
s/\bimmidately\b/immediately/g
s/\bIMMIDATELY\b/IMMEDIATELY/g
s/\bImmidately\b/Immediately/g
s/\bimmidiately\b/immediately/g
s/\bIMMIDIATELY\b/IMMEDIATELY/g
s/\bImmidiately\b/Immediately/g
s/\bimmitate\b/imitate/g
s/\bIMMITATE\b/IMITATE/g
s/\bImmitate\b/Imitate/g
s/\bimmitated\b/imitated/g
s/\bIMMITATED\b/IMITATED/g
s/\bImmitated\b/Imitated/g
s/\bimmitating\b/imitating/g
s/\bIMMITATING\b/IMITATING/g
s/\bImmitating\b/Imitating/g
s/\bimmitator\b/imitator/g
s/\bIMMITATOR\b/IMITATOR/g
s/\bImmitator\b/Imitator/g
s/\bimpecabbly\b/impeccably/g
s/\bIMPECABBLY\b/IMPECCABLY/g
s/\bImpecabbly\b/Impeccably/g
s/\bimpedence\b/impedance/g
s/\bIMPEDENCE\b/IMPEDANCE/g
s/\bImpedence\b/Impedance/g
s/\bimplamenting\b/implementing/g
s/\bIMPLAMENTING\b/IMPLEMENTING/g
s/\bImplamenting\b/Implementing/g
s/\bimpliment\b/implement/g
s/\bIMPLIMENT\b/IMPLEMENT/g
s/\bImpliment\b/Implement/g
s/\bimplimented\b/implemented/g
s/\bIMPLIMENTED\b/IMPLEMENTED/g
s/\bImplimented\b/Implemented/g
s/\bimploys\b/employs/g
s/\bIMPLOYS\b/EMPLOYS/g
s/\bImploys\b/Employs/g
s/\bimportamt\b/important/g
s/\bIMPORTAMT\b/IMPORTANT/g
s/\bImportamt\b/Important/g
s/\bimpressario\b/impresario/g
s/\bIMPRESSARIO\b/IMPRESARIO/g
s/\bImpressario\b/Impresario/g
s/\bimprioned\b/imprisoned/g
s/\bIMPRIONED\b/IMPRISONED/g
s/\bImprioned\b/Imprisoned/g
s/\bimprisonned\b/imprisoned/g
s/\bIMPRISONNED\b/IMPRISONED/g
s/\bImprisonned\b/Imprisoned/g
s/\bimprovision\b/improvisation/g
s/\bIMPROVISION\b/IMPROVISATION/g
s/\bImprovision\b/Improvisation/g
s/\bimprovments\b/improvements/g
s/\bIMPROVMENTS\b/IMPROVEMENTS/g
s/\bImprovments\b/Improvements/g
s/\binablility\b/inability/g
s/\bINABLILITY\b/INABILITY/g
s/\bInablility\b/Inability/g
s/\binaccessable\b/inaccessible/g
s/\bINACCESSABLE\b/INACCESSIBLE/g
s/\bInaccessable\b/Inaccessible/g
s/\binadiquate\b/inadequate/g
s/\bINADIQUATE\b/INADEQUATE/g
s/\bInadiquate\b/Inadequate/g
s/\binadquate\b/inadequate/g
s/\bINADQUATE\b/INADEQUATE/g
s/\bInadquate\b/Inadequate/g
s/\binadvertant\b/inadvertent/g
s/\bINADVERTANT\b/INADVERTENT/g
s/\bInadvertant\b/Inadvertent/g
s/\binadvertantly\b/inadvertently/g
s/\bINADVERTANTLY\b/INADVERTENTLY/g
s/\bInadvertantly\b/Inadvertently/g
s/\binagurated\b/inaugurated/g
s/\bINAGURATED\b/INAUGURATED/g
s/\bInagurated\b/Inaugurated/g
s/\binaguration\b/inauguration/g
s/\bINAGURATION\b/INAUGURATION/g
s/\bInaguration\b/Inauguration/g
s/\binaugures\b/inaugurates/g
s/\bINAUGURES\b/INAUGURATES/g
s/\bInaugures\b/Inaugurates/g
s/\binbalance\b/imbalance/g
s/\bINBALANCE\b/IMBALANCE/g
s/\bInbalance\b/Imbalance/g
s/\binbalanced\b/imbalanced/g
s/\bINBALANCED\b/IMBALANCED/g
s/\bInbalanced\b/Imbalanced/g
s/\binbetween\b/between/g
s/\bINBETWEEN\b/BETWEEN/g
s/\bInbetween\b/Between/g
s/\bincarcirated\b/incarcerated/g
s/\bINCARCIRATED\b/INCARCERATED/g
s/\bIncarcirated\b/Incarcerated/g
s/\bincidentially\b/incidentally/g
s/\bINCIDENTIALLY\b/INCIDENTALLY/g
s/\bIncidentially\b/Incidentally/g
s/\bincidently\b/incidentally/g
s/\bINCIDENTLY\b/INCIDENTALLY/g
s/\bIncidently\b/Incidentally/g
s/\binclreased\b/increased/g
s/\bINCLREASED\b/INCREASED/g
s/\bInclreased\b/Increased/g
s/\binclud\b/include/g
s/\bINCLUD\b/INCLUDE/g
s/\bInclud\b/Include/g
s/\bincludng\b/including/g
s/\bINCLUDNG\b/INCLUDING/g
s/\bIncludng\b/Including/g
s/\bincompatabilities\b/incompatibilities/g
s/\bINCOMPATABILITIES\b/INCOMPATIBILITIES/g
s/\bIncompatabilities\b/Incompatibilities/g
s/\bincompatable\b/incompatible/g
s/\bINCOMPATABLE\b/INCOMPATIBLE/g
s/\bIncompatable\b/Incompatible/g
s/\bincompatablities\b/incompatibilities/g
s/\bINCOMPATABLITIES\b/INCOMPATIBILITIES/g
s/\bIncompatablities\b/Incompatibilities/g
s/\bincompatablity\b/incompatibility/g
s/\bINCOMPATABLITY\b/INCOMPATIBILITY/g
s/\bIncompatablity\b/Incompatibility/g
s/\bincompatiblities\b/incompatibilities/g
s/\bINCOMPATIBLITIES\b/INCOMPATIBILITIES/g
s/\bIncompatiblities\b/Incompatibilities/g
s/\bincompetance\b/incompetence/g
s/\bINCOMPETANCE\b/INCOMPETENCE/g
s/\bIncompetance\b/Incompetence/g
s/\bincompetant\b/incompetent/g
s/\bINCOMPETANT\b/INCOMPETENT/g
s/\bIncompetant\b/Incompetent/g
s/\bincomptable\b/incompatible/g
s/\bINCOMPTABLE\b/INCOMPATIBLE/g
s/\bIncomptable\b/Incompatible/g
s/\bincomptetent\b/incompetent/g
s/\bINCOMPTETENT\b/INCOMPETENT/g
s/\bIncomptetent\b/Incompetent/g
s/\bincoroporated\b/incorporated/g
s/\bINCOROPORATED\b/INCORPORATED/g
s/\bIncoroporated\b/Incorporated/g
s/\bincorperation\b/incorporation/g
s/\bINCORPERATION\b/INCORPORATION/g
s/\bIncorperation\b/Incorporation/g
s/\bincorportaed\b/incorporated/g
s/\bINCORPORTAED\b/INCORPORATED/g
s/\bIncorportaed\b/Incorporated/g
s/\bincorprates\b/incorporates/g
s/\bINCORPRATES\b/INCORPORATES/g
s/\bIncorprates\b/Incorporates/g
s/\bincorruptable\b/incorruptible/g
s/\bINCORRUPTABLE\b/INCORRUPTIBLE/g
s/\bIncorruptable\b/Incorruptible/g
s/\bincramentally\b/incrementally/g
s/\bINCRAMENTALLY\b/INCREMENTALLY/g
s/\bIncramentally\b/Incrementally/g
s/\bincreadible\b/incredible/g
s/\bINCREADIBLE\b/INCREDIBLE/g
s/\bIncreadible\b/Incredible/g
s/\bincredable\b/incredible/g
s/\bINCREDABLE\b/INCREDIBLE/g
s/\bIncredable\b/Incredible/g
s/\binctroduce\b/introduce/g
s/\bINCTRODUCE\b/INTRODUCE/g
s/\bInctroduce\b/Introduce/g
s/\binctroduced\b/introduced/g
s/\bINCTRODUCED\b/INTRODUCED/g
s/\bInctroduced\b/Introduced/g
s/\bincuding\b/including/g
s/\bINCUDING\b/INCLUDING/g
s/\bIncuding\b/Including/g
s/\bincunabla\b/incunabula/g
s/\bINCUNABLA\b/INCUNABULA/g
s/\bIncunabla\b/Incunabula/g
s/\bindefineable\b/undefinable/g
s/\bINDEFINEABLE\b/UNDEFINABLE/g
s/\bIndefineable\b/Undefinable/g
s/\bindefinitly\b/indefinitely/g
s/\bINDEFINITLY\b/INDEFINITELY/g
s/\bIndefinitly\b/Indefinitely/g
s/\bindentical\b/identical/g
s/\bINDENTICAL\b/IDENTICAL/g
s/\bIndentical\b/Identical/g
s/\bindepedantly\b/independently/g
s/\bINDEPEDANTLY\b/INDEPENDENTLY/g
s/\bIndepedantly\b/Independently/g
s/\bindepedence\b/independence/g
s/\bINDEPEDENCE\b/INDEPENDENCE/g
s/\bIndepedence\b/Independence/g
s/\bindependece\b/independence/g
s/\bINDEPENDECE\b/INDEPENDENCE/g
s/\bIndependece\b/Independence/g
s/\bindespensable\b/indispensable/g
s/\bINDESPENSABLE\b/INDISPENSABLE/g
s/\bIndespensable\b/Indispensable/g
s/\bindespensible\b/indispensable/g
s/\bINDESPENSIBLE\b/INDISPENSABLE/g
s/\bIndespensible\b/Indispensable/g
s/\bindictement\b/indictment/g
s/\bINDICTEMENT\b/INDICTMENT/g
s/\bIndictement\b/Indictment/g
s/\bindigineous\b/indigenous/g
s/\bINDIGINEOUS\b/INDIGENOUS/g
s/\bIndigineous\b/Indigenous/g
s/\bindipendence\b/independence/g
s/\bINDIPENDENCE\b/INDEPENDENCE/g
s/\bIndipendence\b/Independence/g
s/\bindipendent\b/independent/g
s/\bINDIPENDENT\b/INDEPENDENT/g
s/\bIndipendent\b/Independent/g
s/\bindipendently\b/independently/g
s/\bINDIPENDENTLY\b/INDEPENDENTLY/g
s/\bIndipendently\b/Independently/g
s/\bindispensible\b/indispensable/g
s/\bINDISPENSIBLE\b/INDISPENSABLE/g
s/\bIndispensible\b/Indispensable/g
s/\bindisputible\b/indisputable/g
s/\bINDISPUTIBLE\b/INDISPUTABLE/g
s/\bIndisputible\b/Indisputable/g
s/\bindisputibly\b/indisputably/g
s/\bINDISPUTIBLY\b/INDISPUTABLY/g
s/\bIndisputibly\b/Indisputably/g
s/\bindite\b/indict/g
s/\bINDITE\b/INDICT/g
s/\bIndite\b/Indict/g
s/\bindividualy\b/individually/g
s/\bINDIVIDUALY\b/INDIVIDUALLY/g
s/\bIndividualy\b/Individually/g
s/\bindpendent\b/independent/g
s/\bINDPENDENT\b/INDEPENDENT/g
s/\bIndpendent\b/Independent/g
s/\bindpendently\b/independently/g
s/\bINDPENDENTLY\b/INDEPENDENTLY/g
s/\bIndpendently\b/Independently/g
s/\bindulgue\b/indulge/g
s/\bINDULGUE\b/INDULGE/g
s/\bIndulgue\b/Indulge/g
s/\bindutrial\b/industrial/g
s/\bINDUTRIAL\b/INDUSTRIAL/g
s/\bIndutrial\b/Industrial/g
s/\bindviduals\b/individuals/g
s/\bINDVIDUALS\b/INDIVIDUALS/g
s/\bIndviduals\b/Individuals/g
s/\binefficienty\b/inefficiently/g
s/\bINEFFICIENTY\b/INEFFICIENTLY/g
s/\bInefficienty\b/Inefficiently/g
s/\binevatible\b/inevitable/g
s/\bINEVATIBLE\b/INEVITABLE/g
s/\bInevatible\b/Inevitable/g
s/\binevitible\b/inevitable/g
s/\bINEVITIBLE\b/INEVITABLE/g
s/\bInevitible\b/Inevitable/g
s/\binevititably\b/inevitably/g
s/\bINEVITITABLY\b/INEVITABLY/g
s/\bInevititably\b/Inevitably/g
s/\binfalability\b/infallibility/g
s/\bINFALABILITY\b/INFALLIBILITY/g
s/\bInfalability\b/Infallibility/g
s/\binfallable\b/infallible/g
s/\bINFALLABLE\b/INFALLIBLE/g
s/\bInfallable\b/Infallible/g
s/\binfectuous\b/infectious/g
s/\bINFECTUOUS\b/INFECTIOUS/g
s/\bInfectuous\b/Infectious/g
s/\binfered\b/inferred/g
s/\bINFERED\b/INFERRED/g
s/\bInfered\b/Inferred/g
s/\binfilitrate\b/infiltrate/g
s/\bINFILITRATE\b/INFILTRATE/g
s/\bInfilitrate\b/Infiltrate/g
s/\binfilitrated\b/infiltrated/g
s/\bINFILITRATED\b/INFILTRATED/g
s/\bInfilitrated\b/Infiltrated/g
s/\binfilitration\b/infiltration/g
s/\bINFILITRATION\b/INFILTRATION/g
s/\bInfilitration\b/Infiltration/g
s/\binfinit\b/infinite/g
s/\bINFINIT\b/INFINITE/g
s/\bInfinit\b/Infinite/g
s/\binflamation\b/inflammation/g
s/\bINFLAMATION\b/INFLAMMATION/g
s/\bInflamation\b/Inflammation/g
s/\binfluencial\b/influential/g
s/\bINFLUENCIAL\b/INFLUENTIAL/g
s/\bInfluencial\b/Influential/g
s/\binfluented\b/influenced/g
s/\bINFLUENTED\b/INFLUENCED/g
s/\bInfluented\b/Influenced/g
s/\binfomation\b/information/g
s/\bINFOMATION\b/INFORMATION/g
s/\bInfomation\b/Information/g
s/\binformtion\b/information/g
s/\bINFORMTION\b/INFORMATION/g
s/\bInformtion\b/Information/g
s/\binfrantryman\b/infantryman/g
s/\bINFRANTRYMAN\b/INFANTRYMAN/g
s/\bInfrantryman\b/Infantryman/g
s/\binfrigement\b/infringement/g
s/\bINFRIGEMENT\b/INFRINGEMENT/g
s/\bInfrigement\b/Infringement/g
s/\bingenius\b/ingenious/g
s/\bINGENIUS\b/INGENIOUS/g
s/\bIngenius\b/Ingenious/g
s/\bingreediants\b/ingredients/g
s/\bINGREEDIANTS\b/INGREDIENTS/g
s/\bIngreediants\b/Ingredients/g
s/\binhabitans\b/inhabitants/g
s/\bINHABITANS\b/INHABITANTS/g
s/\bInhabitans\b/Inhabitants/g
s/\binherantly\b/inherently/g
s/\bINHERANTLY\b/INHERENTLY/g
s/\bInherantly\b/Inherently/g
s/\binitally\b/initially/g
s/\bINITALLY\b/INITIALLY/g
s/\bInitally\b/Initially/g
s/\binitation\b/initiation/g
s/\bINITATION\b/INITIATION/g
s/\bInitation\b/Initiation/g
s/\binitiaitive\b/initiative/g
s/\bINITIAITIVE\b/INITIATIVE/g
s/\bInitiaitive\b/Initiative/g
s/\binitilized\b/initialized/g
s/\bINITILIZED\b/INITIALIZED/g
s/\bInitilized\b/Initialized/g
s/\binlcuding\b/including/g
s/\bINLCUDING\b/INCLUDING/g
s/\bInlcuding\b/Including/g
s/\binmigrant\b/immigrant/g
s/\bINMIGRANT\b/IMMIGRANT/g
s/\bInmigrant\b/Immigrant/g
s/\binmigrants\b/immigrants/g
s/\bINMIGRANTS\b/IMMIGRANTS/g
s/\bInmigrants\b/Immigrants/g
s/\binnoculated\b/inoculated/g
s/\bINNOCULATED\b/INOCULATED/g
s/\bInnoculated\b/Inoculated/g
s/\binocence\b/innocence/g
s/\bINOCENCE\b/INNOCENCE/g
s/\bInocence\b/Innocence/g
s/\binofficial\b/unofficial/g
s/\bINOFFICIAL\b/UNOFFICIAL/g
s/\bInofficial\b/Unofficial/g
s/\binot\b/into/g
s/\bINOT\b/INTO/g
s/\bInot\b/Into/g
s/\binpeach\b/impeach/g
s/\bINPEACH\b/IMPEACH/g
s/\bInpeach\b/Impeach/g
s/\binpolite\b/impolite/g
s/\bINPOLITE\b/IMPOLITE/g
s/\bInpolite\b/Impolite/g
s/\binprisonment\b/imprisonment/g
s/\bINPRISONMENT\b/IMPRISONMENT/g
s/\bInprisonment\b/Imprisonment/g
s/\binproving\b/improving/g
s/\bINPROVING\b/IMPROVING/g
s/\bInproving\b/Improving/g
s/\binsectiverous\b/insectivorous/g
s/\bINSECTIVEROUS\b/INSECTIVOROUS/g
s/\bInsectiverous\b/Insectivorous/g
s/\binsensative\b/insensitive/g
s/\bINSENSATIVE\b/INSENSITIVE/g
s/\bInsensative\b/Insensitive/g
s/\binseperable\b/inseparable/g
s/\bINSEPERABLE\b/INSEPARABLE/g
s/\bInseperable\b/Inseparable/g
s/\binsistance\b/insistence/g
s/\bINSISTANCE\b/INSISTENCE/g
s/\bInsistance\b/Insistence/g
s/\binsitution\b/institution/g
s/\bINSITUTION\b/INSTITUTION/g
s/\bInsitution\b/Institution/g
s/\binsitutions\b/institutions/g
s/\bINSITUTIONS\b/INSTITUTIONS/g
s/\bInsitutions\b/Institutions/g
s/\binstade\b/instead/g
s/\bINSTADE\b/INSTEAD/g
s/\bInstade\b/Instead/g
s/\binstatance\b/instance/g
s/\bINSTATANCE\b/INSTANCE/g
s/\bInstatance\b/Instance/g
s/\binstitue\b/institute/g
s/\bINSTITUE\b/INSTITUTE/g
s/\bInstitue\b/Institute/g
s/\binstuction\b/instruction/g
s/\bINSTUCTION\b/INSTRUCTION/g
s/\bInstuction\b/Instruction/g
s/\binstuments\b/instruments/g
s/\bINSTUMENTS\b/INSTRUMENTS/g
s/\bInstuments\b/Instruments/g
s/\binstutionalized\b/institutionalized/g
s/\bINSTUTIONALIZED\b/INSTITUTIONALIZED/g
s/\bInstutionalized\b/Institutionalized/g
s/\binstutions\b/intuitions/g
s/\bINSTUTIONS\b/INTUITIONS/g
s/\bInstutions\b/Intuitions/g
s/\binsurence\b/insurance/g
s/\bINSURENCE\b/INSURANCE/g
s/\bInsurence\b/Insurance/g
s/\bintelectual\b/intellectual/g
s/\bINTELECTUAL\b/INTELLECTUAL/g
s/\bIntelectual\b/Intellectual/g
s/\binteligence\b/intelligence/g
s/\bINTELIGENCE\b/INTELLIGENCE/g
s/\bInteligence\b/Intelligence/g
s/\binteligent\b/intelligent/g
s/\bINTELIGENT\b/INTELLIGENT/g
s/\bInteligent\b/Intelligent/g
s/\bintenational\b/international/g
s/\bINTENATIONAL\b/INTERNATIONAL/g
s/\bIntenational\b/International/g
s/\bintepretation\b/interpretation/g
s/\bINTEPRETATION\b/INTERPRETATION/g
s/\bIntepretation\b/Interpretation/g
s/\bintepretator\b/interpretor/g
s/\bINTEPRETATOR\b/INTERPRETOR/g
s/\bIntepretator\b/Interpretor/g
s/\binterational\b/international/g
s/\bINTERATIONAL\b/INTERNATIONAL/g
s/\bInterational\b/International/g
s/\binterchangably\b/interchangeably/g
s/\bINTERCHANGABLY\b/INTERCHANGEABLY/g
s/\bInterchangably\b/Interchangeably/g
s/\bintercontinential\b/intercontinental/g
s/\bINTERCONTINENTIAL\b/INTERCONTINENTAL/g
s/\bIntercontinential\b/Intercontinental/g
s/\bintercontinetal\b/intercontinental/g
s/\bINTERCONTINETAL\b/INTERCONTINENTAL/g
s/\bIntercontinetal\b/Intercontinental/g
s/\binterelated\b/interrelated/g
s/\bINTERELATED\b/INTERRELATED/g
s/\bInterelated\b/Interrelated/g
s/\binterferance\b/interference/g
s/\bINTERFERANCE\b/INTERFERENCE/g
s/\bInterferance\b/Interference/g
s/\binterfereing\b/interfering/g
s/\bINTERFEREING\b/INTERFERING/g
s/\bInterfereing\b/Interfering/g
s/\bintergrated\b/integrated/g
s/\bINTERGRATED\b/INTEGRATED/g
s/\bIntergrated\b/Integrated/g
s/\bintergration\b/integration/g
s/\bINTERGRATION\b/INTEGRATION/g
s/\bIntergration\b/Integration/g
s/\binterm\b/interim/g
s/\bINTERM\b/INTERIM/g
s/\bInterm\b/Interim/g
s/\binternation\b/international/g
s/\bINTERNATION\b/INTERNATIONAL/g
s/\bInternation\b/International/g
s/\binterpet\b/interpret/g
s/\bINTERPET\b/INTERPRET/g
s/\bInterpet\b/Interpret/g
s/\binterrim\b/interim/g
s/\bINTERRIM\b/INTERIM/g
s/\bInterrim\b/Interim/g
s/\binterrugum\b/interregnum/g
s/\bINTERRUGUM\b/INTERREGNUM/g
s/\bInterrugum\b/Interregnum/g
s/\bintertaining\b/entertaining/g
s/\bINTERTAINING\b/ENTERTAINING/g
s/\bIntertaining\b/Entertaining/g
s/\binterupt\b/interrupt/g
s/\bINTERUPT\b/INTERRUPT/g
s/\bInterupt\b/Interrupt/g
s/\bintervines\b/intervenes/g
s/\bINTERVINES\b/INTERVENES/g
s/\bIntervines\b/Intervenes/g
s/\bintevene\b/intervene/g
s/\bINTEVENE\b/INTERVENE/g
s/\bIntevene\b/Intervene/g
s/\bintrduced\b/introduced/g
s/\bINTRDUCED\b/INTRODUCED/g
s/\bIntrduced\b/Introduced/g
s/\bintrest\b/interest/g
s/\bINTREST\b/INTEREST/g
s/\bIntrest\b/Interest/g
s/\bintrodued\b/introduced/g
s/\bINTRODUED\b/INTRODUCED/g
s/\bIntrodued\b/Introduced/g
s/\bintruduced\b/introduced/g
s/\bINTRUDUCED\b/INTRODUCED/g
s/\bIntruduced\b/Introduced/g
s/\bintrument\b/instrument/g
s/\bINTRUMENT\b/INSTRUMENT/g
s/\bIntrument\b/Instrument/g
s/\bintrumental\b/instrumental/g
s/\bINTRUMENTAL\b/INSTRUMENTAL/g
s/\bIntrumental\b/Instrumental/g
s/\bintruments\b/instruments/g
s/\bINTRUMENTS\b/INSTRUMENTS/g
s/\bIntruments\b/Instruments/g
s/\bintrusted\b/entrusted/g
s/\bINTRUSTED\b/ENTRUSTED/g
s/\bIntrusted\b/Entrusted/g
s/\bintutive\b/intuitive/g
s/\bINTUTIVE\b/INTUITIVE/g
s/\bIntutive\b/Intuitive/g
s/\bintutively\b/intuitively/g
s/\bINTUTIVELY\b/INTUITIVELY/g
s/\bIntutively\b/Intuitively/g
s/\binudstry\b/industry/g
s/\bINUDSTRY\b/INDUSTRY/g
s/\bInudstry\b/Industry/g
s/\binventer\b/inventor/g
s/\bINVENTER\b/INVENTOR/g
s/\bInventer\b/Inventor/g
s/\binvertibrates\b/invertebrates/g
s/\bINVERTIBRATES\b/INVERTEBRATES/g
s/\bInvertibrates\b/Invertebrates/g
s/\binvestingate\b/investigate/g
s/\bINVESTINGATE\b/INVESTIGATE/g
s/\bInvestingate\b/Investigate/g
s/\binvolvment\b/involvement/g
s/\bINVOLVMENT\b/INVOLVEMENT/g
s/\bInvolvment\b/Involvement/g
s/\birelevent\b/irrelevant/g
s/\bIRELEVENT\b/IRRELEVANT/g
s/\bIrelevent\b/Irrelevant/g
s/\biresistable\b/irresistible/g
s/\bIRESISTABLE\b/IRRESISTIBLE/g
s/\bIresistable\b/Irresistible/g
s/\biresistably\b/irresistibly/g
s/\bIRESISTABLY\b/IRRESISTIBLY/g
s/\bIresistably\b/Irresistibly/g
s/\biresistible\b/irresistible/g
s/\bIRESISTIBLE\b/IRRESISTIBLE/g
s/\bIresistible\b/Irresistible/g
s/\biresistibly\b/irresistibly/g
s/\bIRESISTIBLY\b/IRRESISTIBLY/g
s/\bIresistibly\b/Irresistibly/g
s/\biritable\b/irritable/g
s/\bIRITABLE\b/IRRITABLE/g
s/\bIritable\b/Irritable/g
s/\biritated\b/irritated/g
s/\bIRITATED\b/IRRITATED/g
s/\bIritated\b/Irritated/g
s/\bironicly\b/ironically/g
s/\bIRONICLY\b/IRONICALLY/g
s/\bIronicly\b/Ironically/g
s/\birregardless\b/regardless/g
s/\bIRREGARDLESS\b/REGARDLESS/g
s/\bIrregardless\b/Regardless/g
s/\birrelevent\b/irrelevant/g
s/\bIRRELEVENT\b/IRRELEVANT/g
s/\bIrrelevent\b/Irrelevant/g
s/\birreplacable\b/irreplaceable/g
s/\bIRREPLACABLE\b/IRREPLACEABLE/g
s/\bIrreplacable\b/Irreplaceable/g
s/\birresistable\b/irresistible/g
s/\bIRRESISTABLE\b/IRRESISTIBLE/g
s/\bIrresistable\b/Irresistible/g
s/\birresistably\b/irresistibly/g
s/\bIRRESISTABLY\b/IRRESISTIBLY/g
s/\bIrresistably\b/Irresistibly/g
s/\bisnt\b/isn't/g
s/\bISNT\b/ISN'T/g
s/\bIsnt\b/Isn't/g
s/\bissueing\b/issuing/g
s/\bISSUEING\b/ISSUING/g
s/\bIssueing\b/Issuing/g
s/\bitnroduced\b/introduced/g
s/\bITNRODUCED\b/INTRODUCED/g
s/\bItnroduced\b/Introduced/g
s/\biunior\b/junior/g
s/\bIUNIOR\b/JUNIOR/g
s/\bIunior\b/Junior/g
s/\biwll\b/will/g
s/\bIWLL\b/WILL/g
s/\bIwll\b/Will/g
s/\biwth\b/with/g
s/\bIWTH\b/WITH/g
s/\bIwth\b/With/g
s/\bjaques\b/jacques/g
s/\bJAQUES\b/JACQUES/g
s/\bJaques\b/Jacques/g
s/\bjeapardy\b/jeopardy/g
s/\bJEAPARDY\b/JEOPARDY/g
s/\bJeapardy\b/Jeopardy/g
s/\bjewllery\b/jewellery/g
s/\bJEWLLERY\b/JEWELLERY/g
s/\bJewllery\b/Jewellery/g
s/\bjorunal\b/journal/g
s/\bJORUNAL\b/JOURNAL/g
s/\bJorunal\b/Journal/g
s/\bjouney\b/journey/g
s/\bJOUNEY\b/JOURNEY/g
s/\bJouney\b/Journey/g
s/\bjournied\b/journeyed/g
s/\bJOURNIED\b/JOURNEYED/g
s/\bJournied\b/Journeyed/g
s/\bjournies\b/journeys/g
s/\bJOURNIES\b/JOURNEYS/g
s/\bJournies\b/Journeys/g
s/\bjstu\b/just/g
s/\bJSTU\b/JUST/g
s/\bJstu\b/Just/g
s/\bjsut\b/just/g
s/\bJSUT\b/JUST/g
s/\bJsut\b/Just/g
s/\bjudical\b/judicial/g
s/\bJUDICAL\b/JUDICIAL/g
s/\bJudical\b/Judicial/g
s/\bjudisuary\b/judiciary/g
s/\bJUDISUARY\b/JUDICIARY/g
s/\bJudisuary\b/Judiciary/g
s/\bjuducial\b/judicial/g
s/\bJUDUCIAL\b/JUDICIAL/g
s/\bJuducial\b/Judicial/g
s/\bjuristiction\b/jurisdiction/g
s/\bJURISTICTION\b/JURISDICTION/g
s/\bJuristiction\b/Jurisdiction/g
s/\bjuristictions\b/jurisdictions/g
s/\bJURISTICTIONS\b/JURISDICTIONS/g
s/\bJuristictions\b/Jurisdictions/g
s/\bkindergarden\b/kindergarten/g
s/\bKINDERGARDEN\b/KINDERGARTEN/g
s/\bKindergarden\b/Kindergarten/g
s/\bklenex\b/kleenex/g
s/\bKLENEX\b/KLEENEX/g
s/\bKlenex\b/Kleenex/g
s/\bknifes\b/knives/g
s/\bKNIFES\b/KNIVES/g
s/\bKnifes\b/Knives/g
s/\bknive\b/knife/g
s/\bKNIVE\b/KNIFE/g
s/\bKnive\b/Knife/g
s/\bknowlege\b/knowledge/g
s/\bKNOWLEGE\b/KNOWLEDGE/g
s/\bKnowlege\b/Knowledge/g
s/\bknowlegeable\b/knowledgeable/g
s/\bKNOWLEGEABLE\b/KNOWLEDGEABLE/g
s/\bKnowlegeable\b/Knowledgeable/g
s/\bknwo\b/know/g
s/\bKNWO\b/KNOW/g
s/\bKnwo\b/Know/g
s/\bknwos\b/knows/g
s/\bKNWOS\b/KNOWS/g
s/\bKnwos\b/Knows/g
s/\bkonw\b/know/g
s/\bKONW\b/KNOW/g
s/\bKonw\b/Know/g
s/\bkonws\b/knows/g
s/\bKONWS\b/KNOWS/g
s/\bKonws\b/Knows/g
s/\bkwno\b/know/g
s/\bKWNO\b/KNOW/g
s/\bKwno\b/Know/g
s/\blabratory\b/laboratory/g
s/\bLABRATORY\b/LABORATORY/g
s/\bLabratory\b/Laboratory/g
s/\blaguage\b/language/g
s/\bLAGUAGE\b/LANGUAGE/g
s/\bLaguage\b/Language/g
s/\blaguages\b/languages/g
s/\bLAGUAGES\b/LANGUAGES/g
s/\bLaguages\b/Languages/g
s/\blarg\b/large/g
s/\bLARG\b/LARGE/g
s/\bLarg\b/Large/g
s/\blargst\b/largest/g
s/\bLARGST\b/LARGEST/g
s/\bLargst\b/Largest/g
s/\blarrry\b/larry/g
s/\bLARRRY\b/LARRY/g
s/\bLarrry\b/Larry/g
s/\blastr\b/last/g
s/\bLASTR\b/LAST/g
s/\bLastr\b/Last/g
s/\blattitude\b/latitude/g
s/\bLATTITUDE\b/LATITUDE/g
s/\bLattitude\b/Latitude/g
s/\blaunhed\b/launched/g
s/\bLAUNHED\b/LAUNCHED/g
s/\bLaunhed\b/Launched/g
s/\blavae\b/larvae/g
s/\bLAVAE\b/LARVAE/g
s/\bLavae\b/Larvae/g
s/\blayed\b/laid/g
s/\bLAYED\b/LAID/g
s/\bLayed\b/Laid/g
s/\blazyness\b/laziness/g
s/\bLAZYNESS\b/LAZINESS/g
s/\bLazyness\b/Laziness/g
s/\bleage\b/league/g
s/\bLEAGE\b/LEAGUE/g
s/\bLeage\b/League/g
s/\bleathal\b/lethal/g
s/\bLEATHAL\b/LETHAL/g
s/\bLeathal\b/Lethal/g
s/\blefted\b/left/g
s/\bLEFTED\b/LEFT/g
s/\bLefted\b/Left/g
s/\blegitamate\b/legitimate/g
s/\bLEGITAMATE\b/LEGITIMATE/g
s/\bLegitamate\b/Legitimate/g
s/\blegitmate\b/legitimate/g
s/\bLEGITMATE\b/LEGITIMATE/g
s/\bLegitmate\b/Legitimate/g
s/\bleibnitz\b/leibniz/g
s/\bLEIBNITZ\b/LEIBNIZ/g
s/\bLeibnitz\b/Leibniz/g
s/\bleran\b/learn/g
s/\bLERAN\b/LEARN/g
s/\bLeran\b/Learn/g
s/\blerans\b/learns/g
s/\bLERANS\b/LEARNS/g
s/\bLerans\b/Learns/g
s/\bleutenant\b/lieutenant/g
s/\bLEUTENANT\b/LIEUTENANT/g
s/\bLeutenant\b/Lieutenant/g
s/\blevetate\b/levitate/g
s/\bLEVETATE\b/LEVITATE/g
s/\bLevetate\b/Levitate/g
s/\blevetated\b/levitated/g
s/\bLEVETATED\b/LEVITATED/g
s/\bLevetated\b/Levitated/g
s/\blevetates\b/levitates/g
s/\bLEVETATES\b/LEVITATES/g
s/\bLevetates\b/Levitates/g
s/\blevetating\b/levitating/g
s/\bLEVETATING\b/LEVITATING/g
s/\bLevetating\b/Levitating/g
s/\blevle\b/level/g
s/\bLEVLE\b/LEVEL/g
s/\bLevle\b/Level/g
s/\bliasion\b/liaison/g
s/\bLIASION\b/LIAISON/g
s/\bLiasion\b/Liaison/g
s/\bliason\b/liaison/g
s/\bLIASON\b/LIAISON/g
s/\bLiason\b/Liaison/g
s/\bliasons\b/liaisons/g
s/\bLIASONS\b/LIAISONS/g
s/\bLiasons\b/Liaisons/g
s/\blibell\b/libel/g
s/\bLIBELL\b/LIBEL/g
s/\bLibell\b/Libel/g
s/\blibguistic\b/linguistic/g
s/\bLIBGUISTIC\b/LINGUISTIC/g
s/\bLibguistic\b/Linguistic/g
s/\blibguistics\b/linguistics/g
s/\bLIBGUISTICS\b/LINGUISTICS/g
s/\bLibguistics\b/Linguistics/g
s/\blibitarianisn\b/libertarianism/g
s/\bLIBITARIANISN\b/LIBERTARIANISM/g
s/\bLibitarianisn\b/Libertarianism/g
s/\blieing\b/lying/g
s/\bLIEING\b/LYING/g
s/\bLieing\b/Lying/g
s/\bliek\b/like/g
s/\bLIEK\b/LIKE/g
s/\bLiek\b/Like/g
s/\bliekd\b/liked/g
s/\bLIEKD\b/LIKED/g
s/\bLiekd\b/Liked/g
s/\bliesure\b/leisure/g
s/\bLIESURE\b/LEISURE/g
s/\bLiesure\b/Leisure/g
s/\blieuenant\b/lieutenant/g
s/\bLIEUENANT\b/LIEUTENANT/g
s/\bLieuenant\b/Lieutenant/g
s/\blieved\b/lived/g
s/\bLIEVED\b/LIVED/g
s/\bLieved\b/Lived/g
s/\bliftime\b/lifetime/g
s/\bLIFTIME\b/LIFETIME/g
s/\bLiftime\b/Lifetime/g
s/\blightyear\b/light year/g
s/\bLIGHTYEAR\b/LIGHT YEAR/g
s/\bLightyear\b/Light year/g
s/\blightyears\b/light years/g
s/\bLIGHTYEARS\b/LIGHT YEARS/g
s/\bLightyears\b/Light years/g
s/\blikelyhood\b/likelihood/g
s/\bLIKELYHOOD\b/LIKELIHOOD/g
s/\bLikelyhood\b/Likelihood/g
s/\blinnaena\b/linnaean/g
s/\bLINNAENA\b/LINNAEAN/g
s/\bLinnaena\b/Linnaean/g
s/\blippizaner\b/lipizzaner/g
s/\bLIPPIZANER\b/LIPIZZANER/g
s/\bLippizaner\b/Lipizzaner/g
s/\bliquify\b/liquefy/g
s/\bLIQUIFY\b/LIQUEFY/g
s/\bLiquify\b/Liquefy/g
s/\blistners\b/listeners/g
s/\bLISTNERS\b/LISTENERS/g
s/\bListners\b/Listeners/g
s/\blitature\b/literature/g
s/\bLITATURE\b/LITERATURE/g
s/\bLitature\b/Literature/g
s/\bliteraly\b/literally/g
s/\bLITERALY\b/LITERALLY/g
s/\bLiteraly\b/Literally/g
s/\bliterture\b/literature/g
s/\bLITERTURE\b/LITERATURE/g
s/\bLiterture\b/Literature/g
s/\blittel\b/little/g
s/\bLITTEL\b/LITTLE/g
s/\bLittel\b/Little/g
s/\blitterally\b/literally/g
s/\bLITTERALLY\b/LITERALLY/g
s/\bLitterally\b/Literally/g
s/\bliuke\b/like/g
s/\bLIUKE\b/LIKE/g
s/\bLiuke\b/Like/g
s/\blivley\b/lively/g
s/\bLIVLEY\b/LIVELY/g
s/\bLivley\b/Lively/g
s/\blmits\b/limits/g
s/\bLMITS\b/LIMITS/g
s/\bLmits\b/Limits/g
s/\blocla\b/local/g
s/\bLOCLA\b/LOCAL/g
s/\bLocla\b/Local/g
s/\bloev\b/love/g
s/\bLOEV\b/LOVE/g
s/\bLoev\b/Love/g
s/\blonelyness\b/loneliness/g
s/\bLONELYNESS\b/LONELINESS/g
s/\bLonelyness\b/Loneliness/g
s/\blongitudonal\b/longitudinal/g
s/\bLONGITUDONAL\b/LONGITUDINAL/g
s/\bLongitudonal\b/Longitudinal/g
s/\blonley\b/lonely/g
s/\bLONLEY\b/LONELY/g
s/\bLonley\b/Lonely/g
s/\blotharingen\b/lothringen/g
s/\bLOTHARINGEN\b/LOTHRINGEN/g
s/\bLotharingen\b/Lothringen/g
s/\blsat\b/last/g
s/\bLSAT\b/LAST/g
s/\bLsat\b/Last/g
s/\blukid\b/likud/g
s/\bLUKID\b/LIKUD/g
s/\bLukid\b/Likud/g
s/\blveo\b/love/g
s/\bLVEO\b/LOVE/g
s/\bLveo\b/Love/g
s/\blvoe\b/love/g
s/\bLVOE\b/LOVE/g
s/\bLvoe\b/Love/g
s/\bmackeral\b/mackerel/g
s/\bMACKERAL\b/MACKEREL/g
s/\bMackeral\b/Mackerel/g
s/\bmagasine\b/magazine/g
s/\bMAGASINE\b/MAGAZINE/g
s/\bMagasine\b/Magazine/g
s/\bmagincian\b/magician/g
s/\bMAGINCIAN\b/MAGICIAN/g
s/\bMagincian\b/Magician/g
s/\bmagisine\b/magazine/g
s/\bMAGISINE\b/MAGAZINE/g
s/\bMagisine\b/Magazine/g
s/\bmagizine\b/magazine/g
s/\bMAGIZINE\b/MAGAZINE/g
s/\bMagizine\b/Magazine/g
s/\bmagnificient\b/magnificent/g
s/\bMAGNIFICIENT\b/MAGNIFICENT/g
s/\bMagnificient\b/Magnificent/g
s/\bmagolia\b/magnolia/g
s/\bMAGOLIA\b/MAGNOLIA/g
s/\bMagolia\b/Magnolia/g
s/\bmailny\b/mainly/g
s/\bMAILNY\b/MAINLY/g
s/\bMailny\b/Mainly/g
s/\bmaintainance\b/maintenance/g
s/\bMAINTAINANCE\b/MAINTENANCE/g
s/\bMaintainance\b/Maintenance/g
s/\bmaintainence\b/maintenance/g
s/\bMAINTAINENCE\b/MAINTENANCE/g
s/\bMaintainence\b/Maintenance/g
s/\bmaintance\b/maintenance/g
s/\bMAINTANCE\b/MAINTENANCE/g
s/\bMaintance\b/Maintenance/g
s/\bmaintenence\b/maintenance/g
s/\bMAINTENENCE\b/MAINTENANCE/g
s/\bMaintenence\b/Maintenance/g
s/\bmaintinaing\b/maintaining/g
s/\bMAINTINAING\b/MAINTAINING/g
s/\bMaintinaing\b/Maintaining/g
s/\bmaintioned\b/mentioned/g
s/\bMAINTIONED\b/MENTIONED/g
s/\bMaintioned\b/Mentioned/g
s/\bmajoroty\b/majority/g
s/\bMAJOROTY\b/MAJORITY/g
s/\bMajoroty\b/Majority/g
s/\bmakse\b/makes/g
s/\bMAKSE\b/MAKES/g
s/\bMakse\b/Makes/g
s/\bmaltesian\b/maltese/g
s/\bMALTESIAN\b/MALTESE/g
s/\bMaltesian\b/Maltese/g
s/\bmamal\b/mammal/g
s/\bMAMAL\b/MAMMAL/g
s/\bMamal\b/Mammal/g
s/\bmamalian\b/mammalian/g
s/\bMAMALIAN\b/MAMMALIAN/g
s/\bMamalian\b/Mammalian/g
s/\bmanagment\b/management/g
s/\bMANAGMENT\b/MANAGEMENT/g
s/\bManagment\b/Management/g
s/\bmaneouvre\b/manoeuvre/g
s/\bMANEOUVRE\b/MANOEUVRE/g
s/\bManeouvre\b/Manoeuvre/g
s/\bmaneouvred\b/manoeuvred/g
s/\bMANEOUVRED\b/MANOEUVRED/g
s/\bManeouvred\b/Manoeuvred/g
s/\bmaneouvres\b/manoeuvres/g
s/\bMANEOUVRES\b/MANOEUVRES/g
s/\bManeouvres\b/Manoeuvres/g
s/\bmaneouvring\b/manoeuvring/g
s/\bMANEOUVRING\b/MANOEUVRING/g
s/\bManeouvring\b/Manoeuvring/g
s/\bmanisfestations\b/manifestations/g
s/\bMANISFESTATIONS\b/MANIFESTATIONS/g
s/\bManisfestations\b/Manifestations/g
s/\bmanoeuverability\b/maneuverability/g
s/\bMANOEUVERABILITY\b/MANEUVERABILITY/g
s/\bManoeuverability\b/Maneuverability/g
s/\bmantained\b/maintained/g
s/\bMANTAINED\b/MAINTAINED/g
s/\bMantained\b/Maintained/g
s/\bmanufacturedd\b/manufactured/g
s/\bMANUFACTUREDD\b/MANUFACTURED/g
s/\bManufacturedd\b/Manufactured/g
s/\bmanufature\b/manufacture/g
s/\bMANUFATURE\b/MANUFACTURE/g
s/\bManufature\b/Manufacture/g
s/\bmanufatured\b/manufactured/g
s/\bMANUFATURED\b/MANUFACTURED/g
s/\bManufatured\b/Manufactured/g
s/\bmanufaturing\b/manufacturing/g
s/\bMANUFATURING\b/MANUFACTURING/g
s/\bManufaturing\b/Manufacturing/g
s/\bmanuver\b/maneuver/g
s/\bMANUVER\b/MANEUVER/g
s/\bManuver\b/Maneuver/g
s/\bmariage\b/marriage/g
s/\bMARIAGE\b/MARRIAGE/g
s/\bMariage\b/Marriage/g
s/\bmarjority\b/majority/g
s/\bMARJORITY\b/MAJORITY/g
s/\bMarjority\b/Majority/g
s/\bmarketting\b/marketing/g
s/\bMARKETTING\b/MARKETING/g
s/\bMarketting\b/Marketing/g
s/\bmarmelade\b/marmalade/g
s/\bMARMELADE\b/MARMALADE/g
s/\bMarmelade\b/Marmalade/g
s/\bmarrage\b/marriage/g
s/\bMARRAGE\b/MARRIAGE/g
s/\bMarrage\b/Marriage/g
s/\bmarraige\b/marriage/g
s/\bMARRAIGE\b/MARRIAGE/g
s/\bMarraige\b/Marriage/g
s/\bmarrtyred\b/martyred/g
s/\bMARRTYRED\b/MARTYRED/g
s/\bMarrtyred\b/Martyred/g
s/\bmarryied\b/married/g
s/\bMARRYIED\b/MARRIED/g
s/\bMarryied\b/Married/g
s/\bmassmedia\b/mass media/g
s/\bMASSMEDIA\b/MASS MEDIA/g
s/\bMassmedia\b/Mass media/g
s/\bmasterbation\b/masturbation/g
s/\bMASTERBATION\b/MASTURBATION/g
s/\bMasterbation\b/Masturbation/g
s/\bmataphysical\b/metaphysical/g
s/\bMATAPHYSICAL\b/METAPHYSICAL/g
s/\bMataphysical\b/Metaphysical/g
s/\bmateralists\b/materialist/g
s/\bMATERALISTS\b/MATERIALIST/g
s/\bMateralists\b/Materialist/g
s/\bmathamatics\b/mathematics/g
s/\bMATHAMATICS\b/MATHEMATICS/g
s/\bMathamatics\b/Mathematics/g
s/\bmathematican\b/mathematician/g
s/\bMATHEMATICAN\b/MATHEMATICIAN/g
s/\bMathematican\b/Mathematician/g
s/\bmathematicas\b/mathematics/g
s/\bMATHEMATICAS\b/MATHEMATICS/g
s/\bMathematicas\b/Mathematics/g
s/\bmatheticians\b/mathematicians/g
s/\bMATHETICIANS\b/MATHEMATICIANS/g
s/\bMatheticians\b/Mathematicians/g
s/\bmathmatically\b/mathematically/g
s/\bMATHMATICALLY\b/MATHEMATICALLY/g
s/\bMathmatically\b/Mathematically/g
s/\bmathmatician\b/mathematician/g
s/\bMATHMATICIAN\b/MATHEMATICIAN/g
s/\bMathmatician\b/Mathematician/g
s/\bmathmaticians\b/mathematicians/g
s/\bMATHMATICIANS\b/MATHEMATICIANS/g
s/\bMathmaticians\b/Mathematicians/g
s/\bmccarthyst\b/mccarthyist/g
s/\bMCCARTHYST\b/MCCARTHYIST/g
s/\bMccarthyst\b/Mccarthyist/g
s/\bmchanics\b/mechanics/g
s/\bMCHANICS\b/MECHANICS/g
s/\bMchanics\b/Mechanics/g
s/\bmeaninng\b/meaning/g
s/\bMEANINNG\b/MEANING/g
s/\bMeaninng\b/Meaning/g
s/\bmechandise\b/merchandise/g
s/\bMECHANDISE\b/MERCHANDISE/g
s/\bMechandise\b/Merchandise/g
s/\bmedacine\b/medicine/g
s/\bMEDACINE\b/MEDICINE/g
s/\bMedacine\b/Medicine/g
s/\bmedeival\b/medieval/g
s/\bMEDEIVAL\b/MEDIEVAL/g
s/\bMedeival\b/Medieval/g
s/\bmedevial\b/medieval/g
s/\bMEDEVIAL\b/MEDIEVAL/g
s/\bMedevial\b/Medieval/g
s/\bmediciney\b/mediciny/g
s/\bMEDICINEY\b/MEDICINY/g
s/\bMediciney\b/Mediciny/g
s/\bmedievel\b/medieval/g
s/\bMEDIEVEL\b/MEDIEVAL/g
s/\bMedievel\b/Medieval/g
s/\bmediterainnean\b/mediterranean/g
s/\bMEDITERAINNEAN\b/MEDITERRANEAN/g
s/\bMediterainnean\b/Mediterranean/g
s/\bmeerkrat\b/meerkat/g
s/\bMEERKRAT\b/MEERKAT/g
s/\bMeerkrat\b/Meerkat/g
s/\bmelieux\b/milieux/g
s/\bMELIEUX\b/MILIEUX/g
s/\bMelieux\b/Milieux/g
s/\bmembranaphone\b/membranophone/g
s/\bMEMBRANAPHONE\b/MEMBRANOPHONE/g
s/\bMembranaphone\b/Membranophone/g
s/\bmemeber\b/member/g
s/\bMEMEBER\b/MEMBER/g
s/\bMemeber\b/Member/g
s/\bmenally\b/mentally/g
s/\bMENALLY\b/MENTALLY/g
s/\bMenally\b/Mentally/g
s/\bmercentile\b/mercantile/g
s/\bMERCENTILE\b/MERCANTILE/g
s/\bMercentile\b/Mercantile/g
s/\bmessanger\b/messenger/g
s/\bMESSANGER\b/MESSENGER/g
s/\bMessanger\b/Messenger/g
s/\bmessenging\b/messaging/g
s/\bMESSENGING\b/MESSAGING/g
s/\bMessenging\b/Messaging/g
s/\bmetalic\b/metallic/g
s/\bMETALIC\b/METALLIC/g
s/\bMetalic\b/Metallic/g
s/\bmetalurgic\b/metallurgic/g
s/\bMETALURGIC\b/METALLURGIC/g
s/\bMetalurgic\b/Metallurgic/g
s/\bmetalurgical\b/metallurgical/g
s/\bMETALURGICAL\b/METALLURGICAL/g
s/\bMetalurgical\b/Metallurgical/g
s/\bmetalurgy\b/metallurgy/g
s/\bMETALURGY\b/METALLURGY/g
s/\bMetalurgy\b/Metallurgy/g
s/\bmetamorphysis\b/metamorphosis/g
s/\bMETAMORPHYSIS\b/METAMORPHOSIS/g
s/\bMetamorphysis\b/Metamorphosis/g
s/\bmetaphoricial\b/metaphorical/g
s/\bMETAPHORICIAL\b/METAPHORICAL/g
s/\bMetaphoricial\b/Metaphorical/g
s/\bmeterologist\b/meteorologist/g
s/\bMETEROLOGIST\b/METEOROLOGIST/g
s/\bMeterologist\b/Meteorologist/g
s/\bmeterology\b/meteorology/g
s/\bMETEROLOGY\b/METEOROLOGY/g
s/\bMeterology\b/Meteorology/g
s/\bmethaphor\b/metaphor/g
s/\bMETHAPHOR\b/METAPHOR/g
s/\bMethaphor\b/Metaphor/g
s/\bmethaphors\b/metaphors/g
s/\bMETHAPHORS\b/METAPHORS/g
s/\bMethaphors\b/Metaphors/g
s/\bmicoscopy\b/microscopy/g
s/\bMICOSCOPY\b/MICROSCOPY/g
s/\bMicoscopy\b/Microscopy/g
s/\bmidwifes\b/midwives/g
s/\bMIDWIFES\b/MIDWIVES/g
s/\bMidwifes\b/Midwives/g
s/\bmileau\b/milieu/g
s/\bMILEAU\b/MILIEU/g
s/\bMileau\b/Milieu/g
s/\bmilennia\b/millennia/g
s/\bMILENNIA\b/MILLENNIA/g
s/\bMilennia\b/Millennia/g
s/\bmilennium\b/millennium/g
s/\bMILENNIUM\b/MILLENNIUM/g
s/\bMilennium\b/Millennium/g
s/\bmileu\b/milieu/g
s/\bMILEU\b/MILIEU/g
s/\bMileu\b/Milieu/g
s/\bmiliary\b/military/g
s/\bMILIARY\b/MILITARY/g
s/\bMiliary\b/Military/g
s/\bmiligram\b/milligram/g
s/\bMILIGRAM\b/MILLIGRAM/g
s/\bMiligram\b/Milligram/g
s/\bmilion\b/million/g
s/\bMILION\b/MILLION/g
s/\bMilion\b/Million/g
s/\bmiliraty\b/military/g
s/\bMILIRATY\b/MILITARY/g
s/\bMiliraty\b/Military/g
s/\bmillenia\b/millennia/g
s/\bMILLENIA\b/MILLENNIA/g
s/\bMillenia\b/Millennia/g
s/\bmillenial\b/millennial/g
s/\bMILLENIAL\b/MILLENNIAL/g
s/\bMillenial\b/Millennial/g
s/\bmillenialism\b/millennialism/g
s/\bMILLENIALISM\b/MILLENNIALISM/g
s/\bMillenialism\b/Millennialism/g
s/\bmillenium\b/millennium/g
s/\bMILLENIUM\b/MILLENNIUM/g
s/\bMillenium\b/Millennium/g
s/\bmillepede\b/millipede/g
s/\bMILLEPEDE\b/MILLIPEDE/g
s/\bMillepede\b/Millipede/g
s/\bmillioniare\b/millionaire/g
s/\bMILLIONIARE\b/MILLIONAIRE/g
s/\bMillioniare\b/Millionaire/g
s/\bmillitary\b/military/g
s/\bMILLITARY\b/MILITARY/g
s/\bMillitary\b/Military/g
s/\bmillon\b/million/g
s/\bMILLON\b/MILLION/g
s/\bMillon\b/Million/g
s/\bmiltary\b/military/g
s/\bMILTARY\b/MILITARY/g
s/\bMiltary\b/Military/g
s/\bminature\b/miniature/g
s/\bMINATURE\b/MINIATURE/g
s/\bMinature\b/Miniature/g
s/\bminerial\b/mineral/g
s/\bMINERIAL\b/MINERAL/g
s/\bMinerial\b/Mineral/g
s/\bministery\b/ministry/g
s/\bMINISTERY\b/MINISTRY/g
s/\bMinistery\b/Ministry/g
s/\bminsitry\b/ministry/g
s/\bMINSITRY\b/MINISTRY/g
s/\bMinsitry\b/Ministry/g
s/\bminstries\b/ministries/g
s/\bMINSTRIES\b/MINISTRIES/g
s/\bMinstries\b/Ministries/g
s/\bminstry\b/ministry/g
s/\bMINSTRY\b/MINISTRY/g
s/\bMinstry\b/Ministry/g
s/\bmirrorred\b/mirrored/g
s/\bMIRRORRED\b/MIRRORED/g
s/\bMirrorred\b/Mirrored/g
s/\bmiscelaneous\b/miscellaneous/g
s/\bMISCELANEOUS\b/MISCELLANEOUS/g
s/\bMiscelaneous\b/Miscellaneous/g
s/\bmiscellanious\b/miscellaneous/g
s/\bMISCELLANIOUS\b/MISCELLANEOUS/g
s/\bMiscellanious\b/Miscellaneous/g
s/\bmiscellanous\b/miscellaneous/g
s/\bMISCELLANOUS\b/MISCELLANEOUS/g
s/\bMiscellanous\b/Miscellaneous/g
s/\bmischeivous\b/mischievous/g
s/\bMISCHEIVOUS\b/MISCHIEVOUS/g
s/\bMischeivous\b/Mischievous/g
s/\bmischevious\b/mischievous/g
s/\bMISCHEVIOUS\b/MISCHIEVOUS/g
s/\bMischevious\b/Mischievous/g
s/\bmischievious\b/mischievous/g
s/\bMISCHIEVIOUS\b/MISCHIEVOUS/g
s/\bMischievious\b/Mischievous/g
s/\bmisdameanor\b/misdemeanor/g
s/\bMISDAMEANOR\b/MISDEMEANOR/g
s/\bMisdameanor\b/Misdemeanor/g
s/\bmisdameanors\b/misdemeanors/g
s/\bMISDAMEANORS\b/MISDEMEANORS/g
s/\bMisdameanors\b/Misdemeanors/g
s/\bmisdemenor\b/misdemeanor/g
s/\bMISDEMENOR\b/MISDEMEANOR/g
s/\bMisdemenor\b/Misdemeanor/g
s/\bmisdemenors\b/misdemeanors/g
s/\bMISDEMENORS\b/MISDEMEANORS/g
s/\bMisdemenors\b/Misdemeanors/g
s/\bmisfourtunes\b/misfortunes/g
s/\bMISFOURTUNES\b/MISFORTUNES/g
s/\bMisfourtunes\b/Misfortunes/g
s/\bmisile\b/missile/g
s/\bMISILE\b/MISSILE/g
s/\bMisile\b/Missile/g
s/\bmispell\b/misspell/g
s/\bMISPELL\b/MISSPELL/g
s/\bMispell\b/Misspell/g
s/\bmispelled\b/misspelled/g
s/\bMISPELLED\b/MISSPELLED/g
s/\bMispelled\b/Misspelled/g
s/\bmispelling\b/misspelling/g
s/\bMISPELLING\b/MISSPELLING/g
s/\bMispelling\b/Misspelling/g
s/\bmissen\b/mizzen/g
s/\bMISSEN\b/MIZZEN/g
s/\bMissen\b/Mizzen/g
s/\bmissle\b/missile/g
s/\bMISSLE\b/MISSILE/g
s/\bMissle\b/Missile/g
s/\bmissonary\b/missionary/g
s/\bMISSONARY\b/MISSIONARY/g
s/\bMissonary\b/Missionary/g
s/\bmisterious\b/mysterious/g
s/\bMISTERIOUS\b/MYSTERIOUS/g
s/\bMisterious\b/Mysterious/g
s/\bmistery\b/mystery/g
s/\bMISTERY\b/MYSTERY/g
s/\bMistery\b/Mystery/g
s/\bmisteryous\b/mysterious/g
s/\bMISTERYOUS\b/MYSTERIOUS/g
s/\bMisteryous\b/Mysterious/g
s/\bmkae\b/make/g
s/\bMKAE\b/MAKE/g
s/\bMkae\b/Make/g
s/\bmkaes\b/makes/g
s/\bMKAES\b/MAKES/g
s/\bMkaes\b/Makes/g
s/\bmkaing\b/making/g
s/\bMKAING\b/MAKING/g
s/\bMkaing\b/Making/g
s/\bmkea\b/make/g
s/\bMKEA\b/MAKE/g
s/\bMkea\b/Make/g
s/\bmoderm\b/modem/g
s/\bMODERM\b/MODEM/g
s/\bModerm\b/Modem/g
s/\bmodle\b/model/g
s/\bMODLE\b/MODEL/g
s/\bModle\b/Model/g
s/\bmoent\b/moment/g
s/\bMOENT\b/MOMENT/g
s/\bMoent\b/Moment/g
s/\bmoeny\b/money/g
s/\bMOENY\b/MONEY/g
s/\bMoeny\b/Money/g
s/\bmohammedans\b/muslims/g
s/\bMOHAMMEDANS\b/MUSLIMS/g
s/\bMohammedans\b/Muslims/g
s/\bmoil\b/mohel/g
s/\bMOIL\b/MOHEL/g
s/\bMoil\b/Mohel/g
s/\bmoil\b/soil/g
s/\bMOIL\b/SOIL/g
s/\bMoil\b/Soil/g
s/\bmoleclues\b/molecules/g
s/\bMOLECLUES\b/MOLECULES/g
s/\bMoleclues\b/Molecules/g
s/\bmomento\b/memento/g
s/\bMOMENTO\b/MEMENTO/g
s/\bMomento\b/Memento/g
s/\bmonestaries\b/monasteries/g
s/\bMONESTARIES\b/MONASTERIES/g
s/\bMonestaries\b/Monasteries/g
s/\bmonickers\b/monikers/g
s/\bMONICKERS\b/MONIKERS/g
s/\bMonickers\b/Monikers/g
s/\bmonolite\b/monolithic/g
s/\bMONOLITE\b/MONOLITHIC/g
s/\bMonolite\b/Monolithic/g
s/\bmontains\b/mountains/g
s/\bMONTAINS\b/MOUNTAINS/g
s/\bMontains\b/Mountains/g
s/\bmontanous\b/mountainous/g
s/\bMONTANOUS\b/MOUNTAINOUS/g
s/\bMontanous\b/Mountainous/g
s/\bmonts\b/months/g
s/\bMONTS\b/MONTHS/g
s/\bMonts\b/Months/g
s/\bmontypic\b/monotypic/g
s/\bMONTYPIC\b/MONOTYPIC/g
s/\bMontypic\b/Monotypic/g
s/\bmorgage\b/mortgage/g
s/\bMORGAGE\b/MORTGAGE/g
s/\bMorgage\b/Mortgage/g
s/\bmorroccan\b/moroccan/g
s/\bMORROCCAN\b/MOROCCAN/g
s/\bMorroccan\b/Moroccan/g
s/\bmorrocco\b/morocco/g
s/\bMORROCCO\b/MOROCCO/g
s/\bMorrocco\b/Morocco/g
s/\bmorroco\b/morocco/g
s/\bMORROCO\b/MOROCCO/g
s/\bMorroco\b/Morocco/g
s/\bmortage\b/mortgage/g
s/\bMORTAGE\b/MORTGAGE/g
s/\bMortage\b/Mortgage/g
s/\bmosture\b/moisture/g
s/\bMOSTURE\b/MOISTURE/g
s/\bMosture\b/Moisture/g
s/\bmotiviated\b/motivated/g
s/\bMOTIVIATED\b/MOTIVATED/g
s/\bMotiviated\b/Motivated/g
s/\bmounth\b/month/g
s/\bMOUNTH\b/MONTH/g
s/\bMounth\b/Month/g
s/\bmovei\b/movie/g
s/\bMOVEI\b/MOVIE/g
s/\bMovei\b/Movie/g
s/\bmovment\b/movement/g
s/\bMOVMENT\b/MOVEMENT/g
s/\bMovment\b/Movement/g
s/\bmroe\b/more/g
s/\bMROE\b/MORE/g
s/\bMroe\b/More/g
s/\bmucuous\b/mucous/g
s/\bMUCUOUS\b/MUCOUS/g
s/\bMucuous\b/Mucous/g
s/\bmuder\b/murder/g
s/\bMUDER\b/MURDER/g
s/\bMuder\b/Murder/g
s/\bmudering\b/murdering/g
s/\bMUDERING\b/MURDERING/g
s/\bMudering\b/Murdering/g
s/\bmuhammadan\b/muslim/g
s/\bMUHAMMADAN\b/MUSLIM/g
s/\bMuhammadan\b/Muslim/g
s/\bmulticultralism\b/multiculturalism/g
s/\bMULTICULTRALISM\b/MULTICULTURALISM/g
s/\bMulticultralism\b/Multiculturalism/g
s/\bmultipled\b/multiplied/g
s/\bMULTIPLED\b/MULTIPLIED/g
s/\bMultipled\b/Multiplied/g
s/\bmultiplers\b/multipliers/g
s/\bMULTIPLERS\b/MULTIPLIERS/g
s/\bMultiplers\b/Multipliers/g
s/\bmunbers\b/numbers/g
s/\bMUNBERS\b/NUMBERS/g
s/\bMunbers\b/Numbers/g
s/\bmuncipalities\b/municipalities/g
s/\bMUNCIPALITIES\b/MUNICIPALITIES/g
s/\bMuncipalities\b/Municipalities/g
s/\bmuncipality\b/municipality/g
s/\bMUNCIPALITY\b/MUNICIPALITY/g
s/\bMuncipality\b/Municipality/g
s/\bmunnicipality\b/municipality/g
s/\bMUNNICIPALITY\b/MUNICIPALITY/g
s/\bMunnicipality\b/Municipality/g
s/\bmuscial\b/musical/g
s/\bMUSCIAL\b/MUSICAL/g
s/\bMuscial\b/Musical/g
s/\bmuscician\b/musician/g
s/\bMUSCICIAN\b/MUSICIAN/g
s/\bMuscician\b/Musician/g
s/\bmuscicians\b/musicians/g
s/\bMUSCICIANS\b/MUSICIANS/g
s/\bMuscicians\b/Musicians/g
s/\bmutiliated\b/mutilated/g
s/\bMUTILIATED\b/MUTILATED/g
s/\bMutiliated\b/Mutilated/g
s/\bmyraid\b/myriad/g
s/\bMYRAID\b/MYRIAD/g
s/\bMyraid\b/Myriad/g
s/\bmysef\b/myself/g
s/\bMYSEF\b/MYSELF/g
s/\bMysef\b/Myself/g
s/\bmysogynist\b/misogynist/g
s/\bMYSOGYNIST\b/MISOGYNIST/g
s/\bMysogynist\b/Misogynist/g
s/\bmysogyny\b/misogyny/g
s/\bMYSOGYNY\b/MISOGYNY/g
s/\bMysogyny\b/Misogyny/g
s/\bmysterous\b/mysterious/g
s/\bMYSTEROUS\b/MYSTERIOUS/g
s/\bMysterous\b/Mysterious/g
s/\bnaieve\b/naive/g
s/\bNAIEVE\b/NAIVE/g
s/\bNaieve\b/Naive/g
s/\bnaturaly\b/naturally/g
s/\bNATURALY\b/NATURALLY/g
s/\bNaturaly\b/Naturally/g
s/\bnaturely\b/naturally/g
s/\bNATURELY\b/NATURALLY/g
s/\bNaturely\b/Naturally/g
s/\bnaturual\b/natural/g
s/\bNATURUAL\b/NATURAL/g
s/\bNaturual\b/Natural/g
s/\bnaturually\b/naturally/g
s/\bNATURUALLY\b/NATURALLY/g
s/\bNaturually\b/Naturally/g
s/\bneccessities\b/necessities/g
s/\bNECCESSITIES\b/NECESSITIES/g
s/\bNeccessities\b/Necessities/g
s/\bnecesarily\b/necessarily/g
s/\bNECESARILY\b/NECESSARILY/g
s/\bNecesarily\b/Necessarily/g
s/\bnecesary\b/necessary/g
s/\bNECESARY\b/NECESSARY/g
s/\bNecesary\b/Necessary/g
s/\bnecessiate\b/necessitate/g
s/\bNECESSIATE\b/NECESSITATE/g
s/\bNecessiate\b/Necessitate/g
s/\bneglible\b/negligible/g
s/\bNEGLIBLE\b/NEGLIGIBLE/g
s/\bNeglible\b/Negligible/g
s/\bnegligable\b/negligible/g
s/\bNEGLIGABLE\b/NEGLIGIBLE/g
s/\bNegligable\b/Negligible/g
s/\bnegociate\b/negotiate/g
s/\bNEGOCIATE\b/NEGOTIATE/g
s/\bNegociate\b/Negotiate/g
s/\bnegociation\b/negotiation/g
s/\bNEGOCIATION\b/NEGOTIATION/g
s/\bNegociation\b/Negotiation/g
s/\bnegociations\b/negotiations/g
s/\bNEGOCIATIONS\b/NEGOTIATIONS/g
s/\bNegociations\b/Negotiations/g
s/\bnegotation\b/negotiation/g
s/\bNEGOTATION\b/NEGOTIATION/g
s/\bNegotation\b/Negotiation/g
s/\bneigborhood\b/neighborhood/g
s/\bNEIGBORHOOD\b/NEIGHBORHOOD/g
s/\bNeigborhood\b/Neighborhood/g
s/\bneigbourhood\b/neighbourhood/g
s/\bNEIGBOURHOOD\b/NEIGHBOURHOOD/g
s/\bNeigbourhood\b/Neighbourhood/g
s/\bneolitic\b/neolithic/g
s/\bNEOLITIC\b/NEOLITHIC/g
s/\bNeolitic\b/Neolithic/g
s/\bnessasarily\b/necessarily/g
s/\bNESSASARILY\b/NECESSARILY/g
s/\bNessasarily\b/Necessarily/g
s/\bnessecary\b/necessary/g
s/\bNESSECARY\b/NECESSARY/g
s/\bNessecary\b/Necessary/g
s/\bnestin\b/nesting/g
s/\bNESTIN\b/NESTING/g
s/\bNestin\b/Nesting/g
s/\bneverthless\b/nevertheless/g
s/\bNEVERTHLESS\b/NEVERTHELESS/g
s/\bNeverthless\b/Nevertheless/g
s/\bnewletters\b/newsletters/g
s/\bNEWLETTERS\b/NEWSLETTERS/g
s/\bNewletters\b/Newsletters/g
s/\bnickle\b/nickel/g
s/\bNICKLE\b/NICKEL/g
s/\bNickle\b/Nickel/g
s/\bnightfa;;\b/nightfall/g
s/\bNIGHTFA;;\b/NIGHTFALL/g
s/\bNightfa;;\b/Nightfall/g
s/\bnightime\b/nighttime/g
s/\bNIGHTIME\b/NIGHTTIME/g
s/\bNightime\b/Nighttime/g
s/\bnineth\b/ninth/g
s/\bNINETH\b/NINTH/g
s/\bNineth\b/Ninth/g
s/\bninteenth\b/nineteenth/g
s/\bNINTEENTH\b/NINETEENTH/g
s/\bNinteenth\b/Nineteenth/g
s/\bninties\b/1990s/g
s/\bNINTIES\b/1990S/g
s/\bNinties\b/1990s/g
s/\bninty\b/ninety/g
s/\bNINTY\b/NINETY/g
s/\bNinty\b/Ninety/g
s/\bnkow\b/know/g
s/\bNKOW\b/KNOW/g
s/\bNkow\b/Know/g
s/\bnkwo\b/know/g
s/\bNKWO\b/KNOW/g
s/\bNkwo\b/Know/g
s/\bnmae\b/name/g
s/\bNMAE\b/NAME/g
s/\bNmae\b/Name/g
s/\bnoncombatents\b/noncombatants/g
s/\bNONCOMBATENTS\b/NONCOMBATANTS/g
s/\bNoncombatents\b/Noncombatants/g
s/\bnonsence\b/nonsense/g
s/\bNONSENCE\b/NONSENSE/g
s/\bNonsence\b/Nonsense/g
s/\bnontheless\b/nonetheless/g
s/\bNONTHELESS\b/NONETHELESS/g
s/\bNontheless\b/Nonetheless/g
s/\bnoone\b/no one/g
s/\bNOONE\b/NO ONE/g
s/\bNoone\b/No one/g
s/\bnorhern\b/northern/g
s/\bNORHERN\b/NORTHERN/g
s/\bNorhern\b/Northern/g
s/\bnorthen\b/northern/g
s/\bNORTHEN\b/NORTHERN/g
s/\bNorthen\b/Northern/g
s/\bnorthereastern\b/northeastern/g
s/\bNORTHEREASTERN\b/NORTHEASTERN/g
s/\bNorthereastern\b/Northeastern/g
s/\bnotabley\b/notably/g
s/\bNOTABLEY\b/NOTABLY/g
s/\bNotabley\b/Notably/g
s/\bnoteable\b/notable/g
s/\bNOTEABLE\b/NOTABLE/g
s/\bNoteable\b/Notable/g
s/\bnoteably\b/notably/g
s/\bNOTEABLY\b/NOTABLY/g
s/\bNoteably\b/Notably/g
s/\bnoteriety\b/notoriety/g
s/\bNOTERIETY\b/NOTORIETY/g
s/\bNoteriety\b/Notoriety/g
s/\bnoth\b/north/g
s/\bNOTH\b/NORTH/g
s/\bNoth\b/North/g
s/\bnothern\b/northern/g
s/\bNOTHERN\b/NORTHERN/g
s/\bNothern\b/Northern/g
s/\bnoticable\b/noticeable/g
s/\bNOTICABLE\b/NOTICEABLE/g
s/\bNoticable\b/Noticeable/g
s/\bnoticably\b/noticeably/g
s/\bNOTICABLY\b/NOTICEABLY/g
s/\bNoticably\b/Noticeably/g
s/\bnoticeing\b/noticing/g
s/\bNOTICEING\b/NOTICING/g
s/\bNoticeing\b/Noticing/g
s/\bnoticible\b/noticeable/g
s/\bNOTICIBLE\b/NOTICEABLE/g
s/\bNoticible\b/Noticeable/g
s/\bnotwhithstanding\b/notwithstanding/g
s/\bNOTWHITHSTANDING\b/NOTWITHSTANDING/g
s/\bNotwhithstanding\b/Notwithstanding/g
s/\bnoveau\b/nouveau/g
s/\bNOVEAU\b/NOUVEAU/g
s/\bNoveau\b/Nouveau/g
s/\bnowdays\b/nowadays/g
s/\bNOWDAYS\b/NOWADAYS/g
s/\bNowdays\b/Nowadays/g
s/\bnowe\b/now/g
s/\bNOWE\b/NOW/g
s/\bNowe\b/Now/g
s/\bnucular\b/nuclear/g
s/\bNUCULAR\b/NUCLEAR/g
s/\bNucular\b/Nuclear/g
s/\bnuculear\b/nuclear/g
s/\bNUCULEAR\b/NUCLEAR/g
s/\bNuculear\b/Nuclear/g
s/\bnuisanse\b/nuisance/g
s/\bNUISANSE\b/NUISANCE/g
s/\bNuisanse\b/Nuisance/g
s/\bnumberous\b/numerous/g
s/\bNUMBEROUS\b/NUMEROUS/g
s/\bNumberous\b/Numerous/g
s/\bnusance\b/nuisance/g
s/\bNUSANCE\b/NUISANCE/g
s/\bNusance\b/Nuisance/g
s/\bnutritent\b/nutrient/g
s/\bNUTRITENT\b/NUTRIENT/g
s/\bNutritent\b/Nutrient/g
s/\bnutritents\b/nutrients/g
s/\bNUTRITENTS\b/NUTRIENTS/g
s/\bNutritents\b/Nutrients/g
s/\bnuturing\b/nurturing/g
s/\bNUTURING\b/NURTURING/g
s/\bNuturing\b/Nurturing/g
s/\bobediance\b/obedience/g
s/\bOBEDIANCE\b/OBEDIENCE/g
s/\bObediance\b/Obedience/g
s/\bobediant\b/obedient/g
s/\bOBEDIANT\b/OBEDIENT/g
s/\bObediant\b/Obedient/g
s/\bobession\b/obsession/g
s/\bOBESSION\b/OBSESSION/g
s/\bObession\b/Obsession/g
s/\bobssessed\b/obsessed/g
s/\bOBSSESSED\b/OBSESSED/g
s/\bObssessed\b/Obsessed/g
s/\bobstacal\b/obstacle/g
s/\bOBSTACAL\b/OBSTACLE/g
s/\bObstacal\b/Obstacle/g
s/\bobstancles\b/obstacles/g
s/\bOBSTANCLES\b/OBSTACLES/g
s/\bObstancles\b/Obstacles/g
s/\bobstruced\b/obstructed/g
s/\bOBSTRUCED\b/OBSTRUCTED/g
s/\bObstruced\b/Obstructed/g
s/\bocasional\b/occasional/g
s/\bOCASIONAL\b/OCCASIONAL/g
s/\bOcasional\b/Occasional/g
s/\bocasionally\b/occasionally/g
s/\bOCASIONALLY\b/OCCASIONALLY/g
s/\bOcasionally\b/Occasionally/g
s/\bocasionaly\b/occasionally/g
s/\bOCASIONALY\b/OCCASIONALLY/g
s/\bOcasionaly\b/Occasionally/g
s/\bocasioned\b/occasioned/g
s/\bOCASIONED\b/OCCASIONED/g
s/\bOcasioned\b/Occasioned/g
s/\bocassion\b/occasion/g
s/\bOCASSION\b/OCCASION/g
s/\bOcassion\b/Occasion/g
s/\bocassional\b/occasional/g
s/\bOCASSIONAL\b/OCCASIONAL/g
s/\bOcassional\b/Occasional/g
s/\bocassionally\b/occasionally/g
s/\bOCASSIONALLY\b/OCCASIONALLY/g
s/\bOcassionally\b/Occasionally/g
s/\bocassionaly\b/occasionally/g
s/\bOCASSIONALY\b/OCCASIONALLY/g
s/\bOcassionaly\b/Occasionally/g
s/\bocassioned\b/occasioned/g
s/\bOCASSIONED\b/OCCASIONED/g
s/\bOcassioned\b/Occasioned/g
s/\bocassions\b/occasions/g
s/\bOCASSIONS\b/OCCASIONS/g
s/\bOcassions\b/Occasions/g
s/\boccaison\b/occasion/g
s/\bOCCAISON\b/OCCASION/g
s/\bOccaison\b/Occasion/g
s/\boccassion\b/occasion/g
s/\bOCCASSION\b/OCCASION/g
s/\bOccassion\b/Occasion/g
s/\boccassional\b/occasional/g
s/\bOCCASSIONAL\b/OCCASIONAL/g
s/\bOccassional\b/Occasional/g
s/\boccassionally\b/occasionally/g
s/\bOCCASSIONALLY\b/OCCASIONALLY/g
s/\bOccassionally\b/Occasionally/g
s/\boccassionaly\b/occasionally/g
s/\bOCCASSIONALY\b/OCCASIONALLY/g
s/\bOccassionaly\b/Occasionally/g
s/\boccassioned\b/occasioned/g
s/\bOCCASSIONED\b/OCCASIONED/g
s/\bOccassioned\b/Occasioned/g
s/\boccassions\b/occasions/g
s/\bOCCASSIONS\b/OCCASIONS/g
s/\bOccassions\b/Occasions/g
s/\boccationally\b/occasionally/g
s/\bOCCATIONALLY\b/OCCASIONALLY/g
s/\bOccationally\b/Occasionally/g
s/\boccour\b/occur/g
s/\bOCCOUR\b/OCCUR/g
s/\bOccour\b/Occur/g
s/\boccurr\b/occur/g
s/\bOCCURR\b/OCCUR/g
s/\bOccurr\b/Occur/g
s/\boccurrance\b/occurrence/g
s/\bOCCURRANCE\b/OCCURRENCE/g
s/\bOccurrance\b/Occurrence/g
s/\boccurrances\b/occurrences/g
s/\bOCCURRANCES\b/OCCURRENCES/g
s/\bOccurrances\b/Occurrences/g
s/\boctohedra\b/octahedra/g
s/\bOCTOHEDRA\b/OCTAHEDRA/g
s/\bOctohedra\b/Octahedra/g
s/\boctohedral\b/octahedral/g
s/\bOCTOHEDRAL\b/OCTAHEDRAL/g
s/\bOctohedral\b/Octahedral/g
s/\boctohedron\b/octahedron/g
s/\bOCTOHEDRON\b/OCTAHEDRON/g
s/\bOctohedron\b/Octahedron/g
s/\bocuntries\b/countries/g
s/\bOCUNTRIES\b/COUNTRIES/g
s/\bOcuntries\b/Countries/g
s/\bocuntry\b/country/g
s/\bOCUNTRY\b/COUNTRY/g
s/\bOcuntry\b/Country/g
s/\bocurr\b/occur/g
s/\bOCURR\b/OCCUR/g
s/\bOcurr\b/Occur/g
s/\bocurrance\b/occurrence/g
s/\bOCURRANCE\b/OCCURRENCE/g
s/\bOcurrance\b/Occurrence/g
s/\bocurrence\b/occurrence/g
s/\bOCURRENCE\b/OCCURRENCE/g
s/\bOcurrence\b/Occurrence/g
s/\boffcers\b/officers/g
s/\bOFFCERS\b/OFFICERS/g
s/\bOffcers\b/Officers/g
s/\boffcially\b/officially/g
s/\bOFFCIALLY\b/OFFICIALLY/g
s/\bOffcially\b/Officially/g
s/\boffereings\b/offerings/g
s/\bOFFEREINGS\b/OFFERINGS/g
s/\bOffereings\b/Offerings/g
s/\boffically\b/officially/g
s/\bOFFICALLY\b/OFFICIALLY/g
s/\bOffically\b/Officially/g
s/\bofficals\b/officials/g
s/\bOFFICALS\b/OFFICIALS/g
s/\bOfficals\b/Officials/g
s/\bofficaly\b/officially/g
s/\bOFFICALY\b/OFFICIALLY/g
s/\bOfficaly\b/Officially/g
s/\bofficialy\b/officially/g
s/\bOFFICIALY\b/OFFICIALLY/g
s/\bOfficialy\b/Officially/g
s/\boffred\b/offered/g
s/\bOFFRED\b/OFFERED/g
s/\bOffred\b/Offered/g
s/\boftenly\b/often/g
s/\bOFTENLY\b/OFTEN/g
s/\bOftenly\b/Often/g
s/\bomision\b/omission/g
s/\bOMISION\b/OMISSION/g
s/\bOmision\b/Omission/g
s/\bomited\b/omitted/g
s/\bOMITED\b/OMITTED/g
s/\bOmited\b/Omitted/g
s/\bomiting\b/omitting/g
s/\bOMITING\b/OMITTING/g
s/\bOmiting\b/Omitting/g
s/\bomlette\b/omelette/g
s/\bOMLETTE\b/OMELETTE/g
s/\bOmlette\b/Omelette/g
s/\bommision\b/omission/g
s/\bOMMISION\b/OMISSION/g
s/\bOmmision\b/Omission/g
s/\bommiting\b/omitting/g
s/\bOMMITING\b/OMITTING/g
s/\bOmmiting\b/Omitting/g
s/\bomniverous\b/omnivorous/g
s/\bOMNIVEROUS\b/OMNIVOROUS/g
s/\bOmniverous\b/Omnivorous/g
s/\bomniverously\b/omnivorously/g
s/\bOMNIVEROUSLY\b/OMNIVOROUSLY/g
s/\bOmniverously\b/Omnivorously/g
s/\bomre\b/more/g
s/\bOMRE\b/MORE/g
s/\bOmre\b/More/g
s/\bopeness\b/openness/g
s/\bOPENESS\b/OPENNESS/g
s/\bOpeness\b/Openness/g
s/\boponent\b/opponent/g
s/\bOPONENT\b/OPPONENT/g
s/\bOponent\b/Opponent/g
s/\boportunity\b/opportunity/g
s/\bOPORTUNITY\b/OPPORTUNITY/g
s/\bOportunity\b/Opportunity/g
s/\bopose\b/oppose/g
s/\bOPOSE\b/OPPOSE/g
s/\bOpose\b/Oppose/g
s/\boposite\b/opposite/g
s/\bOPOSITE\b/OPPOSITE/g
s/\bOposite\b/Opposite/g
s/\boposition\b/opposition/g
s/\bOPOSITION\b/OPPOSITION/g
s/\bOposition\b/Opposition/g
s/\boppenly\b/openly/g
s/\bOPPENLY\b/OPENLY/g
s/\bOppenly\b/Openly/g
s/\boppinion\b/opinion/g
s/\bOPPINION\b/OPINION/g
s/\bOppinion\b/Opinion/g
s/\bopponant\b/opponent/g
s/\bOPPONANT\b/OPPONENT/g
s/\bOpponant\b/Opponent/g
s/\boppononent\b/opponent/g
s/\bOPPONONENT\b/OPPONENT/g
s/\bOppononent\b/Opponent/g
s/\boppositition\b/opposition/g
s/\bOPPOSITITION\b/OPPOSITION/g
s/\bOppositition\b/Opposition/g
s/\boppossed\b/opposed/g
s/\bOPPOSSED\b/OPPOSED/g
s/\bOppossed\b/Opposed/g
s/\bopprotunity\b/opportunity/g
s/\bOPPROTUNITY\b/OPPORTUNITY/g
s/\bOpprotunity\b/Opportunity/g
s/\bopression\b/oppression/g
s/\bOPRESSION\b/OPPRESSION/g
s/\bOpression\b/Oppression/g
s/\bopressive\b/oppressive/g
s/\bOPRESSIVE\b/OPPRESSIVE/g
s/\bOpressive\b/Oppressive/g
s/\bopthalmic\b/ophthalmic/g
s/\bOPTHALMIC\b/OPHTHALMIC/g
s/\bOpthalmic\b/Ophthalmic/g
s/\bopthalmologist\b/ophthalmologist/g
s/\bOPTHALMOLOGIST\b/OPHTHALMOLOGIST/g
s/\bOpthalmologist\b/Ophthalmologist/g
s/\bopthalmology\b/ophthalmology/g
s/\bOPTHALMOLOGY\b/OPHTHALMOLOGY/g
s/\bOpthalmology\b/Ophthalmology/g
s/\bopthamologist\b/ophthalmologist/g
s/\bOPTHAMOLOGIST\b/OPHTHALMOLOGIST/g
s/\bOpthamologist\b/Ophthalmologist/g
s/\boptmizations\b/optimizations/g
s/\bOPTMIZATIONS\b/OPTIMIZATIONS/g
s/\bOptmizations\b/Optimizations/g
s/\boptomism\b/optimism/g
s/\bOPTOMISM\b/OPTIMISM/g
s/\bOptomism\b/Optimism/g
s/\borded\b/ordered/g
s/\bORDED\b/ORDERED/g
s/\bOrded\b/Ordered/g
s/\borganim\b/organism/g
s/\bORGANIM\b/ORGANISM/g
s/\bOrganim\b/Organism/g
s/\borganistion\b/organisation/g
s/\bORGANISTION\b/ORGANISATION/g
s/\bOrganistion\b/Organisation/g
s/\borganiztion\b/organization/g
s/\bORGANIZTION\b/ORGANIZATION/g
s/\bOrganiztion\b/Organization/g
s/\borginize\b/organise/g
s/\bORGINIZE\b/ORGANISE/g
s/\bOrginize\b/Organise/g
s/\boridinarily\b/ordinarily/g
s/\bORIDINARILY\b/ORDINARILY/g
s/\bOridinarily\b/Ordinarily/g
s/\boriganaly\b/originally/g
s/\bORIGANALY\b/ORIGINALLY/g
s/\bOriganaly\b/Originally/g
s/\boriginaly\b/originally/g
s/\bORIGINALY\b/ORIGINALLY/g
s/\bOriginaly\b/Originally/g
s/\boriginially\b/originally/g
s/\bORIGINIALLY\b/ORIGINALLY/g
s/\bOriginially\b/Originally/g
s/\boriginnally\b/originally/g
s/\bORIGINNALLY\b/ORIGINALLY/g
s/\bOriginnally\b/Originally/g
s/\borignially\b/originally/g
s/\bORIGNIALLY\b/ORIGINALLY/g
s/\bOrignially\b/Originally/g
s/\botehr\b/other/g
s/\bOTEHR\b/OTHER/g
s/\bOtehr\b/Other/g
s/\boublisher\b/publisher/g
s/\bOUBLISHER\b/PUBLISHER/g
s/\bOublisher\b/Publisher/g
s/\bouevre\b/oeuvre/g
s/\bOUEVRE\b/OEUVRE/g
s/\bOuevre\b/Oeuvre/g
s/\boustanding\b/outstanding/g
s/\bOUSTANDING\b/OUTSTANDING/g
s/\bOustanding\b/Outstanding/g
s/\bovershaddowed\b/overshadowed/g
s/\bOVERSHADDOWED\b/OVERSHADOWED/g
s/\bOvershaddowed\b/Overshadowed/g
s/\boverthere\b/over there/g
s/\bOVERTHERE\b/OVER THERE/g
s/\bOverthere\b/Over there/g
s/\boverwelming\b/overwhelming/g
s/\bOVERWELMING\b/OVERWHELMING/g
s/\bOverwelming\b/Overwhelming/g
s/\boverwheliming\b/overwhelming/g
s/\bOVERWHELIMING\b/OVERWHELMING/g
s/\bOverwheliming\b/Overwhelming/g
s/\bowrk\b/work/g
s/\bOWRK\b/WORK/g
s/\bOwrk\b/Work/g
s/\bowudl\b/would/g
s/\bOWUDL\b/WOULD/g
s/\bOwudl\b/Would/g
s/\boxigen\b/oxygen/g
s/\bOXIGEN\b/OXYGEN/g
s/\bOxigen\b/Oxygen/g
s/\boximoron\b/oxymoron/g
s/\bOXIMORON\b/OXYMORON/g
s/\bOximoron\b/Oxymoron/g
s/\bp0enis\b/penis/g
s/\bP0ENIS\b/PENIS/g
s/\bP0enis\b/Penis/g
s/\bpaches/patches/g
s/\bPACHES/PATCHES/g
s/\bPaches/Patches/g
s/\bpaide\b/paid/g
s/\bPAIDE\b/PAID/g
s/\bPaide\b/Paid/g
s/\bpaitience\b/patience/g
s/\bPAITIENCE\b/PATIENCE/g
s/\bPaitience\b/Patience/g
s/\bpaleolitic\b/paleolithic/g
s/\bPALEOLITIC\b/PALEOLITHIC/g
s/\bPaleolitic\b/Paleolithic/g
s/\bpaliamentarian\b/parliamentarian/g
s/\bPALIAMENTARIAN\b/PARLIAMENTARIAN/g
s/\bPaliamentarian\b/Parliamentarian/g
s/\bpamflet\b/pamphlet/g
s/\bPAMFLET\b/PAMPHLET/g
s/\bPamflet\b/Pamphlet/g
s/\bpamplet\b/pamphlet/g
s/\bPAMPLET\b/PAMPHLET/g
s/\bPamplet\b/Pamphlet/g
s/\bpantomine\b/pantomime/g
s/\bPANTOMINE\b/PANTOMIME/g
s/\bPantomine\b/Pantomime/g
s/\bparalel\b/parallel/g
s/\bPARALEL\b/PARALLEL/g
s/\bParalel\b/Parallel/g
s/\bparalell\b/parallel/g
s/\bPARALELL\b/PARALLEL/g
s/\bParalell\b/Parallel/g
s/\bparalelly\b/parallelly/g
s/\bPARALELLY\b/PARALLELLY/g
s/\bParalelly\b/Parallelly/g
s/\bparalely\b/parallelly/g
s/\bPARALELY\b/PARALLELLY/g
s/\bParalely\b/Parallelly/g
s/\bparallely\b/parallelly/g
s/\bPARALLELY\b/PARALLELLY/g
s/\bParallely\b/Parallelly/g
s/\bparanthesis\b/parenthesis/g
s/\bPARANTHESIS\b/PARENTHESIS/g
s/\bParanthesis\b/Parenthesis/g
s/\bparaphenalia\b/paraphernalia/g
s/\bPARAPHENALIA\b/PARAPHERNALIA/g
s/\bParaphenalia\b/Paraphernalia/g
s/\bparellels\b/parallels/g
s/\bPARELLELS\b/PARALLELS/g
s/\bParellels\b/Parallels/g
s/\bparisitic\b/parasitic/g
s/\bPARISITIC\b/PARASITIC/g
s/\bParisitic\b/Parasitic/g
s/\bparituclar\b/particular/g
s/\bPARITUCLAR\b/PARTICULAR/g
s/\bParituclar\b/Particular/g
s/\bparliment\b/parliament/g
s/\bPARLIMENT\b/PARLIAMENT/g
s/\bParliment\b/Parliament/g
s/\bparrakeets\b/parakeets/g
s/\bPARRAKEETS\b/PARAKEETS/g
s/\bParrakeets\b/Parakeets/g
s/\bparralel\b/parallel/g
s/\bPARRALEL\b/PARALLEL/g
s/\bParralel\b/Parallel/g
s/\bparrallel\b/parallel/g
s/\bPARRALLEL\b/PARALLEL/g
s/\bParrallel\b/Parallel/g
s/\bparrallell\b/parallel/g
s/\bPARRALLELL\b/PARALLEL/g
s/\bParrallell\b/Parallel/g
s/\bparrallelly\b/parallelly/g
s/\bPARRALLELLY\b/PARALLELLY/g
s/\bParrallelly\b/Parallelly/g
s/\bparrallely\b/parallelly/g
s/\bPARRALLELY\b/PARALLELLY/g
s/\bParrallely\b/Parallelly/g
s/\bpartialy\b/partially/g
s/\bPARTIALY\b/PARTIALLY/g
s/\bPartialy\b/Partially/g
s/\bparticually\b/particularly/g
s/\bPARTICUALLY\b/PARTICULARLY/g
s/\bParticually\b/Particularly/g
s/\bparticualr\b/particular/g
s/\bPARTICUALR\b/PARTICULAR/g
s/\bParticualr\b/Particular/g
s/\bparticuarly\b/particularly/g
s/\bPARTICUARLY\b/PARTICULARLY/g
s/\bParticuarly\b/Particularly/g
s/\bparticularily\b/particularly/g
s/\bPARTICULARILY\b/PARTICULARLY/g
s/\bParticularily\b/Particularly/g
s/\bpary\b/party/g
s/\bPARY\b/PARTY/g
s/\bPary\b/Party/g
s/\bpasengers\b/passengers/g
s/\bPASENGERS\b/PASSENGERS/g
s/\bPasengers\b/Passengers/g
s/\bpasserbys\b/passersby/g
s/\bPASSERBYS\b/PASSERSBY/g
s/\bPasserbys\b/Passersby/g
s/\bpasttime\b/pastime/g
s/\bPASTTIME\b/PASTIME/g
s/\bPasttime\b/Pastime/g
s/\bpastural\b/pastoral/g
s/\bPASTURAL\b/PASTORAL/g
s/\bPastural\b/Pastoral/g
s/\bpaticular\b/particular/g
s/\bPATICULAR\b/PARTICULAR/g
s/\bPaticular\b/Particular/g
s/\bpattented\b/patented/g
s/\bPATTENTED\b/PATENTED/g
s/\bPattented\b/Patented/g
s/\bpavillion\b/pavilion/g
s/\bPAVILLION\b/PAVILION/g
s/\bPavillion\b/Pavilion/g
s/\bpayed\b/paid/g
s/\bPAYED\b/PAID/g
s/\bPayed\b/Paid/g
s/\bpblisher\b/publisher/g
s/\bPBLISHER\b/PUBLISHER/g
s/\bPblisher\b/Publisher/g
s/\bpbulisher\b/publisher/g
s/\bPBULISHER\b/PUBLISHER/g
s/\bPbulisher\b/Publisher/g
s/\bpeacefuland\b/peaceful and/g
s/\bPEACEFULAND\b/PEACEFUL AND/g
s/\bPeacefuland\b/Peaceful and/g
s/\bpeageant\b/pageant/g
s/\bPEAGEANT\b/PAGEANT/g
s/\bPeageant\b/Pageant/g
s/\bpeculure\b/peculiar/g
s/\bPECULURE\b/PECULIAR/g
s/\bPeculure\b/Peculiar/g
s/\bpedestrain\b/pedestrian/g
s/\bPEDESTRAIN\b/PEDESTRIAN/g
s/\bPedestrain\b/Pedestrian/g
s/\bpeice\b/piece/g
s/\bPEICE\b/PIECE/g
s/\bPeice\b/Piece/g
s/\bpenatly\b/penalty/g
s/\bPENATLY\b/PENALTY/g
s/\bPenatly\b/Penalty/g
s/\bpenerator\b/penetrator/g
s/\bPENERATOR\b/PENETRATOR/g
s/\bPenerator\b/Penetrator/g
s/\bpenisula\b/peninsula/g
s/\bPENISULA\b/PENINSULA/g
s/\bPenisula\b/Peninsula/g
s/\bpenisular\b/peninsular/g
s/\bPENISULAR\b/PENINSULAR/g
s/\bPenisular\b/Peninsular/g
s/\bpenninsula\b/peninsula/g
s/\bPENNINSULA\b/PENINSULA/g
s/\bPenninsula\b/Peninsula/g
s/\bpenninsular\b/peninsular/g
s/\bPENNINSULAR\b/PENINSULAR/g
s/\bPenninsular\b/Peninsular/g
s/\bpennisula\b/peninsula/g
s/\bPENNISULA\b/PENINSULA/g
s/\bPennisula\b/Peninsula/g
s/\bpensinula\b/peninsula/g
s/\bPENSINULA\b/PENINSULA/g
s/\bPensinula\b/Peninsula/g
s/\bpensle\b/pencil/g
s/\bPENSLE\b/PENCIL/g
s/\bPensle\b/Pencil/g
s/\bpeom\b/poem/g
s/\bPEOM\b/POEM/g
s/\bPeom\b/Poem/g
s/\bpeoms\b/poems/g
s/\bPEOMS\b/POEMS/g
s/\bPeoms\b/Poems/g
s/\bpeopel\b/people/g
s/\bPEOPEL\b/PEOPLE/g
s/\bPeopel\b/People/g
s/\bpeotry\b/poetry/g
s/\bPEOTRY\b/POETRY/g
s/\bPeotry\b/Poetry/g
s/\bperade\b/parade/g
s/\bPERADE\b/PARADE/g
s/\bPerade\b/Parade/g
s/\bpercepted\b/perceived/g
s/\bPERCEPTED\b/PERCEIVED/g
s/\bPercepted\b/Perceived/g
s/\bpercieve\b/perceive/g
s/\bPERCIEVE\b/PERCEIVE/g
s/\bPercieve\b/Perceive/g
s/\bpercieved\b/perceived/g
s/\bPERCIEVED\b/PERCEIVED/g
s/\bPercieved\b/Perceived/g
s/\bperenially\b/perennially/g
s/\bPERENIALLY\b/PERENNIALLY/g
s/\bPerenially\b/Perennially/g
s/\bperfomers\b/performers/g
s/\bPERFOMERS\b/PERFORMERS/g
s/\bPerfomers\b/Performers/g
s/\bperformence\b/performance/g
s/\bPERFORMENCE\b/PERFORMANCE/g
s/\bPerformence\b/Performance/g
s/\bperhasp\b/perhaps/g
s/\bPERHASP\b/PERHAPS/g
s/\bPerhasp\b/Perhaps/g
s/\bperheaps\b/perhaps/g
s/\bPERHEAPS\b/PERHAPS/g
s/\bPerheaps\b/Perhaps/g
s/\bperhpas\b/perhaps/g
s/\bPERHPAS\b/PERHAPS/g
s/\bPerhpas\b/Perhaps/g
s/\bperipathetic\b/peripatetic/g
s/\bPERIPATHETIC\b/PERIPATETIC/g
s/\bPeripathetic\b/Peripatetic/g
s/\bperjery\b/perjury/g
s/\bPERJERY\b/PERJURY/g
s/\bPerjery\b/Perjury/g
s/\bperjorative\b/pejorative/g
s/\bPERJORATIVE\b/PEJORATIVE/g
s/\bPerjorative\b/Pejorative/g
s/\bpermanant\b/permanent/g
s/\bPERMANANT\b/PERMANENT/g
s/\bPermanant\b/Permanent/g
s/\bpermenant\b/permanent/g
s/\bPERMENANT\b/PERMANENT/g
s/\bPermenant\b/Permanent/g
s/\bpermenantly\b/permanently/g
s/\bPERMENANTLY\b/PERMANENTLY/g
s/\bPermenantly\b/Permanently/g
s/\bpermissable\b/permissible/g
s/\bPERMISSABLE\b/PERMISSIBLE/g
s/\bPermissable\b/Permissible/g
s/\bperogative\b/prerogative/g
s/\bPEROGATIVE\b/PREROGATIVE/g
s/\bPerogative\b/Prerogative/g
s/\bperonal\b/personal/g
s/\bPERONAL\b/PERSONAL/g
s/\bPeronal\b/Personal/g
s/\bperosnality\b/personality/g
s/\bPEROSNALITY\b/PERSONALITY/g
s/\bPerosnality\b/Personality/g
s/\bperpertrated\b/perpetrated/g
s/\bPERPERTRATED\b/PERPETRATED/g
s/\bPerpertrated\b/Perpetrated/g
s/\bperphas\b/perhaps/g
s/\bPERPHAS\b/PERHAPS/g
s/\bPerphas\b/Perhaps/g
s/\bperpindicular\b/perpendicular/g
s/\bPERPINDICULAR\b/PERPENDICULAR/g
s/\bPerpindicular\b/Perpendicular/g
s/\bperseverence\b/perseverance/g
s/\bPERSEVERENCE\b/PERSEVERANCE/g
s/\bPerseverence\b/Perseverance/g
s/\bpersonell\b/personnel/g
s/\bPERSONELL\b/PERSONNEL/g
s/\bPersonell\b/Personnel/g
s/\bpersonnell\b/personnel/g
s/\bPERSONNELL\b/PERSONNEL/g
s/\bPersonnell\b/Personnel/g
s/\bpersuded\b/persuaded/g
s/\bPERSUDED\b/PERSUADED/g
s/\bPersuded\b/Persuaded/g
s/\bpersue\b/pursue/g
s/\bPERSUE\b/PURSUE/g
s/\bPersue\b/Pursue/g
s/\bpersued\b/pursued/g
s/\bPERSUED\b/PURSUED/g
s/\bPersued\b/Pursued/g
s/\bpersuing\b/pursuing/g
s/\bPERSUING\b/PURSUING/g
s/\bPersuing\b/Pursuing/g
s/\bpersuit\b/pursuit/g
s/\bPERSUIT\b/PURSUIT/g
s/\bPersuit\b/Pursuit/g
s/\bpersuits\b/pursuits/g
s/\bPERSUITS\b/PURSUITS/g
s/\bPersuits\b/Pursuits/g
s/\bpertubation\b/perturbation/g
s/\bPERTUBATION\b/PERTURBATION/g
s/\bPertubation\b/Perturbation/g
s/\bpertubations\b/perturbations/g
s/\bPERTUBATIONS\b/PERTURBATIONS/g
s/\bPertubations\b/Perturbations/g
s/\bpessiary\b/pessary/g
s/\bPESSIARY\b/PESSARY/g
s/\bPessiary\b/Pessary/g
s/\bpetetion\b/petition/g
s/\bPETETION\b/PETITION/g
s/\bPetetion\b/Petition/g
s/\bphenomenom\b/phenomenon/g
s/\bPHENOMENOM\b/PHENOMENON/g
s/\bPhenomenom\b/Phenomenon/g
s/\bphenomenonal\b/phenomenal/g
s/\bPHENOMENONAL\b/PHENOMENAL/g
s/\bPhenomenonal\b/Phenomenal/g
s/\bphenomenonly\b/phenomenally/g
s/\bPHENOMENONLY\b/PHENOMENALLY/g
s/\bPhenomenonly\b/Phenomenally/g
s/\bphenomonenon\b/phenomenon/g
s/\bPHENOMONENON\b/PHENOMENON/g
s/\bPhenomonenon\b/Phenomenon/g
s/\bphenomonon\b/phenomenon/g
s/\bPHENOMONON\b/PHENOMENON/g
s/\bPhenomonon\b/Phenomenon/g
s/\bphenonmena\b/phenomena/g
s/\bPHENONMENA\b/PHENOMENA/g
s/\bPhenonmena\b/Phenomena/g
s/\bphilisopher\b/philosopher/g
s/\bPHILISOPHER\b/PHILOSOPHER/g
s/\bPhilisopher\b/Philosopher/g
s/\bphilisophical\b/philosophical/g
s/\bPHILISOPHICAL\b/PHILOSOPHICAL/g
s/\bPhilisophical\b/Philosophical/g
s/\bphilisophy\b/philosophy/g
s/\bPHILISOPHY\b/PHILOSOPHY/g
s/\bPhilisophy\b/Philosophy/g
s/\bphillosophically\b/philosophically/g
s/\bPHILLOSOPHICALLY\b/PHILOSOPHICALLY/g
s/\bPhillosophically\b/Philosophically/g
s/\bphilospher\b/philosopher/g
s/\bPHILOSPHER\b/PHILOSOPHER/g
s/\bPhilospher\b/Philosopher/g
s/\bphilosphies\b/philosophies/g
s/\bPHILOSPHIES\b/PHILOSOPHIES/g
s/\bPhilosphies\b/Philosophies/g
s/\bphilosphy\b/philosophy/g
s/\bPHILOSPHY\b/PHILOSOPHY/g
s/\bPhilosphy\b/Philosophy/g
s/\bphongraph\b/phonograph/g
s/\bPHONGRAPH\b/PHONOGRAPH/g
s/\bPhongraph\b/Phonograph/g
s/\bphylosophical\b/philosophical/g
s/\bPHYLOSOPHICAL\b/PHILOSOPHICAL/g
s/\bPhylosophical\b/Philosophical/g
s/\bphysicaly\b/physically/g
s/\bPHYSICALY\b/PHYSICALLY/g
s/\bPhysicaly\b/Physically/g
s/\bpiblisher\b/publisher/g
s/\bPIBLISHER\b/PUBLISHER/g
s/\bPiblisher\b/Publisher/g
s/\bpich\b/pitch/g
s/\bPICH\b/PITCH/g
s/\bPich\b/Pitch/g
s/\bpilgrimmage\b/pilgrimage/g
s/\bPILGRIMMAGE\b/PILGRIMAGE/g
s/\bPilgrimmage\b/Pilgrimage/g
s/\bpilgrimmages\b/pilgrimages/g
s/\bPILGRIMMAGES\b/PILGRIMAGES/g
s/\bPilgrimmages\b/Pilgrimages/g
s/\bpinapple\b/pineapple/g
s/\bPINAPPLE\b/PINEAPPLE/g
s/\bPinapple\b/Pineapple/g
s/\bpinnaple\b/pineapple/g
s/\bPINNAPLE\b/PINEAPPLE/g
s/\bPinnaple\b/Pineapple/g
s/\bpinoneered\b/pioneered/g
s/\bPINONEERED\b/PIONEERED/g
s/\bPinoneered\b/Pioneered/g
s/\bplagarism\b/plagiarism/g
s/\bPLAGARISM\b/PLAGIARISM/g
s/\bPlagarism\b/Plagiarism/g
s/\bplanation\b/plantation/g
s/\bPLANATION\b/PLANTATION/g
s/\bPlanation\b/Plantation/g
s/\bplaned\b/planned/g
s/\bPLANED\b/PLANNED/g
s/\bPlaned\b/Planned/g
s/\bplantiff\b/plaintiff/g
s/\bPLANTIFF\b/PLAINTIFF/g
s/\bPlantiff\b/Plaintiff/g
s/\bplateu\b/plateau/g
s/\bPLATEU\b/PLATEAU/g
s/\bPlateu\b/Plateau/g
s/\bplausable\b/plausible/g
s/\bPLAUSABLE\b/PLAUSIBLE/g
s/\bPlausable\b/Plausible/g
s/\bplayright\b/playwright/g
s/\bPLAYRIGHT\b/PLAYWRIGHT/g
s/\bPlayright\b/Playwright/g
s/\bplaywrite\b/playwright/g
s/\bPLAYWRITE\b/PLAYWRIGHT/g
s/\bPlaywrite\b/Playwright/g
s/\bplaywrites\b/playwrights/g
s/\bPLAYWRITES\b/PLAYWRIGHTS/g
s/\bPlaywrites\b/Playwrights/g
s/\bpleasent\b/pleasant/g
s/\bPLEASENT\b/PLEASANT/g
s/\bPleasent\b/Pleasant/g
s/\bplebicite\b/plebiscite/g
s/\bPLEBICITE\b/PLEBISCITE/g
s/\bPlebicite\b/Plebiscite/g
s/\bplesant\b/pleasant/g
s/\bPLESANT\b/PLEASANT/g
s/\bPlesant\b/Pleasant/g
s/\bpoenis\b/penis/g
s/\bPOENIS\b/PENIS/g
s/\bPoenis\b/Penis/g
s/\bpoeoples\b/peoples/g
s/\bPOEOPLES\b/PEOPLES/g
s/\bPoeoples\b/Peoples/g
s/\bpoety\b/poetry/g
s/\bPOETY\b/POETRY/g
s/\bPoety\b/Poetry/g
s/\bpoisin\b/poison/g
s/\bPOISIN\b/POISON/g
s/\bPoisin\b/Poison/g
s/\bpolical\b/political/g
s/\bPOLICAL\b/POLITICAL/g
s/\bPolical\b/Political/g
s/\bpolinator\b/pollinator/g
s/\bPOLINATOR\b/POLLINATOR/g
s/\bPolinator\b/Pollinator/g
s/\bpolinators\b/pollinators/g
s/\bPOLINATORS\b/POLLINATORS/g
s/\bPolinators\b/Pollinators/g
s/\bpolitican\b/politician/g
s/\bPOLITICAN\b/POLITICIAN/g
s/\bPolitican\b/Politician/g
s/\bpoliticans\b/politicians/g
s/\bPOLITICANS\b/POLITICIANS/g
s/\bPoliticans\b/Politicians/g
s/\bpoltical\b/political/g
s/\bPOLTICAL\b/POLITICAL/g
s/\bPoltical\b/Political/g
s/\bpolute\b/pollute/g
s/\bPOLUTE\b/POLLUTE/g
s/\bPolute\b/Pollute/g
s/\bpoluted\b/polluted/g
s/\bPOLUTED\b/POLLUTED/g
s/\bPoluted\b/Polluted/g
s/\bpolutes\b/pollutes/g
s/\bPOLUTES\b/POLLUTES/g
s/\bPolutes\b/Pollutes/g
s/\bpoluting\b/polluting/g
s/\bPOLUTING\b/POLLUTING/g
s/\bPoluting\b/Polluting/g
s/\bpolution\b/pollution/g
s/\bPOLUTION\b/POLLUTION/g
s/\bPolution\b/Pollution/g
s/\bpolyphonyic\b/polyphonic/g
s/\bPOLYPHONYIC\b/POLYPHONIC/g
s/\bPolyphonyic\b/Polyphonic/g
s/\bpolysaccaride\b/polysaccharide/g
s/\bPOLYSACCARIDE\b/POLYSACCHARIDE/g
s/\bPolysaccaride\b/Polysaccharide/g
s/\bpolysaccharid\b/polysaccharide/g
s/\bPOLYSACCHARID\b/POLYSACCHARIDE/g
s/\bPolysaccharid\b/Polysaccharide/g
s/\bpomegranite\b/pomegranate/g
s/\bPOMEGRANITE\b/POMEGRANATE/g
s/\bPomegranite\b/Pomegranate/g
s/\bpomotion\b/promotion/g
s/\bPOMOTION\b/PROMOTION/g
s/\bPomotion\b/Promotion/g
s/\bpoportional\b/proportional/g
s/\bPOPORTIONAL\b/PROPORTIONAL/g
s/\bPoportional\b/Proportional/g
s/\bpopoulation\b/population/g
s/\bPOPOULATION\b/POPULATION/g
s/\bPopoulation\b/Population/g
s/\bpopularaty\b/popularity/g
s/\bPOPULARATY\b/POPULARITY/g
s/\bPopularaty\b/Popularity/g
s/\bpopulare\b/popular/g
s/\bPOPULARE\b/POPULAR/g
s/\bPopulare\b/Popular/g
s/\bpopuler\b/popular/g
s/\bPOPULER\b/POPULAR/g
s/\bPopuler\b/Popular/g
s/\bporshan\b/portion/g
s/\bPORSHAN\b/PORTION/g
s/\bPorshan\b/Portion/g
s/\bporshon\b/portion/g
s/\bPORSHON\b/PORTION/g
s/\bPorshon\b/Portion/g
s/\bportait\b/portrait/g
s/\bPORTAIT\b/PORTRAIT/g
s/\bPortait\b/Portrait/g
s/\bportayed\b/portrayed/g
s/\bPORTAYED\b/PORTRAYED/g
s/\bPortayed\b/Portrayed/g
s/\bportraing\b/portraying/g
s/\bPORTRAING\b/PORTRAYING/g
s/\bPortraing\b/Portraying/g
s/\bportuguease\b/portuguese/g
s/\bPORTUGUEASE\b/PORTUGUESE/g
s/\bPortuguease\b/Portuguese/g
s/\bportugues\b/portuguese/g
s/\bPORTUGUES\b/PORTUGUESE/g
s/\bPortugues\b/Portuguese/g
s/\bposess\b/possess/g
s/\bPOSESS\b/POSSESS/g
s/\bPosess\b/Possess/g
s/\bposessed\b/possessed/g
s/\bPOSESSED\b/POSSESSED/g
s/\bPosessed\b/Possessed/g
s/\bposesses\b/possesses/g
s/\bPOSESSES\b/POSSESSES/g
s/\bPosesses\b/Possesses/g
s/\bposessing\b/possessing/g
s/\bPOSESSING\b/POSSESSING/g
s/\bPosessing\b/Possessing/g
s/\bposession\b/possession/g
s/\bPOSESSION\b/POSSESSION/g
s/\bPosession\b/Possession/g
s/\bposessions\b/possessions/g
s/\bPOSESSIONS\b/POSSESSIONS/g
s/\bPosessions\b/Possessions/g
s/\bposion\b/poison/g
s/\bPOSION\b/POISON/g
s/\bPosion\b/Poison/g
s/\bpossable\b/possible/g
s/\bPOSSABLE\b/POSSIBLE/g
s/\bPossable\b/Possible/g
s/\bpossably\b/possibly/g
s/\bPOSSABLY\b/POSSIBLY/g
s/\bPossably\b/Possibly/g
s/\bposseses\b/possesses/g
s/\bPOSSESES\b/POSSESSES/g
s/\bPosseses\b/Possesses/g
s/\bpossesing\b/possessing/g
s/\bPOSSESING\b/POSSESSING/g
s/\bPossesing\b/Possessing/g
s/\bpossesion\b/possession/g
s/\bPOSSESION\b/POSSESSION/g
s/\bPossesion\b/Possession/g
s/\bpossessess\b/possesses/g
s/\bPOSSESSESS\b/POSSESSES/g
s/\bPossessess\b/Possesses/g
s/\bpossibile\b/possible/g
s/\bPOSSIBILE\b/POSSIBLE/g
s/\bPossibile\b/Possible/g
s/\bpossibilty\b/possibility/g
s/\bPOSSIBILTY\b/POSSIBILITY/g
s/\bPossibilty\b/Possibility/g
s/\bpossiblility\b/possibility/g
s/\bPOSSIBLILITY\b/POSSIBILITY/g
s/\bPossiblility\b/Possibility/g
s/\bpossiblilty\b/possibility/g
s/\bPOSSIBLILTY\b/POSSIBILITY/g
s/\bPossiblilty\b/Possibility/g
s/\bpossiblities\b/possibilities/g
s/\bPOSSIBLITIES\b/POSSIBILITIES/g
s/\bPossiblities\b/Possibilities/g
s/\bpossition\b/position/g
s/\bPOSSITION\b/POSITION/g
s/\bPossition\b/Position/g
s/\bposthomous\b/posthumous/g
s/\bPOSTHOMOUS\b/POSTHUMOUS/g
s/\bPosthomous\b/Posthumous/g
s/\bpostion\b/position/g
s/\bPOSTION\b/POSITION/g
s/\bPostion\b/Position/g
s/\bpotatos\b/potatoes/g
s/\bPOTATOS\b/POTATOES/g
s/\bPotatos\b/Potatoes/g
s/\bpotrait\b/portrait/g
s/\bPOTRAIT\b/PORTRAIT/g
s/\bPotrait\b/Portrait/g
s/\bpotrayed\b/portrayed/g
s/\bPOTRAYED\b/PORTRAYED/g
s/\bPotrayed\b/Portrayed/g
s/\bpoulations\b/populations/g
s/\bPOULATIONS\b/POPULATIONS/g
s/\bPoulations\b/Populations/g
s/\bpoverful\b/powerful/g
s/\bPOVERFUL\b/POWERFUL/g
s/\bPoverful\b/Powerful/g
s/\bpoweful\b/powerful/g
s/\bPOWEFUL\b/POWERFUL/g
s/\bPoweful\b/Powerful/g
s/\bpowerfull\b/powerful/g
s/\bPOWERFULL\b/POWERFUL/g
s/\bPowerfull\b/Powerful/g
s/\bppublisher\b/publisher/g
s/\bPPUBLISHER\b/PUBLISHER/g
s/\bPpublisher\b/Publisher/g
s/\bpractial\b/practical/g
s/\bPRACTIAL\b/PRACTICAL/g
s/\bPractial\b/Practical/g
s/\bpractially\b/practically/g
s/\bPRACTIALLY\b/PRACTICALLY/g
s/\bPractially\b/Practically/g
s/\bpracticaly\b/practically/g
s/\bPRACTICALY\b/PRACTICALLY/g
s/\bPracticaly\b/Practically/g
s/\bpracticioner\b/practitioner/g
s/\bPRACTICIONER\b/PRACTITIONER/g
s/\bPracticioner\b/Practitioner/g
s/\bpracticioners\b/practitioners/g
s/\bPRACTICIONERS\b/PRACTITIONERS/g
s/\bPracticioners\b/Practitioners/g
s/\bpracticly\b/practically/g
s/\bPRACTICLY\b/PRACTICALLY/g
s/\bPracticly\b/Practically/g
s/\bpractioner\b/practitioner/g
s/\bPRACTIONER\b/PRACTITIONER/g
s/\bPractioner\b/Practitioner/g
s/\bpractioners\b/practitioners/g
s/\bPRACTIONERS\b/PRACTITIONERS/g
s/\bPractioners\b/Practitioners/g
s/\bprairy\b/prairie/g
s/\bPRAIRY\b/PRAIRIE/g
s/\bPrairy\b/Prairie/g
s/\bprarie\b/prairie/g
s/\bPRARIE\b/PRAIRIE/g
s/\bPrarie\b/Prairie/g
s/\bpraries\b/prairies/g
s/\bPRARIES\b/PRAIRIES/g
s/\bPraries\b/Prairies/g
s/\bpratice\b/practice/g
s/\bPRATICE\b/PRACTICE/g
s/\bPratice\b/Practice/g
s/\bpreample\b/preamble/g
s/\bPREAMPLE\b/PREAMBLE/g
s/\bPreample\b/Preamble/g
s/\bprecedessor\b/predecessor/g
s/\bPRECEDESSOR\b/PREDECESSOR/g
s/\bPrecedessor\b/Predecessor/g
s/\bprecentage\b/percentage/g
s/\bPRECENTAGE\b/PERCENTAGE/g
s/\bPrecentage\b/Percentage/g
s/\bprecice\b/precise/g
s/\bPRECICE\b/PRECISE/g
s/\bPrecice\b/Precise/g
s/\bprecisly\b/precisely/g
s/\bPRECISLY\b/PRECISELY/g
s/\bPrecisly\b/Precisely/g
s/\bprecurser\b/precursor/g
s/\bPRECURSER\b/PRECURSOR/g
s/\bPrecurser\b/Precursor/g
s/\bpredecesors\b/predecessors/g
s/\bPREDECESORS\b/PREDECESSORS/g
s/\bPredecesors\b/Predecessors/g
s/\bpredicatble\b/predictable/g
s/\bPREDICATBLE\b/PREDICTABLE/g
s/\bPredicatble\b/Predictable/g
s/\bpredicitons\b/predictions/g
s/\bPREDICITONS\b/PREDICTIONS/g
s/\bPredicitons\b/Predictions/g
s/\bpredomiantly\b/predominately/g
s/\bPREDOMIANTLY\b/PREDOMINATELY/g
s/\bPredomiantly\b/Predominately/g
s/\bprefering\b/preferring/g
s/\bPREFERING\b/PREFERRING/g
s/\bPrefering\b/Preferring/g
s/\bpreferrably\b/preferably/g
s/\bPREFERRABLY\b/PREFERABLY/g
s/\bPreferrably\b/Preferably/g
s/\bpregancies\b/pregnancies/g
s/\bPREGANCIES\b/PREGNANCIES/g
s/\bPregancies\b/Pregnancies/g
s/\bpreiod\b/period/g
s/\bPREIOD\b/PERIOD/g
s/\bPreiod\b/Period/g
s/\bpreliferation\b/proliferation/g
s/\bPRELIFERATION\b/PROLIFERATION/g
s/\bPreliferation\b/Proliferation/g
s/\bpremeire\b/premiere/g
s/\bPREMEIRE\b/PREMIERE/g
s/\bPremeire\b/Premiere/g
s/\bpremeired\b/premiered/g
s/\bPREMEIRED\b/PREMIERED/g
s/\bPremeired\b/Premiered/g
s/\bpremillenial\b/premillennial/g
s/\bPREMILLENIAL\b/PREMILLENNIAL/g
s/\bPremillenial\b/Premillennial/g
s/\bpreminence\b/preeminence/g
s/\bPREMINENCE\b/PREEMINENCE/g
s/\bPreminence\b/Preeminence/g
s/\bpremission\b/permission/g
s/\bPREMISSION\b/PERMISSION/g
s/\bPremission\b/Permission/g
s/\bpreocupation\b/preoccupation/g
s/\bPREOCUPATION\b/PREOCCUPATION/g
s/\bPreocupation\b/Preoccupation/g
s/\bprepair\b/prepare/g
s/\bPREPAIR\b/PREPARE/g
s/\bPrepair\b/Prepare/g
s/\bprepartion\b/preparation/g
s/\bPREPARTION\b/PREPARATION/g
s/\bPrepartion\b/Preparation/g
s/\bprepatory\b/preparatory/g
s/\bPREPATORY\b/PREPARATORY/g
s/\bPrepatory\b/Preparatory/g
s/\bpreperation\b/preparation/g
s/\bPREPERATION\b/PREPARATION/g
s/\bPreperation\b/Preparation/g
s/\bpreperations\b/preparations/g
s/\bPREPERATIONS\b/PREPARATIONS/g
s/\bPreperations\b/Preparations/g
s/\bpreriod\b/period/g
s/\bPRERIOD\b/PERIOD/g
s/\bPreriod\b/Period/g
s/\bpresedential\b/presidential/g
s/\bPRESEDENTIAL\b/PRESIDENTIAL/g
s/\bPresedential\b/Presidential/g
s/\bpresidenital\b/presidential/g
s/\bPRESIDENITAL\b/PRESIDENTIAL/g
s/\bPresidenital\b/Presidential/g
s/\bpresidental\b/presidential/g
s/\bPRESIDENTAL\b/PRESIDENTIAL/g
s/\bPresidental\b/Presidential/g
s/\bpresitgious\b/prestigious/g
s/\bPRESITGIOUS\b/PRESTIGIOUS/g
s/\bPresitgious\b/Prestigious/g
s/\bprespective\b/perspective/g
s/\bPRESPECTIVE\b/PERSPECTIVE/g
s/\bPrespective\b/Perspective/g
s/\bprestigeous\b/prestigious/g
s/\bPRESTIGEOUS\b/PRESTIGIOUS/g
s/\bPrestigeous\b/Prestigious/g
s/\bprestigous\b/prestigious/g
s/\bPRESTIGOUS\b/PRESTIGIOUS/g
s/\bPrestigous\b/Prestigious/g
s/\bpresumabely\b/presumably/g
s/\bPRESUMABELY\b/PRESUMABLY/g
s/\bPresumabely\b/Presumably/g
s/\bpresumibly\b/presumably/g
s/\bPRESUMIBLY\b/PRESUMABLY/g
s/\bPresumibly\b/Presumably/g
s/\bpretection\b/protection/g
s/\bPRETECTION\b/PROTECTION/g
s/\bPretection\b/Protection/g
s/\bprevelant\b/prevalent/g
s/\bPREVELANT\b/PREVALENT/g
s/\bPrevelant\b/Prevalent/g
s/\bpreverse\b/perverse/g
s/\bPREVERSE\b/PERVERSE/g
s/\bPreverse\b/Perverse/g
s/\bprevivous\b/previous/g
s/\bPREVIVOUS\b/PREVIOUS/g
s/\bPrevivous\b/Previous/g
s/\bpricipal\b/principal/g
s/\bPRICIPAL\b/PRINCIPAL/g
s/\bPricipal\b/Principal/g
s/\bpriciple\b/principle/g
s/\bPRICIPLE\b/PRINCIPLE/g
s/\bPriciple\b/Principle/g
s/\bpriestood\b/priesthood/g
s/\bPRIESTOOD\b/PRIESTHOOD/g
s/\bPriestood\b/Priesthood/g
s/\bprimarly\b/primarily/g
s/\bPRIMARLY\b/PRIMARILY/g
s/\bPrimarly\b/Primarily/g
s/\bprimative\b/primitive/g
s/\bPRIMATIVE\b/PRIMITIVE/g
s/\bPrimative\b/Primitive/g
s/\bprimatively\b/primitively/g
s/\bPRIMATIVELY\b/PRIMITIVELY/g
s/\bPrimatively\b/Primitively/g
s/\bprimatives\b/primitives/g
s/\bPRIMATIVES\b/PRIMITIVES/g
s/\bPrimatives\b/Primitives/g
s/\bprimordal\b/primordial/g
s/\bPRIMORDAL\b/PRIMORDIAL/g
s/\bPrimordal\b/Primordial/g
s/\bprincipaly\b/principality/g
s/\bPRINCIPALY\b/PRINCIPALITY/g
s/\bPrincipaly\b/Principality/g
s/\bprincipial\b/principal/g
s/\bPRINCIPIAL\b/PRINCIPAL/g
s/\bPrincipial\b/Principal/g
s/\bprinciplaity\b/principality/g
s/\bPRINCIPLAITY\b/PRINCIPALITY/g
s/\bPrinciplaity\b/Principality/g
s/\bprinciply\b/principally/g
s/\bPRINCIPLY\b/PRINCIPALLY/g
s/\bPrinciply\b/Principally/g
s/\bprinicipal\b/principal/g
s/\bPRINICIPAL\b/PRINCIPAL/g
s/\bPrinicipal\b/Principal/g
s/\bprivalege\b/privilege/g
s/\bPRIVALEGE\b/PRIVILEGE/g
s/\bPrivalege\b/Privilege/g
s/\bprivaleges\b/privileges/g
s/\bPRIVALEGES\b/PRIVILEGES/g
s/\bPrivaleges\b/Privileges/g
s/\bpriveledges\b/privileges/g
s/\bPRIVELEDGES\b/PRIVILEGES/g
s/\bPriveledges\b/Privileges/g
s/\bprivelege\b/privilege/g
s/\bPRIVELEGE\b/PRIVILEGE/g
s/\bPrivelege\b/Privilege/g
s/\bpriveleged\b/privileged/g
s/\bPRIVELEGED\b/PRIVILEGED/g
s/\bPriveleged\b/Privileged/g
s/\bpriveleges\b/privileges/g
s/\bPRIVELEGES\b/PRIVILEGES/g
s/\bPriveleges\b/Privileges/g
s/\bprivelige\b/privilege/g
s/\bPRIVELIGE\b/PRIVILEGE/g
s/\bPrivelige\b/Privilege/g
s/\bpriveliged\b/privileged/g
s/\bPRIVELIGED\b/PRIVILEGED/g
s/\bPriveliged\b/Privileged/g
s/\bpriveliges\b/privileges/g
s/\bPRIVELIGES\b/PRIVILEGES/g
s/\bPriveliges\b/Privileges/g
s/\bprivelleges\b/privileges/g
s/\bPRIVELLEGES\b/PRIVILEGES/g
s/\bPrivelleges\b/Privileges/g
s/\bprivilage\b/privilege/g
s/\bPRIVILAGE\b/PRIVILEGE/g
s/\bPrivilage\b/Privilege/g
s/\bpriviledge\b/privilege/g
s/\bPRIVILEDGE\b/PRIVILEGE/g
s/\bPriviledge\b/Privilege/g
s/\bpriviledges\b/privileges/g
s/\bPRIVILEDGES\b/PRIVILEGES/g
s/\bPriviledges\b/Privileges/g
s/\bprivledge\b/privilege/g
s/\bPRIVLEDGE\b/PRIVILEGE/g
s/\bPrivledge\b/Privilege/g
s/\bprivte\b/private/g
s/\bPRIVTE\b/PRIVATE/g
s/\bPrivte\b/Private/g
s/\bprobabilaty\b/probability/g
s/\bPROBABILATY\b/PROBABILITY/g
s/\bProbabilaty\b/Probability/g
s/\bprobablistic\b/probabilistic/g
s/\bPROBABLISTIC\b/PROBABILISTIC/g
s/\bProbablistic\b/Probabilistic/g
s/\bprobablly\b/probably/g
s/\bPROBABLLY\b/PROBABLY/g
s/\bProbablly\b/Probably/g
s/\bprobalibity\b/probability/g
s/\bPROBALIBITY\b/PROBABILITY/g
s/\bProbalibity\b/Probability/g
s/\bprobaly\b/probably/g
s/\bPROBALY\b/PROBABLY/g
s/\bProbaly\b/Probably/g
s/\bprobelm\b/problem/g
s/\bPROBELM\b/PROBLEM/g
s/\bProbelm\b/Problem/g
s/\bproccess\b/process/g
s/\bPROCCESS\b/PROCESS/g
s/\bProccess\b/Process/g
s/\bproccessing\b/processing/g
s/\bPROCCESSING\b/PROCESSING/g
s/\bProccessing\b/Processing/g
s/\bprocedger\b/procedure/g
s/\bPROCEDGER\b/PROCEDURE/g
s/\bProcedger\b/Procedure/g
s/\bprocedings\b/proceedings/g
s/\bPROCEDINGS\b/PROCEEDINGS/g
s/\bProcedings\b/Proceedings/g
s/\bproceedure\b/procedure/g
s/\bPROCEEDURE\b/PROCEDURE/g
s/\bProceedure\b/Procedure/g
s/\bproces\b/process/g
s/\bPROCES\b/PROCESS/g
s/\bProces\b/Process/g
s/\bproclaimation\b/proclamation/g
s/\bPROCLAIMATION\b/PROCLAMATION/g
s/\bProclaimation\b/Proclamation/g
s/\bproclamed\b/proclaimed/g
s/\bPROCLAMED\b/PROCLAIMED/g
s/\bProclamed\b/Proclaimed/g
s/\bproclaming\b/proclaiming/g
s/\bPROCLAMING\b/PROCLAIMING/g
s/\bProclaming\b/Proclaiming/g
s/\bproclomation\b/proclamation/g
s/\bPROCLOMATION\b/PROCLAMATION/g
s/\bProclomation\b/Proclamation/g
s/\bprofesor\b/professor/g
s/\bPROFESOR\b/PROFESSOR/g
s/\bProfesor\b/Professor/g
s/\bprofesser\b/professor/g
s/\bPROFESSER\b/PROFESSOR/g
s/\bProfesser\b/Professor/g
s/\bproffesed\b/professed/g
s/\bPROFFESED\b/PROFESSED/g
s/\bProffesed\b/Professed/g
s/\bproffesion\b/profession/g
s/\bPROFFESION\b/PROFESSION/g
s/\bProffesion\b/Profession/g
s/\bproffesional\b/professional/g
s/\bPROFFESIONAL\b/PROFESSIONAL/g
s/\bProffesional\b/Professional/g
s/\bproffesor\b/professor/g
s/\bPROFFESOR\b/PROFESSOR/g
s/\bProffesor\b/Professor/g
s/\bprofilic\b/prolific/g
s/\bPROFILIC\b/PROLIFIC/g
s/\bProfilic\b/Prolific/g
s/\bprogessed\b/progressed/g
s/\bPROGESSED\b/PROGRESSED/g
s/\bProgessed\b/Progressed/g
s/\bprogidy\b/prodigy/g
s/\bPROGIDY\b/PRODIGY/g
s/\bProgidy\b/Prodigy/g
s/\bprogramable\b/programmable/g
s/\bPROGRAMABLE\b/PROGRAMMABLE/g
s/\bProgramable\b/Programmable/g
s/\bprohabition\b/prohibition/g
s/\bPROHABITION\b/PROHIBITION/g
s/\bProhabition\b/Prohibition/g
s/\bprologomena\b/prolegomena/g
s/\bPROLOGOMENA\b/PROLEGOMENA/g
s/\bPrologomena\b/Prolegomena/g
s/\bprominance\b/prominence/g
s/\bPROMINANCE\b/PROMINENCE/g
s/\bProminance\b/Prominence/g
s/\bprominant\b/prominent/g
s/\bPROMINANT\b/PROMINENT/g
s/\bProminant\b/Prominent/g
s/\bprominantly\b/prominently/g
s/\bPROMINANTLY\b/PROMINENTLY/g
s/\bProminantly\b/Prominently/g
s/\bpromiscous\b/promiscuous/g
s/\bPROMISCOUS\b/PROMISCUOUS/g
s/\bPromiscous\b/Promiscuous/g
s/\bpromotted\b/promoted/g
s/\bPROMOTTED\b/PROMOTED/g
s/\bPromotted\b/Promoted/g
s/\bpronomial\b/pronominal/g
s/\bPRONOMIAL\b/PRONOMINAL/g
s/\bPronomial\b/Pronominal/g
s/\bpronouced\b/pronounced/g
s/\bPRONOUCED\b/PRONOUNCED/g
s/\bPronouced\b/Pronounced/g
s/\bpronounched\b/pronounced/g
s/\bPRONOUNCHED\b/PRONOUNCED/g
s/\bPronounched\b/Pronounced/g
s/\bpronounciation\b/pronunciation/g
s/\bPRONOUNCIATION\b/PRONUNCIATION/g
s/\bPronounciation\b/Pronunciation/g
s/\bproove\b/prove/g
s/\bPROOVE\b/PROVE/g
s/\bProove\b/Prove/g
s/\bprooved\b/proved/g
s/\bPROOVED\b/PROVED/g
s/\bProoved\b/Proved/g
s/\bprophacy\b/prophecy/g
s/\bPROPHACY\b/PROPHECY/g
s/\bProphacy\b/Prophecy/g
s/\bpropietary\b/proprietary/g
s/\bPROPIETARY\b/PROPRIETARY/g
s/\bPropietary\b/Proprietary/g
s/\bpropmted\b/prompted/g
s/\bPROPMTED\b/PROMPTED/g
s/\bPropmted\b/Prompted/g
s/\bpropoganda\b/propaganda/g
s/\bPROPOGANDA\b/PROPAGANDA/g
s/\bPropoganda\b/Propaganda/g
s/\bpropogates\b/propagates/g
s/\bPROPOGATES\b/PROPAGATES/g
s/\bPropogates\b/Propagates/g
s/\bpropogation\b/propagation/g
s/\bPROPOGATION\b/PROPAGATION/g
s/\bPropogation\b/Propagation/g
s/\bpropostion\b/proposition/g
s/\bPROPOSTION\b/PROPOSITION/g
s/\bPropostion\b/Proposition/g
s/\bpropotions\b/proportions/g
s/\bPROPOTIONS\b/PROPORTIONS/g
s/\bPropotions\b/Proportions/g
s/\bpropperly\b/properly/g
s/\bPROPPERLY\b/PROPERLY/g
s/\bPropperly\b/Properly/g
s/\bproprietory\b/proprietary/g
s/\bPROPRIETORY\b/PROPRIETARY/g
s/\bProprietory\b/Proprietary/g
s/\bproseletyzing\b/proselytizing/g
s/\bPROSELETYZING\b/PROSELYTIZING/g
s/\bProseletyzing\b/Proselytizing/g
s/\bprotaganist\b/protagonist/g
s/\bPROTAGANIST\b/PROTAGONIST/g
s/\bProtaganist\b/Protagonist/g
s/\bprotaganists\b/protagonists/g
s/\bPROTAGANISTS\b/PROTAGONISTS/g
s/\bProtaganists\b/Protagonists/g
s/\bprotocal\b/protocol/g
s/\bPROTOCAL\b/PROTOCOL/g
s/\bProtocal\b/Protocol/g
s/\bprotoganist\b/protagonist/g
s/\bPROTOGANIST\b/PROTAGONIST/g
s/\bProtoganist\b/Protagonist/g
s/\bprotrayed\b/portrayed/g
s/\bPROTRAYED\b/PORTRAYED/g
s/\bProtrayed\b/Portrayed/g
s/\bprotruberance\b/protuberance/g
s/\bPROTRUBERANCE\b/PROTUBERANCE/g
s/\bProtruberance\b/Protuberance/g
s/\bprotruberances\b/protuberances/g
s/\bPROTRUBERANCES\b/PROTUBERANCES/g
s/\bProtruberances\b/Protuberances/g
s/\bprouncements\b/pronouncements/g
s/\bPROUNCEMENTS\b/PRONOUNCEMENTS/g
s/\bProuncements\b/Pronouncements/g
s/\bprovacative\b/provocative/g
s/\bPROVACATIVE\b/PROVOCATIVE/g
s/\bProvacative\b/Provocative/g
s/\bprovded\b/provided/g
s/\bPROVDED\b/PROVIDED/g
s/\bProvded\b/Provided/g
s/\bprovicial\b/provincial/g
s/\bPROVICIAL\b/PROVINCIAL/g
s/\bProvicial\b/Provincial/g
s/\bprovinicial\b/provincial/g
s/\bPROVINICIAL\b/PROVINCIAL/g
s/\bProvinicial\b/Provincial/g
s/\bprovisiosn\b/provision/g
s/\bPROVISIOSN\b/PROVISION/g
s/\bProvisiosn\b/Provision/g
s/\bprovisonal\b/provisional/g
s/\bPROVISONAL\b/PROVISIONAL/g
s/\bProvisonal\b/Provisional/g
s/\bproximty\b/proximity/g
s/\bPROXIMTY\b/PROXIMITY/g
s/\bProximty\b/Proximity/g
s/\bpseudononymous\b/pseudonymous/g
s/\bPSEUDONONYMOUS\b/PSEUDONYMOUS/g
s/\bPseudononymous\b/Pseudonymous/g
s/\bpseudonyn\b/pseudonym/g
s/\bPSEUDONYN\b/PSEUDONYM/g
s/\bPseudonyn\b/Pseudonym/g
s/\bpsycology\b/psychology/g
s/\bPSYCOLOGY\b/PSYCHOLOGY/g
s/\bPsycology\b/Psychology/g
s/\bpsyhic\b/psychic/g
s/\bPSYHIC\b/PSYCHIC/g
s/\bPsyhic\b/Psychic/g
s/\bpubilsher\b/publisher/g
s/\bPUBILSHER\b/PUBLISHER/g
s/\bPubilsher\b/Publisher/g
s/\bpubisher\b/publisher/g
s/\bPUBISHER\b/PUBLISHER/g
s/\bPubisher\b/Publisher/g
s/\bpubliaher\b/publisher/g
s/\bPUBLIAHER\b/PUBLISHER/g
s/\bPubliaher\b/Publisher/g
s/\bpublically\b/publicly/g
s/\bPUBLICALLY\b/PUBLICLY/g
s/\bPublically\b/Publicly/g
s/\bpublicaly\b/publicly/g
s/\bPUBLICALY\b/PUBLICLY/g
s/\bPublicaly\b/Publicly/g
s/\bpublicher\b/publisher/g
s/\bPUBLICHER\b/PUBLISHER/g
s/\bPublicher\b/Publisher/g
s/\bpublihser\b/publisher/g
s/\bPUBLIHSER\b/PUBLISHER/g
s/\bPublihser\b/Publisher/g
s/\bpublisehr\b/publisher/g
s/\bPUBLISEHR\b/PUBLISHER/g
s/\bPublisehr\b/Publisher/g
s/\bpubliser\b/publisher/g
s/\bPUBLISER\b/PUBLISHER/g
s/\bPubliser\b/Publisher/g
s/\bpublisger\b/publisher/g
s/\bPUBLISGER\b/PUBLISHER/g
s/\bPublisger\b/Publisher/g
s/\bpublisheed\b/published/g
s/\bPUBLISHEED\b/PUBLISHED/g
s/\bPublisheed\b/Published/g
s/\bpublisherr\b/publisher/g
s/\bPUBLISHERR\b/PUBLISHER/g
s/\bPublisherr\b/Publisher/g
s/\bpublishher\b/publisher/g
s/\bPUBLISHHER\b/PUBLISHER/g
s/\bPublishher\b/Publisher/g
s/\bpublishor\b/publisher/g
s/\bPUBLISHOR\b/PUBLISHER/g
s/\bPublishor\b/Publisher/g
s/\bpublishre\b/publisher/g
s/\bPUBLISHRE\b/PUBLISHER/g
s/\bPublishre\b/Publisher/g
s/\bpublissher\b/publisher/g
s/\bPUBLISSHER\b/PUBLISHER/g
s/\bPublissher\b/Publisher/g
s/\bpubllisher\b/publisher/g
s/\bPUBLLISHER\b/PUBLISHER/g
s/\bPubllisher\b/Publisher/g
s/\bpublsiher\b/publisher/g
s/\bPUBLSIHER\b/PUBLISHER/g
s/\bPublsiher\b/Publisher/g
s/\bpublusher\b/publisher/g
s/\bPUBLUSHER\b/PUBLISHER/g
s/\bPublusher\b/Publisher/g
s/\bpuchasing\b/purchasing/g
s/\bPUCHASING\b/PURCHASING/g
s/\bPuchasing\b/Purchasing/g
s/\bpulisher\b/publisher/g
s/\bPULISHER\b/PUBLISHER/g
s/\bPulisher\b/Publisher/g
s/\bpumkin\b/pumpkin/g
s/\bPUMKIN\b/PUMPKIN/g
s/\bPumkin\b/Pumpkin/g
s/\bpuplisher\b/publisher/g
s/\bPUPLISHER\b/PUBLISHER/g
s/\bPuplisher\b/Publisher/g
s/\bpuritannical\b/puritanical/g
s/\bPURITANNICAL\b/PURITANICAL/g
s/\bPuritannical\b/Puritanical/g
s/\bpurposedly\b/purposely/g
s/\bPURPOSEDLY\b/PURPOSELY/g
s/\bPurposedly\b/Purposely/g
s/\bpurpotedly\b/purportedly/g
s/\bPURPOTEDLY\b/PURPORTEDLY/g
s/\bPurpotedly\b/Purportedly/g
s/\bpursuade\b/persuade/g
s/\bPURSUADE\b/PERSUADE/g
s/\bPursuade\b/Persuade/g
s/\bpursuaded\b/persuaded/g
s/\bPURSUADED\b/PERSUADED/g
s/\bPursuaded\b/Persuaded/g
s/\bpursuades\b/persuades/g
s/\bPURSUADES\b/PERSUADES/g
s/\bPursuades\b/Persuades/g
s/\bpususading\b/persuading/g
s/\bPUSUSADING\b/PERSUADING/g
s/\bPususading\b/Persuading/g
s/\bputing\b/putting/g
s/\bPUTING\b/PUTTING/g
s/\bPuting\b/Putting/g
s/\bpwoer\b/power/g
s/\bPWOER\b/POWER/g
s/\bPwoer\b/Power/g
s/\bpyscic\b/psychic/g
s/\bPYSCIC\b/PSYCHIC/g
s/\bPyscic\b/Psychic/g
s/\bquantaty\b/quantity/g
s/\bQUANTATY\b/QUANTITY/g
s/\bQuantaty\b/Quantity/g
s/\bquantitiy\b/quantity/g
s/\bQUANTITIY\b/QUANTITY/g
s/\bQuantitiy\b/Quantity/g
s/\bquarantaine\b/quarantine/g
s/\bQUARANTAINE\b/QUARANTINE/g
s/\bQuarantaine\b/Quarantine/g
s/\bquestonable\b/questionable/g
s/\bQUESTONABLE\b/QUESTIONABLE/g
s/\bQuestonable\b/Questionable/g
s/\bquicklyu\b/quickly/g
s/\bQUICKLYU\b/QUICKLY/g
s/\bQuicklyu\b/Quickly/g
s/\bquinessential\b/quintessential/g
s/\bQUINESSENTIAL\b/QUINTESSENTIAL/g
s/\bQuinessential\b/Quintessential/g
s/\bquitted\b/quit/g
s/\bQUITTED\b/QUIT/g
s/\bQuitted\b/Quit/g
s/\bquizes\b/quizzes/g
s/\bQUIZES\b/QUIZZES/g
s/\bQuizes\b/Quizzes/g
s/\brabinnical\b/rabbinical/g
s/\bRABINNICAL\b/RABBINICAL/g
s/\bRabinnical\b/Rabbinical/g
s/\bracaus\b/raucous/g
s/\bRACAUS\b/RAUCOUS/g
s/\bRacaus\b/Raucous/g
s/\bradiactive\b/radioactive/g
s/\bRADIACTIVE\b/RADIOACTIVE/g
s/\bRadiactive\b/Radioactive/g
s/\bradify\b/ratify/g
s/\bRADIFY\b/RATIFY/g
s/\bRadify\b/Ratify/g
s/\braelly\b/really/g
s/\bRAELLY\b/REALLY/g
s/\bRaelly\b/Really/g
s/\brarified\b/rarefied/g
s/\bRARIFIED\b/RAREFIED/g
s/\bRarified\b/Rarefied/g
s/\breaccurring\b/recurring/g
s/\bREACCURRING\b/RECURRING/g
s/\bReaccurring\b/Recurring/g
s/\breacing\b/reaching/g
s/\bREACING\b/REACHING/g
s/\bReacing\b/Reaching/g
s/\breacll\b/recall/g
s/\bREACLL\b/RECALL/g
s/\bReacll\b/Recall/g
s/\breadmition\b/readmission/g
s/\bREADMITION\b/READMISSION/g
s/\bReadmition\b/Readmission/g
s/\brealitvely\b/relatively/g
s/\bREALITVELY\b/RELATIVELY/g
s/\bRealitvely\b/Relatively/g
s/\brealsitic\b/realistic/g
s/\bREALSITIC\b/REALISTIC/g
s/\bRealsitic\b/Realistic/g
s/\brealtions\b/relations/g
s/\bREALTIONS\b/RELATIONS/g
s/\bRealtions\b/Relations/g
s/\breasearch\b/research/g
s/\bREASEARCH\b/RESEARCH/g
s/\bReasearch\b/Research/g
s/\brebiulding\b/rebuilding/g
s/\bREBIULDING\b/REBUILDING/g
s/\bRebiulding\b/Rebuilding/g
s/\brebllions\b/rebellions/g
s/\bREBLLIONS\b/REBELLIONS/g
s/\bRebllions\b/Rebellions/g
s/\brebounce\b/rebound/g
s/\bREBOUNCE\b/REBOUND/g
s/\bRebounce\b/Rebound/g
s/\breccomend\b/recommend/g
s/\bRECCOMEND\b/RECOMMEND/g
s/\bReccomend\b/Recommend/g
s/\breccomendations\b/recommendations/g
s/\bRECCOMENDATIONS\b/RECOMMENDATIONS/g
s/\bReccomendations\b/Recommendations/g
s/\breccomended\b/recommended/g
s/\bRECCOMENDED\b/RECOMMENDED/g
s/\bReccomended\b/Recommended/g
s/\breccomending\b/recommending/g
s/\bRECCOMENDING\b/RECOMMENDING/g
s/\bReccomending\b/Recommending/g
s/\breccommend\b/recommend/g
s/\bRECCOMMEND\b/RECOMMEND/g
s/\bReccommend\b/Recommend/g
s/\breccommended\b/recommended/g
s/\bRECCOMMENDED\b/RECOMMENDED/g
s/\bReccommended\b/Recommended/g
s/\breccommending\b/recommending/g
s/\bRECCOMMENDING\b/RECOMMENDING/g
s/\bReccommending\b/Recommending/g
s/\breccuring\b/recurring/g
s/\bRECCURING\b/RECURRING/g
s/\bReccuring\b/Recurring/g
s/\breceeded\b/receded/g
s/\bRECEEDED\b/RECEDED/g
s/\bReceeded\b/Receded/g
s/\breceeding\b/receding/g
s/\bRECEEDING\b/RECEDING/g
s/\bReceeding\b/Receding/g
s/\breceivedfrom\b/received from/g
s/\bRECEIVEDFROM\b/RECEIVED FROM/g
s/\bReceivedfrom\b/Received from/g
s/\brecepient\b/recipient/g
s/\bRECEPIENT\b/RECIPIENT/g
s/\bRecepient\b/Recipient/g
s/\brecepients\b/recipients/g
s/\bRECEPIENTS\b/RECIPIENTS/g
s/\bRecepients\b/Recipients/g
s/\breceving\b/receiving/g
s/\bRECEVING\b/RECEIVING/g
s/\bReceving\b/Receiving/g
s/\brechargable\b/rechargeable/g
s/\bRECHARGABLE\b/RECHARGEABLE/g
s/\bRechargable\b/Rechargeable/g
s/\breched\b/reached/g
s/\bRECHED\b/REACHED/g
s/\bReched\b/Reached/g
s/\brecide\b/reside/g
s/\bRECIDE\b/RESIDE/g
s/\bRecide\b/Reside/g
s/\brecided\b/resided/g
s/\bRECIDED\b/RESIDED/g
s/\bRecided\b/Resided/g
s/\brecident\b/resident/g
s/\bRECIDENT\b/RESIDENT/g
s/\bRecident\b/Resident/g
s/\brecidents\b/residents/g
s/\bRECIDENTS\b/RESIDENTS/g
s/\bRecidents\b/Residents/g
s/\breciding\b/residing/g
s/\bRECIDING\b/RESIDING/g
s/\bReciding\b/Residing/g
s/\breciepents\b/recipients/g
s/\bRECIEPENTS\b/RECIPIENTS/g
s/\bReciepents\b/Recipients/g
s/\breciept\b/receipt/g
s/\bRECIEPT\b/RECEIPT/g
s/\bReciept\b/Receipt/g
s/\brecipiant\b/recipient/g
s/\bRECIPIANT\b/RECIPIENT/g
s/\bRecipiant\b/Recipient/g
s/\brecipiants\b/recipients/g
s/\bRECIPIANTS\b/RECIPIENTS/g
s/\bRecipiants\b/Recipients/g
s/\brecivership\b/receivership/g
s/\bRECIVERSHIP\b/RECEIVERSHIP/g
s/\bRecivership\b/Receivership/g
s/\brecogise\b/recognise/g
s/\bRECOGISE\b/RECOGNISE/g
s/\bRecogise\b/Recognise/g
s/\brecogize\b/recognize/g
s/\bRECOGIZE\b/RECOGNIZE/g
s/\bRecogize\b/Recognize/g
s/\brecomend\b/recommend/g
s/\bRECOMEND\b/RECOMMEND/g
s/\bRecomend\b/Recommend/g
s/\brecomended\b/recommended/g
s/\bRECOMENDED\b/RECOMMENDED/g
s/\bRecomended\b/Recommended/g
s/\brecomending\b/recommending/g
s/\bRECOMENDING\b/RECOMMENDING/g
s/\bRecomending\b/Recommending/g
s/\brecomends\b/recommends/g
s/\bRECOMENDS\b/RECOMMENDS/g
s/\bRecomends\b/Recommends/g
s/\brecommedations\b/recommendations/g
s/\bRECOMMEDATIONS\b/RECOMMENDATIONS/g
s/\bRecommedations\b/Recommendations/g
s/\brecompence\b/recompense/g
s/\bRECOMPENCE\b/RECOMPENSE/g
s/\bRecompence\b/Recompense/g
s/\breconaissance\b/reconnaissance/g
s/\bRECONAISSANCE\b/RECONNAISSANCE/g
s/\bReconaissance\b/Reconnaissance/g
s/\breconcilation\b/reconciliation/g
s/\bRECONCILATION\b/RECONCILIATION/g
s/\bReconcilation\b/Reconciliation/g
s/\breconized\b/recognized/g
s/\bRECONIZED\b/RECOGNIZED/g
s/\bReconized\b/Recognized/g
s/\breconnaisance\b/reconnaissance/g
s/\bRECONNAISANCE\b/RECONNAISSANCE/g
s/\bReconnaisance\b/Reconnaissance/g
s/\breconnaissence\b/reconnaissance/g
s/\bRECONNAISSENCE\b/RECONNAISSANCE/g
s/\bReconnaissence\b/Reconnaissance/g
s/\brecontructed\b/reconstructed/g
s/\bRECONTRUCTED\b/RECONSTRUCTED/g
s/\bRecontructed\b/Reconstructed/g
s/\brecordproducer\b/record producer/g
s/\bRECORDPRODUCER\b/RECORD PRODUCER/g
s/\bRecordproducer\b/Record producer/g
s/\brecquired\b/required/g
s/\bRECQUIRED\b/REQUIRED/g
s/\bRecquired\b/Required/g
s/\brecrational\b/recreational/g
s/\bRECRATIONAL\b/RECREATIONAL/g
s/\bRecrational\b/Recreational/g
s/\brecrod\b/record/g
s/\bRECROD\b/RECORD/g
s/\bRecrod\b/Record/g
s/\brecuiting\b/recruiting/g
s/\bRECUITING\b/RECRUITING/g
s/\bRecuiting\b/Recruiting/g
s/\brecuring\b/recurring/g
s/\bRECURING\b/RECURRING/g
s/\bRecuring\b/Recurring/g
s/\brecurrance\b/recurrence/g
s/\bRECURRANCE\b/RECURRENCE/g
s/\bRecurrance\b/Recurrence/g
s/\brediculous\b/ridiculous/g
s/\bREDICULOUS\b/RIDICULOUS/g
s/\bRediculous\b/Ridiculous/g
s/\breedeming\b/redeeming/g
s/\bREEDEMING\b/REDEEMING/g
s/\bReedeming\b/Redeeming/g
s/\breenforced\b/reinforced/g
s/\bREENFORCED\b/REINFORCED/g
s/\bReenforced\b/Reinforced/g
s/\brefect\b/reflect/g
s/\bREFECT\b/REFLECT/g
s/\bRefect\b/Reflect/g
s/\brefedendum\b/referendum/g
s/\bREFEDENDUM\b/REFERENDUM/g
s/\bRefedendum\b/Referendum/g
s/\breferal\b/referral/g
s/\bREFERAL\b/REFERRAL/g
s/\bReferal\b/Referral/g
s/\breferemce\b/reference/g
s/\bREFEREMCE\b/REFERENCE/g
s/\bReferemce\b/Reference/g
s/\breferemces\b/references/g
s/\bREFEREMCES\b/REFERENCES/g
s/\bReferemces\b/References/g
s/\breferencs\b/references/g
s/\bREFERENCS\b/REFERENCES/g
s/\bReferencs\b/References/g
s/\breferenece\b/reference/g
s/\bREFERENECE\b/REFERENCE/g
s/\bReferenece\b/Reference/g
s/\brefereneced\b/referenced/g
s/\bREFERENECED\b/REFERENCED/g
s/\bRefereneced\b/Referenced/g
s/\brefereneces\b/references/g
s/\bREFERENECES\b/REFERENCES/g
s/\bRefereneces\b/References/g
s/\breferiang\b/referring/g
s/\bREFERIANG\b/REFERRING/g
s/\bReferiang\b/Referring/g
s/\brefering\b/referring/g
s/\bREFERING\b/REFERRING/g
s/\bRefering\b/Referring/g
s/\brefernce\b/reference/g
s/\bREFERNCE\b/REFERENCE/g
s/\bRefernce\b/Reference/g
s/\brefernce\b/references/g
s/\bREFERNCE\b/REFERENCES/g
s/\bRefernce\b/References/g
s/\brefernces\b/references/g
s/\bREFERNCES\b/REFERENCES/g
s/\bRefernces\b/References/g
s/\breferrences\b/references/g
s/\bREFERRENCES\b/REFERENCES/g
s/\bReferrences\b/References/g
s/\breferrs\b/refers/g
s/\bREFERRS\b/REFERS/g
s/\bReferrs\b/Refers/g
s/\breffered\b/referred/g
s/\bREFFERED\b/REFERRED/g
s/\bReffered\b/Referred/g
s/\brefference\b/reference/g
s/\bREFFERENCE\b/REFERENCE/g
s/\bRefference\b/Reference/g
s/\breffering\b/referring/g
s/\bREFFERING\b/REFERRING/g
s/\bReffering\b/Referring/g
s/\brefrers\b/refers/g
s/\bREFRERS\b/REFERS/g
s/\bRefrers\b/Refers/g
s/\brefridgeration\b/refrigeration/g
s/\bREFRIDGERATION\b/REFRIGERATION/g
s/\bRefridgeration\b/Refrigeration/g
s/\brefridgerator\b/refrigerator/g
s/\bREFRIDGERATOR\b/REFRIGERATOR/g
s/\bRefridgerator\b/Refrigerator/g
s/\brefromist\b/reformist/g
s/\bREFROMIST\b/REFORMIST/g
s/\bRefromist\b/Reformist/g
s/\brefusla\b/refusal/g
s/\bREFUSLA\b/REFUSAL/g
s/\bRefusla\b/Refusal/g
s/\bregardes\b/regards/g
s/\bREGARDES\b/REGARDS/g
s/\bRegardes\b/Regards/g
s/\bregluar\b/regular/g
s/\bREGLUAR\b/REGULAR/g
s/\bRegluar\b/Regular/g
s/\breguarly\b/regularly/g
s/\bREGUARLY\b/REGULARLY/g
s/\bReguarly\b/Regularly/g
s/\bregulaion\b/regulation/g
s/\bREGULAION\b/REGULATION/g
s/\bRegulaion\b/Regulation/g
s/\bregulaotrs\b/regulators/g
s/\bREGULAOTRS\b/REGULATORS/g
s/\bRegulaotrs\b/Regulators/g
s/\bregularily\b/regularly/g
s/\bREGULARILY\b/REGULARLY/g
s/\bRegularily\b/Regularly/g
s/\brehersal\b/rehearsal/g
s/\bREHERSAL\b/REHEARSAL/g
s/\bRehersal\b/Rehearsal/g
s/\breicarnation\b/reincarnation/g
s/\bREICARNATION\b/REINCARNATION/g
s/\bReicarnation\b/Reincarnation/g
s/\breigining\b/reigning/g
s/\bREIGINING\b/REIGNING/g
s/\bReigining\b/Reigning/g
s/\breknown\b/renown/g
s/\bREKNOWN\b/RENOWN/g
s/\bReknown\b/Renown/g
s/\breknowned\b/renowned/g
s/\bREKNOWNED\b/RENOWNED/g
s/\bReknowned\b/Renowned/g
s/\brela\b/real/g
s/\bRELA\b/REAL/g
s/\bRela\b/Real/g
s/\brelaly\b/really/g
s/\bRELALY\b/REALLY/g
s/\bRelaly\b/Really/g
s/\brelatiopnship\b/relationship/g
s/\bRELATIOPNSHIP\b/RELATIONSHIP/g
s/\bRelatiopnship\b/Relationship/g
s/\brelativly\b/relatively/g
s/\bRELATIVLY\b/RELATIVELY/g
s/\bRelativly\b/Relatively/g
s/\brelected\b/reelected/g
s/\bRELECTED\b/REELECTED/g
s/\bRelected\b/Reelected/g
s/\breleive\b/relieve/g
s/\bRELEIVE\b/RELIEVE/g
s/\bReleive\b/Relieve/g
s/\breleived\b/relieved/g
s/\bRELEIVED\b/RELIEVED/g
s/\bReleived\b/Relieved/g
s/\breleiver\b/reliever/g
s/\bRELEIVER\b/RELIEVER/g
s/\bReleiver\b/Reliever/g
s/\breleses\b/releases/g
s/\bRELESES\b/RELEASES/g
s/\bReleses\b/Releases/g
s/\brelevent\b/relevant/g
s/\bRELEVENT\b/RELEVANT/g
s/\bRelevent\b/Relevant/g
s/\breliablity\b/reliability/g
s/\bRELIABLITY\b/RELIABILITY/g
s/\bReliablity\b/Reliability/g
s/\brelient\b/reliant/g
s/\bRELIENT\b/RELIANT/g
s/\bRelient\b/Reliant/g
s/\breligeous\b/religious/g
s/\bRELIGEOUS\b/RELIGIOUS/g
s/\bReligeous\b/Religious/g
s/\breligous\b/religious/g
s/\bRELIGOUS\b/RELIGIOUS/g
s/\bReligous\b/Religious/g
s/\breligously\b/religiously/g
s/\bRELIGOUSLY\b/RELIGIOUSLY/g
s/\bReligously\b/Religiously/g
s/\brelinqushment\b/relinquishment/g
s/\bRELINQUSHMENT\b/RELINQUISHMENT/g
s/\bRelinqushment\b/Relinquishment/g
s/\brelitavely\b/relatively/g
s/\bRELITAVELY\b/RELATIVELY/g
s/\bRelitavely\b/Relatively/g
s/\brelpacement\b/replacement/g
s/\bRELPACEMENT\b/REPLACEMENT/g
s/\bRelpacement\b/Replacement/g
s/\bremaing\b/remaining/g
s/\bREMAING\b/REMAINING/g
s/\bRemaing\b/Remaining/g
s/\brememberable\b/memorable/g
s/\bREMEMBERABLE\b/MEMORABLE/g
s/\bRememberable\b/Memorable/g
s/\brememberance\b/remembrance/g
s/\bREMEMBERANCE\b/REMEMBRANCE/g
s/\bRememberance\b/Remembrance/g
s/\bremembrence\b/remembrance/g
s/\bREMEMBRENCE\b/REMEMBRANCE/g
s/\bRemembrence\b/Remembrance/g
s/\bremenant\b/remnant/g
s/\bREMENANT\b/REMNANT/g
s/\bRemenant\b/Remnant/g
s/\bremenicent\b/reminiscent/g
s/\bREMENICENT\b/REMINISCENT/g
s/\bRemenicent\b/Reminiscent/g
s/\breminent\b/remnant/g
s/\bREMINENT\b/REMNANT/g
s/\bReminent\b/Remnant/g
s/\breminescent\b/reminiscent/g
s/\bREMINESCENT\b/REMINISCENT/g
s/\bReminescent\b/Reminiscent/g
s/\breminscent\b/reminiscent/g
s/\bREMINSCENT\b/REMINISCENT/g
s/\bReminscent\b/Reminiscent/g
s/\breminsicent\b/reminiscent/g
s/\bREMINSICENT\b/REMINISCENT/g
s/\bReminsicent\b/Reminiscent/g
s/\brendevous\b/rendezvous/g
s/\bRENDEVOUS\b/RENDEZVOUS/g
s/\bRendevous\b/Rendezvous/g
s/\brendezous\b/rendezvous/g
s/\bRENDEZOUS\b/RENDEZVOUS/g
s/\bRendezous\b/Rendezvous/g
s/\brenedered\b/rende/g
s/\bRENEDERED\b/RENDE/g
s/\bRenedered\b/Rende/g
s/\brenewl\b/renewal/g
s/\bRENEWL\b/RENEWAL/g
s/\bRenewl\b/Renewal/g
s/\brennovate\b/renovate/g
s/\bRENNOVATE\b/RENOVATE/g
s/\bRennovate\b/Renovate/g
s/\brennovated\b/renovated/g
s/\bRENNOVATED\b/RENOVATED/g
s/\bRennovated\b/Renovated/g
s/\brennovating\b/renovating/g
s/\bRENNOVATING\b/RENOVATING/g
s/\bRennovating\b/Renovating/g
s/\brennovation\b/renovation/g
s/\bRENNOVATION\b/RENOVATION/g
s/\bRennovation\b/Renovation/g
s/\brentors\b/renters/g
s/\bRENTORS\b/RENTERS/g
s/\bRentors\b/Renters/g
s/\breorganision\b/reorganisation/g
s/\bREORGANISION\b/REORGANISATION/g
s/\bReorganision\b/Reorganisation/g
s/\brepblic\b/republic/g
s/\bREPBLIC\b/REPUBLIC/g
s/\bRepblic\b/Republic/g
s/\brepblican\b/republican/g
s/\bREPBLICAN\b/REPUBLICAN/g
s/\bRepblican\b/Republican/g
s/\brepblicans\b/republicans/g
s/\bREPBLICANS\b/REPUBLICANS/g
s/\bRepblicans\b/Republicans/g
s/\brepblics\b/republics/g
s/\bREPBLICS\b/REPUBLICS/g
s/\bRepblics\b/Republics/g
s/\brepectively\b/respectively/g
s/\bREPECTIVELY\b/RESPECTIVELY/g
s/\bRepectively\b/Respectively/g
s/\brepeition\b/repetition/g
s/\bREPEITION\b/REPETITION/g
s/\bRepeition\b/Repetition/g
s/\brepentence\b/repentance/g
s/\bREPENTENCE\b/REPENTANCE/g
s/\bRepentence\b/Repentance/g
s/\brepentent\b/repentant/g
s/\bREPENTENT\b/REPENTANT/g
s/\bRepentent\b/Repentant/g
s/\brepeteadly\b/repeatedly/g
s/\bREPETEADLY\b/REPEATEDLY/g
s/\bRepeteadly\b/Repeatedly/g
s/\brepid\b/rapid/g
s/\bREPID\b/RAPID/g
s/\bRepid\b/Rapid/g
s/\breponse\b/response/g
s/\bREPONSE\b/RESPONSE/g
s/\bReponse\b/Response/g
s/\breportadly\b/reportedly/g
s/\bREPORTADLY\b/REPORTEDLY/g
s/\bReportadly\b/Reportedly/g
s/\brepresantative\b/representative/g
s/\bREPRESANTATIVE\b/REPRESENTATIVE/g
s/\bRepresantative\b/Representative/g
s/\brepresentive\b/representative/g
s/\bREPRESENTIVE\b/REPRESENTATIVE/g
s/\bRepresentive\b/Representative/g
s/\brepresentives\b/representatives/g
s/\bREPRESENTIVES\b/REPRESENTATIVES/g
s/\bRepresentives\b/Representatives/g
s/\breproducable\b/reproducible/g
s/\bREPRODUCABLE\b/REPRODUCIBLE/g
s/\bReproducable\b/Reproducible/g
s/\breprtoire\b/repertoire/g
s/\bREPRTOIRE\b/REPERTOIRE/g
s/\bReprtoire\b/Repertoire/g
s/\brepsectively\b/respectively/g
s/\bREPSECTIVELY\b/RESPECTIVELY/g
s/\bRepsectively\b/Respectively/g
s/\breptition\b/repetition/g
s/\bREPTITION\b/REPETITION/g
s/\bReptition\b/Repetition/g
s/\brepubic\b/republic/g
s/\bREPUBIC\b/REPUBLIC/g
s/\bRepubic\b/Republic/g
s/\brepubican\b/republican/g
s/\bREPUBICAN\b/REPUBLICAN/g
s/\bRepubican\b/Republican/g
s/\brepubicans\b/republicans/g
s/\bREPUBICANS\b/REPUBLICANS/g
s/\bRepubicans\b/Republicans/g
s/\brepubics\b/republics/g
s/\bREPUBICS\b/REPUBLICS/g
s/\bRepubics\b/Republics/g
s/\brepubli\b/republic/g
s/\bREPUBLI\b/REPUBLIC/g
s/\bRepubli\b/Republic/g
s/\brepublian\b/republican/g
s/\bREPUBLIAN\b/REPUBLICAN/g
s/\bRepublian\b/Republican/g
s/\brepublians\b/republicans/g
s/\bREPUBLIANS\b/REPUBLICANS/g
s/\bRepublians\b/Republicans/g
s/\brepublis\b/republics/g
s/\bREPUBLIS\b/REPUBLICS/g
s/\bRepublis\b/Republics/g
s/\brepulic\b/republic/g
s/\bREPULIC\b/REPUBLIC/g
s/\bRepulic\b/Republic/g
s/\brepulican\b/republican/g
s/\bREPULICAN\b/REPUBLICAN/g
s/\bRepulican\b/Republican/g
s/\brepulicans\b/republicans/g
s/\bREPULICANS\b/REPUBLICANS/g
s/\bRepulicans\b/Republicans/g
s/\brepulics\b/republics/g
s/\bREPULICS\b/REPUBLICS/g
s/\bRepulics\b/Republics/g
s/\brequirment\b/requirement/g
s/\bREQUIRMENT\b/REQUIREMENT/g
s/\bRequirment\b/Requirement/g
s/\bresaurant\b/restaurant/g
s/\bRESAURANT\b/RESTAURANT/g
s/\bResaurant\b/Restaurant/g
s/\bresembelance\b/resemblance/g
s/\bRESEMBELANCE\b/RESEMBLANCE/g
s/\bResembelance\b/Resemblance/g
s/\bresembes\b/resembles/g
s/\bRESEMBES\b/RESEMBLES/g
s/\bResembes\b/Resembles/g
s/\bresemblence\b/resemblance/g
s/\bRESEMBLENCE\b/RESEMBLANCE/g
s/\bResemblence\b/Resemblance/g
s/\bresevoir\b/reservoir/g
s/\bRESEVOIR\b/RESERVOIR/g
s/\bResevoir\b/Reservoir/g
s/\bresidental\b/residential/g
s/\bRESIDENTAL\b/RESIDENTIAL/g
s/\bResidental\b/Residential/g
s/\bresignement\b/resignment/g
s/\bRESIGNEMENT\b/RESIGNMENT/g
s/\bResignement\b/Resignment/g
s/\bresistable\b/resistible/g
s/\bRESISTABLE\b/RESISTIBLE/g
s/\bResistable\b/Resistible/g
s/\bresistent\b/resistant/g
s/\bRESISTENT\b/RESISTANT/g
s/\bResistent\b/Resistant/g
s/\brespectivly\b/respectively/g
s/\bRESPECTIVLY\b/RESPECTIVELY/g
s/\bRespectivly\b/Respectively/g
s/\bresponce\b/response/g
s/\bRESPONCE\b/RESPONSE/g
s/\bResponce\b/Response/g
s/\bresponibilities\b/responsibilities/g
s/\bRESPONIBILITIES\b/RESPONSIBILITIES/g
s/\bResponibilities\b/Responsibilities/g
s/\bresponisble\b/responsible/g
s/\bRESPONISBLE\b/RESPONSIBLE/g
s/\bResponisble\b/Responsible/g
s/\bresponnsibilty\b/responsibility/g
s/\bRESPONNSIBILTY\b/RESPONSIBILITY/g
s/\bResponnsibilty\b/Responsibility/g
s/\bresponsability\b/responsibility/g
s/\bRESPONSABILITY\b/RESPONSIBILITY/g
s/\bResponsability\b/Responsibility/g
s/\bresponsibile\b/responsible/g
s/\bRESPONSIBILE\b/RESPONSIBLE/g
s/\bResponsibile\b/Responsible/g
s/\bresponsibilites\b/responsibilities/g
s/\bRESPONSIBILITES\b/RESPONSIBILITIES/g
s/\bResponsibilites\b/Responsibilities/g
s/\bresponsiblities\b/responsibilities/g
s/\bRESPONSIBLITIES\b/RESPONSIBILITIES/g
s/\bResponsiblities\b/Responsibilities/g
s/\bresponsiblity\b/responsibility/g
s/\bRESPONSIBLITY\b/RESPONSIBILITY/g
s/\bResponsiblity\b/Responsibility/g
s/\bressemblance\b/resemblance/g
s/\bRESSEMBLANCE\b/RESEMBLANCE/g
s/\bRessemblance\b/Resemblance/g
s/\bressemble\b/resemble/g
s/\bRESSEMBLE\b/RESEMBLE/g
s/\bRessemble\b/Resemble/g
s/\bressembled\b/resembled/g
s/\bRESSEMBLED\b/RESEMBLED/g
s/\bRessembled\b/Resembled/g
s/\bressemblence\b/resemblance/g
s/\bRESSEMBLENCE\b/RESEMBLANCE/g
s/\bRessemblence\b/Resemblance/g
s/\bressembling\b/resembling/g
s/\bRESSEMBLING\b/RESEMBLING/g
s/\bRessembling\b/Resembling/g
s/\bresssurecting\b/resurrecting/g
s/\bRESSSURECTING\b/RESURRECTING/g
s/\bResssurecting\b/Resurrecting/g
s/\bressurect\b/resurrect/g
s/\bRESSURECT\b/RESURRECT/g
s/\bRessurect\b/Resurrect/g
s/\bressurected\b/resurrected/g
s/\bRESSURECTED\b/RESURRECTED/g
s/\bRessurected\b/Resurrected/g
s/\bressurection\b/resurrection/g
s/\bRESSURECTION\b/RESURRECTION/g
s/\bRessurection\b/Resurrection/g
s/\bressurrection\b/resurrection/g
s/\bRESSURRECTION\b/RESURRECTION/g
s/\bRessurrection\b/Resurrection/g
s/\brestarant\b/restaurant/g
s/\bRESTARANT\b/RESTAURANT/g
s/\bRestarant\b/Restaurant/g
s/\brestarants\b/restaurants/g
s/\bRESTARANTS\b/RESTAURANTS/g
s/\bRestarants\b/Restaurants/g
s/\brestaraunt\b/restaurant/g
s/\bRESTARAUNT\b/RESTAURANT/g
s/\bRestaraunt\b/Restaurant/g
s/\brestaraunteur\b/restaurateur/g
s/\bRESTARAUNTEUR\b/RESTAURATEUR/g
s/\bRestaraunteur\b/Restaurateur/g
s/\brestaraunteurs\b/restaurateurs/g
s/\bRESTARAUNTEURS\b/RESTAURATEURS/g
s/\bRestaraunteurs\b/Restaurateurs/g
s/\brestaraunts\b/restaurants/g
s/\bRESTARAUNTS\b/RESTAURANTS/g
s/\bRestaraunts\b/Restaurants/g
s/\brestauranteurs\b/restaurateurs/g
s/\bRESTAURANTEURS\b/RESTAURATEURS/g
s/\bRestauranteurs\b/Restaurateurs/g
s/\brestauration\b/restoration/g
s/\bRESTAURATION\b/RESTORATION/g
s/\bRestauration\b/Restoration/g
s/\brestauraunt\b/restaurant/g
s/\bRESTAURAUNT\b/RESTAURANT/g
s/\bRestauraunt\b/Restaurant/g
s/\bresteraunt\b/restaurant/g
s/\bRESTERAUNT\b/RESTAURANT/g
s/\bResteraunt\b/Restaurant/g
s/\bresteraunts\b/restaurants/g
s/\bRESTERAUNTS\b/RESTAURANTS/g
s/\bResteraunts\b/Restaurants/g
s/\bresticted\b/restricted/g
s/\bRESTICTED\b/RESTRICTED/g
s/\bResticted\b/Restricted/g
s/\bresturant\b/restaurant/g
s/\bRESTURANT\b/RESTAURANT/g
s/\bResturant\b/Restaurant/g
s/\bresturants\b/restaurants/g
s/\bRESTURANTS\b/RESTAURANTS/g
s/\bResturants\b/Restaurants/g
s/\bresturaunt\b/restaurant/g
s/\bRESTURAUNT\b/RESTAURANT/g
s/\bResturaunt\b/Restaurant/g
s/\bresturaunts\b/restaurants/g
s/\bRESTURAUNTS\b/RESTAURANTS/g
s/\bResturaunts\b/Restaurants/g
s/\bresurecting\b/resurrecting/g
s/\bRESURECTING\b/RESURRECTING/g
s/\bResurecting\b/Resurrecting/g
s/\bretalitated\b/retaliated/g
s/\bRETALITATED\b/RETALIATED/g
s/\bRetalitated\b/Retaliated/g
s/\bretalitation\b/retaliation/g
s/\bRETALITATION\b/RETALIATION/g
s/\bRetalitation\b/Retaliation/g
s/\breturnd\b/returned/g
s/\bRETURND\b/RETURNED/g
s/\bReturnd\b/Returned/g
s/\brevaluated\b/reevaluated/g
s/\bREVALUATED\b/REEVALUATED/g
s/\bRevaluated\b/Reevaluated/g
s/\breveiw\b/review/g
s/\bREVEIW\b/REVIEW/g
s/\bReveiw\b/Review/g
s/\breveral\b/reversal/g
s/\bREVERAL\b/REVERSAL/g
s/\bReveral\b/Reversal/g
s/\breversable\b/reversible/g
s/\bREVERSABLE\b/REVERSIBLE/g
s/\bReversable\b/Reversible/g
s/\brevolutionar\b/revolutionary/g
s/\bREVOLUTIONAR\b/REVOLUTIONARY/g
s/\bRevolutionar\b/Revolutionary/g
s/\brewitten\b/rewritten/g
s/\bREWITTEN\b/REWRITTEN/g
s/\bRewitten\b/Rewritten/g
s/\brewriet\b/rewrite/g
s/\bREWRIET\b/REWRITE/g
s/\bRewriet\b/Rewrite/g
s/\brference\b/reference/g
s/\bRFERENCE\b/REFERENCE/g
s/\bRference\b/Reference/g
s/\brferences\b/references/g
s/\bRFERENCES\b/REFERENCES/g
s/\bRferences\b/References/g
s/\brhymme\b/rhyme/g
s/\bRHYMME\b/RHYME/g
s/\bRhymme\b/Rhyme/g
s/\brhythem\b/rhythm/g
s/\bRHYTHEM\b/RHYTHM/g
s/\bRhythem\b/Rhythm/g
s/\brhythim\b/rhythm/g
s/\bRHYTHIM\b/RHYTHM/g
s/\bRhythim\b/Rhythm/g
s/\brhytmic\b/rhythmic/g
s/\bRHYTMIC\b/RHYTHMIC/g
s/\bRhytmic\b/Rhythmic/g
s/\brininging\b/ringing/g
s/\bRININGING\b/RINGING/g
s/\bRininging\b/Ringing/g
s/\brococco\b/rococo/g
s/\bROCOCCO\b/ROCOCO/g
s/\bRococco\b/Rococo/g
s/\brocord\b/record/g
s/\bROCORD\b/RECORD/g
s/\bRocord\b/Record/g
s/\broomate\b/roommate/g
s/\bROOMATE\b/ROOMMATE/g
s/\bRoomate\b/Roommate/g
s/\brougly\b/roughly/g
s/\bROUGLY\b/ROUGHLY/g
s/\bRougly\b/Roughly/g
s/\brucuperate\b/recuperate/g
s/\bRUCUPERATE\b/RECUPERATE/g
s/\bRucuperate\b/Recuperate/g
s/\brudimentatry\b/rudimentary/g
s/\bRUDIMENTATRY\b/RUDIMENTARY/g
s/\bRudimentatry\b/Rudimentary/g
s/\brulle\b/rule/g
s/\bRULLE\b/RULE/g
s/\bRulle\b/Rule/g
s/\bruning\b/running/g
s/\bRUNING\b/RUNNING/g
s/\bRuning\b/Running/g
s/\brunnung\b/running/g
s/\bRUNNUNG\b/RUNNING/g
s/\bRunnung\b/Running/g
s/\brussina\b/russian/g
s/\bRUSSINA\b/RUSSIAN/g
s/\bRussina\b/Russian/g
s/\brwite\b/write/g
s/\bRWITE\b/WRITE/g
s/\bRwite\b/Write/g
s/\brythem\b/rhythm/g
s/\bRYTHEM\b/RHYTHM/g
s/\bRythem\b/Rhythm/g
s/\brythim\b/rhythm/g
s/\bRYTHIM\b/RHYTHM/g
s/\bRythim\b/Rhythm/g
s/\brythm\b/rhythm/g
s/\bRYTHM\b/RHYTHM/g
s/\bRythm\b/Rhythm/g
s/\brythmic\b/rhythmic/g
s/\bRYTHMIC\b/RHYTHMIC/g
s/\bRythmic\b/Rhythmic/g
s/\brythyms\b/rhythms/g
s/\bRYTHYMS\b/RHYTHMS/g
s/\bRythyms\b/Rhythms/g
s/\bsacrafice\b/sacrifice/g
s/\bSACRAFICE\b/SACRIFICE/g
s/\bSacrafice\b/Sacrifice/g
s/\bsacreligious\b/sacrilegious/g
s/\bSACRELIGIOUS\b/SACRILEGIOUS/g
s/\bSacreligious\b/Sacrilegious/g
s/\bsacrifical\b/sacrificial/g
s/\bSACRIFICAL\b/SACRIFICIAL/g
s/\bSacrifical\b/Sacrificial/g
s/\bsaftey\b/safety/g
s/\bSAFTEY\b/SAFETY/g
s/\bSaftey\b/Safety/g
s/\bsafty\b/safety/g
s/\bSAFTY\b/SAFETY/g
s/\bSafty\b/Safety/g
s/\bsalery\b/salary/g
s/\bSALERY\b/SALARY/g
s/\bSalery\b/Salary/g
s/\bsanctionning\b/sanctioning/g
s/\bSANCTIONNING\b/SANCTIONING/g
s/\bSanctionning\b/Sanctioning/g
s/\bsandwhich\b/sandwich/g
s/\bSANDWHICH\b/SANDWICH/g
s/\bSandwhich\b/Sandwich/g
s/\bsantioned\b/sanctioned/g
s/\bSANTIONED\b/SANCTIONED/g
s/\bSantioned\b/Sanctioned/g
s/\bsargant\b/sergeant/g
s/\bSARGANT\b/SERGEANT/g
s/\bSargant\b/Sergeant/g
s/\bsargeant\b/sergeant/g
s/\bSARGEANT\b/SERGEANT/g
s/\bSargeant\b/Sergeant/g
s/\bsatelite\b/satellite/g
s/\bSATELITE\b/SATELLITE/g
s/\bSatelite\b/Satellite/g
s/\bsatelites\b/satellites/g
s/\bSATELITES\b/SATELLITES/g
s/\bSatelites\b/Satellites/g
s/\bsatisfactority\b/satisfactorily/g
s/\bSATISFACTORITY\b/SATISFACTORILY/g
s/\bSatisfactority\b/Satisfactorily/g
s/\bsatric\b/satiric/g
s/\bSATRIC\b/SATIRIC/g
s/\bSatric\b/Satiric/g
s/\bsatrical\b/satirical/g
s/\bSATRICAL\b/SATIRICAL/g
s/\bSatrical\b/Satirical/g
s/\bsatrically\b/satirically/g
s/\bSATRICALLY\b/SATIRICALLY/g
s/\bSatrically\b/Satirically/g
s/\bsattelite\b/satellite/g
s/\bSATTELITE\b/SATELLITE/g
s/\bSattelite\b/Satellite/g
s/\bsattelites\b/satellites/g
s/\bSATTELITES\b/SATELLITES/g
s/\bSattelites\b/Satellites/g
s/\bsaught\b/sought/g
s/\bSAUGHT\b/SOUGHT/g
s/\bSaught\b/Sought/g
s/\bsaveing\b/saving/g
s/\bSAVEING\b/SAVING/g
s/\bSaveing\b/Saving/g
s/\bsaxaphone\b/saxophone/g
s/\bSAXAPHONE\b/SAXOPHONE/g
s/\bSaxaphone\b/Saxophone/g
s/\bscaleable\b/scalable/g
s/\bSCALEABLE\b/SCALABLE/g
s/\bScaleable\b/Scalable/g
s/\bscandanavia\b/scandinavia/g
s/\bSCANDANAVIA\b/SCANDINAVIA/g
s/\bScandanavia\b/Scandinavia/g
s/\bscaricity\b/scarcity/g
s/\bSCARICITY\b/SCARCITY/g
s/\bScaricity\b/Scarcity/g
s/\bscavanged\b/scavenged/g
s/\bSCAVANGED\b/SCAVENGED/g
s/\bScavanged\b/Scavenged/g
s/\bschedual\b/schedule/g
s/\bSCHEDUAL\b/SCHEDULE/g
s/\bSchedual\b/Schedule/g
s/\bscholarhip\b/scholarship/g
s/\bSCHOLARHIP\b/SCHOLARSHIP/g
s/\bScholarhip\b/Scholarship/g
s/\bscientfic\b/scientific/g
s/\bSCIENTFIC\b/SCIENTIFIC/g
s/\bScientfic\b/Scientific/g
s/\bscientifc\b/scientific/g
s/\bSCIENTIFC\b/SCIENTIFIC/g
s/\bScientifc\b/Scientific/g
s/\bscientis\b/scientist/g
s/\bSCIENTIS\b/SCIENTIST/g
s/\bScientis\b/Scientist/g
s/\bscince\b/science/g
s/\bSCINCE\b/SCIENCE/g
s/\bScince\b/Science/g
s/\bscinece\b/science/g
s/\bSCINECE\b/SCIENCE/g
s/\bScinece\b/Science/g
s/\bscirpt\b/script/g
s/\bSCIRPT\b/SCRIPT/g
s/\bScirpt\b/Script/g
s/\bscoll\b/scroll/g
s/\bSCOLL\b/SCROLL/g
s/\bScoll\b/Scroll/g
s/\bscreenwrighter\b/screenwriter/g
s/\bSCREENWRIGHTER\b/SCREENWRITER/g
s/\bScreenwrighter\b/Screenwriter/g
s/\bscrutinity\b/scrutiny/g
s/\bSCRUTINITY\b/SCRUTINY/g
s/\bScrutinity\b/Scrutiny/g
s/\bscuptures\b/sculptures/g
s/\bSCUPTURES\b/SCULPTURES/g
s/\bScuptures\b/Sculptures/g
s/\bseach\b/search/g
s/\bSEACH\b/SEARCH/g
s/\bSeach\b/Search/g
s/\bseached\b/searched/g
s/\bSEACHED\b/SEARCHED/g
s/\bSeached\b/Searched/g
s/\bseaches\b/searches/g
s/\bSEACHES\b/SEARCHES/g
s/\bSeaches\b/Searches/g
s/\bsecratary\b/secretary/g
s/\bSECRATARY\b/SECRETARY/g
s/\bSecratary\b/Secretary/g
s/\bsecretery\b/secretary/g
s/\bSECRETERY\b/SECRETARY/g
s/\bSecretery\b/Secretary/g
s/\bsedereal\b/sidereal/g
s/\bSEDEREAL\b/SIDEREAL/g
s/\bSedereal\b/Sidereal/g
s/\bseeked\b/sought/g
s/\bSEEKED\b/SOUGHT/g
s/\bSeeked\b/Sought/g
s/\bseguoys\b/segues/g
s/\bSEGUOYS\b/SEGUES/g
s/\bSeguoys\b/Segues/g
s/\bseige\b/siege/g
s/\bSEIGE\b/SIEGE/g
s/\bSeige\b/Siege/g
s/\bseing\b/seeing/g
s/\bSEING\b/SEEING/g
s/\bSeing\b/Seeing/g
s/\bseinor\b/senior/g
s/\bSEINOR\b/SENIOR/g
s/\bSeinor\b/Senior/g
s/\bseldomly\b/seldom/g
s/\bSELDOMLY\b/SELDOM/g
s/\bSeldomly\b/Seldom/g
s/\bsenarios\b/scenarios/g
s/\bSENARIOS\b/SCENARIOS/g
s/\bSenarios\b/Scenarios/g
s/\bsenstive\b/sensitive/g
s/\bSENSTIVE\b/SENSITIVE/g
s/\bSenstive\b/Sensitive/g
s/\bsensure\b/censure/g
s/\bSENSURE\b/CENSURE/g
s/\bSensure\b/Censure/g
s/\bsepina\b/subpoena/g
s/\bSEPINA\b/SUBPOENA/g
s/\bSepina\b/Subpoena/g
s/\bsergent\b/sergeant/g
s/\bSERGENT\b/SERGEANT/g
s/\bSergent\b/Sergeant/g
s/\bsettelement\b/settlement/g
s/\bSETTELEMENT\b/SETTLEMENT/g
s/\bSettelement\b/Settlement/g
s/\bsettlment\b/settlement/g
s/\bSETTLMENT\b/SETTLEMENT/g
s/\bSettlment\b/Settlement/g
s/\bsevereal\b/several/g
s/\bSEVEREAL\b/SEVERAL/g
s/\bSevereal\b/Several/g
s/\bseverley\b/severely/g
s/\bSEVERLEY\b/SEVERELY/g
s/\bSeverley\b/Severely/g
s/\bseverly\b/severely/g
s/\bSEVERLY\b/SEVERELY/g
s/\bSeverly\b/Severely/g
s/\bsevice\b/service/g
s/\bSEVICE\b/SERVICE/g
s/\bSevice\b/Service/g
s/\bshadasloo\b/shadaloo/g
s/\bSHADASLOO\b/SHADALOO/g
s/\bShadasloo\b/Shadaloo/g
s/\bshaddow\b/shadow/g
s/\bSHADDOW\b/SHADOW/g
s/\bShaddow\b/Shadow/g
s/\bshadoloo\b/shadaloo/g
s/\bSHADOLOO\b/SHADALOO/g
s/\bShadoloo\b/Shadaloo/g
s/\bsheild\b/shield/g
s/\bSHEILD\b/SHIELD/g
s/\bSheild\b/Shield/g
s/\bsherif\b/sheriff/g
s/\bSHERIF\b/SHERIFF/g
s/\bSherif\b/Sheriff/g
s/\bshineing\b/shining/g
s/\bSHINEING\b/SHINING/g
s/\bShineing\b/Shining/g
s/\bshiped\b/shipped/g
s/\bSHIPED\b/SHIPPED/g
s/\bShiped\b/Shipped/g
s/\bshiping\b/shipping/g
s/\bSHIPING\b/SHIPPING/g
s/\bShiping\b/Shipping/g
s/\bshopkeeepers\b/shopkeepers/g
s/\bSHOPKEEEPERS\b/SHOPKEEPERS/g
s/\bShopkeeepers\b/Shopkeepers/g
s/\bshorly\b/shortly/g
s/\bSHORLY\b/SHORTLY/g
s/\bShorly\b/Shortly/g
s/\bshortwhile\b/short while/g
s/\bSHORTWHILE\b/SHORT WHILE/g
s/\bShortwhile\b/Short while/g
s/\bshouldnt\b/should not/g
s/\bSHOULDNT\b/SHOULD NOT/g
s/\bShouldnt\b/Should not/g
s/\bshreak\b/shriek/g
s/\bSHREAK\b/SHRIEK/g
s/\bShreak\b/Shriek/g
s/\bshrinked\b/shrunk/g
s/\bSHRINKED\b/SHRUNK/g
s/\bShrinked\b/Shrunk/g
s/\bsicne\b/since/g
s/\bSICNE\b/SINCE/g
s/\bSicne\b/Since/g
s/\bsideral\b/sidereal/g
s/\bSIDERAL\b/SIDEREAL/g
s/\bSideral\b/Sidereal/g
s/\bsiezure\b/seizure/g
s/\bSIEZURE\b/SEIZURE/g
s/\bSiezure\b/Seizure/g
s/\bsiezures\b/seizures/g
s/\bSIEZURES\b/SEIZURES/g
s/\bSiezures\b/Seizures/g
s/\bsiginificant\b/significant/g
s/\bSIGINIFICANT\b/SIGNIFICANT/g
s/\bSiginificant\b/Significant/g
s/\bsignficant\b/significant/g
s/\bSIGNFICANT\b/SIGNIFICANT/g
s/\bSignficant\b/Significant/g
s/\bsignficiant\b/significant/g
s/\bSIGNFICIANT\b/SIGNIFICANT/g
s/\bSignficiant\b/Significant/g
s/\bsignfies\b/signifies/g
s/\bSIGNFIES\b/SIGNIFIES/g
s/\bSignfies\b/Signifies/g
s/\bsignifantly\b/significantly/g
s/\bSIGNIFANTLY\b/SIGNIFICANTLY/g
s/\bSignifantly\b/Significantly/g
s/\bsignificently\b/significantly/g
s/\bSIGNIFICENTLY\b/SIGNIFICANTLY/g
s/\bSignificently\b/Significantly/g
s/\bsignifigant\b/significant/g
s/\bSIGNIFIGANT\b/SIGNIFICANT/g
s/\bSignifigant\b/Significant/g
s/\bsignifigantly\b/significantly/g
s/\bSIGNIFIGANTLY\b/SIGNIFICANTLY/g
s/\bSignifigantly\b/Significantly/g
s/\bsignitories\b/signatories/g
s/\bSIGNITORIES\b/SIGNATORIES/g
s/\bSignitories\b/Signatories/g
s/\bsignitory\b/signatory/g
s/\bSIGNITORY\b/SIGNATORY/g
s/\bSignitory\b/Signatory/g
s/\bsimilarily\b/similarly/g
s/\bSIMILARILY\b/SIMILARLY/g
s/\bSimilarily\b/Similarly/g
s/\bsimiliar\b/similar/g
s/\bSIMILIAR\b/SIMILAR/g
s/\bSimiliar\b/Similar/g
s/\bsimiliarity\b/similarity/g
s/\bSIMILIARITY\b/SIMILARITY/g
s/\bSimiliarity\b/Similarity/g
s/\bsimiliarly\b/similarly/g
s/\bSIMILIARLY\b/SIMILARLY/g
s/\bSimiliarly\b/Similarly/g
s/\bsimmilar\b/similar/g
s/\bSIMMILAR\b/SIMILAR/g
s/\bSimmilar\b/Similar/g
s/\bsimpley\b/simply/g
s/\bSIMPLEY\b/SIMPLY/g
s/\bSimpley\b/Simply/g
s/\bsimultanous\b/simultaneous/g
s/\bSIMULTANOUS\b/SIMULTANEOUS/g
s/\bSimultanous\b/Simultaneous/g
s/\bsimultanously\b/simultaneously/g
s/\bSIMULTANOUSLY\b/SIMULTANEOUSLY/g
s/\bSimultanously\b/Simultaneously/g
s/\bsincerley\b/sincerely/g
s/\bSINCERLEY\b/SINCERELY/g
s/\bSincerley\b/Sincerely/g
s/\bsingsog\b/singsong/g
s/\bSINGSOG\b/SINGSONG/g
s/\bSingsog\b/Singsong/g
s/\bskateing\b/skating/g
s/\bSKATEING\b/SKATING/g
s/\bSkateing\b/Skating/g
s/\bslaugterhouses\b/slaughterhouses/g
s/\bSLAUGTERHOUSES\b/SLAUGHTERHOUSES/g
s/\bSlaugterhouses\b/Slaughterhouses/g
s/\bslighly\b/slightly/g
s/\bSLIGHLY\b/SLIGHTLY/g
s/\bSlighly\b/Slightly/g
s/\bslippy\b/slippery/g
s/\bSLIPPY\b/SLIPPERY/g
s/\bSlippy\b/Slippery/g
s/\bslowy\b/slowly/g
s/\bSLOWY\b/SLOWLY/g
s/\bSlowy\b/Slowly/g
s/\bsmae\b/same/g
s/\bSMAE\b/SAME/g
s/\bSmae\b/Same/g
s/\bsmealting\b/smelting/g
s/\bSMEALTING\b/SMELTING/g
s/\bSmealting\b/Smelting/g
s/\bsmoe\b/some/g
s/\bSMOE\b/SOME/g
s/\bSmoe\b/Some/g
s/\bsneeks\b/sneaks/g
s/\bSNEEKS\b/SNEAKS/g
s/\bSneeks\b/Sneaks/g
s/\bsnese\b/sneeze/g
s/\bSNESE\b/SNEEZE/g
s/\bSnese\b/Sneeze/g
s/\bsocalism\b/socialism/g
s/\bSOCALISM\b/SOCIALISM/g
s/\bSocalism\b/Socialism/g
s/\bsocities\b/societies/g
s/\bSOCITIES\b/SOCIETIES/g
s/\bSocities\b/Societies/g
s/\bsoem\b/some/g
s/\bSOEM\b/SOME/g
s/\bSoem\b/Some/g
s/\bsofware\b/software/g
s/\bSOFWARE\b/SOFTWARE/g
s/\bSofware\b/Software/g
s/\bsohw\b/show/g
s/\bSOHW\b/SHOW/g
s/\bSohw\b/Show/g
s/\bsoilders\b/soldiers/g
s/\bSOILDERS\b/SOLDIERS/g
s/\bSoilders\b/Soldiers/g
s/\bsolatary\b/solitary/g
s/\bSOLATARY\b/SOLITARY/g
s/\bSolatary\b/Solitary/g
s/\bsoley\b/solely/g
s/\bSOLEY\b/SOLELY/g
s/\bSoley\b/Solely/g
s/\bsoliders\b/soldiers/g
s/\bSOLIDERS\b/SOLDIERS/g
s/\bSoliders\b/Soldiers/g
s/\bsoliliquy\b/soliloquy/g
s/\bSOLILIQUY\b/SOLILOQUY/g
s/\bSoliliquy\b/Soliloquy/g
s/\bsoluable\b/soluble/g
s/\bSOLUABLE\b/SOLUBLE/g
s/\bSoluable\b/Soluble/g
s/\bsomene\b/someone/g
s/\bSOMENE\b/SOMEONE/g
s/\bSomene\b/Someone/g
s/\bsomtimes\b/sometimes/g
s/\bSOMTIMES\b/SOMETIMES/g
s/\bSomtimes\b/Sometimes/g
s/\bsomwhere\b/somewhere/g
s/\bSOMWHERE\b/SOMEWHERE/g
s/\bSomwhere\b/Somewhere/g
s/\bsophicated\b/sophisticated/g
s/\bSOPHICATED\b/SOPHISTICATED/g
s/\bSophicated\b/Sophisticated/g
s/\bsophmore\b/sophomore/g
s/\bSOPHMORE\b/SOPHOMORE/g
s/\bSophmore\b/Sophomore/g
s/\bsorceror\b/sorcerer/g
s/\bSORCEROR\b/SORCERER/g
s/\bSorceror\b/Sorcerer/g
s/\bsorrounding\b/surrounding/g
s/\bSORROUNDING\b/SURROUNDING/g
s/\bSorrounding\b/Surrounding/g
s/\bsotry\b/story/g
s/\bSOTRY\b/STORY/g
s/\bSotry\b/Story/g
s/\bsoudn\b/sound/g
s/\bSOUDN\b/SOUND/g
s/\bSoudn\b/Sound/g
s/\bsoudns\b/sounds/g
s/\bSOUDNS\b/SOUNDS/g
s/\bSoudns\b/Sounds/g
s/\bsountrack\b/soundtrack/g
s/\bSOUNTRACK\b/SOUNDTRACK/g
s/\bSountrack\b/Soundtrack/g
s/\bsourth\b/south/g
s/\bSOURTH\b/SOUTH/g
s/\bSourth\b/South/g
s/\bsourthern\b/southern/g
s/\bSOURTHERN\b/SOUTHERN/g
s/\bSourthern\b/Southern/g
s/\bsouvenier\b/souvenir/g
s/\bSOUVENIER\b/SOUVENIR/g
s/\bSouvenier\b/Souvenir/g
s/\bsouveniers\b/souvenirs/g
s/\bSOUVENIERS\b/SOUVENIRS/g
s/\bSouveniers\b/Souvenirs/g
s/\bsoveits\b/soviets/g
s/\bSOVEITS\b/SOVIETS/g
s/\bSoveits\b/Soviets/g
s/\bsovereignity\b/sovereignty/g
s/\bSOVEREIGNITY\b/SOVEREIGNTY/g
s/\bSovereignity\b/Sovereignty/g
s/\bsoverign\b/sovereign/g
s/\bSOVERIGN\b/SOVEREIGN/g
s/\bSoverign\b/Sovereign/g
s/\bsoverignity\b/sovereignty/g
s/\bSOVERIGNITY\b/SOVEREIGNTY/g
s/\bSoverignity\b/Sovereignty/g
s/\bsoverignty\b/sovereignty/g
s/\bSOVERIGNTY\b/SOVEREIGNTY/g
s/\bSoverignty\b/Sovereignty/g
s/\bspainish\b/spanish/g
s/\bSPAINISH\b/SPANISH/g
s/\bSpainish\b/Spanish/g
s/\bspeach\b/speech/g
s/\bSPEACH\b/SPEECH/g
s/\bSpeach\b/Speech/g
s/\bspecifiying\b/specifying/g
s/\bSPECIFIYING\b/SPECIFYING/g
s/\bSpecifiying\b/Specifying/g
s/\bspeciman\b/specimen/g
s/\bSPECIMAN\b/SPECIMEN/g
s/\bSpeciman\b/Specimen/g
s/\bspectauclar\b/spectacular/g
s/\bSPECTAUCLAR\b/SPECTACULAR/g
s/\bSpectauclar\b/Spectacular/g
s/\bspectaulars\b/spectaculars/g
s/\bSPECTAULARS\b/SPECTACULARS/g
s/\bSpectaulars\b/Spectaculars/g
s/\bspectum\b/spectrum/g
s/\bSPECTUM\b/SPECTRUM/g
s/\bSpectum\b/Spectrum/g
s/\bspeices\b/species/g
s/\bSPEICES\b/SPECIES/g
s/\bSpeices\b/Species/g
s/\bspendour\b/splendour/g
s/\bSPENDOUR\b/SPLENDOUR/g
s/\bSpendour\b/Splendour/g
s/\bspermatozoan\b/spermatozoon/g
s/\bSPERMATOZOAN\b/SPERMATOZOON/g
s/\bSpermatozoan\b/Spermatozoon/g
s/\bspoace\b/space/g
s/\bSPOACE\b/SPACE/g
s/\bSpoace\b/Space/g
s/\bsponser\b/sponsor/g
s/\bSPONSER\b/SPONSOR/g
s/\bSponser\b/Sponsor/g
s/\bsponsered\b/sponsored/g
s/\bSPONSERED\b/SPONSORED/g
s/\bSponsered\b/Sponsored/g
s/\bspontanous\b/spontaneous/g
s/\bSPONTANOUS\b/SPONTANEOUS/g
s/\bSpontanous\b/Spontaneous/g
s/\bsponzored\b/sponsored/g
s/\bSPONZORED\b/SPONSORED/g
s/\bSponzored\b/Sponsored/g
s/\bspoonfulls\b/spoonfuls/g
s/\bSPOONFULLS\b/SPOONFULS/g
s/\bSpoonfulls\b/Spoonfuls/g
s/\bsppeches\b/speeches/g
s/\bSPPECHES\b/SPEECHES/g
s/\bSppeches\b/Speeches/g
s/\bspreaded\b/spread/g
s/\bSPREADED\b/SPREAD/g
s/\bSpreaded\b/Spread/g
s/\bsprech\b/speech/g
s/\bSPRECH\b/SPEECH/g
s/\bSprech\b/Speech/g
s/\bspred\b/spread/g
s/\bSPRED\b/SPREAD/g
s/\bSpred\b/Spread/g
s/\bspriritual\b/spiritual/g
s/\bSPRIRITUAL\b/SPIRITUAL/g
s/\bSpriritual\b/Spiritual/g
s/\bspritual\b/spiritual/g
s/\bSPRITUAL\b/SPIRITUAL/g
s/\bSpritual\b/Spiritual/g
s/\bsqaure\b/square/g
s/\bSQAURE\b/SQUARE/g
s/\bSqaure\b/Square/g
s/\bstablility\b/stability/g
s/\bSTABLILITY\b/STABILITY/g
s/\bStablility\b/Stability/g
s/\bstainlees\b/stainless/g
s/\bSTAINLEES\b/STAINLESS/g
s/\bStainlees\b/Stainless/g
s/\bstaion\b/station/g
s/\bSTAION\b/STATION/g
s/\bStaion\b/Station/g
s/\bstandars\b/standards/g
s/\bSTANDARS\b/STANDARDS/g
s/\bStandars\b/Standards/g
s/\bstange\b/strange/g
s/\bSTANGE\b/STRANGE/g
s/\bStange\b/Strange/g
s/\bstartegic\b/strategic/g
s/\bSTARTEGIC\b/STRATEGIC/g
s/\bStartegic\b/Strategic/g
s/\bstartegies\b/strategies/g
s/\bSTARTEGIES\b/STRATEGIES/g
s/\bStartegies\b/Strategies/g
s/\bstartegy\b/strategy/g
s/\bSTARTEGY\b/STRATEGY/g
s/\bStartegy\b/Strategy/g
s/\bstateman\b/statesman/g
s/\bSTATEMAN\b/STATESMAN/g
s/\bStateman\b/Statesman/g
s/\bstatememts\b/statements/g
s/\bSTATEMEMTS\b/STATEMENTS/g
s/\bStatememts\b/Statements/g
s/\bsteriods\b/steroids/g
s/\bSTERIODS\b/STEROIDS/g
s/\bSteriods\b/Steroids/g
s/\bsterotypes\b/stereotypes/g
s/\bSTEROTYPES\b/STEREOTYPES/g
s/\bSterotypes\b/Stereotypes/g
s/\bstilus\b/stylus/g
s/\bSTILUS\b/STYLUS/g
s/\bStilus\b/Stylus/g
s/\bstingent\b/stringent/g
s/\bSTINGENT\b/STRINGENT/g
s/\bStingent\b/Stringent/g
s/\bstiring\b/stirring/g
s/\bSTIRING\b/STIRRING/g
s/\bStiring\b/Stirring/g
s/\bstirrs\b/stirs/g
s/\bSTIRRS\b/STIRS/g
s/\bStirrs\b/Stirs/g
s/\bstlye\b/style/g
s/\bSTLYE\b/STYLE/g
s/\bStlye\b/Style/g
s/\bstomache\b/stomach/g
s/\bSTOMACHE\b/STOMACH/g
s/\bStomache\b/Stomach/g
s/\bstong\b/strong/g
s/\bSTONG\b/STRONG/g
s/\bStong\b/Strong/g
s/\bstopry\b/story/g
s/\bSTOPRY\b/STORY/g
s/\bStopry\b/Story/g
s/\bstoreis\b/stories/g
s/\bSTOREIS\b/STORIES/g
s/\bStoreis\b/Stories/g
s/\bstorise\b/stories/g
s/\bSTORISE\b/STORIES/g
s/\bStorise\b/Stories/g
s/\bstornegst\b/strongest/g
s/\bSTORNEGST\b/STRONGEST/g
s/\bStornegst\b/Strongest/g
s/\bstoyr\b/story/g
s/\bSTOYR\b/STORY/g
s/\bStoyr\b/Story/g
s/\bstpo\b/stop/g
s/\bSTPO\b/STOP/g
s/\bStpo\b/Stop/g
s/\bstradegies\b/strategies/g
s/\bSTRADEGIES\b/STRATEGIES/g
s/\bStradegies\b/Strategies/g
s/\bstradegy\b/strategy/g
s/\bSTRADEGY\b/STRATEGY/g
s/\bStradegy\b/Strategy/g
s/\bstratagically\b/strategically/g
s/\bSTRATAGICALLY\b/STRATEGICALLY/g
s/\bStratagically\b/Strategically/g
s/\bstreemlining\b/streamlining/g
s/\bSTREEMLINING\b/STREAMLINING/g
s/\bStreemlining\b/Streamlining/g
s/\bstregth\b/strength/g
s/\bSTREGTH\b/STRENGTH/g
s/\bStregth\b/Strength/g
s/\bstrenghen\b/strengthen/g
s/\bSTRENGHEN\b/STRENGTHEN/g
s/\bStrenghen\b/Strengthen/g
s/\bstrenghened\b/strengthened/g
s/\bSTRENGHENED\b/STRENGTHENED/g
s/\bStrenghened\b/Strengthened/g
s/\bstrenghening\b/strengthening/g
s/\bSTRENGHENING\b/STRENGTHENING/g
s/\bStrenghening\b/Strengthening/g
s/\bstrenght\b/strength/g
s/\bSTRENGHT\b/STRENGTH/g
s/\bStrenght\b/Strength/g
s/\bstrenghten\b/strengthen/g
s/\bSTRENGHTEN\b/STRENGTHEN/g
s/\bStrenghten\b/Strengthen/g
s/\bstrenghtened\b/strengthened/g
s/\bSTRENGHTENED\b/STRENGTHENED/g
s/\bStrenghtened\b/Strengthened/g
s/\bstrenghtening\b/strengthening/g
s/\bSTRENGHTENING\b/STRENGTHENING/g
s/\bStrenghtening\b/Strengthening/g
s/\bstrengtened\b/strengthened/g
s/\bSTRENGTENED\b/STRENGTHENED/g
s/\bStrengtened\b/Strengthened/g
s/\bstrenous\b/strenuous/g
s/\bSTRENOUS\b/STRENUOUS/g
s/\bStrenous\b/Strenuous/g
s/\bstrictist\b/strictest/g
s/\bSTRICTIST\b/STRICTEST/g
s/\bStrictist\b/Strictest/g
s/\bstrikely\b/strikingly/g
s/\bSTRIKELY\b/STRIKINGLY/g
s/\bStrikely\b/Strikingly/g
s/\bstrnad\b/strand/g
s/\bSTRNAD\b/STRAND/g
s/\bStrnad\b/Strand/g
s/\bstructual\b/structural/g
s/\bSTRUCTUAL\b/STRUCTURAL/g
s/\bStructual\b/Structural/g
s/\bstubborness\b/stubbornness/g
s/\bSTUBBORNESS\b/STUBBORNNESS/g
s/\bStubborness\b/Stubbornness/g
s/\bstucture\b/structure/g
s/\bSTUCTURE\b/STRUCTURE/g
s/\bStucture\b/Structure/g
s/\bstuctured\b/structured/g
s/\bSTUCTURED\b/STRUCTURED/g
s/\bStuctured\b/Structured/g
s/\bstuddy\b/study/g
s/\bSTUDDY\b/STUDY/g
s/\bStuddy\b/Study/g
s/\bstuding\b/studying/g
s/\bSTUDING\b/STUDYING/g
s/\bStuding\b/Studying/g
s/\bstuggling\b/struggling/g
s/\bSTUGGLING\b/STRUGGLING/g
s/\bStuggling\b/Struggling/g
s/\bsturcture\b/structure/g
s/\bSTURCTURE\b/STRUCTURE/g
s/\bSturcture\b/Structure/g
s/\bsubconsiously\b/subconsciously/g
s/\bSUBCONSIOUSLY\b/SUBCONSCIOUSLY/g
s/\bSubconsiously\b/Subconsciously/g
s/\bsubjudgation\b/subjugation/g
s/\bSUBJUDGATION\b/SUBJUGATION/g
s/\bSubjudgation\b/Subjugation/g
s/\bsubmachne\b/submachine/g
s/\bSUBMACHNE\b/SUBMACHINE/g
s/\bSubmachne\b/Submachine/g
s/\bsubpecies\b/subspecies/g
s/\bSUBPECIES\b/SUBSPECIES/g
s/\bSubpecies\b/Subspecies/g
s/\bsubsidary\b/subsidiary/g
s/\bSUBSIDARY\b/SUBSIDIARY/g
s/\bSubsidary\b/Subsidiary/g
s/\bsubsquent\b/subsequent/g
s/\bSUBSQUENT\b/SUBSEQUENT/g
s/\bSubsquent\b/Subsequent/g
s/\bsubsquently\b/subsequently/g
s/\bSUBSQUENTLY\b/SUBSEQUENTLY/g
s/\bSubsquently\b/Subsequently/g
s/\bsubstace\b/substance/g
s/\bSUBSTACE\b/SUBSTANCE/g
s/\bSubstace\b/Substance/g
s/\bsubstancial\b/substantial/g
s/\bSUBSTANCIAL\b/SUBSTANTIAL/g
s/\bSubstancial\b/Substantial/g
s/\bsubstatial\b/substantial/g
s/\bSUBSTATIAL\b/SUBSTANTIAL/g
s/\bSubstatial\b/Substantial/g
s/\bsubstituded\b/substituted/g
s/\bSUBSTITUDED\b/SUBSTITUTED/g
s/\bSubstituded\b/Substituted/g
s/\bsubstracted\b/subtracted/g
s/\bSUBSTRACTED\b/SUBTRACTED/g
s/\bSubstracted\b/Subtracted/g
s/\bsubstracting\b/subtracting/g
s/\bSUBSTRACTING\b/SUBTRACTING/g
s/\bSubstracting\b/Subtracting/g
s/\bsubstraction\b/subtraction/g
s/\bSUBSTRACTION\b/SUBTRACTION/g
s/\bSubstraction\b/Subtraction/g
s/\bsubtances\b/substances/g
s/\bSUBTANCES\b/SUBSTANCES/g
s/\bSubtances\b/Substances/g
s/\bsubterranian\b/subterranean/g
s/\bSUBTERRANIAN\b/SUBTERRANEAN/g
s/\bSubterranian\b/Subterranean/g
s/\bsuburburban\b/suburban/g
s/\bSUBURBURBAN\b/SUBURBAN/g
s/\bSuburburban\b/Suburban/g
s/\bsuccceeded\b/succeeded/g
s/\bSUCCCEEDED\b/SUCCEEDED/g
s/\bSuccceeded\b/Succeeded/g
s/\bsucccesses\b/successes/g
s/\bSUCCCESSES\b/SUCCESSES/g
s/\bSucccesses\b/Successes/g
s/\bsuccedded\b/succeeded/g
s/\bSUCCEDDED\b/SUCCEEDED/g
s/\bSuccedded\b/Succeeded/g
s/\bsucceds\b/succeeds/g
s/\bSUCCEDS\b/SUCCEEDS/g
s/\bSucceds\b/Succeeds/g
s/\bsuccesion\b/succession/g
s/\bSUCCESION\b/SUCCESSION/g
s/\bSuccesion\b/Succession/g
s/\bsuccesive\b/successive/g
s/\bSUCCESIVE\b/SUCCESSIVE/g
s/\bSuccesive\b/Successive/g
s/\bsuccessully\b/successfully/g
s/\bSUCCESSULLY\b/SUCCESSFULLY/g
s/\bSuccessully\b/Successfully/g
s/\bsuccsess\b/success/g
s/\bSUCCSESS\b/SUCCESS/g
s/\bSuccsess\b/Success/g
s/\bsuccsessfull\b/successful/g
s/\bSUCCSESSFULL\b/SUCCESSFUL/g
s/\bSuccsessfull\b/Successful/g
s/\bsuceed\b/succeed/g
s/\bSUCEED\b/SUCCEED/g
s/\bSuceed\b/Succeed/g
s/\bsuceeded\b/succeeded/g
s/\bSUCEEDED\b/SUCCEEDED/g
s/\bSuceeded\b/Succeeded/g
s/\bsuceeding\b/succeeding/g
s/\bSUCEEDING\b/SUCCEEDING/g
s/\bSuceeding\b/Succeeding/g
s/\bsuceeds\b/succeeds/g
s/\bSUCEEDS\b/SUCCEEDS/g
s/\bSuceeds\b/Succeeds/g
s/\bsucesful\b/successful/g
s/\bSUCESFUL\b/SUCCESSFUL/g
s/\bSucesful\b/Successful/g
s/\bsucesfully\b/successfully/g
s/\bSUCESFULLY\b/SUCCESSFULLY/g
s/\bSucesfully\b/Successfully/g
s/\bsucesfuly\b/successfully/g
s/\bSUCESFULY\b/SUCCESSFULLY/g
s/\bSucesfuly\b/Successfully/g
s/\bsucesion\b/succession/g
s/\bSUCESION\b/SUCCESSION/g
s/\bSucesion\b/Succession/g
s/\bsucide\b/suicide/g
s/\bSUCIDE\b/SUICIDE/g
s/\bSucide\b/Suicide/g
s/\bsucidial\b/suicidal/g
s/\bSUCIDIAL\b/SUICIDAL/g
s/\bSucidial\b/Suicidal/g
s/\bsufferage\b/suffrage/g
s/\bSUFFERAGE\b/SUFFRAGE/g
s/\bSufferage\b/Suffrage/g
s/\bsufferred\b/suffered/g
s/\bSUFFERRED\b/SUFFERED/g
s/\bSufferred\b/Suffered/g
s/\bsufferring\b/suffering/g
s/\bSUFFERRING\b/SUFFERING/g
s/\bSufferring\b/Suffering/g
s/\bsufficent\b/sufficient/g
s/\bSUFFICENT\b/SUFFICIENT/g
s/\bSufficent\b/Sufficient/g
s/\bsufficently\b/sufficiently/g
s/\bSUFFICENTLY\b/SUFFICIENTLY/g
s/\bSufficently\b/Sufficiently/g
s/\bsumary\b/summary/g
s/\bSUMARY\b/SUMMARY/g
s/\bSumary\b/Summary/g
s/\bsunglases\b/sunglasses/g
s/\bSUNGLASES\b/SUNGLASSES/g
s/\bSunglases\b/Sunglasses/g
s/\bsuop\b/soup/g
s/\bSUOP\b/SOUP/g
s/\bSuop\b/Soup/g
s/\bsuperceeded\b/superseded/g
s/\bSUPERCEEDED\b/SUPERSEDED/g
s/\bSuperceeded\b/Superseded/g
s/\bsuperintendant\b/superintendent/g
s/\bSUPERINTENDANT\b/SUPERINTENDENT/g
s/\bSuperintendant\b/Superintendent/g
s/\bsuphisticated\b/sophisticated/g
s/\bSUPHISTICATED\b/SOPHISTICATED/g
s/\bSuphisticated\b/Sophisticated/g
s/\bsuplimented\b/supplemented/g
s/\bSUPLIMENTED\b/SUPPLEMENTED/g
s/\bSuplimented\b/Supplemented/g
s/\bsupose\b/suppose/g
s/\bSUPOSE\b/SUPPOSE/g
s/\bSupose\b/Suppose/g
s/\bsuposed\b/supposed/g
s/\bSUPOSED\b/SUPPOSED/g
s/\bSuposed\b/Supposed/g
s/\bsuposedly\b/supposedly/g
s/\bSUPOSEDLY\b/SUPPOSEDLY/g
s/\bSuposedly\b/Supposedly/g
s/\bsuposes\b/supposes/g
s/\bSUPOSES\b/SUPPOSES/g
s/\bSuposes\b/Supposes/g
s/\bsuposing\b/supposing/g
s/\bSUPOSING\b/SUPPOSING/g
s/\bSuposing\b/Supposing/g
s/\bsupplamented\b/supplemented/g
s/\bSUPPLAMENTED\b/SUPPLEMENTED/g
s/\bSupplamented\b/Supplemented/g
s/\bsuppliementing\b/supplementing/g
s/\bSUPPLIEMENTING\b/SUPPLEMENTING/g
s/\bSuppliementing\b/Supplementing/g
s/\bsuppoed\b/supposed/g
s/\bSUPPOED\b/SUPPOSED/g
s/\bSuppoed\b/Supposed/g
s/\bsupposingly\b/supposedly/g
s/\bSUPPOSINGLY\b/SUPPOSEDLY/g
s/\bSupposingly\b/Supposedly/g
s/\bsuppy\b/supply/g
s/\bSUPPY\b/SUPPLY/g
s/\bSuppy\b/Supply/g
s/\bsuprise\b/surprise/g
s/\bSUPRISE\b/SURPRISE/g
s/\bSuprise\b/Surprise/g
s/\bsuprised\b/surprised/g
s/\bSUPRISED\b/SURPRISED/g
s/\bSuprised\b/Surprised/g
s/\bsuprising\b/surprising/g
s/\bSUPRISING\b/SURPRISING/g
s/\bSuprising\b/Surprising/g
s/\bsuprisingly\b/surprisingly/g
s/\bSUPRISINGLY\b/SURPRISINGLY/g
s/\bSuprisingly\b/Surprisingly/g
s/\bsuprize\b/surprise/g
s/\bSUPRIZE\b/SURPRISE/g
s/\bSuprize\b/Surprise/g
s/\bsuprized\b/surprised/g
s/\bSUPRIZED\b/SURPRISED/g
s/\bSuprized\b/Surprised/g
s/\bsuprizing\b/surprising/g
s/\bSUPRIZING\b/SURPRISING/g
s/\bSuprizing\b/Surprising/g
s/\bsuprizingly\b/surprisingly/g
s/\bSUPRIZINGLY\b/SURPRISINGLY/g
s/\bSuprizingly\b/Surprisingly/g
s/\bsurfce\b/surface/g
s/\bSURFCE\b/SURFACE/g
s/\bSurfce\b/Surface/g
s/\bsuround\b/surround/g
s/\bSUROUND\b/SURROUND/g
s/\bSuround\b/Surround/g
s/\bsurounded\b/surrounded/g
s/\bSUROUNDED\b/SURROUNDED/g
s/\bSurounded\b/Surrounded/g
s/\bsurounding\b/surrounding/g
s/\bSUROUNDING\b/SURROUNDING/g
s/\bSurounding\b/Surrounding/g
s/\bsuroundings\b/surroundings/g
s/\bSUROUNDINGS\b/SURROUNDINGS/g
s/\bSuroundings\b/Surroundings/g
s/\bsurounds\b/surrounds/g
s/\bSUROUNDS\b/SURROUNDS/g
s/\bSurounds\b/Surrounds/g
s/\bsurplanted\b/supplanted/g
s/\bSURPLANTED\b/SUPPLANTED/g
s/\bSurplanted\b/Supplanted/g
s/\bsurpress\b/suppress/g
s/\bSURPRESS\b/SUPPRESS/g
s/\bSurpress\b/Suppress/g
s/\bsurpressed\b/suppressed/g
s/\bSURPRESSED\b/SUPPRESSED/g
s/\bSurpressed\b/Suppressed/g
s/\bsurprize\b/surprise/g
s/\bSURPRIZE\b/SURPRISE/g
s/\bSurprize\b/Surprise/g
s/\bsurprized\b/surprised/g
s/\bSURPRIZED\b/SURPRISED/g
s/\bSurprized\b/Surprised/g
s/\bsurprizing\b/surprising/g
s/\bSURPRIZING\b/SURPRISING/g
s/\bSurprizing\b/Surprising/g
s/\bsurprizingly\b/surprisingly/g
s/\bSURPRIZINGLY\b/SURPRISINGLY/g
s/\bSurprizingly\b/Surprisingly/g
s/\bsurrepetitious\b/surreptitious/g
s/\bSURREPETITIOUS\b/SURREPTITIOUS/g
s/\bSurrepetitious\b/Surreptitious/g
s/\bsurrepetitiously\b/surreptitiously/g
s/\bSURREPETITIOUSLY\b/SURREPTITIOUSLY/g
s/\bSurrepetitiously\b/Surreptitiously/g
s/\bsurreptious\b/surreptitious/g
s/\bSURREPTIOUS\b/SURREPTITIOUS/g
s/\bSurreptious\b/Surreptitious/g
s/\bsurreptiously\b/surreptitiously/g
s/\bSURREPTIOUSLY\b/SURREPTITIOUSLY/g
s/\bSurreptiously\b/Surreptitiously/g
s/\bsurronded\b/surrounded/g
s/\bSURRONDED\b/SURROUNDED/g
s/\bSurronded\b/Surrounded/g
s/\bsurrouded\b/surrounded/g
s/\bSURROUDED\b/SURROUNDED/g
s/\bSurrouded\b/Surrounded/g
s/\bsurrouding\b/surrounding/g
s/\bSURROUDING\b/SURROUNDING/g
s/\bSurrouding\b/Surrounding/g
s/\bsurrundering\b/surrendering/g
s/\bSURRUNDERING\b/SURRENDERING/g
s/\bSurrundering\b/Surrendering/g
s/\bsurveilence\b/surveillance/g
s/\bSURVEILENCE\b/SURVEILLANCE/g
s/\bSurveilence\b/Surveillance/g
s/\bsurveill\b/surveil/g
s/\bSURVEILL\b/SURVEIL/g
s/\bSurveill\b/Surveil/g
s/\bsurveyer\b/surveyor/g
s/\bSURVEYER\b/SURVEYOR/g
s/\bSurveyer\b/Surveyor/g
s/\bsurviver\b/survivor/g
s/\bSURVIVER\b/SURVIVOR/g
s/\bSurviver\b/Survivor/g
s/\bsurvivers\b/survivors/g
s/\bSURVIVERS\b/SURVIVORS/g
s/\bSurvivers\b/Survivors/g
s/\bsurvivied\b/survived/g
s/\bSURVIVIED\b/SURVIVED/g
s/\bSurvivied\b/Survived/g
s/\bsuseptable\b/susceptible/g
s/\bSUSEPTABLE\b/SUSCEPTIBLE/g
s/\bSuseptable\b/Susceptible/g
s/\bsuseptible\b/susceptible/g
s/\bSUSEPTIBLE\b/SUSCEPTIBLE/g
s/\bSuseptible\b/Susceptible/g
s/\bsuspention\b/suspension/g
s/\bSUSPENTION\b/SUSPENSION/g
s/\bSuspention\b/Suspension/g
s/\bswaer\b/swear/g
s/\bSWAER\b/SWEAR/g
s/\bSwaer\b/Swear/g
s/\bswaers\b/swears/g
s/\bSWAERS\b/SWEARS/g
s/\bSwaers\b/Swears/g
s/\bswepth\b/swept/g
s/\bSWEPTH\b/SWEPT/g
s/\bSwepth\b/Swept/g
s/\bswiming\b/swimming/g
s/\bSWIMING\b/SWIMMING/g
s/\bSwiming\b/Swimming/g
s/\bsyas\b/says/g
s/\bSYAS\b/SAYS/g
s/\bSyas\b/Says/g
s/\bsymetrical\b/symmetrical/g
s/\bSYMETRICAL\b/SYMMETRICAL/g
s/\bSymetrical\b/Symmetrical/g
s/\bsymetrically\b/symmetrically/g
s/\bSYMETRICALLY\b/SYMMETRICALLY/g
s/\bSymetrically\b/Symmetrically/g
s/\bsymetry\b/symmetry/g
s/\bSYMETRY\b/SYMMETRY/g
s/\bSymetry\b/Symmetry/g
s/\bsymettric\b/symmetric/g
s/\bSYMETTRIC\b/SYMMETRIC/g
s/\bSymettric\b/Symmetric/g
s/\bsymmetral\b/symmetric/g
s/\bSYMMETRAL\b/SYMMETRIC/g
s/\bSymmetral\b/Symmetric/g
s/\bsymmetricaly\b/symmetrically/g
s/\bSYMMETRICALY\b/SYMMETRICALLY/g
s/\bSymmetricaly\b/Symmetrically/g
s/\bsynagouge\b/synagogue/g
s/\bSYNAGOUGE\b/SYNAGOGUE/g
s/\bSynagouge\b/Synagogue/g
s/\bsyncronization\b/synchronization/g
s/\bSYNCRONIZATION\b/SYNCHRONIZATION/g
s/\bSyncronization\b/Synchronization/g
s/\bsynonomous\b/synonymous/g
s/\bSYNONOMOUS\b/SYNONYMOUS/g
s/\bSynonomous\b/Synonymous/g
s/\bsynonymns\b/synonyms/g
s/\bSYNONYMNS\b/SYNONYMS/g
s/\bSynonymns\b/Synonyms/g
s/\bsynphony\b/symphony/g
s/\bSYNPHONY\b/SYMPHONY/g
s/\bSynphony\b/Symphony/g
s/\bsyphyllis\b/syphilis/g
s/\bSYPHYLLIS\b/SYPHILIS/g
s/\bSyphyllis\b/Syphilis/g
s/\bsypmtoms\b/symptoms/g
s/\bSYPMTOMS\b/SYMPTOMS/g
s/\bSypmtoms\b/Symptoms/g
s/\bsyrap\b/syrup/g
s/\bSYRAP\b/SYRUP/g
s/\bSyrap\b/Syrup/g
s/\bsysmatically\b/systematically/g
s/\bSYSMATICALLY\b/SYSTEMATICALLY/g
s/\bSysmatically\b/Systematically/g
s/\bsytle\b/style/g
s/\bSYTLE\b/STYLE/g
s/\bSytle\b/Style/g
s/\btabacco\b/tobacco/g
s/\bTABACCO\b/TOBACCO/g
s/\bTabacco\b/Tobacco/g
s/\btahn\b/than/g
s/\bTAHN\b/THAN/g
s/\bTahn\b/Than/g
s/\btaht\b/that/g
s/\bTAHT\b/THAT/g
s/\bTaht\b/That/g
s/\btalekd\b/talked/g
s/\bTALEKD\b/TALKED/g
s/\bTalekd\b/Talked/g
s/\btast\b/taste/g
s/\bTAST\b/TASTE/g
s/\bTast\b/Taste/g
s/\btath\b/that/g
s/\bTATH\b/THAT/g
s/\bTath\b/That/g
s/\btattooes\b/tattoos/g
s/\bTATTOOES\b/TATTOOS/g
s/\bTattooes\b/Tattoos/g
s/\btaxanomic\b/taxonomic/g
s/\bTAXANOMIC\b/TAXONOMIC/g
s/\bTaxanomic\b/Taxonomic/g
s/\btaxanomy\b/taxonomy/g
s/\bTAXANOMY\b/TAXONOMY/g
s/\bTaxanomy\b/Taxonomy/g
s/\bteached\b/taught/g
s/\bTEACHED\b/TAUGHT/g
s/\bTeached\b/Taught/g
s/\btechician\b/technician/g
s/\bTECHICIAN\b/TECHNICIAN/g
s/\bTechician\b/Technician/g
s/\btechicians\b/technicians/g
s/\bTECHICIANS\b/TECHNICIANS/g
s/\bTechicians\b/Technicians/g
s/\btechiniques\b/techniques/g
s/\bTECHINIQUES\b/TECHNIQUES/g
s/\bTechiniques\b/Techniques/g
s/\btechnitian\b/technician/g
s/\bTECHNITIAN\b/TECHNICIAN/g
s/\bTechnitian\b/Technician/g
s/\btechnnology\b/technology/g
s/\bTECHNNOLOGY\b/TECHNOLOGY/g
s/\bTechnnology\b/Technology/g
s/\btechnolgy\b/technology/g
s/\bTECHNOLGY\b/TECHNOLOGY/g
s/\bTechnolgy\b/Technology/g
s/\btehy\b/they/g
s/\bTEHY\b/THEY/g
s/\bTehy\b/They/g
s/\btelelevision\b/television/g
s/\bTELELEVISION\b/TELEVISION/g
s/\bTelelevision\b/Television/g
s/\btelevsion\b/television/g
s/\bTELEVSION\b/TELEVISION/g
s/\bTelevsion\b/Television/g
s/\btelphony\b/telephony/g
s/\bTELPHONY\b/TELEPHONY/g
s/\bTelphony\b/Telephony/g
s/\btemerature\b/temperature/g
s/\bTEMERATURE\b/TEMPERATURE/g
s/\bTemerature\b/Temperature/g
s/\btempalte\b/template/g
s/\bTEMPALTE\b/TEMPLATE/g
s/\bTempalte\b/Template/g
s/\btempaltes\b/templates/g
s/\bTEMPALTES\b/TEMPLATES/g
s/\bTempaltes\b/Templates/g
s/\btemparate\b/temperate/g
s/\bTEMPARATE\b/TEMPERATE/g
s/\bTemparate\b/Temperate/g
s/\btemperarily\b/temporarily/g
s/\bTEMPERARILY\b/TEMPORARILY/g
s/\bTemperarily\b/Temporarily/g
s/\btemperment\b/temperament/g
s/\bTEMPERMENT\b/TEMPERAMENT/g
s/\bTemperment\b/Temperament/g
s/\btempertaure\b/temperature/g
s/\bTEMPERTAURE\b/TEMPERATURE/g
s/\bTempertaure\b/Temperature/g
s/\btemperture\b/temperature/g
s/\bTEMPERTURE\b/TEMPERATURE/g
s/\bTemperture\b/Temperature/g
s/\btemprary\b/temporary/g
s/\bTEMPRARY\b/TEMPORARY/g
s/\bTemprary\b/Temporary/g
s/\btenacle\b/tentacle/g
s/\bTENACLE\b/TENTACLE/g
s/\bTenacle\b/Tentacle/g
s/\btenacles\b/tentacles/g
s/\bTENACLES\b/TENTACLES/g
s/\bTenacles\b/Tentacles/g
s/\btendacy\b/tendency/g
s/\bTENDACY\b/TENDENCY/g
s/\bTendacy\b/Tendency/g
s/\btendancies\b/tendencies/g
s/\bTENDANCIES\b/TENDENCIES/g
s/\bTendancies\b/Tendencies/g
s/\btendancy\b/tendency/g
s/\bTENDANCY\b/TENDENCY/g
s/\bTendancy\b/Tendency/g
s/\btennisplayer\b/tennis player/g
s/\bTENNISPLAYER\b/TENNIS PLAYER/g
s/\bTennisplayer\b/Tennis player/g
s/\btepmorarily\b/temporarily/g
s/\bTEPMORARILY\b/TEMPORARILY/g
s/\bTepmorarily\b/Temporarily/g
s/\bterrestial\b/terrestrial/g
s/\bTERRESTIAL\b/TERRESTRIAL/g
s/\bTerrestial\b/Terrestrial/g
s/\bterriories\b/territories/g
s/\bTERRIORIES\b/TERRITORIES/g
s/\bTerriories\b/Territories/g
s/\bterriory\b/territory/g
s/\bTERRIORY\b/TERRITORY/g
s/\bTerriory\b/Territory/g
s/\bterritorist\b/terrorist/g
s/\bTERRITORIST\b/TERRORIST/g
s/\bTerritorist\b/Terrorist/g
s/\bterritoy\b/territory/g
s/\bTERRITOY\b/TERRITORY/g
s/\bTerritoy\b/Territory/g
s/\bterroist\b/terrorist/g
s/\bTERROIST\b/TERRORIST/g
s/\bTerroist\b/Terrorist/g
s/\btesticlular\b/testicular/g
s/\bTESTICLULAR\b/TESTICULAR/g
s/\bTesticlular\b/Testicular/g
s/\btestomony\b/testimony/g
s/\bTESTOMONY\b/TESTIMONY/g
s/\bTestomony\b/Testimony/g
s/\btghe\b/the/g
s/\bTGHE\b/THE/g
s/\bTghe\b/The/g
s/\btheather\b/theater/g
s/\bTHEATHER\b/THEATER/g
s/\bTheather\b/Theater/g
s/\btheif\b/thief/g
s/\bTHEIF\b/THIEF/g
s/\bTheif\b/Thief/g
s/\btheives\b/thieves/g
s/\bTHEIVES\b/THIEVES/g
s/\bTheives\b/Thieves/g
s/\bthemselfs\b/themselves/g
s/\bTHEMSELFS\b/THEMSELVES/g
s/\bThemselfs\b/Themselves/g
s/\bthemslves\b/themselves/g
s/\bTHEMSLVES\b/THEMSELVES/g
s/\bThemslves\b/Themselves/g
s/\btherafter\b/thereafter/g
s/\bTHERAFTER\b/THEREAFTER/g
s/\bTherafter\b/Thereafter/g
s/\btherby\b/thereby/g
s/\bTHERBY\b/THEREBY/g
s/\bTherby\b/Thereby/g
s/\btheri\b/their/g
s/\bTHERI\b/THEIR/g
s/\bTheri\b/Their/g
s/\btheyre\b/they're/g
s/\bTHEYRE\b/THEY'RE/g
s/\bTheyre\b/They're/g
s/\bthgat\b/that/g
s/\bTHGAT\b/THAT/g
s/\bThgat\b/That/g
s/\bthge\b/the/g
s/\bTHGE\b/THE/g
s/\bThge\b/The/g
s/\bthier\b/their/g
s/\bTHIER\b/THEIR/g
s/\bThier\b/Their/g
s/\bthign\b/thing/g
s/\bTHIGN\b/THING/g
s/\bThign\b/Thing/g
s/\bthigns\b/things/g
s/\bTHIGNS\b/THINGS/g
s/\bThigns\b/Things/g
s/\bthigsn\b/things/g
s/\bTHIGSN\b/THINGS/g
s/\bThigsn\b/Things/g
s/\bthikn\b/think/g
s/\bTHIKN\b/THINK/g
s/\bThikn\b/Think/g
s/\bthikns\b/thinks/g
s/\bTHIKNS\b/THINKS/g
s/\bThikns\b/Thinks/g
s/\bthiunk\b/think/g
s/\bTHIUNK\b/THINK/g
s/\bThiunk\b/Think/g
s/\bthn\b/then/g
s/\bTHN\b/THEN/g
s/\bThn\b/Then/g
s/\bthna\b/than/g
s/\bTHNA\b/THAN/g
s/\bThna\b/Than/g
s/\bthne\b/then/g
s/\bTHNE\b/THEN/g
s/\bThne\b/Then/g
s/\bthnig\b/thing/g
s/\bTHNIG\b/THING/g
s/\bThnig\b/Thing/g
s/\bthnigs\b/things/g
s/\bTHNIGS\b/THINGS/g
s/\bThnigs\b/Things/g
s/\bthoughout\b/throughout/g
s/\bTHOUGHOUT\b/THROUGHOUT/g
s/\bThoughout\b/Throughout/g
s/\bthreatend\b/threatened/g
s/\bTHREATEND\b/THREATENED/g
s/\bThreatend\b/Threatened/g
s/\bthreatning\b/threatening/g
s/\bTHREATNING\b/THREATENING/g
s/\bThreatning\b/Threatening/g
s/\bthreee\b/three/g
s/\bTHREEE\b/THREE/g
s/\bThreee\b/Three/g
s/\bthrid\b/third/g
s/\bTHRID\b/THIRD/g
s/\bThrid\b/Third/g
s/\bthrorough\b/thorough/g
s/\bTHROROUGH\b/THOROUGH/g
s/\bThrorough\b/Thorough/g
s/\bthroughly\b/thoroughly/g
s/\bTHROUGHLY\b/THOROUGHLY/g
s/\bThroughly\b/Thoroughly/g
s/\bthrougout\b/throughout/g
s/\bTHROUGOUT\b/THROUGHOUT/g
s/\bThrougout\b/Throughout/g
s/\bthsi\b/this/g
s/\bTHSI\b/THIS/g
s/\bThsi\b/This/g
s/\bthsoe\b/those/g
s/\bTHSOE\b/THOSE/g
s/\bThsoe\b/Those/g
s/\bthyat\b/that/g
s/\bTHYAT\b/THAT/g
s/\bThyat\b/That/g
s/\btihkn\b/think/g
s/\bTIHKN\b/THINK/g
s/\bTihkn\b/Think/g
s/\btihs\b/this/g
s/\bTIHS\b/THIS/g
s/\bTihs\b/This/g
s/\btimne\b/time/g
s/\bTIMNE\b/TIME/g
s/\bTimne\b/Time/g
s/\btje\b/the/g
s/\bTJE\b/THE/g
s/\bTje\b/The/g
s/\btjhe\b/the/g
s/\bTJHE\b/THE/g
s/\bTjhe\b/The/g
s/\btjpanishad\b/upanishad/g
s/\bTJPANISHAD\b/UPANISHAD/g
s/\bTjpanishad\b/Upanishad/g
s/\btkae\b/take/g
s/\bTKAE\b/TAKE/g
s/\bTkae\b/Take/g
s/\btkaes\b/takes/g
s/\bTKAES\b/TAKES/g
s/\bTkaes\b/Takes/g
s/\btkaing\b/taking/g
s/\bTKAING\b/TAKING/g
s/\bTkaing\b/Taking/g
s/\btlaking\b/talking/g
s/\bTLAKING\b/TALKING/g
s/\bTlaking\b/Talking/g
s/\btobbaco\b/tobacco/g
s/\bTOBBACO\b/TOBACCO/g
s/\bTobbaco\b/Tobacco/g
s/\btodays\b/today's/g
s/\bTODAYS\b/TODAY'S/g
s/\bTodays\b/Today's/g
s/\btodya\b/today/g
s/\bTODYA\b/TODAY/g
s/\bTodya\b/Today/g
s/\btoghether\b/together/g
s/\bTOGHETHER\b/TOGETHER/g
s/\bToghether\b/Together/g
s/\btolerence\b/tolerance/g
s/\bTOLERENCE\b/TOLERANCE/g
s/\bTolerence\b/Tolerance/g
s/\btomatos\b/tomatoes/g
s/\bTOMATOS\b/TOMATOES/g
s/\bTomatos\b/Tomatoes/g
s/\btommorow\b/tomorrow/g
s/\bTOMMOROW\b/TOMORROW/g
s/\bTommorow\b/Tomorrow/g
s/\btommorrow\b/tomorrow/g
s/\bTOMMORROW\b/TOMORROW/g
s/\bTommorrow\b/Tomorrow/g
s/\btongiht\b/tonight/g
s/\bTONGIHT\b/TONIGHT/g
s/\bTongiht\b/Tonight/g
s/\btoriodal\b/toroidal/g
s/\bTORIODAL\b/TOROIDAL/g
s/\bToriodal\b/Toroidal/g
s/\btormenters\b/tormentors/g
s/\bTORMENTERS\b/TORMENTORS/g
s/\bTormenters\b/Tormentors/g
s/\btornadoe\b/tornado/g
s/\bTORNADOE\b/TORNADO/g
s/\bTornadoe\b/Tornado/g
s/\btorpeados\b/torpedoes/g
s/\bTORPEADOS\b/TORPEDOES/g
s/\bTorpeados\b/Torpedoes/g
s/\btorpedos\b/torpedoes/g
s/\bTORPEDOS\b/TORPEDOES/g
s/\bTorpedos\b/Torpedoes/g
s/\btothe\b/to the/g
s/\bTOTHE\b/TO THE/g
s/\bTothe\b/To the/g
s/\btoubles\b/troubles/g
s/\bTOUBLES\b/TROUBLES/g
s/\bToubles\b/Troubles/g
s/\btounge\b/tongue/g
s/\bTOUNGE\b/TONGUE/g
s/\bTounge\b/Tongue/g
s/\btowords\b/towards/g
s/\bTOWORDS\b/TOWARDS/g
s/\bTowords\b/Towards/g
s/\btowrad\b/toward/g
s/\bTOWRAD\b/TOWARD/g
s/\bTowrad\b/Toward/g
s/\btradionally\b/traditionally/g
s/\bTRADIONALLY\b/TRADITIONALLY/g
s/\bTradionally\b/Traditionally/g
s/\btraditionaly\b/traditionally/g
s/\bTRADITIONALY\b/TRADITIONALLY/g
s/\bTraditionaly\b/Traditionally/g
s/\btraditionnal\b/traditional/g
s/\bTRADITIONNAL\b/TRADITIONAL/g
s/\bTraditionnal\b/Traditional/g
s/\btraditition\b/tradition/g
s/\bTRADITITION\b/TRADITION/g
s/\bTraditition\b/Tradition/g
s/\btradtionally\b/traditionally/g
s/\bTRADTIONALLY\b/TRADITIONALLY/g
s/\bTradtionally\b/Traditionally/g
s/\btrafficed\b/trafficked/g
s/\bTRAFFICED\b/TRAFFICKED/g
s/\bTrafficed\b/Trafficked/g
s/\btrafficing\b/trafficking/g
s/\bTRAFFICING\b/TRAFFICKING/g
s/\bTrafficing\b/Trafficking/g
s/\btrafic\b/traffic/g
s/\bTRAFIC\b/TRAFFIC/g
s/\bTrafic\b/Traffic/g
s/\btrancendent\b/transcendent/g
s/\bTRANCENDENT\b/TRANSCENDENT/g
s/\bTrancendent\b/Transcendent/g
s/\btrancending\b/transcending/g
s/\bTRANCENDING\b/TRANSCENDING/g
s/\bTrancending\b/Transcending/g
s/\btranform\b/transform/g
s/\bTRANFORM\b/TRANSFORM/g
s/\bTranform\b/Transform/g
s/\btranformed\b/transformed/g
s/\bTRANFORMED\b/TRANSFORMED/g
s/\bTranformed\b/Transformed/g
s/\btranscendance\b/transcendence/g
s/\bTRANSCENDANCE\b/TRANSCENDENCE/g
s/\bTranscendance\b/Transcendence/g
s/\btranscendant\b/transcendent/g
s/\bTRANSCENDANT\b/TRANSCENDENT/g
s/\bTranscendant\b/Transcendent/g
s/\btranscendentational\b/transcendental/g
s/\bTRANSCENDENTATIONAL\b/TRANSCENDENTAL/g
s/\bTranscendentational\b/Transcendental/g
s/\btransending\b/transcending/g
s/\bTRANSENDING\b/TRANSCENDING/g
s/\bTransending\b/Transcending/g
s/\btransesxuals\b/transsexuals/g
s/\bTRANSESXUALS\b/TRANSSEXUALS/g
s/\bTransesxuals\b/Transsexuals/g
s/\btransformaton\b/transformation/g
s/\bTRANSFORMATON\b/TRANSFORMATION/g
s/\bTransformaton\b/Transformation/g
s/\btranslater\b/translator/g
s/\bTRANSLATER\b/TRANSLATOR/g
s/\bTranslater\b/Translator/g
s/\btranslaters\b/translators/g
s/\bTRANSLATERS\b/TRANSLATORS/g
s/\bTranslaters\b/Translators/g
s/\btransmissable\b/transmissible/g
s/\bTRANSMISSABLE\b/TRANSMISSIBLE/g
s/\bTransmissable\b/Transmissible/g
s/\btransporation\b/transportation/g
s/\bTRANSPORATION\b/TRANSPORTATION/g
s/\bTransporation\b/Transportation/g
s/\btremelo\b/tremolo/g
s/\bTREMELO\b/TREMOLO/g
s/\bTremelo\b/Tremolo/g
s/\btremelos\b/tremolos/g
s/\bTREMELOS\b/TREMOLOS/g
s/\bTremelos\b/Tremolos/g
s/\btriguered\b/triggered/g
s/\bTRIGUERED\b/TRIGGERED/g
s/\bTriguered\b/Triggered/g
s/\btriology\b/trilogy/g
s/\bTRIOLOGY\b/TRILOGY/g
s/\bTriology\b/Trilogy/g
s/\btroling\b/trolling/g
s/\bTROLING\b/TROLLING/g
s/\bTroling\b/Trolling/g
s/\btroup\b/troupe/g
s/\bTROUP\b/TROUPE/g
s/\bTroup\b/Troupe/g
s/\btrustworthyness\b/trustworthiness/g
s/\bTRUSTWORTHYNESS\b/TRUSTWORTHINESS/g
s/\bTrustworthyness\b/Trustworthiness/g
s/\btust\b/trust/g
s/\bTUST\b/TRUST/g
s/\bTust\b/Trust/g
s/\btwelth\b/twelfth/g
s/\bTWELTH\b/TWELFTH/g
s/\bTwelth\b/Twelfth/g
s/\btwon\b/town/g
s/\bTWON\b/TOWN/g
s/\bTwon\b/Town/g
s/\btwpo\b/two/g
s/\bTWPO\b/TWO/g
s/\bTwpo\b/Two/g
s/\btyhat\b/that/g
s/\bTYHAT\b/THAT/g
s/\bTyhat\b/That/g
s/\btyhe\b/they/g
s/\bTYHE\b/THEY/g
s/\bTyhe\b/They/g
s/\btypcial\b/typical/g
s/\bTYPCIAL\b/TYPICAL/g
s/\bTypcial\b/Typical/g
s/\btypicaly\b/typically/g
s/\bTYPICALY\b/TYPICALLY/g
s/\bTypicaly\b/Typically/g
s/\btyranies\b/tyrannies/g
s/\bTYRANIES\b/TYRANNIES/g
s/\bTyranies\b/Tyrannies/g
s/\btyrany\b/tyranny/g
s/\bTYRANY\b/TYRANNY/g
s/\bTyrany\b/Tyranny/g
s/\btyrranies\b/tyrannies/g
s/\bTYRRANIES\b/TYRANNIES/g
s/\bTyrranies\b/Tyrannies/g
s/\btyrrany\b/tyranny/g
s/\bTYRRANY\b/TYRANNY/g
s/\bTyrrany\b/Tyranny/g
s/\bubiquitious\b/ubiquitous/g
s/\bUBIQUITIOUS\b/UBIQUITOUS/g
s/\bUbiquitious\b/Ubiquitous/g
s/\bublisher\b/publisher/g
s/\bUBLISHER\b/PUBLISHER/g
s/\bUblisher\b/Publisher/g
s/\buise\b/use/g
s/\bUISE\b/USE/g
s/\bUise\b/Use/g
s/\bultimely\b/ultimately/g
s/\bULTIMELY\b/ULTIMATELY/g
s/\bUltimely\b/Ultimately/g
s/\bunacompanied\b/unaccompanied/g
s/\bUNACOMPANIED\b/UNACCOMPANIED/g
s/\bUnacompanied\b/Unaccompanied/g
s/\bunahppy\b/unhappy/g
s/\bUNAHPPY\b/UNHAPPY/g
s/\bUnahppy\b/Unhappy/g
s/\bunanymous\b/unanimous/g
s/\bUNANYMOUS\b/UNANIMOUS/g
s/\bUnanymous\b/Unanimous/g
s/\bunathorised\b/unauthorised/g
s/\bUNATHORISED\b/UNAUTHORISED/g
s/\bUnathorised\b/Unauthorised/g
s/\bunavailible\b/unavailable/g
s/\bUNAVAILIBLE\b/UNAVAILABLE/g
s/\bUnavailible\b/Unavailable/g
s/\bunballance\b/unbalance/g
s/\bUNBALLANCE\b/UNBALANCE/g
s/\bUnballance\b/Unbalance/g
s/\bunbeknowst\b/unbeknownst/g
s/\bUNBEKNOWST\b/UNBEKNOWNST/g
s/\bUnbeknowst\b/Unbeknownst/g
s/\bunbeleivable\b/unbelievable/g
s/\bUNBELEIVABLE\b/UNBELIEVABLE/g
s/\bUnbeleivable\b/Unbelievable/g
s/\buncertainity\b/uncertainty/g
s/\bUNCERTAINITY\b/UNCERTAINTY/g
s/\bUncertainity\b/Uncertainty/g
s/\bunchallengable\b/unchallengeable/g
s/\bUNCHALLENGABLE\b/UNCHALLENGEABLE/g
s/\bUnchallengable\b/Unchallengeable/g
s/\buncompetive\b/uncompetitive/g
s/\bUNCOMPETIVE\b/UNCOMPETITIVE/g
s/\bUncompetive\b/Uncompetitive/g
s/\bunconcious\b/unconscious/g
s/\bUNCONCIOUS\b/UNCONSCIOUS/g
s/\bUnconcious\b/Unconscious/g
s/\bunconciousness\b/unconsciousness/g
s/\bUNCONCIOUSNESS\b/UNCONSCIOUSNESS/g
s/\bUnconciousness\b/Unconsciousness/g
s/\bunconfortability\b/discomfort/g
s/\bUNCONFORTABILITY\b/DISCOMFORT/g
s/\bUnconfortability\b/Discomfort/g
s/\buncontitutional\b/unconstitutional/g
s/\bUNCONTITUTIONAL\b/UNCONSTITUTIONAL/g
s/\bUncontitutional\b/Unconstitutional/g
s/\bunconvential\b/unconventional/g
s/\bUNCONVENTIAL\b/UNCONVENTIONAL/g
s/\bUnconvential\b/Unconventional/g
s/\bundecideable\b/undecidable/g
s/\bUNDECIDEABLE\b/UNDECIDABLE/g
s/\bUndecideable\b/Undecidable/g
s/\bunderstoon\b/understood/g
s/\bUNDERSTOON\b/UNDERSTOOD/g
s/\bUnderstoon\b/Understood/g
s/\bundetecable\b/undetectable/g
s/\bUNDETECABLE\b/UNDETECTABLE/g
s/\bUndetecable\b/Undetectable/g
s/\bundoubtely\b/undoubtedly/g
s/\bUNDOUBTELY\b/UNDOUBTEDLY/g
s/\bUndoubtely\b/Undoubtedly/g
s/\bundreground\b/underground/g
s/\bUNDREGROUND\b/UNDERGROUND/g
s/\bUndreground\b/Underground/g
s/\bunequalities\b/inequalities/g
s/\bUNEQUALITIES\b/INEQUALITIES/g
s/\bUnequalities\b/Inequalities/g
s/\bunforetunately\b/unfortunately/g
s/\bUNFORETUNATELY\b/UNFORTUNATELY/g
s/\bUnforetunately\b/Unfortunately/g
s/\bunforgetable\b/unforgettable/g
s/\bUNFORGETABLE\b/UNFORGETTABLE/g
s/\bUnforgetable\b/Unforgettable/g
s/\bunforgiveable\b/unforgivable/g
s/\bUNFORGIVEABLE\b/UNFORGIVABLE/g
s/\bUnforgiveable\b/Unforgivable/g
s/\bunfortunatley\b/unfortunately/g
s/\bUNFORTUNATLEY\b/UNFORTUNATELY/g
s/\bUnfortunatley\b/Unfortunately/g
s/\bunfourtunately\b/unfortunately/g
s/\bUNFOURTUNATELY\b/UNFORTUNATELY/g
s/\bUnfourtunately\b/Unfortunately/g
s/\bunihabited\b/uninhabited/g
s/\bUNIHABITED\b/UNINHABITED/g
s/\bUnihabited\b/Uninhabited/g
s/\bunilateraly\b/unilaterally/g
s/\bUNILATERALY\b/UNILATERALLY/g
s/\bUnilateraly\b/Unilaterally/g
s/\bunilatreal\b/unilateral/g
s/\bUNILATREAL\b/UNILATERAL/g
s/\bUnilatreal\b/Unilateral/g
s/\bunilatreally\b/unilaterally/g
s/\bUNILATREALLY\b/UNILATERALLY/g
s/\bUnilatreally\b/Unilaterally/g
s/\buninterruped\b/uninterrupted/g
s/\bUNINTERRUPED\b/UNINTERRUPTED/g
s/\bUninterruped\b/Uninterrupted/g
s/\buninterupted\b/uninterrupted/g
s/\bUNINTERUPTED\b/UNINTERRUPTED/g
s/\bUninterupted\b/Uninterrupted/g
s/\buniveral\b/universal/g
s/\bUNIVERAL\b/UNIVERSAL/g
s/\bUniveral\b/Universal/g
s/\buniveristies\b/universities/g
s/\bUNIVERISTIES\b/UNIVERSITIES/g
s/\bUniveristies\b/Universities/g
s/\buniveristy\b/university/g
s/\bUNIVERISTY\b/UNIVERSITY/g
s/\bUniveristy\b/University/g
s/\buniverity\b/university/g
s/\bUNIVERITY\b/UNIVERSITY/g
s/\bUniverity\b/University/g
s/\buniverstiy\b/university/g
s/\bUNIVERSTIY\b/UNIVERSITY/g
s/\bUniverstiy\b/University/g
s/\bunivesities\b/universities/g
s/\bUNIVESITIES\b/UNIVERSITIES/g
s/\bUnivesities\b/Universities/g
s/\bunivesity\b/university/g
s/\bUNIVESITY\b/UNIVERSITY/g
s/\bUnivesity\b/University/g
s/\bunlikey\b/unlikely/g
s/\bUNLIKEY\b/UNLIKELY/g
s/\bUnlikey\b/Unlikely/g
s/\bunmistakeably\b/unmistakably/g
s/\bUNMISTAKEABLY\b/UNMISTAKABLY/g
s/\bUnmistakeably\b/Unmistakably/g
s/\bunnecesarily\b/unnecessarily/g
s/\bUNNECESARILY\b/UNNECESSARILY/g
s/\bUnnecesarily\b/Unnecessarily/g
s/\bunnecesary\b/unnecessary/g
s/\bUNNECESARY\b/UNNECESSARY/g
s/\bUnnecesary\b/Unnecessary/g
s/\bunoffical\b/unofficial/g
s/\bUNOFFICAL\b/UNOFFICIAL/g
s/\bUnoffical\b/Unofficial/g
s/\bunoperational\b/nonoperational/g
s/\bUNOPERATIONAL\b/NONOPERATIONAL/g
s/\bUnoperational\b/Nonoperational/g
s/\bunoticeable\b/unnoticeable/g
s/\bUNOTICEABLE\b/UNNOTICEABLE/g
s/\bUnoticeable\b/Unnoticeable/g
s/\bunplease\b/displease/g
s/\bUNPLEASE\b/DISPLEASE/g
s/\bUnplease\b/Displease/g
s/\bunplesant\b/unpleasant/g
s/\bUNPLESANT\b/UNPLEASANT/g
s/\bUnplesant\b/Unpleasant/g
s/\bunprecendented\b/unprecedented/g
s/\bUNPRECENDENTED\b/UNPRECEDENTED/g
s/\bUnprecendented\b/Unprecedented/g
s/\bunprecidented\b/unprecedented/g
s/\bUNPRECIDENTED\b/UNPRECEDENTED/g
s/\bUnprecidented\b/Unprecedented/g
s/\bunrepentent\b/unrepentant/g
s/\bUNREPENTENT\b/UNREPENTANT/g
s/\bUnrepentent\b/Unrepentant/g
s/\bunrepetant\b/unrepentant/g
s/\bUNREPETANT\b/UNREPENTANT/g
s/\bUnrepetant\b/Unrepentant/g
s/\bunrepetent\b/unrepentant/g
s/\bUNREPETENT\b/UNREPENTANT/g
s/\bUnrepetent\b/Unrepentant/g
s/\bunsubstanciated\b/unsubstantiated/g
s/\bUNSUBSTANCIATED\b/UNSUBSTANTIATED/g
s/\bUnsubstanciated\b/Unsubstantiated/g
s/\bunsucesful\b/unsuccessful/g
s/\bUNSUCESFUL\b/UNSUCCESSFUL/g
s/\bUnsucesful\b/Unsuccessful/g
s/\bunsucesfuly\b/unsuccessfully/g
s/\bUNSUCESFULY\b/UNSUCCESSFULLY/g
s/\bUnsucesfuly\b/Unsuccessfully/g
s/\bunsuprised\b/unsurprised/g
s/\bUNSUPRISED\b/UNSURPRISED/g
s/\bUnsuprised\b/Unsurprised/g
s/\bunsuprising\b/unsurprising/g
s/\bUNSUPRISING\b/UNSURPRISING/g
s/\bUnsuprising\b/Unsurprising/g
s/\bunsuprisingly\b/unsurprisingly/g
s/\bUNSUPRISINGLY\b/UNSURPRISINGLY/g
s/\bUnsuprisingly\b/Unsurprisingly/g
s/\bunsuprized\b/unsurprised/g
s/\bUNSUPRIZED\b/UNSURPRISED/g
s/\bUnsuprized\b/Unsurprised/g
s/\bunsuprizing\b/unsurprising/g
s/\bUNSUPRIZING\b/UNSURPRISING/g
s/\bUnsuprizing\b/Unsurprising/g
s/\bunsuprizingly\b/unsurprisingly/g
s/\bUNSUPRIZINGLY\b/UNSURPRISINGLY/g
s/\bUnsuprizingly\b/Unsurprisingly/g
s/\bunsurprized\b/unsurprised/g
s/\bUNSURPRIZED\b/UNSURPRISED/g
s/\bUnsurprized\b/Unsurprised/g
s/\bunsurprizing\b/unsurprising/g
s/\bUNSURPRIZING\b/UNSURPRISING/g
s/\bUnsurprizing\b/Unsurprising/g
s/\bunsurprizingly\b/unsurprisingly/g
s/\bUNSURPRIZINGLY\b/UNSURPRISINGLY/g
s/\bUnsurprizingly\b/Unsurprisingly/g
s/\buntranslateable\b/untranslatable/g
s/\bUNTRANSLATEABLE\b/UNTRANSLATABLE/g
s/\bUntranslateable\b/Untranslatable/g
s/\bunuseable\b/unusable/g
s/\bUNUSEABLE\b/UNUSABLE/g
s/\bUnuseable\b/Unusable/g
s/\bunusuable\b/unusable/g
s/\bUNUSUABLE\b/UNUSABLE/g
s/\bUnusuable\b/Unusable/g
s/\bunviersity\b/university/g
s/\bUNVIERSITY\b/UNIVERSITY/g
s/\bUnviersity\b/University/g
s/\bunwarrented\b/unwarranted/g
s/\bUNWARRENTED\b/UNWARRANTED/g
s/\bUnwarrented\b/Unwarranted/g
s/\bunweildly\b/unwieldy/g
s/\bUNWEILDLY\b/UNWIELDY/g
s/\bUnweildly\b/Unwieldy/g
s/\bunwieldly\b/unwieldy/g
s/\bUNWIELDLY\b/UNWIELDY/g
s/\bUnwieldly\b/Unwieldy/g
s/\bupgradded\b/upgraded/g
s/\bUPGRADDED\b/UPGRADED/g
s/\bUpgradded\b/Upgraded/g
s/\busally\b/usually/g
s/\bUSALLY\b/USUALLY/g
s/\bUsally\b/Usually/g
s/\buseage\b/usage/g
s/\bUSEAGE\b/USAGE/g
s/\bUseage\b/Usage/g
s/\busefuly\b/usefully/g
s/\bUSEFULY\b/USEFULLY/g
s/\bUsefuly\b/Usefully/g
s/\buseing\b/using/g
s/\bUSEING\b/USING/g
s/\bUseing\b/Using/g
s/\bususally\b/usually/g
s/\bUSUSALLY\b/USUALLY/g
s/\bUsusally\b/Usually/g
s/\bvaccum\b/vacuum/g
s/\bVACCUM\b/VACUUM/g
s/\bVaccum\b/Vacuum/g
s/\bvaccume\b/vacuum/g
s/\bVACCUME\b/VACUUM/g
s/\bVaccume\b/Vacuum/g
s/\bvacinity\b/vicinity/g
s/\bVACINITY\b/VICINITY/g
s/\bVacinity\b/Vicinity/g
s/\bvaguaries\b/vagaries/g
s/\bVAGUARIES\b/VAGARIES/g
s/\bVaguaries\b/Vagaries/g
s/\bvaieties\b/varieties/g
s/\bVAIETIES\b/VARIETIES/g
s/\bVaieties\b/Varieties/g
s/\bvailidty\b/validity/g
s/\bVAILIDTY\b/VALIDITY/g
s/\bVailidty\b/Validity/g
s/\bvaletta\b/valletta/g
s/\bVALETTA\b/VALLETTA/g
s/\bValetta\b/Valletta/g
s/\bvaluble\b/valuable/g
s/\bVALUBLE\b/VALUABLE/g
s/\bValuble\b/Valuable/g
s/\bvalueable\b/valuable/g
s/\bVALUEABLE\b/VALUABLE/g
s/\bValueable\b/Valuable/g
s/\bvarations\b/variations/g
s/\bVARATIONS\b/VARIATIONS/g
s/\bVarations\b/Variations/g
s/\bvarient\b/variant/g
s/\bVARIENT\b/VARIANT/g
s/\bVarient\b/Variant/g
s/\bvariey\b/variety/g
s/\bVARIEY\b/VARIETY/g
s/\bVariey\b/Variety/g
s/\bvaring\b/varying/g
s/\bVARING\b/VARYING/g
s/\bVaring\b/Varying/g
s/\bvarities\b/varieties/g
s/\bVARITIES\b/VARIETIES/g
s/\bVarities\b/Varieties/g
s/\bvarity\b/variety/g
s/\bVARITY\b/VARIETY/g
s/\bVarity\b/Variety/g
s/\bvasall\b/vassal/g
s/\bVASALL\b/VASSAL/g
s/\bVasall\b/Vassal/g
s/\bvasalls\b/vassals/g
s/\bVASALLS\b/VASSALS/g
s/\bVasalls\b/Vassals/g
s/\bvegatarian\b/vegetarian/g
s/\bVEGATARIAN\b/VEGETARIAN/g
s/\bVegatarian\b/Vegetarian/g
s/\bvegitable\b/vegetable/g
s/\bVEGITABLE\b/VEGETABLE/g
s/\bVegitable\b/Vegetable/g
s/\bvegitables\b/vegetables/g
s/\bVEGITABLES\b/VEGETABLES/g
s/\bVegitables\b/Vegetables/g
s/\bvegtable\b/vegetable/g
s/\bVEGTABLE\b/VEGETABLE/g
s/\bVegtable\b/Vegetable/g
s/\bvehicule\b/vehicle/g
s/\bVEHICULE\b/VEHICLE/g
s/\bVehicule\b/Vehicle/g
s/\bvell\b/well/g
s/\bVELL\b/WELL/g
s/\bVell\b/Well/g
s/\bvenemous\b/venomous/g
s/\bVENEMOUS\b/VENOMOUS/g
s/\bVenemous\b/Venomous/g
s/\bvengance\b/vengeance/g
s/\bVENGANCE\b/VENGEANCE/g
s/\bVengance\b/Vengeance/g
s/\bvengence\b/vengeance/g
s/\bVENGENCE\b/VENGEANCE/g
s/\bVengence\b/Vengeance/g
s/\bverfication\b/verification/g
s/\bVERFICATION\b/VERIFICATION/g
s/\bVerfication\b/Verification/g
s/\bverison\b/version/g
s/\bVERISON\b/VERSION/g
s/\bVerison\b/Version/g
s/\bverisons\b/versions/g
s/\bVERISONS\b/VERSIONS/g
s/\bVerisons\b/Versions/g
s/\bvermillion\b/vermilion/g
s/\bVERMILLION\b/VERMILION/g
s/\bVermillion\b/Vermilion/g
s/\bversitilaty\b/versatility/g
s/\bVERSITILATY\b/VERSATILITY/g
s/\bVersitilaty\b/Versatility/g
s/\bversitlity\b/versatility/g
s/\bVERSITLITY\b/VERSATILITY/g
s/\bVersitlity\b/Versatility/g
s/\bvetween\b/between/g
s/\bVETWEEN\b/BETWEEN/g
s/\bVetween\b/Between/g
s/\bveyr\b/very/g
s/\bVEYR\b/VERY/g
s/\bVeyr\b/Very/g
s/\bvigilence\b/vigilance/g
s/\bVIGILENCE\b/VIGILANCE/g
s/\bVigilence\b/Vigilance/g
s/\bvigourous\b/vigorous/g
s/\bVIGOUROUS\b/VIGOROUS/g
s/\bVigourous\b/Vigorous/g
s/\bvillian\b/villain/g
s/\bVILLIAN\b/VILLAIN/g
s/\bVillian\b/Villain/g
s/\bvillification\b/vilification/g
s/\bVILLIFICATION\b/VILIFICATION/g
s/\bVillification\b/Vilification/g
s/\bvillify\b/vilify/g
s/\bVILLIFY\b/VILIFY/g
s/\bVillify\b/Vilify/g
s/\bvincinity\b/vicinity/g
s/\bVINCINITY\b/VICINITY/g
s/\bVincinity\b/Vicinity/g
s/\bviolentce\b/violence/g
s/\bVIOLENTCE\b/VIOLENCE/g
s/\bViolentce\b/Violence/g
s/\bvirtualy\b/virtually/g
s/\bVIRTUALY\b/VIRTUALLY/g
s/\bVirtualy\b/Virtually/g
s/\bvirutal\b/virtual/g
s/\bVIRUTAL\b/VIRTUAL/g
s/\bVirutal\b/Virtual/g
s/\bvirutally\b/virtually/g
s/\bVIRUTALLY\b/VIRTUALLY/g
s/\bVirutally\b/Virtually/g
s/\bvisable\b/visible/g
s/\bVISABLE\b/VISIBLE/g
s/\bVisable\b/Visible/g
s/\bvisably\b/visibly/g
s/\bVISABLY\b/VISIBLY/g
s/\bVisably\b/Visibly/g
s/\bvisting\b/visiting/g
s/\bVISTING\b/VISITING/g
s/\bVisting\b/Visiting/g
s/\bvistors\b/visitors/g
s/\bVISTORS\b/VISITORS/g
s/\bVistors\b/Visitors/g
s/\bvitories\b/victories/g
s/\bVITORIES\b/VICTORIES/g
s/\bVitories\b/Victories/g
s/\bvolcanoe\b/volcano/g
s/\bVOLCANOE\b/VOLCANO/g
s/\bVolcanoe\b/Volcano/g
s/\bvoleyball\b/volleyball/g
s/\bVOLEYBALL\b/VOLLEYBALL/g
s/\bVoleyball\b/Volleyball/g
s/\bvolontary\b/voluntary/g
s/\bVOLONTARY\b/VOLUNTARY/g
s/\bVolontary\b/Voluntary/g
s/\bvolonteer\b/volunteer/g
s/\bVOLONTEER\b/VOLUNTEER/g
s/\bVolonteer\b/Volunteer/g
s/\bvolonteered\b/volunteered/g
s/\bVOLONTEERED\b/VOLUNTEERED/g
s/\bVolonteered\b/Volunteered/g
s/\bvolonteering\b/volunteering/g
s/\bVOLONTEERING\b/VOLUNTEERING/g
s/\bVolonteering\b/Volunteering/g
s/\bvolonteers\b/volunteers/g
s/\bVOLONTEERS\b/VOLUNTEERS/g
s/\bVolonteers\b/Volunteers/g
s/\bvolounteer\b/volunteer/g
s/\bVOLOUNTEER\b/VOLUNTEER/g
s/\bVolounteer\b/Volunteer/g
s/\bvolounteered\b/volunteered/g
s/\bVOLOUNTEERED\b/VOLUNTEERED/g
s/\bVolounteered\b/Volunteered/g
s/\bvolounteering\b/volunteering/g
s/\bVOLOUNTEERING\b/VOLUNTEERING/g
s/\bVolounteering\b/Volunteering/g
s/\bvolounteers\b/volunteers/g
s/\bVOLOUNTEERS\b/VOLUNTEERS/g
s/\bVolounteers\b/Volunteers/g
s/\bvolumne\b/volume/g
s/\bVOLUMNE\b/VOLUME/g
s/\bVolumne\b/Volume/g
s/\bvreity\b/variety/g
s/\bVREITY\b/VARIETY/g
s/\bVreity\b/Variety/g
s/\bvrey\b/very/g
s/\bVREY\b/VERY/g
s/\bVrey\b/Very/g
s/\bvriety\b/variety/g
s/\bVRIETY\b/VARIETY/g
s/\bVriety\b/Variety/g
s/\bvulnerablility\b/vulnerability/g
s/\bVULNERABLILITY\b/VULNERABILITY/g
s/\bVulnerablility\b/Vulnerability/g
s/\bvyer\b/very/g
s/\bVYER\b/VERY/g
s/\bVyer\b/Very/g
s/\bvyre\b/very/g
s/\bVYRE\b/VERY/g
s/\bVyre\b/Very/g
s/\bwaht\b/what/g
s/\bWAHT\b/WHAT/g
s/\bWaht\b/What/g
s/\bwarantee\b/warranty/g
s/\bWARANTEE\b/WARRANTY/g
s/\bWarantee\b/Warranty/g
s/\bwardobe\b/wardrobe/g
s/\bWARDOBE\b/WARDROBE/g
s/\bWardobe\b/Wardrobe/g
s/\bwarrent\b/warrant/g
s/\bWARRENT\b/WARRANT/g
s/\bWarrent\b/Warrant/g
s/\bwarrriors\b/warriors/g
s/\bWARRRIORS\b/WARRIORS/g
s/\bWarrriors\b/Warriors/g
s/\bwasnt\b/wasn't/g
s/\bWASNT\b/WASN'T/g
s/\bWasnt\b/Wasn't/g
s/\bwass\b/was/g
s/\bWASS\b/WAS/g
s/\bWass\b/Was/g
s/\bwatn\b/want/g
s/\bWATN\b/WANT/g
s/\bWatn\b/Want/g
s/\bwayword\b/wayward/g
s/\bWAYWORD\b/WAYWARD/g
s/\bWayword\b/Wayward/g
s/\bweaponary\b/weaponry/g
s/\bWEAPONARY\b/WEAPONRY/g
s/\bWeaponary\b/Weaponry/g
s/\bweas\b/was/g
s/\bWEAS\b/WAS/g
s/\bWeas\b/Was/g
s/\bwehn\b/when/g
s/\bWEHN\b/WHEN/g
s/\bWehn\b/When/g
s/\bweilded\b/wielded/g
s/\bWEILDED\b/WIELDED/g
s/\bWeilded\b/Wielded/g
s/\bwendsay\b/wednesday/g
s/\bWENDSAY\b/WEDNESDAY/g
s/\bWendsay\b/Wednesday/g
s/\bwensday\b/wednesday/g
s/\bWENSDAY\b/WEDNESDAY/g
s/\bWensday\b/Wednesday/g
s/\bwereabouts\b/whereabouts/g
s/\bWEREABOUTS\b/WHEREABOUTS/g
s/\bWereabouts\b/Whereabouts/g
s/\bwhant\b/want/g
s/\bWHANT\b/WANT/g
s/\bWhant\b/Want/g
s/\bwhants\b/wants/g
s/\bWHANTS\b/WANTS/g
s/\bWhants\b/Wants/g
s/\bwhcih\b/which/g
s/\bWHCIH\b/WHICH/g
s/\bWhcih\b/Which/g
s/\bwheras\b/whereas/g
s/\bWHERAS\b/WHEREAS/g
s/\bWheras\b/Whereas/g
s/\bwherease\b/whereas/g
s/\bWHEREASE\b/WHEREAS/g
s/\bWherease\b/Whereas/g
s/\bwhereever\b/wherever/g
s/\bWHEREEVER\b/WHEREVER/g
s/\bWhereever\b/Wherever/g
s/\bwhihc\b/which/g
s/\bWHIHC\b/WHICH/g
s/\bWhihc\b/Which/g
s/\bwhith\b/with/g
s/\bWHITH\b/WITH/g
s/\bWhith\b/With/g
s/\bwhlch\b/which/g
s/\bWHLCH\b/WHICH/g
s/\bWhlch\b/Which/g
s/\bwhn\b/when/g
s/\bWHN\b/WHEN/g
s/\bWhn\b/When/g
s/\bwholey\b/wholly/g
s/\bWHOLEY\b/WHOLLY/g
s/\bWholey\b/Wholly/g
s/\bwhta\b/what/g
s/\bWHTA\b/WHAT/g
s/\bWhta\b/What/g
s/\bwidesread\b/widespread/g
s/\bWIDESREAD\b/WIDESPREAD/g
s/\bWidesread\b/Widespread/g
s/\bwief\b/wife/g
s/\bWIEF\b/WIFE/g
s/\bWief\b/Wife/g
s/\bwiew\b/view/g
s/\bWIEW\b/VIEW/g
s/\bWiew\b/View/g
s/\bwih\b/with/g
s/\bWIH\b/WITH/g
s/\bWih\b/With/g
s/\bwiht\b/with/g
s/\bWIHT\b/WITH/g
s/\bWiht\b/With/g
s/\bwille\b/will/g
s/\bWILLE\b/WILL/g
s/\bWille\b/Will/g
s/\bwillingless\b/willingness/g
s/\bWILLINGLESS\b/WILLINGNESS/g
s/\bWillingless\b/Willingness/g
s/\bwillk\b/will/g
s/\bWILLK\b/WILL/g
s/\bWillk\b/Will/g
s/\bwirting\b/writing/g
s/\bWIRTING\b/WRITING/g
s/\bWirting\b/Writing/g
s/\bwitheld\b/withheld/g
s/\bWITHELD\b/WITHHELD/g
s/\bWitheld\b/Withheld/g
s/\bwithh\b/with/g
s/\bWITHH\b/WITH/g
s/\bWithh\b/With/g
s/\bwithold\b/withhold/g
s/\bWITHOLD\b/WITHHOLD/g
s/\bWithold\b/Withhold/g
s/\bwitht\b/with/g
s/\bWITHT\b/WITH/g
s/\bWitht\b/With/g
s/\bwitn\b/with/g
s/\bWITN\b/WITH/g
s/\bWitn\b/With/g
s/\bwiull\b/will/g
s/\bWIULL\b/WILL/g
s/\bWiull\b/Will/g
s/\bwnat\b/want/g
s/\bWNAT\b/WANT/g
s/\bWnat\b/Want/g
s/\bwnated\b/wanted/g
s/\bWNATED\b/WANTED/g
s/\bWnated\b/Wanted/g
s/\bwnats\b/wants/g
s/\bWNATS\b/WANTS/g
s/\bWnats\b/Wants/g
s/\bwohle\b/whole/g
s/\bWOHLE\b/WHOLE/g
s/\bWohle\b/Whole/g
s/\bwokr\b/work/g
s/\bWOKR\b/WORK/g
s/\bWokr\b/Work/g
s/\bwokring\b/working/g
s/\bWOKRING\b/WORKING/g
s/\bWokring\b/Working/g
s/\bwonderfull\b/wonderful/g
s/\bWONDERFULL\b/WONDERFUL/g
s/\bWonderfull\b/Wonderful/g
s/\bwordlwide\b/worldwide/g
s/\bWORDLWIDE\b/WORLDWIDE/g
s/\bWordlwide\b/Worldwide/g
s/\bworkststion\b/workstation/g
s/\bWORKSTSTION\b/WORKSTATION/g
s/\bWorkststion\b/Workstation/g
s/\bworls\b/world/g
s/\bWORLS\b/WORLD/g
s/\bWorls\b/World/g
s/\bworstened\b/worsened/g
s/\bWORSTENED\b/WORSENED/g
s/\bWorstened\b/Worsened/g
s/\bwoudl\b/would/g
s/\bWOUDL\b/WOULD/g
s/\bWoudl\b/Would/g
s/\bwresters\b/wrestlers/g
s/\bWRESTERS\b/WRESTLERS/g
s/\bWresters\b/Wrestlers/g
s/\bwriet\b/write/g
s/\bWRIET\b/WRITE/g
s/\bWriet\b/Write/g
s/\bwroet\b/wrote/g
s/\bWROET\b/WROTE/g
s/\bWroet\b/Wrote/g
s/\bwrok\b/work/g
s/\bWROK\b/WORK/g
s/\bWrok\b/Work/g
s/\bwroking\b/working/g
s/\bWROKING\b/WORKING/g
s/\bWroking\b/Working/g
s/\bwtih\b/with/g
s/\bWTIH\b/WITH/g
s/\bWtih\b/With/g
s/\bwupport\b/support/g
s/\bWUPPORT\b/SUPPORT/g
s/\bWupport\b/Support/g
s/\bxenophoby\b/xenophobia/g
s/\bXENOPHOBY\b/XENOPHOBIA/g
s/\bXenophoby\b/Xenophobia/g
s/\byaching\b/yachting/g
s/\bYACHING\b/YACHTING/g
s/\bYaching\b/Yachting/g
s/\byaer\b/year/g
s/\bYAER\b/YEAR/g
s/\bYaer\b/Year/g
s/\byaerly\b/yearly/g
s/\bYAERLY\b/YEARLY/g
s/\bYaerly\b/Yearly/g
s/\byaers\b/years/g
s/\bYAERS\b/YEARS/g
s/\bYaers\b/Years/g
s/\byatch\b/yacht/g
s/\bYATCH\b/YACHT/g
s/\bYatch\b/Yacht/g
s/\byearm\b/year/g
s/\bYEARM\b/YEAR/g
s/\bYearm\b/Year/g
s/\byeasr\b/years/g
s/\bYEASR\b/YEARS/g
s/\bYeasr\b/Years/g
s/\byeild\b/yield/g
s/\bYEILD\b/YIELD/g
s/\bYeild\b/Yield/g
s/\byeilding\b/yielding/g
s/\bYEILDING\b/YIELDING/g
s/\bYeilding\b/Yielding/g
s/\byera\b/year/g
s/\bYERA\b/YEAR/g
s/\bYera\b/Year/g
s/\byeras\b/years/g
s/\bYERAS\b/YEARS/g
s/\bYeras\b/Years/g
s/\byersa\b/years/g
s/\bYERSA\b/YEARS/g
s/\bYersa\b/Years/g
s/\byotube\b/youtube/g
s/\bYOTUBE\b/YOUTUBE/g
s/\bYotube\b/Youtube/g
s/\byouseff\b/yousef/g
s/\bYOUSEFF\b/YOUSEF/g
s/\bYouseff\b/Yousef/g
s/\byouself\b/yourself/g
s/\bYOUSELF\b/YOURSELF/g
s/\bYouself\b/Yourself/g
s/\byrea\b/year/g
s/\bYREA\b/YEAR/g
s/\bYrea\b/Year/g
s/\bytou\b/you/g
s/\bYTOU\b/YOU/g
s/\bYtou\b/You/g
s/\byuo\b/you/g
s/\bYUO\b/YOU/g
s/\bYuo\b/You/g
s/\bzeebra\b/zebra/g
s/\bZEEBRA\b/ZEBRA/g
s/\bZeebra\b/Zebra/g
s/a'ready/already/g
s/A'READY/ALREADY/g
s/A'ready/Already/g
s/abbott/abort/g
s/ABBOTT/ABORT/g
s/Abbott/Abort/g
s/abiove/above/g
s/ABIOVE/ABOVE/g
s/Abiove/Above/g
s/abouve/above/g
s/ABOUVE/ABOVE/g
s/Abouve/Above/g
s/acccepted/accepted/g
s/ACCCEPTED/ACCEPTED/g
s/Acccepted/Accepted/g
s/accees/access/g
s/ACCEES/ACCESS/g
s/Accees/Access/g
s/accellerated/accelerated/g
s/ACCELLERATED/ACCELERATED/g
s/Accellerated/Accelerated/g
s/acceptible/acceptable/g
s/ACCEPTIBLE/ACCEPTABLE/g
s/Acceptible/Acceptable/g
s/acceses/accesses/g
s/ACCESES/ACCESSES/g
s/Acceses/Accesses/g
s/accestor/accessor/g
s/ACCESTOR/ACCESSOR/g
s/Accestor/Accessor/g
s/accompagning/accompanying/g
s/ACCOMPAGNING/ACCOMPANYING/g
s/Accompagning/Accompanying/g
s/accordinly/accordingly/g
s/ACCORDINLY/ACCORDINGLY/g
s/Accordinly/Accordingly/g
s/accoutrements/accouterments/g
s/ACCOUTREMENTS/ACCOUTERMENTS/g
s/Accoutrements/Accouterments/g
s/accreting/accrediting/g
s/ACCRETING/ACCREDITING/g
s/Accreting/Accrediting/g
s/accumlator/accumulator/g
s/ACCUMLATOR/ACCUMULATOR/g
s/Accumlator/Accumulator/g
s/accummulating/accumulating/g
s/ACCUMMULATING/ACCUMULATING/g
s/Accummulating/Accumulating/g
s/accummulators/accumulators/g
s/ACCUMMULATORS/ACCUMULATORS/g
s/Accummulators/Accumulators/g
s/acessable/accessible/g
s/ACESSABLE/ACCESSIBLE/g
s/Acessable/Accessible/g
s/achive/archive/g
s/ACHIVE/ARCHIVE/g
s/Achive/Archive/g
s/actuall\b/actual/g
s/ACTUALL\b/ACTUAL/g
s/Actuall\b/Actual/g
s/actullay/actually/g
s/ACTULLAY/ACTUALLY/g
s/Actullay/Actually/g
s/acual/actual/g
s/ACUAL/ACTUAL/g
s/Acual/Actual/g
s/addesses/addresses/g
s/ADDESSES/ADDRESSES/g
s/Addesses/Addresses/g
s/additionnal/additional/g
s/ADDITIONNAL/ADDITIONAL/g
s/Additionnal/Additional/g
s/addressibility/addressability/g
s/ADDRESSIBILITY/ADDRESSABILITY/g
s/Addressibility/Addressability/g
s/addressings/addressing/g
s/ADDRESSINGS/ADDRESSING/g
s/Addressings/Addressing/g
s/adjusment/adjustment/g
s/ADJUSMENT/ADJUSTMENT/g
s/Adjusment/Adjustment/g
s/adjustements/adjustments/g
s/ADJUSTEMENTS/ADJUSTMENTS/g
s/Adjustements/Adjustments/g
s/adjustement/adjustment/g
s/ADJUSTEMENT/ADJUSTMENT/g
s/Adjustement/Adjustment/g
s/adjustes/adjusts/g
s/ADJUSTES/ADJUSTS/g
s/Adjustes/Adjusts/g
s/advantagous/advantageous/g
s/ADVANTAGOUS/ADVANTAGEOUS/g
s/Advantagous/Advantageous/g
s/aggegate/aggregate/g
s/AGGEGATE/AGGREGATE/g
s/Aggegate/Aggregate/g
s/agggregate/aggregate/g
s/AGGGREGATE/AGGREGATE/g
s/Agggregate/Aggregate/g
s/aggragate/aggregate/g
s/AGGRAGATE/AGGREGATE/g
s/Aggragate/Aggregate/g
s/aggreagate/aggregate/g
s/AGGREAGATE/AGGREGATE/g
s/Aggreagate/Aggregate/g
s/aggreate/aggregate/g
s/AGGREATE/AGGREGATE/g
s/Aggreate/Aggregate/g
s/aggreggate/aggregate/g
s/AGGREGGATE/AGGREGATE/g
s/Aggreggate/Aggregate/g
s/agression/aggression/g
s/AGRESSION/AGGRESSION/g
s/Agression/Aggression/g
s/agument/argument/g
s/AGUMENT/ARGUMENT/g
s/Agument/Argument/g
s/algebric/algebraic/g
s/ALGEBRIC/ALGEBRAIC/g
s/Algebric/Algebraic/g
s/algorith\b/algorithm/g
s/ALGORITH\b/ALGORITHM/g
s/Algorith\b/Algorithm/g
s/algorithsm/algorithms/g
s/ALGORITHSM/ALGORITHMS/g
s/Algorithsm/Algorithms/g
s/algoritms/algorithms/g
s/ALGORITMS/ALGORITHMS/g
s/Algoritms/Algorithms/g
s/aligment/alignment/g
s/ALIGMENT/ALIGNMENT/g
s/Aligment/Alignment/g
s/alignemnt/alignment/g
s/ALIGNEMNT/ALIGNMENT/g
s/Alignemnt/Alignment/g
s/allcation/allocation/g
s/ALLCATION/ALLOCATION/g
s/Allcation/Allocation/g
s/allcoated/allocated/g
s/ALLCOATED/ALLOCATED/g
s/Allcoated/Allocated/g
s/allocatbale/allocatable/g
s/ALLOCATBALE/ALLOCATABLE/g
s/Allocatbale/Allocatable/g
s/allocatoor/allocator/g
s/ALLOCATOOR/ALLOCATOR/g
s/Allocatoor/Allocator/g
s/alocatable/allocatable/g
s/ALOCATABLE/ALLOCATABLE/g
s/Alocatable/Allocatable/g
s/alogorithms/algorithms/g
s/ALOGORITHMS/ALGORITHMS/g
s/Alogorithms/Algorithms/g
s/alreadh/already/g
s/ALREADH/ALREADY/g
s/Alreadh/Already/g
s/alsoneeds/also_needs/g
s/ALSONEEDS/ALSO_NEEDS/g
s/Alsoneeds/Also_needs/g
s/amendement/amendment/g
s/AMENDEMENT/AMENDMENT/g
s/Amendement/Amendment/g
s/analoguous/analogous/g
s/ANALOGUOUS/ANALOGOUS/g
s/Analoguous/Analogous/g
s/ancilliary/ancillary/g
s/ANCILLIARY/ANCILLARY/g
s/Ancilliary/Ancillary/g
s/anway/anyway/g
s/ANWAY/ANYWAY/g
s/Anway/Anyway/g
s/apilogue/epilogue/g
s/APILOGUE/EPILOGUE/g
s/Apilogue/Epilogue/g
s/aplications/applications/g
s/APLICATIONS/APPLICATIONS/g
s/Aplications/Applications/g
s/appearantly/apparently/g
s/APPEARANTLY/APPARENTLY/g
s/Appearantly/Apparently/g
s/appearence/appearance/g
s/APPEARENCE/APPEARANCE/g
s/Appearence/Appearance/g
s/apperances/appearances/g
s/APPERANCES/APPEARANCES/g
s/Apperances/Appearances/g
s/appereance/appearance/g
s/APPEREANCE/APPEARANCE/g
s/Appereance/Appearance/g
s/applyting/applying/g
s/APPLYTING/APPLYING/g
s/Applyting/Applying/g
s/appoximately/approximately/g
s/APPOXIMATELY/APPROXIMATELY/g
s/Appoximately/Approximately/g
s/apppears/appears/g
s/APPPEARS/APPEARS/g
s/Apppears/Appears/g
s/appproach/approach/g
s/APPPROACH/APPROACH/g
s/Appproach/Approach/g
s/apprently/apparently/g
s/APPRENTLY/APPARENTLY/g
s/Apprently/Apparently/g
s/approprite/appropriate/g
s/APPROPRITE/APPROPRIATE/g
s/Approprite/Appropriate/g
s/apprpriate/appropriate/g
s/APPRPRIATE/APPROPRIATE/g
s/Apprpriate/Appropriate/g
s/archtiecture/architecture/g
s/ARCHTIECTURE/ARCHITECTURE/g
s/Archtiecture/Architecture/g
s/arguemtns/arguments/g
s/ARGUEMTNS/ARGUMENTS/g
s/Arguemtns/Arguments/g
s/argumens/arguments/g
s/ARGUMENS/ARGUMENTS/g
s/Argumens/Arguments/g
s/argumetn/argument/g
s/ARGUMETN/ARGUMENT/g
s/Argumetn/Argument/g
s/argumet/argument/g
s/ARGUMET/ARGUMENT/g
s/Argumet/Argument/g
s/aribtrary/arbitrary/g
s/ARIBTRARY/ARBITRARY/g
s/Aribtrary/Arbitrary/g
s/arithmatic/arithmetic/g
s/ARITHMATIC/ARITHMETIC/g
s/Arithmatic/Arithmetic/g
s/aritmetic/arithmetic/g
s/ARITMETIC/ARITHMETIC/g
s/Aritmetic/Arithmetic/g
s/assignemnt/assignment/g
s/ASSIGNEMNT/ASSIGNMENT/g
s/Assignemnt/Assignment/g
s/assignmen\b/assignment/g
s/ASSIGNMEN\b/ASSIGNMENT/g
s/Assignmen\b/Assignment/g
s/assignmnet/assignment/g
s/ASSIGNMNET/ASSIGNMENT/g
s/Assignmnet/Assignment/g
s/assings/assigns/g
s/ASSINGS/ASSIGNS/g
s/Assings/Assigns/g
s/assinment/assignment/g
s/ASSINMENT/ASSIGNMENT/g
s/Assinment/Assignment/g
s/associatied/associated/g
s/ASSOCIATIED/ASSOCIATED/g
s/Associatied/Associated/g
s/assotiated/associated/g
s/ASSOTIATED/ASSOCIATED/g
s/Assotiated/Associated/g
s/asssume/assume/g
s/ASSSUME/ASSUME/g
s/Asssume/Assume/g
s/assumpation/assumption/g
s/ASSUMPATION/ASSUMPTION/g
s/Assumpation/Assumption/g
s/assumtions/assumptions/g
s/ASSUMTIONS/ASSUMPTIONS/g
s/Assumtions/Assumptions/g
s/assupmption/assumption/g
s/ASSUPMPTION/ASSUMPTION/g
s/Assupmption/Assumption/g
s/asterices/asterisks/g
s/ASTERICES/ASTERISKS/g
s/Asterices/Asterisks/g
s/asthetics/aesthetics/g
s/ASTHETICS/AESTHETICS/g
s/Asthetics/Aesthetics/g
s/asumption/assumption/g
s/ASUMPTION/ASSUMPTION/g
s/Asumption/Assumption/g
s/attemps/attempts/g
s/ATTEMPS/ATTEMPTS/g
s/Attemps/Attempts/g
s/automtically/automatically/g
s/AUTOMTICALLY/AUTOMATICALLY/g
s/Automtically/Automatically/g
s/auxiliar\b/auxiliary/g
s/AUXILIAR\b/AUXILIARY/g
s/Auxiliar\b/Auxiliary/g
s/availablity/availability/g
s/AVAILABLITY/AVAILABILITY/g
s/Availablity/Availability/g
s/avoidpaste/avoid_paste/g
s/AVOIDPASTE/AVOID_PASTE/g
s/Avoidpaste/Avoid_paste/g
s/avove/above/g
s/AVOVE/ABOVE/g
s/Avove/Above/g
s/awrning/warning/g
s/AWRNING/WARNING/g
s/Awrning/Warning/g
s/backards/backwards/g
s/BACKARDS/BACKWARDS/g
s/Backards/Backwards/g
s/barrer/barrier/g
s/BARRER/BARRIER/g
s/Barrer/Barrier/g
s/becaause/because/g
s/BECAAUSE/BECAUSE/g
s/Becaause/Because/g
s/becacdd/because/g
s/BECACDD/BECAUSE/g
s/Becacdd/Because/g
s/becauae/because/g
s/BECAUAE/BECAUSE/g
s/Becauae/Because/g
s/benchmkar/benchmark/g
s/BENCHMKAR/BENCHMARK/g
s/Benchmkar/Benchmark/g
s/benefical/beneficial/g
s/BENEFICAL/BENEFICIAL/g
s/Benefical/Beneficial/g
s/beneits/benefits/g
s/BENEITS/BENEFITS/g
s/Beneits/Benefits/g
s/benificial/beneficial/g
s/BENIFICIAL/BENEFICIAL/g
s/Benificial/Beneficial/g
s/beteween/between/g
s/BETEWEEN/BETWEEN/g
s/Beteween/Between/g
s/betweed/between/g
s/BETWEED/BETWEEN/g
s/Betweed/Between/g
s/bimask/bitmask/g
s/BIMASK/BITMASK/g
s/Bimask/Bitmask/g
s/bogous/bogus/g
s/BOGOUS/BOGUS/g
s/Bogous/Bogus/g
s/bookeeping/bookkeeping/g
s/BOOKEEPING/BOOKKEEPING/g
s/Bookeeping/Bookkeeping/g
s/bookkeeing/bookkeeping/g
s/BOOKKEEING/BOOKKEEPING/g
s/Bookkeeing/Bookkeeping/g
s/bookkeeiping/bookkeeping/g
s/BOOKKEEIPING/BOOKKEEPING/g
s/Bookkeeiping/Bookkeeping/g
s/bookkepp/bookkeep/g
s/BOOKKEPP/BOOKKEEP/g
s/Bookkepp/Bookkeep/g
s/buidling/building/g
s/BUIDLING/BUILDING/g
s/Buidling/Building/g
s/builitn/builtin/g
s/BUILITN/BUILTIN/g
s/Builitn/Builtin/g
s/cachline/cacheline/g
s/CACHLINE/CACHELINE/g
s/Cachline/Cacheline/g
s/caclulated/calculated/g
s/CACLULATED/CALCULATED/g
s/Caclulated/Calculated/g
s/calback/callback/g
s/CALBACK/CALLBACK/g
s/Calback/Callback/g
s/calculatable/calculable/g
s/CALCULATABLE/CALCULABLE/g
s/Calculatable/Calculable/g
s/caleee/callee/g
s/CALEEE/CALLEE/g
s/Caleee/Callee/g
s/calees/callees/g
s/CALEES/CALLEES/g
s/Calees/Callees/g
s/calle\b/callee/g
s/CALLE\b/CALLEE/g
s/Calle\b/Callee/g
s/calll/call/g
s/CALLL/CALL/g
s/Calll/Call/g
s/calulates/calculates/g
s/CALULATES/CALCULATES/g
s/Calulates/Calculates/g
s/camparing/comparing/g
s/CAMPARING/COMPARING/g
s/Camparing/Comparing/g
s/canonicalizations/canonizations/g
s/CANONICALIZATIONS/CANONIZATIONS/g
s/Canonicalizations/Canonizations/g
s/canonival/canonical/g
s/CANONIVAL/CANONICAL/g
s/Canonival/Canonical/g
s/carefuly/carefully/g
s/CAREFULY/CAREFULLY/g
s/Carefuly/Carefully/g
s/catagory/category/g
s/CATAGORY/CATEGORY/g
s/Catagory/Category/g
s/ccoutant/accountant/g
s/CCOUTANT/ACCOUNTANT/g
s/Ccoutant/Accountant/g
s/characte\b/character/g
s/CHARACTE\b/CHARACTER/g
s/Characte\b/Character/g
s/characts/characters/g
s/CHARACTS/CHARACTERS/g
s/Characts/Characters/g
s/charcter/character/g
s/CHARCTER/CHARACTER/g
s/Charcter/Character/g
s/cheching/checking/g
s/CHECHING/CHECKING/g
s/Cheching/Checking/g
s/chlids/children/g
s/CHLIDS/CHILDREN/g
s/Chlids/Children/g
s/choicing/choosing/g
s/CHOICING/CHOOSING/g
s/Choicing/Choosing/g
s/cirtcuit/circuit/g
s/CIRTCUIT/CIRCUIT/g
s/Cirtcuit/Circuit/g
s/cloure/closure/g
s/CLOURE/CLOSURE/g
s/Cloure/Closure/g
s/coefficents/coefficients/g
s/COEFFICENTS/COEFFICIENTS/g
s/Coefficents/Coefficients/g
s/coefficent/coefficient/g
s/COEFFICENT/COEFFICIENT/g
s/Coefficent/Coefficient/g
s/coeficients/coefficients/g
s/COEFICIENTS/COEFFICIENTS/g
s/Coeficients/Coefficients/g
s/collationg/collation/g
s/COLLATIONG/COLLATION/g
s/Collationg/Collation/g
s/colleection/collection/g
s/COLLEECTION/COLLECTION/g
s/Colleection/Collection/g
s/coloringh/coloring/g
s/COLORINGH/COLORING/g
s/Coloringh/Coloring/g
s/combinine/combine/g
s/COMBININE/COMBINE/g
s/Combinine/Combine/g
s/comformance/conformance/g
s/COMFORMANCE/CONFORMANCE/g
s/Comformance/Conformance/g
s/comitee/committee/g
s/COMITEE/COMMITTEE/g
s/Comitee/Committee/g
s/comlexity/complexity/g
s/COMLEXITY/COMPLEXITY/g
s/Comlexity/Complexity/g
s/comminucating/communicating/g
s/COMMINUCATING/COMMUNICATING/g
s/Comminucating/Communicating/g
s/commtted/committed/g
s/COMMTTED/COMMITTED/g
s/Commtted/Committed/g
s/commutated/commuted/g
s/COMMUTATED/COMMUTED/g
s/Commutated/Commuted/g
s/commutating/commuting/g
s/COMMUTATING/COMMUTING/g
s/Commutating/Commuting/g
s/comnparing/comparing/g
s/COMNPARING/COMPARING/g
s/Comnparing/Comparing/g
s/comnpletion/completion/g
s/COMNPLETION/COMPLETION/g
s/Comnpletion/Completion/g
s/comparsions/comparisons/g
s/COMPARSIONS/COMPARISONS/g
s/Comparsions/Comparisons/g
s/compatibiliy/compatibility/g
s/COMPATIBILIY/COMPATIBILITY/g
s/Compatibiliy/Compatibility/g
s/compatibity/compatibility/g
s/COMPATIBITY/COMPATIBILITY/g
s/Compatibity/Compatibility/g
s/compativle/compatible/g
s/COMPATIVLE/COMPATIBLE/g
s/Compativle/Compatible/g
s/compications/complications/g
s/COMPICATIONS/COMPLICATIONS/g
s/Compications/Complications/g
s/compilability/compatibility/g
s/COMPILABILITY/COMPATIBILITY/g
s/Compilability/Compatibility/g
s/compiliant/compliant/g
s/COMPILIANT/COMPLIANT/g
s/Compiliant/Compliant/g
s/compination/combination/g
s/COMPINATION/COMBINATION/g
s/Compination/Combination/g
s/compination/compilation/g
s/COMPINATION/COMPILATION/g
s/Compination/Compilation/g
s/complementt/complement/g
s/COMPLEMENTT/COMPLEMENT/g
s/Complementt/Complement/g
s/completelly/completely/g
s/COMPLETELLY/COMPLETELY/g
s/Completelly/Completely/g
s/complette/complete/g
s/COMPLETTE/COMPLETE/g
s/Complette/Complete/g
s/compnent/component/g
s/COMPNENT/COMPONENT/g
s/Compnent/Component/g
s/compoents/components/g
s/COMPOENTS/COMPONENTS/g
s/Compoents/Components/g
s/compuatation/computation/g
s/COMPUATATION/COMPUTATION/g
s/Compuatation/Computation/g
s/compuation/computation/g
s/COMPUATION/COMPUTATION/g
s/Compuation/Computation/g
s/computaton/computation/g
s/COMPUTATON/COMPUTATION/g
s/Computaton/Computation/g
s/comventions/conventions/g
s/COMVENTIONS/CONVENTIONS/g
s/Comventions/Conventions/g
s/concantenated/concatenated/g
s/CONCANTENATED/CONCATENATED/g
s/Concantenated/Concatenated/g
s/concensus/consensus/g
s/CONCENSUS/CONSENSUS/g
s/Concensus/Consensus/g
s/conceptification/conceptualization/g
s/CONCEPTIFICATION/CONCEPTUALIZATION/g
s/Conceptification/Conceptualization/g
s/concerened/concerned/g
s/CONCERENED/CONCERNED/g
s/Concerened/Concerned/g
s/conditoinal/conditional/g
s/CONDITOINAL/CONDITIONAL/g
s/Conditoinal/Conditional/g
s/condtiion/condition/g
s/CONDTIION/CONDITION/g
s/Condtiion/Condition/g
s/condtions/conditions/g
s/CONDTIONS/CONDITIONS/g
s/Condtions/Conditions/g
s/condtition/condition/g
s/CONDTITION/CONDITION/g
s/Condtition/Condition/g
s/conervative/conservative/g
s/CONERVATIVE/CONSERVATIVE/g
s/Conervative/Conservative/g
s/conjonction/conjunction/g
s/CONJONCTION/CONJUNCTION/g
s/Conjonction/Conjunction/g
s/consequentely/consequently/g
s/CONSEQUENTELY/CONSEQUENTLY/g
s/Consequentely/Consequently/g
s/consequtive/consecutive/g
s/CONSEQUTIVE/CONSECUTIVE/g
s/Consequtive/Consecutive/g
s/conservativeky/conservatively/g
s/CONSERVATIVEKY/CONSERVATIVELY/g
s/Conservativeky/Conservatively/g
s/consistuents/constituents/g
s/CONSISTUENTS/CONSTITUENTS/g
s/Consistuents/Constituents/g
s/consits/consists/g
s/CONSITS/CONSISTS/g
s/Consits/Consists/g
s/consructor/constructor/g
s/CONSRUCTOR/CONSTRUCTOR/g
s/Consructor/Constructor/g
s/constained/constrained/g
s/CONSTAINED/CONSTRAINED/g
s/Constained/Constrained/g
s/constan\b/constant/g
s/CONSTAN\b/CONSTANT/g
s/Constan\b/Constant/g
s/constraucts/constructs/g
s/CONSTRAUCTS/CONSTRUCTS/g
s/Constraucts/Constructs/g
s/constriants/constraints/g
s/CONSTRIANTS/CONSTRAINTS/g
s/Constriants/Constraints/g
s/construciton/construction/g
s/CONSTRUCITON/CONSTRUCTION/g
s/Construciton/Construction/g
s/constuction/construction/g
s/CONSTUCTION/CONSTRUCTION/g
s/Constuction/Construction/g
s/constucts/constructs/g
s/CONSTUCTS/CONSTRUCTS/g
s/Constucts/Constructs/g
s/containings/containing/g
s/CONTAININGS/CONTAINING/g
s/Containings/Containing/g
s/contentionz/contentions/g
s/CONTENTIONZ/CONTENTIONS/g
s/Contentionz/Contentions/g
s/contigious/contiguous/g
s/CONTIGIOUS/CONTIGUOUS/g
s/Contigious/Contiguous/g
s/contiguities/continuities/g
s/CONTIGUITIES/CONTINUITIES/g
s/Contiguities/Continuities/g
s/contruction/construction/g
s/CONTRUCTION/CONSTRUCTION/g
s/Contruction/Construction/g
s/conventient/convenient/g
s/CONVENTIENT/CONVENIENT/g
s/Conventient/Convenient/g
s/converions/conversions/g
s/CONVERIONS/CONVERSIONS/g
s/Converions/Conversions/g
s/copmilation/compilation/g
s/COPMILATION/COMPILATION/g
s/Copmilation/Compilation/g
s/copmutations/computations/g
s/COPMUTATIONS/COMPUTATIONS/g
s/Copmutations/Computations/g
s/copyied/copied/g
s/COPYIED/COPIED/g
s/Copyied/Copied/g
s/correspdoning/corresponding/g
s/CORRESPDONING/CORRESPONDING/g
s/Correspdoning/Corresponding/g
s/correspending/corresponding/g
s/CORRESPENDING/CORRESPONDING/g
s/Correspending/Corresponding/g
s/correspnding/corresponding/g
s/CORRESPNDING/CORRESPONDING/g
s/Correspnding/Corresponding/g
s/correspondances/correspondences/g
s/CORRESPONDANCES/CORRESPONDENCES/g
s/Correspondances/Correspondences/g
s/corrresponding/corresponding/g
s/CORRRESPONDING/CORRESPONDING/g
s/Corrresponding/Corresponding/g
s/corse/coarse/g
s/CORSE/COARSE/g
s/Corse/Coarse/g
s/cosntructed/constructed/g
s/COSNTRUCTED/CONSTRUCTED/g
s/Cosntructed/Constructed/g
s/costant/constant/g
s/COSTANT/CONSTANT/g
s/Costant/Constant/g
s/counterpoart/counterpart/g
s/COUNTERPOART/COUNTERPART/g
s/Counterpoart/Counterpart/g
s/cpecial/special/g
s/CPECIAL/SPECIAL/g
s/Cpecial/Special/g
s/curefully/carefully/g
s/CUREFULLY/CAREFULLY/g
s/Curefully/Carefully/g
s/curefuly/carefully/g
s/CUREFULY/CAREFULLY/g
s/Curefuly/Carefully/g
s/cureful/careful/g
s/CUREFUL/CAREFUL/g
s/Cureful/Careful/g
s/curently/currently/g
s/CURENTLY/CURRENTLY/g
s/Curently/Currently/g
s/curretly/currently/g
s/CURRETLY/CURRENTLY/g
s/Curretly/Currently/g
s/customising/customizing/g
s/CUSTOMISING/CUSTOMIZING/g
s/Customising/Customizing/g
s/daclaration/declaration/g
s/DACLARATION/DECLARATION/g
s/Daclaration/Declaration/g
s/daplicating/duplicating/g
s/DAPLICATING/DUPLICATING/g
s/Daplicating/Duplicating/g
s/dealloacte/deallocate/g
s/DEALLOACTE/DEALLOCATE/g
s/Dealloacte/Deallocate/g
s/deapth/depth/g
s/DEAPTH/DEPTH/g
s/Deapth/Depth/g
s/declaratinos/declarations/g
s/DECLARATINOS/DECLARATIONS/g
s/Declaratinos/Declarations/g
s/declartion/declaration/g
s/DECLARTION/DECLARATION/g
s/Declartion/Declaration/g
s/decompresed/decompressed/g
s/DECOMPRESED/DECOMPRESSED/g
s/Decompresed/Decompressed/g
s/decompressd/decompressed/g
s/DECOMPRESSD/DECOMPRESSED/g
s/Decompressd/Decompressed/g
s/decrese/decrease/g
s/DECRESE/DECREASE/g
s/Decrese/Decrease/g
s/decribed/described/g
s/DECRIBED/DESCRIBED/g
s/Decribed/Described/g
s/decribing/describing/g
s/DECRIBING/DESCRIBING/g
s/Decribing/Describing/g
s/defenition/definition/g
s/DEFENITION/DEFINITION/g
s/Defenition/Definition/g
s/delcarations/declarations/g
s/DELCARATIONS/DECLARATIONS/g
s/Delcarations/Declarations/g
s/delimters/delimiter/g
s/DELIMTERS/DELIMITER/g
s/Delimters/Delimiter/g
s/depdendence/dependence/g
s/DEPDENDENCE/DEPENDENCE/g
s/Depdendence/Dependence/g
s/dependecy/dependency/g
s/DEPENDECY/DEPENDENCY/g
s/Dependecy/Dependency/g
s/dependees/dependencies/g
s/DEPENDEES/DEPENDENCIES/g
s/Dependees/Dependencies/g
s/desciptors/descriptors/g
s/DESCIPTORS/DESCRIPTORS/g
s/Desciptors/Descriptors/g
s/describng/describing/g
s/DESCRIBNG/DESCRIBING/g
s/Describng/Describing/g
s/descrptor/descriptor/g
s/DESCRPTOR/DESCRIPTOR/g
s/Descrptor/Descriptor/g
s/desctructive/destructive/g
s/DESCTRUCTIVE/DESTRUCTIVE/g
s/Desctructive/Destructive/g
s/desribed/described/g
s/DESRIBED/DESCRIBED/g
s/Desribed/Described/g
s/desriptors/descriptors/g
s/DESRIPTORS/DESCRIPTORS/g
s/Desriptors/Descriptors/g
s/destinarion/destination/g
s/DESTINARION/DESTINATION/g
s/Destinarion/Destination/g
s/determenistic/deterministic/g
s/DETERMENISTIC/DETERMINISTIC/g
s/Determenistic/Deterministic/g
s/diagnositc/diagnostic/g
s/DIAGNOSITC/DIAGNOSTIC/g
s/Diagnositc/Diagnostic/g
s/dimensonal/dimensional/g
s/DIMENSONAL/DIMENSIONAL/g
s/Dimensonal/Dimensional/g
s/dimesions/dimensions/g
s/DIMESIONS/DIMENSIONS/g
s/Dimesions/Dimensions/g
s/diplay/display/g
s/DIPLAY/DISPLAY/g
s/Diplay/Display/g
s/direcly/directly/g
s/DIRECLY/DIRECTLY/g
s/Direcly/Directly/g
s/dirrectly/directly/g
s/DIRRECTLY/DIRECTLY/g
s/Dirrectly/Directly/g
s/disgnostic/diagnostic/g
s/DISGNOSTIC/DIAGNOSTIC/g
s/Disgnostic/Diagnostic/g
s/displacment/displacement/g
s/DISPLACMENT/DISPLACEMENT/g
s/Displacment/Displacement/g
s/disregrad/disregard/g
s/DISREGRAD/DISREGARD/g
s/Disregrad/Disregard/g
s/dissappears/disappears/g
s/DISSAPPEARS/DISAPPEARS/g
s/Dissappears/Disappears/g
s/dissble/disable/g
s/DISSBLE/DISABLE/g
s/Dissble/Disable/g
s/distictly/distinctly/g
s/DISTICTLY/DISTINCTLY/g
s/Distictly/Distinctly/g
s/distingiush/distinguish/g
s/DISTINGIUSH/DISTINGUISH/g
s/Distingiush/Distinguish/g
s/distingush/distinguish/g
s/DISTINGUSH/DISTINGUISH/g
s/Distingush/Distinguish/g
s/distintions/distinctions/g
s/DISTINTIONS/DISTINCTIONS/g
s/Distintions/Distinctions/g
s/distroying/destroying/g
s/DISTROYING/DESTROYING/g
s/Distroying/Destroying/g
s/documentaton/documentation/g
s/DOCUMENTATON/DOCUMENTATION/g
s/Documentaton/Documentation/g
s/documentdescription/document_description/g
s/DOCUMENTDESCRIPTION/DOCUMENT_DESCRIPTION/g
s/Documentdescription/Document_description/g
s/documentencoding/document_encoding/g
s/DOCUMENTENCODING/DOCUMENT_ENCODING/g
s/Documentencoding/Document_encoding/g
s/documention/documentation/g
s/DOCUMENTION/DOCUMENTATION/g
s/Documention/Documentation/g
s/dupliate/duplicate/g
s/DUPLIATE/DUPLICATE/g
s/Dupliate/Duplicate/g
s/easilty/easily/g
s/EASILTY/EASILY/g
s/Easilty/Easily/g
s/effectiviness/effectiveness/g
s/EFFECTIVINESS/EFFECTIVENESS/g
s/Effectiviness/Effectiveness/g
s/effeect/effect/g
s/EFFEECT/EFFECT/g
s/Effeect/Effect/g
s/elimiante/eliminate/g
s/ELIMIANTE/ELIMINATE/g
s/Elimiante/Eliminate/g
s/elliminated/eliminated/g
s/ELLIMINATED/ELIMINATED/g
s/Elliminated/Eliminated/g
s/elliminate/eliminate/g
s/ELLIMINATE/ELIMINATE/g
s/Elliminate/Eliminate/g
s/ellipsises/ellipsis/g
s/ELLIPSISES/ELLIPSIS/g
s/Ellipsises/Ellipsis/g
s/ellision/elision/g
s/ELLISION/ELISION/g
s/Ellision/Elision/g
s/elsehwere/elsewhere/g
s/ELSEHWERE/ELSEWHERE/g
s/Elsehwere/Elsewhere/g
s/empiricaly/empirically/g
s/EMPIRICALY/EMPIRICALLY/g
s/Empiricaly/Empirically/g
s/epilgoue/epilogue/g
s/EPILGOUE/EPILOGUE/g
s/Epilgoue/Epilogue/g
s/erraneously/erroneously/g
s/ERRANEOUSLY/ERRONEOUSLY/g
s/Erraneously/Erroneously/g
s/esily/easily/g
s/ESILY/EASILY/g
s/Esily/Easily/g
s/esitmate/estimate/g
s/ESITMATE/ESTIMATE/g
s/Esitmate/Estimate/g
s/essentailly/essentially/g
s/ESSENTAILLY/ESSENTIALLY/g
s/Essentailly/Essentially/g
s/essentialy/essentially/g
s/ESSENTIALY/ESSENTIALLY/g
s/Essentialy/Essentially/g
s/estabish/establish/g
s/ESTABISH/ESTABLISH/g
s/Estabish/Establish/g
s/evauluated/evaluated/g
s/EVAULUATED/EVALUATED/g
s/Evauluated/Evaluated/g
s/eventaully/eventually/g
s/EVENTAULLY/EVENTUALLY/g
s/Eventaully/Eventually/g
s/evertything/everything/g
s/EVERTYTHING/EVERYTHING/g
s/Evertything/Everything/g
s/exapnsion/expansion/g
s/EXAPNSION/EXPANSION/g
s/Exapnsion/Expansion/g
s/exceuted/executed/g
s/EXCEUTED/EXECUTED/g
s/Exceuted/Executed/g
s/exexutable/executable/g
s/EXEXUTABLE/EXECUTABLE/g
s/Exexutable/Executable/g
s/exhaused/exhausted/g
s/EXHAUSED/EXHAUSTED/g
s/Exhaused/Exhausted/g
s/existencd/existence/g
s/EXISTENCD/EXISTENCE/g
s/Existencd/Existence/g
s/expaned/expanded/g
s/EXPANED/EXPANDED/g
s/Expaned/Expanded/g
s/expilicitely/explicitly/g
s/EXPILICITELY/EXPLICITLY/g
s/Expilicitely/Explicitly/g
s/explicilty/explicitly/g
s/EXPLICILTY/EXPLICITLY/g
s/Explicilty/Explicitly/g
s/explicits/explicit/g
s/EXPLICITS/EXPLICIT/g
s/Explicits/Explicit/g
s/exponentials/exponential/g
s/EXPONENTIALS/EXPONENTIAL/g
s/Exponentials/Exponential/g
s/exponentialy/exponentially/g
s/EXPONENTIALY/EXPONENTIALLY/g
s/Exponentialy/Exponentially/g
s/extaction/extraction/g
s/EXTACTION/EXTRACTION/g
s/Extaction/Extraction/g
s/exteded/extended/g
s/EXTEDED/EXTENDED/g
s/Exteded/Extended/g
s/extendsions/extensions/g
s/EXTENDSIONS/EXTENSIONS/g
s/Extendsions/Extensions/g
s/extened/extended/g
s/EXTENED/EXTENDED/g
s/Extened/Extended/g
s/exteral/external/g
s/EXTERAL/EXTERNAL/g
s/Exteral/External/g
s/extrapoliate/extrapolate/g
s/EXTRAPOLIATE/EXTRAPOLATE/g
s/Extrapoliate/Extrapolate/g
s/extrat\b/extract/g
s/EXTRAT\b/EXTRACT/g
s/Extrat\b/Extract/g
s/factorisation/factorization/g
s/FACTORISATION/FACTORIZATION/g
s/Factorisation/Factorization/g
s/featues/features/g
s/FEATUES/FEATURES/g
s/Featues/Features/g
s/flattenning/flattening/g
s/FLATTENNING/FLATTENING/g
s/Flattenning/Flattening/g
s/functionon/function/g
s/FUNCTIONON/FUNCTION/g
s/Functionon/Function/g
s/functon/function/g
s/FUNCTON/FUNCTION/g
s/Functon/Function/g
s/garantie/guarantee/g
s/GARANTIE/GUARANTEE/g
s/Garantie/Guarantee/g
s/granilarity/granularity/g
s/GRANILARITY/GRANULARITY/g
s/Granilarity/Granularity/g
s/hundredsof/hundreds_of/g
s/HUNDREDSOF/HUNDREDS_OF/g
s/Hundredsof/Hundreds_of/g
s/incremeneted/incremented/g
s/INCREMENETED/INCREMENTED/g
s/Incremeneted/Incremented/g
s/ineqality/inequality/g
s/INEQALITY/INEQUALITY/g
s/Ineqality/Inequality/g
s/infinately/infinitely/g
s/INFINATELY/INFINITELY/g
s/Infinately/Infinitely/g
s/inlcude/include/g
s/INLCUDE/INCLUDE/g
s/Inlcude/Include/g
s/interesing/interesting/g
s/INTERESING/INTERESTING/g
s/Interesing/Interesting/g
s/interpeter/interpreter/g
s/INTERPETER/INTERPRETER/g
s/Interpeter/Interpreter/g
s/lenghth/lengths/g
s/LENGHTH/LENGTHS/g
s/Lenghth/Lengths/g
s/matris/matrix/g
s/MATRIS/MATRIX/g
s/Matris/Matrix/g
s/mechnanism/mechanism/g
s/MECHNANISM/MECHANISM/g
s/Mechnanism/Mechanism/g
s/multipliciaton/multiplication/g
s/MULTIPLICIATON/MULTIPLICATION/g
s/Multipliciaton/Multiplication/g
s/obtaines/obtains/g
s/OBTAINES/OBTAINS/g
s/Obtaines/Obtains/g
s/occurrs/occurs/g
s/OCCURRS/OCCURS/g
s/Occurrs/Occurs/g
s/plaftorms/platforms/g
s/PLAFTORMS/PLATFORMS/g
s/Plaftorms/Platforms/g
s/preced\b/precede/g
s/PRECED\b/PRECEDE/g
s/Preced\b/Precede/g
s/preceds/precedes/g
s/PRECEDS/PRECEDES/g
s/Preceds/Precedes/g
s/probabilty/probability/g
s/PROBABILTY/PROBABILITY/g
s/Probabilty/Probability/g
s/probabily/probability/g
s/PROBABILY/PROBABILITY/g
s/Probabily/Probability/g
s/procesors/processors/g
s/PROCESORS/PROCESSORS/g
s/Procesors/Processors/g
s/programmes/programmers/g
s/PROGRAMMES/PROGRAMMERS/g
s/Programmes/Programmers/g
s/realiable/reliable/g
s/REALIABLE/RELIABLE/g
s/Realiable/Reliable/g
s/recommanded/recommended/g
s/RECOMMANDED/RECOMMENDED/g
s/Recommanded/Recommended/g
s/recommened/recommend/g
s/RECOMMENED/RECOMMEND/g
s/Recommened/Recommend/g
s/recurrency/recurrence/g
s/RECURRENCY/RECURRENCE/g
s/Recurrency/Recurrence/g
s/referensed/referenced/g
s/REFERENSED/REFERENCED/g
s/Referensed/Referenced/g
s/regsiters/registers/g
s/REGSITERS/REGISTERS/g
s/Regsiters/Registers/g
s/remebers/remembers/g
s/REMEBERS/REMEMBERS/g
s/Remebers/Remembers/g
s/resetable/resettable/g
s/RESETABLE/RESETTABLE/g
s/Resetable/Resettable/g
s/respectivley/respectively/g
s/RESPECTIVLEY/RESPECTIVELY/g
s/Respectivley/Respectively/g
s/restire/restore/g
s/RESTIRE/RESTORE/g
s/Restire/Restore/g
s/retore/restore/g
s/RETORE/RESTORE/g
s/Retore/Restore/g
s/returing/returning/g
s/RETURING/RETURNING/g
s/Returing/Returning/g
s/rigourous/rigorous/g
s/RIGOUROUS/RIGOROUS/g
s/Rigourous/Rigorous/g
s/satelitte/satellite/g
s/SATELITTE/SATELLITE/g
s/Satelitte/Satellite/g
s/sendign/sending/g
s/SENDIGN/SENDING/g
s/Sendign/Sending/g
s/seqence/sequence/g
s/SEQENCE/SEQUENCE/g
s/Seqence/Sequence/g
s/sigificance/significance/g
s/SIGIFICANCE/SIGNIFICANCE/g
s/Sigificance/Significance/g
s/simplicty/simplicity/g
s/SIMPLICTY/SIMPLICITY/g
s/Simplicty/Simplicity/g
s/sligthly/slightly/g
s/SLIGTHLY/SLIGHTLY/g
s/Sligthly/Slightly/g
s/sligtly/slightly/g
s/SLIGTLY/SLIGHTLY/g
s/Sligtly/Slightly/g
s/spcecified/specified/g
s/SPCECIFIED/SPECIFIED/g
s/Spcecified/Specified/g
s/specifyed/specified/g
s/SPECIFYED/SPECIFIED/g
s/Specifyed/Specified/g
s/sucesss/success/g
s/SUCESSS/SUCCESS/g
s/Sucesss/Success/g
s/thounsands/thousands/g
s/THOUNSANDS/THOUSANDS/g
s/Thounsands/Thousands/g
s/typicall\b/typical/g
s/TYPICALL\b/TYPICAL/g
s/Typicall\b/Typical/g
s/uless/unless/g
s/ULESS/UNLESS/g
s/Uless/Unless/g
s/vaues/values/g
s/VAUES/VALUES/g
s/Vaues/Values/g
