#!/bin/sed
s/\babandonned\b/abandoned/g
s/\bABANDONNED\b/ABANDONED/g
s/\bAbandonned\b/Abandoned/g
s/\babandonning\b/abandoning/g
s/\bABANDONNING\b/ABANDONING/g
s/\bAbandonning\b/Abandoning/g
s/\babbrevation\b/abbreviation/g
s/\bABBREVATION\b/ABBREVIATION/g
s/\bAbbrevation\b/Abbreviation/g
s/\babbrevations\b/abbreviations/g
s/\bABBREVATIONS\b/ABBREVIATIONS/g
s/\bAbbrevations\b/Abbreviations/g
s/\babigious\b/ambiguous/g
s/\bABIGIOUS\b/AMBIGUOUS/g
s/\bAbigious\b/Ambiguous/g
s/\babilties\b/abilities/g
s/\bABILTIES\b/ABILITIES/g
s/\bAbilties\b/Abilities/g
s/\babilty\b/ability/g
s/\bABILTY\b/ABILITY/g
s/\bAbilty\b/Ability/g
s/\babitrate\b/arbitrate/g
s/\bABITRATE\b/ARBITRATE/g
s/\bAbitrate\b/Arbitrate/g
s/\babolute\b/absolute/g
s/\bABOLUTE\b/ABSOLUTE/g
s/\bAbolute\b/Absolute/g
s/\babov\b/above/g
s/\bABOV\b/ABOVE/g
s/\bAbov\b/Above/g
s/\babsense\b/absence/g
s/\bABSENSE\b/ABSENCE/g
s/\bAbsense\b/Absence/g
s/\babsolut\b/absolute/g
s/\bABSOLUT\b/ABSOLUTE/g
s/\bAbsolut\b/Absolute/g
s/\babsoulte\b/absolute/g
s/\bABSOULTE\b/ABSOLUTE/g
s/\bAbsoulte\b/Absolute/g
s/\bacccept\b/accept/g
s/\bACCCEPT\b/ACCEPT/g
s/\bAcccept\b/Accept/g
s/\bacccepted\b/accepted/g
s/\bACCCEPTED\b/ACCEPTED/g
s/\bAcccepted\b/Accepted/g
s/\bacccepting\b/accepting/g
s/\bACCCEPTING\b/ACCEPTING/g
s/\bAcccepting\b/Accepting/g
s/\bacccepts\b/accepts/g
s/\bACCCEPTS\b/ACCEPTS/g
s/\bAcccepts\b/Accepts/g
s/\bacccess\b/access/g
s/\bACCCESS\b/ACCESS/g
s/\bAcccess\b/Access/g
s/\bacceleratoin\b/acceleration/g
s/\bACCELERATOIN\b/ACCELERATION/g
s/\bAcceleratoin\b/Acceleration/g
s/\baccelleration\b/acceleration/g
s/\bACCELLERATION\b/ACCELERATION/g
s/\bAccelleration\b/Acceleration/g
s/\baccesing\b/accessing/g
s/\bACCESING\b/ACCESSING/g
s/\bAccesing\b/Accessing/g
s/\baccesnt\b/accent/g
s/\bACCESNT\b/ACCENT/g
s/\bAccesnt\b/Accent/g
s/\baccessable\b/accessible/g
s/\bACCESSABLE\b/ACCESSIBLE/g
s/\bAccessable\b/Accessible/g
s/\baccesss\b/access/g
s/\bACCESSS\b/ACCESS/g
s/\bAccesss\b/Access/g
s/\baccidentaly\b/accidentally/g
s/\bACCIDENTALY\b/ACCIDENTALLY/g
s/\bAccidentaly\b/Accidentally/g
s/\baccidentually\b/accidentally/g
s/\bACCIDENTUALLY\b/ACCIDENTALLY/g
s/\bAccidentually\b/Accidentally/g
s/\baccomodates\b/accommodates/g
s/\bACCOMODATES\b/ACCOMMODATES/g
s/\bAccomodates\b/Accommodates/g
s/\baccompagnied\b/accompanied/g
s/\bACCOMPAGNIED\b/ACCOMPANIED/g
s/\bAccompagnied\b/Accompanied/g
s/\baccompagnies\b/accompanies/g
s/\bACCOMPAGNIES\b/ACCOMPANIES/g
s/\bAccompagnies\b/Accompanies/g
s/\baccompagny\b/accompany/g
s/\bACCOMPAGNY\b/ACCOMPANY/g
s/\bAccompagny\b/Accompany/g
s/\baccompagnying\b/accompanying/g
s/\bACCOMPAGNYING\b/ACCOMPANYING/g
s/\bAccompagnying\b/Accompanying/g
s/\baccordint\b/according/g
s/\bACCORDINT\b/ACCORDING/g
s/\bAccordint\b/According/g
s/\baccoring\b/according/g
s/\bACCORING\b/ACCORDING/g
s/\bAccoring\b/According/g
s/\baccout\b/account/g
s/\bACCOUT\b/ACCOUNT/g
s/\bAccout\b/Account/g
s/\bacess\b/access/g
s/\bACESS\b/ACCESS/g
s/\bAcess\b/Access/g
s/\bacessable\b/accessible/g
s/\bACESSABLE\b/ACCESSIBLE/g
s/\bAcessable\b/Accessible/g
s/\bachitecture\b/architecture/g
s/\bACHITECTURE\b/ARCHITECTURE/g
s/\bAchitecture\b/Architecture/g
s/\bachitectures\b/architectures/g
s/\bACHITECTURES\b/ARCHITECTURES/g
s/\bAchitectures\b/Architectures/g
s/\bachor\b/anchor/g
s/\bACHOR\b/ANCHOR/g
s/\bAchor\b/Anchor/g
s/\bachored\b/anchored/g
s/\bACHORED\b/ANCHORED/g
s/\bAchored\b/Anchored/g
s/\bachoring\b/anchoring/g
s/\bACHORING\b/ANCHORING/g
s/\bAchoring\b/Anchoring/g
s/\bachors\b/anchors/g
s/\bACHORS\b/ANCHORS/g
s/\bAchors\b/Anchors/g
s/\bacient\b/ancient/g
s/\bACIENT\b/ANCIENT/g
s/\bAcient\b/Ancient/g
s/\backnowldegement\b/acknowledgement/g
s/\bACKNOWLDEGEMENT\b/ACKNOWLEDGEMENT/g
s/\bAcknowldegement\b/Acknowledgement/g
s/\backowledge\b/acknowledge/g
s/\bACKOWLEDGE\b/ACKNOWLEDGE/g
s/\bAckowledge\b/Acknowledge/g
s/\backowledged\b/acknowledged/g
s/\bACKOWLEDGED\b/ACKNOWLEDGED/g
s/\bAckowledged\b/Acknowledged/g
s/\bacording\b/according/g
s/\bACORDING\b/ACCORDING/g
s/\bAcording\b/According/g
s/\bacqure\b/acquire/g
s/\bACQURE\b/ACQUIRE/g
s/\bAcqure\b/Acquire/g
s/\bacqured\b/acquired/g
s/\bACQURED\b/ACQUIRED/g
s/\bAcqured\b/Acquired/g
s/\bacqures\b/acquires/g
s/\bACQURES\b/ACQUIRES/g
s/\bAcqures\b/Acquires/g
s/\bacquring\b/acquiring/g
s/\bACQURING\b/ACQUIRING/g
s/\bAcquring\b/Acquiring/g
s/\bactaul\b/actual/g
s/\bACTAUL\b/ACTUAL/g
s/\bActaul\b/Actual/g
s/\bactaully\b/actually/g
s/\bACTAULLY\b/ACTUALLY/g
s/\bActaully\b/Actually/g
s/\bactivete\b/activate/g
s/\bACTIVETE\b/ACTIVATE/g
s/\bActivete\b/Activate/g
s/\bacually\b/actually/g
s/\bACUALLY\b/ACTUALLY/g
s/\bAcually\b/Actually/g
s/\bacumulating\b/accumulating/g
s/\bACUMULATING\b/ACCUMULATING/g
s/\bAcumulating\b/Accumulating/g
s/\bacutally\b/actually/g
s/\bACUTALLY\b/ACTUALLY/g
s/\bAcutally\b/Actually/g
s/\badapated\b/adapted/g
s/\bADAPATED\b/ADAPTED/g
s/\bAdapated\b/Adapted/g
s/\baddd\b/add/g
s/\bADDD\b/ADD/g
s/\bAddd\b/Add/g
s/\baddded\b/added/g
s/\bADDDED\b/ADDED/g
s/\bAddded\b/Added/g
s/\baddding\b/adding/g
s/\bADDDING\b/ADDING/g
s/\bAddding\b/Adding/g
s/\baddds\b/adds/g
s/\bADDDS\b/ADDS/g
s/\bAddds\b/Adds/g
s/\baddess\b/address/g
s/\bADDESS\b/ADDRESS/g
s/\bAddess\b/Address/g
s/\baddessed\b/addressed/g
s/\bADDESSED\b/ADDRESSED/g
s/\bAddessed\b/Addressed/g
s/\baddesses\b/addresses/g
s/\bADDESSES\b/ADDRESSES/g
s/\bAddesses\b/Addresses/g
s/\baddessing\b/addressing/g
s/\bADDESSING\b/ADDRESSING/g
s/\bAddessing\b/Addressing/g
s/\baddional\b/additional/g
s/\bADDIONAL\b/ADDITIONAL/g
s/\bAddional\b/Additional/g
s/\badditionaly\b/additionally/g
s/\bADDITIONALY\b/ADDITIONALLY/g
s/\bAdditionaly\b/Additionally/g
s/\badditonal\b/additional/g
s/\bADDITONAL\b/ADDITIONAL/g
s/\bAdditonal\b/Additional/g
s/\badditonally\b/additionally/g
s/\bADDITONALLY\b/ADDITIONALLY/g
s/\bAdditonally\b/Additionally/g
s/\baddres\b/address/g
s/\bADDRES\b/ADDRESS/g
s/\bAddres\b/Address/g
s/\baddresed\b/addressed/g
s/\bADDRESED\b/ADDRESSED/g
s/\bAddresed\b/Addressed/g
s/\baddreses\b/addresses/g
s/\bADDRESES\b/ADDRESSES/g
s/\bAddreses\b/Addresses/g
s/\baddresing\b/addressing/g
s/\bADDRESING\b/ADDRESSING/g
s/\bAddresing\b/Addressing/g
s/\baditional\b/additional/g
s/\bADITIONAL\b/ADDITIONAL/g
s/\bAditional\b/Additional/g
s/\baditionally\b/additionally/g
s/\bADITIONALLY\b/ADDITIONALLY/g
s/\bAditionally\b/Additionally/g
s/\baditionaly\b/additionally/g
s/\bADITIONALY\b/ADDITIONALLY/g
s/\bAditionaly\b/Additionally/g
s/\badress\b/address/g
s/\bADRESS\b/ADDRESS/g
s/\bAdress\b/Address/g
s/\badressed\b/addressed/g
s/\bADRESSED\b/ADDRESSED/g
s/\bAdressed\b/Addressed/g
s/\badresses\b/addresses/g
s/\bADRESSES\b/ADDRESSES/g
s/\bAdresses\b/Addresses/g
s/\badressing\b/addressing/g
s/\bADRESSING\b/ADDRESSING/g
s/\bAdressing\b/Addressing/g
s/\badvertisment\b/advertisement/g
s/\bADVERTISMENT\b/ADVERTISEMENT/g
s/\bAdvertisment\b/Advertisement/g
s/\badvertisments\b/advertisements/g
s/\bADVERTISMENTS\b/ADVERTISEMENTS/g
s/\bAdvertisments\b/Advertisements/g
s/\badviced\b/advised/g
s/\bADVICED\b/ADVISED/g
s/\bAdviced\b/Advised/g
s/\bafecting\b/affecting/g
s/\bAFECTING\b/AFFECTING/g
s/\bAfecting\b/Affecting/g
s/\bafer\b/after/g
s/\bAFER\b/AFTER/g
s/\bAfer\b/After/g
s/\baforementionned\b/aforementioned/g
s/\bAFOREMENTIONNED\b/AFOREMENTIONED/g
s/\bAforementionned\b/Aforementioned/g
s/\baformentioned\b/aforementioned/g
s/\bAFORMENTIONED\b/AFOREMENTIONED/g
s/\bAformentioned\b/Aforementioned/g
s/\bafterall\b/after all/g
s/\bAFTERALL\b/AFTER ALL/g
s/\bAfterall\b/After all/g
s/\bagains\b/against/g
s/\bAGAINS\b/AGAINST/g
s/\bAgains\b/Against/g
s/\bagressive\b/aggressive/g
s/\bAGRESSIVE\b/AGGRESSIVE/g
s/\bAgressive\b/Aggressive/g
s/\bagressively\b/aggressively/g
s/\bAGRESSIVELY\b/AGGRESSIVELY/g
s/\bAgressively\b/Aggressively/g
s/\bagrument\b/argument/g
s/\bAGRUMENT\b/ARGUMENT/g
s/\bAgrument\b/Argument/g
s/\bagruments\b/arguments/g
s/\bAGRUMENTS\b/ARGUMENTS/g
s/\bAgruments\b/Arguments/g
s/\balbumns\b/albums/g
s/\bALBUMNS\b/ALBUMS/g
s/\bAlbumns\b/Albums/g
s/\balegorical\b/allegorical/g
s/\bALEGORICAL\b/ALLEGORICAL/g
s/\bAlegorical\b/Allegorical/g
s/\balgorith\b/algorithm/g
s/\bALGORITH\b/ALGORITHM/g
s/\bAlgorith\b/Algorithm/g
s/\balgorithmical\b/algorithmically/g
s/\bALGORITHMICAL\b/ALGORITHMICALLY/g
s/\bAlgorithmical\b/Algorithmically/g
s/\balgoritm\b/algorithm/g
s/\bALGORITM\b/ALGORITHM/g
s/\bAlgoritm\b/Algorithm/g
s/\balgoritms\b/algorithms/g
s/\bALGORITMS\b/ALGORITHMS/g
s/\bAlgoritms\b/Algorithms/g
s/\balgorrithm\b/algorithm/g
s/\bALGORRITHM\b/ALGORITHM/g
s/\bAlgorrithm\b/Algorithm/g
s/\balgorritm\b/algorithm/g
s/\bALGORRITM\b/ALGORITHM/g
s/\bAlgorritm\b/Algorithm/g
s/\balignemnt\b/alignment/g
s/\bALIGNEMNT\b/ALIGNMENT/g
s/\bAlignemnt\b/Alignment/g
s/\balignemnts\b/alignments/g
s/\bALIGNEMNTS\b/ALIGNMENTS/g
s/\bAlignemnts\b/Alignments/g
s/\ballign\b/align/g
s/\bALLIGN\b/ALIGN/g
s/\bAllign\b/Align/g
s/\balligned\b/aligned/g
s/\bALLIGNED\b/ALIGNED/g
s/\bAlligned\b/Aligned/g
s/\balligning\b/aligning/g
s/\bALLIGNING\b/ALIGNING/g
s/\bAlligning\b/Aligning/g
s/\balligns\b/aligns/g
s/\bALLIGNS\b/ALIGNS/g
s/\bAlligns\b/Aligns/g
s/\ballpication\b/application/g
s/\bALLPICATION\b/APPLICATION/g
s/\bAllpication\b/Application/g
s/\ballthough\b/although/g
s/\bALLTHOUGH\b/ALTHOUGH/g
s/\bAllthough\b/Although/g
s/\balltogether\b/altogether/g
s/\bALLTOGETHER\b/ALTOGETHER/g
s/\bAlltogether\b/Altogether/g
s/\balocate\b/allocate/g
s/\bALOCATE\b/ALLOCATE/g
s/\bAlocate\b/Allocate/g
s/\balocated\b/allocated/g
s/\bALOCATED\b/ALLOCATED/g
s/\bAlocated\b/Allocated/g
s/\balocates\b/allocates/g
s/\bALOCATES\b/ALLOCATES/g
s/\bAlocates\b/Allocates/g
s/\balocating\b/allocating/g
s/\bALOCATING\b/ALLOCATING/g
s/\bAlocating\b/Allocating/g
s/\balogirhtms\b/algorithms/g
s/\bALOGIRHTMS\b/ALGORITHMS/g
s/\bAlogirhtms\b/Algorithms/g
s/\balogrithm\b/algorithm/g
s/\bALOGRITHM\b/ALGORITHM/g
s/\bAlogrithm\b/Algorithm/g
s/\balogrithms\b/algorithms/g
s/\bALOGRITHMS\b/ALGORITHMS/g
s/\bAlogrithms\b/Algorithms/g
s/\balot\b/a lot/g
s/\bALOT\b/A LOT/g
s/\bAlot\b/A lot/g
s/\balow\b/allow/g
s/\bALOW\b/ALLOW/g
s/\bAlow\b/Allow/g
s/\balows\b/allows/g
s/\bALOWS\b/ALLOWS/g
s/\bAlows\b/Allows/g
s/\balpabet\b/alphabet/g
s/\bALPABET\b/ALPHABET/g
s/\bAlpabet\b/Alphabet/g
s/\balpabetic\b/alphabetic/g
s/\bALPABETIC\b/ALPHABETIC/g
s/\bAlpabetic\b/Alphabetic/g
s/\balpabetical\b/alphabetical/g
s/\bALPABETICAL\b/ALPHABETICAL/g
s/\bAlpabetical\b/Alphabetical/g
s/\balpabets\b/alphabets/g
s/\bALPABETS\b/ALPHABETS/g
s/\bAlpabets\b/Alphabets/g
s/\balreay\b/already/g
s/\bALREAY\b/ALREADY/g
s/\bAlreay\b/Already/g
s/\baltough\b/although/g
s/\bALTOUGH\b/ALTHOUGH/g
s/\bAltough\b/Although/g
s/\bambigious\b/ambiguous/g
s/\bAMBIGIOUS\b/AMBIGUOUS/g
s/\bAmbigious\b/Ambiguous/g
s/\bambigous\b/ambiguous/g
s/\bAMBIGOUS\b/AMBIGUOUS/g
s/\bAmbigous\b/Ambiguous/g
s/\bammend\b/amend/g
s/\bAMMEND\b/AMEND/g
s/\bAmmend\b/Amend/g
s/\bammended\b/amended/g
s/\bAMMENDED\b/AMENDED/g
s/\bAmmended\b/Amended/g
s/\bammending\b/amending/g
s/\bAMMENDING\b/AMENDING/g
s/\bAmmending\b/Amending/g
s/\bammends\b/amends/g
s/\bAMMENDS\b/AMENDS/g
s/\bAmmends\b/Amends/g
s/\bammount\b/amount/g
s/\bAMMOUNT\b/AMOUNT/g
s/\bAmmount\b/Amount/g
s/\bamoung\b/among/g
s/\bAMOUNG\b/AMONG/g
s/\bAmoung\b/Among/g
s/\banalagous\b/analogous/g
s/\bANALAGOUS\b/ANALOGOUS/g
s/\bAnalagous\b/Analogous/g
s/\banalysator\b/analyzer/g
s/\bANALYSATOR\b/ANALYZER/g
s/\bAnalysator\b/Analyzer/g
s/\bang\b/and/g
s/\bANG\b/AND/g
s/\bAng\b/And/g
s/\banniversery\b/anniversary/g
s/\bANNIVERSERY\b/ANNIVERSARY/g
s/\bAnniversery\b/Anniversary/g
s/\bannoucement\b/announcement/g
s/\bANNOUCEMENT\b/ANNOUNCEMENT/g
s/\bAnnoucement\b/Announcement/g
s/\banomolies\b/anomalies/g
s/\bANOMOLIES\b/ANOMALIES/g
s/\bAnomolies\b/Anomalies/g
s/\banomoly\b/anomaly/g
s/\bANOMOLY\b/ANOMALY/g
s/\bAnomoly\b/Anomaly/g
s/\banyting\b/anything/g
s/\bANYTING\b/ANYTHING/g
s/\bAnyting\b/Anything/g
s/\baplication\b/application/g
s/\bAPLICATION\b/APPLICATION/g
s/\bAplication\b/Application/g
s/\bappearence\b/appearance/g
s/\bAPPEARENCE\b/APPEARANCE/g
s/\bAppearence\b/Appearance/g
s/\bappeneded\b/appended/g
s/\bAPPENEDED\b/APPENDED/g
s/\bAppeneded\b/Appended/g
s/\bappliction\b/application/g
s/\bAPPLICTION\b/APPLICATION/g
s/\bAppliction\b/Application/g
s/\bapplictions\b/applications/g
s/\bAPPLICTIONS\b/APPLICATIONS/g
s/\bApplictions\b/Applications/g
s/\bappplication\b/application/g
s/\bAPPPLICATION\b/APPLICATION/g
s/\bAppplication\b/Application/g
s/\bappplications\b/applications/g
s/\bAPPPLICATIONS\b/APPLICATIONS/g
s/\bAppplications\b/Applications/g
s/\bappropiate\b/appropriate/g
s/\bAPPROPIATE\b/APPROPRIATE/g
s/\bAppropiate\b/Appropriate/g
s/\bappropriatly\b/appropriately/g
s/\bAPPROPRIATLY\b/APPROPRIATELY/g
s/\bAppropriatly\b/Appropriately/g
s/\bapproproate\b/appropriate/g
s/\bAPPROPROATE\b/APPROPRIATE/g
s/\bApproproate\b/Appropriate/g
s/\bappropropriate\b/appropriate/g
s/\bAPPROPROPRIATE\b/APPROPRIATE/g
s/\bAppropropriate\b/Appropriate/g
s/\bapproriate\b/appropriate/g
s/\bAPPRORIATE\b/APPROPRIATE/g
s/\bApproriate\b/Appropriate/g
s/\bapproriately\b/appropriately/g
s/\bAPPRORIATELY\b/APPROPRIATELY/g
s/\bApproriately\b/Appropriately/g
s/\bapproximatly\b/approximately/g
s/\bAPPROXIMATLY\b/APPROXIMATELY/g
s/\bApproximatly\b/Approximately/g
s/\baproximation\b/approximation/g
s/\bAPROXIMATION\b/APPROXIMATION/g
s/\bAproximation\b/Approximation/g
s/\baproximations\b/approximations/g
s/\bAPROXIMATIONS\b/APPROXIMATIONS/g
s/\bAproximations\b/Approximations/g
s/\baqcuire\b/acquire/g
s/\bAQCUIRE\b/ACQUIRE/g
s/\bAqcuire\b/Acquire/g
s/\baqcuired\b/acquired/g
s/\bAQCUIRED\b/ACQUIRED/g
s/\bAqcuired\b/Acquired/g
s/\baqcuires\b/acquires/g
s/\bAQCUIRES\b/ACQUIRES/g
s/\bAqcuires\b/Acquires/g
s/\baqcuiring\b/acquiring/g
s/\bAQCUIRING\b/ACQUIRING/g
s/\bAqcuiring\b/Acquiring/g
s/\baquaint\b/acquaint/g
s/\bAQUAINT\b/ACQUAINT/g
s/\bAquaint\b/Acquaint/g
s/\baquainted\b/acquainted/g
s/\bAQUAINTED\b/ACQUAINTED/g
s/\bAquainted\b/Acquainted/g
s/\baquainting\b/acquainting/g
s/\bAQUAINTING\b/ACQUAINTING/g
s/\bAquainting\b/Acquainting/g
s/\baquaints\b/acquaints/g
s/\bAQUAINTS\b/ACQUAINTS/g
s/\bAquaints\b/Acquaints/g
s/\baquisition\b/acquisition/g
s/\bAQUISITION\b/ACQUISITION/g
s/\bAquisition\b/Acquisition/g
s/\barbitary\b/arbitrary/g
s/\bARBITARY\b/ARBITRARY/g
s/\bArbitary\b/Arbitrary/g
s/\barbitray\b/arbitrary/g
s/\bARBITRAY\b/ARBITRARY/g
s/\bArbitray\b/Arbitrary/g
s/\barchiecture\b/architecture/g
s/\bARCHIECTURE\b/ARCHITECTURE/g
s/\bArchiecture\b/Architecture/g
s/\barchiectures\b/architectures/g
s/\bARCHIECTURES\b/ARCHITECTURES/g
s/\bArchiectures\b/Architectures/g
s/\barchitechture\b/architecture/g
s/\bARCHITECHTURE\b/ARCHITECTURE/g
s/\bArchitechture\b/Architecture/g
s/\barchitechtures\b/architectures/g
s/\bARCHITECHTURES\b/ARCHITECTURES/g
s/\bArchitechtures\b/Architectures/g
s/\barchvie\b/archive/g
s/\bARCHVIE\b/ARCHIVE/g
s/\bArchvie\b/Archive/g
s/\barchvies\b/archives/g
s/\bARCHVIES\b/ARCHIVES/g
s/\bArchvies\b/Archives/g
s/\baready\b/already/g
s/\bAREADY\b/ALREADY/g
s/\bAready\b/Already/g
s/\barguement\b/argument/g
s/\bARGUEMENT\b/ARGUMENT/g
s/\bArguement\b/Argument/g
s/\barguements\b/arguments/g
s/\bARGUEMENTS\b/ARGUMENTS/g
s/\bArguements\b/Arguments/g
s/\barithmatic\b/arithmetic/g
s/\bARITHMATIC\b/ARITHMETIC/g
s/\bArithmatic\b/Arithmetic/g
s/\baritmetic\b/arithmetic/g
s/\bARITMETIC\b/ARITHMETIC/g
s/\bAritmetic\b/Arithmetic/g
s/\barne't\b/aren't/g
s/\bARNE'T\b/AREN'T/g
s/\bArne't\b/Aren't/g
s/\baroung\b/around/g
s/\bAROUNG\b/AROUND/g
s/\bAroung\b/Around/g
s/\barraival\b/arrival/g
s/\bARRAIVAL\b/ARRIVAL/g
s/\bArraival\b/Arrival/g
s/\barround\b/around/g
s/\bARROUND\b/AROUND/g
s/\bArround\b/Around/g
s/\bartifical\b/artificial/g
s/\bARTIFICAL\b/ARTIFICIAL/g
s/\bArtifical\b/Artificial/g
s/\bartifically\b/artificially/g
s/\bARTIFICALLY\b/ARTIFICIALLY/g
s/\bArtifically\b/Artificially/g
s/\bartillary\b/artillery/g
s/\bARTILLARY\b/ARTILLERY/g
s/\bArtillary\b/Artillery/g
s/\barugment\b/argument/g
s/\bARUGMENT\b/ARGUMENT/g
s/\bArugment\b/Argument/g
s/\barugments\b/arguments/g
s/\bARUGMENTS\b/ARGUMENTS/g
s/\bArugments\b/Arguments/g
s/\bassertation\b/assertion/g
s/\bASSERTATION\b/ASSERTION/g
s/\bAssertation\b/Assertion/g
s/\bassgin\b/assign/g
s/\bASSGIN\b/ASSIGN/g
s/\bAssgin\b/Assign/g
s/\bassgined\b/assigned/g
s/\bASSGINED\b/ASSIGNED/g
s/\bAssgined\b/Assigned/g
s/\bassgining\b/assigning/g
s/\bASSGINING\b/ASSIGNING/g
s/\bAssgining\b/Assigning/g
s/\bassginment\b/assignment/g
s/\bASSGINMENT\b/ASSIGNMENT/g
s/\bAssginment\b/Assignment/g
s/\bassginments\b/assignments/g
s/\bASSGINMENTS\b/ASSIGNMENTS/g
s/\bAssginments\b/Assignments/g
s/\bassgins\b/assigns/g
s/\bASSGINS\b/ASSIGNS/g
s/\bAssgins\b/Assigns/g
s/\bassigments\b/assignments/g
s/\bASSIGMENTS\b/ASSIGNMENTS/g
s/\bAssigments\b/Assignments/g
s/\bassignemnt\b/assignment/g
s/\bASSIGNEMNT\b/ASSIGNMENT/g
s/\bAssignemnt\b/Assignment/g
s/\bassignemnts\b/assignments/g
s/\bASSIGNEMNTS\b/ASSIGNMENTS/g
s/\bAssignemnts\b/Assignments/g
s/\bassistent\b/assistant/g
s/\bASSISTENT\b/ASSISTANT/g
s/\bAssistent\b/Assistant/g
s/\bassocate\b/associate/g
s/\bASSOCATE\b/ASSOCIATE/g
s/\bAssocate\b/Associate/g
s/\bassocated\b/associated/g
s/\bASSOCATED\b/ASSOCIATED/g
s/\bAssocated\b/Associated/g
s/\bassocates\b/associates/g
s/\bASSOCATES\b/ASSOCIATES/g
s/\bAssocates\b/Associates/g
s/\bassocating\b/associating/g
s/\bASSOCATING\b/ASSOCIATING/g
s/\bAssocating\b/Associating/g
s/\bassocation\b/association/g
s/\bASSOCATION\b/ASSOCIATION/g
s/\bAssocation\b/Association/g
s/\bassocicate\b/associate/g
s/\bASSOCICATE\b/ASSOCIATE/g
s/\bAssocicate\b/Associate/g
s/\bassocicated\b/associated/g
s/\bASSOCICATED\b/ASSOCIATED/g
s/\bAssocicated\b/Associated/g
s/\bassocicates\b/associates/g
s/\bASSOCICATES\b/ASSOCIATES/g
s/\bAssocicates\b/Associates/g
s/\bassocicating\b/associating/g
s/\bASSOCICATING\b/ASSOCIATING/g
s/\bAssocicating\b/Associating/g
s/\bassotiated\b/associated/g
s/\bASSOTIATED\b/ASSOCIATED/g
s/\bAssotiated\b/Associated/g
s/\basthetic\b/aesthetic/g
s/\bASTHETIC\b/AESTHETIC/g
s/\bAsthetic\b/Aesthetic/g
s/\basuming\b/assuming/g
s/\bASUMING\b/ASSUMING/g
s/\bAsuming\b/Assuming/g
s/\basycronous\b/asynchronous/g
s/\bASYCRONOUS\b/ASYNCHRONOUS/g
s/\bAsycronous\b/Asynchronous/g
s/\basynchonous\b/asynchronous/g
s/\bASYNCHONOUS\b/ASYNCHRONOUS/g
s/\bAsynchonous\b/Asynchronous/g
s/\basynchonously\b/asynchronously/g
s/\bASYNCHONOUSLY\b/ASYNCHRONOUSLY/g
s/\bAsynchonously\b/Asynchronously/g
s/\batomatically\b/automatically/g
s/\bATOMATICALLY\b/AUTOMATICALLY/g
s/\bAtomatically\b/Automatically/g
s/\battachement\b/attachment/g
s/\bATTACHEMENT\b/ATTACHMENT/g
s/\bAttachement\b/Attachment/g
s/\battemps\b/attempts/g
s/\bATTEMPS\b/ATTEMPTS/g
s/\bAttemps\b/Attempts/g
s/\battemt\b/attempt/g
s/\bATTEMT\b/ATTEMPT/g
s/\bAttemt\b/Attempt/g
s/\battemted\b/attempted/g
s/\bATTEMTED\b/ATTEMPTED/g
s/\bAttemted\b/Attempted/g
s/\battemting\b/attempting/g
s/\bATTEMTING\b/ATTEMPTING/g
s/\bAttemting\b/Attempting/g
s/\battemtp\b/attempt/g
s/\bATTEMTP\b/ATTEMPT/g
s/\bAttemtp\b/Attempt/g
s/\battemtped\b/attempted/g
s/\bATTEMTPED\b/ATTEMPTED/g
s/\bAttemtped\b/Attempted/g
s/\battemtping\b/attempting/g
s/\bATTEMTPING\b/ATTEMPTING/g
s/\bAttemtping\b/Attempting/g
s/\battemtps\b/attempts/g
s/\bATTEMTPS\b/ATTEMPTS/g
s/\bAttemtps\b/Attempts/g
s/\battemts\b/attempts/g
s/\bATTEMTS\b/ATTEMPTS/g
s/\bAttemts\b/Attempts/g
s/\battibute\b/attribute/g
s/\bATTIBUTE\b/ATTRIBUTE/g
s/\bAttibute\b/Attribute/g
s/\battibutes\b/attributes/g
s/\bATTIBUTES\b/ATTRIBUTES/g
s/\bAttibutes\b/Attributes/g
s/\battirbute\b/attribute/g
s/\bATTIRBUTE\b/ATTRIBUTE/g
s/\bAttirbute\b/Attribute/g
s/\battirbutes\b/attributes/g
s/\bATTIRBUTES\b/ATTRIBUTES/g
s/\bAttirbutes\b/Attributes/g
s/\battruibutes\b/attributes/g
s/\bATTRUIBUTES\b/ATTRIBUTES/g
s/\bAttruibutes\b/Attributes/g
s/\batttribute\b/attribute/g
s/\bATTTRIBUTE\b/ATTRIBUTE/g
s/\bAtttribute\b/Attribute/g
s/\batttributes\b/attributes/g
s/\bATTTRIBUTES\b/ATTRIBUTES/g
s/\bAtttributes\b/Attributes/g
s/\bautenticate\b/authenticate/g
s/\bAUTENTICATE\b/AUTHENTICATE/g
s/\bAutenticate\b/Authenticate/g
s/\bautenticated\b/authenticated/g
s/\bAUTENTICATED\b/AUTHENTICATED/g
s/\bAutenticated\b/Authenticated/g
s/\bautenticates\b/authenticates/g
s/\bAUTENTICATES\b/AUTHENTICATES/g
s/\bAutenticates\b/Authenticates/g
s/\bautenticating\b/authenticating/g
s/\bAUTENTICATING\b/AUTHENTICATING/g
s/\bAutenticating\b/Authenticating/g
s/\bautentication\b/authentication/g
s/\bAUTENTICATION\b/AUTHENTICATION/g
s/\bAutentication\b/Authentication/g
s/\bauthenticaiton\b/authentication/g
s/\bAUTHENTICAITON\b/AUTHENTICATION/g
s/\bAuthenticaiton\b/Authentication/g
s/\bauthentification\b/authentication/g
s/\bAUTHENTIFICATION\b/AUTHENTICATION/g
s/\bAuthentification\b/Authentication/g
s/\bauthorative\b/authoritative/g
s/\bAUTHORATIVE\b/AUTHORITATIVE/g
s/\bAuthorative\b/Authoritative/g
s/\bauthoritive\b/authoritative/g
s/\bAUTHORITIVE\b/AUTHORITATIVE/g
s/\bAuthoritive\b/Authoritative/g
s/\bautomaticall\b/automatically/g
s/\bAUTOMATICALL\b/AUTOMATICALLY/g
s/\bAutomaticall\b/Automatically/g
s/\bautomaticaly\b/automatically/g
s/\bAUTOMATICALY\b/AUTOMATICALLY/g
s/\bAutomaticaly\b/Automatically/g
s/\bautomaticly\b/automatically/g
s/\bAUTOMATICLY\b/AUTOMATICALLY/g
s/\bAutomaticly\b/Automatically/g
s/\bautomatize\b/automate/g
s/\bAUTOMATIZE\b/AUTOMATE/g
s/\bAutomatize\b/Automate/g
s/\bautomatized\b/automated/g
s/\bAUTOMATIZED\b/AUTOMATED/g
s/\bAutomatized\b/Automated/g
s/\bautomatizes\b/automates/g
s/\bAUTOMATIZES\b/AUTOMATES/g
s/\bAutomatizes\b/Automates/g
s/\bautonymous\b/autonomous/g
s/\bAUTONYMOUS\b/AUTONOMOUS/g
s/\bAutonymous\b/Autonomous/g
s/\bauxilary\b/auxiliary/g
s/\bAUXILARY\b/AUXILIARY/g
s/\bAuxilary\b/Auxiliary/g
s/\bauxillary\b/auxiliary/g
s/\bAUXILLARY\b/AUXILIARY/g
s/\bAuxillary\b/Auxiliary/g
s/\bauxilliary\b/auxiliary/g
s/\bAUXILLIARY\b/AUXILIARY/g
s/\bAuxilliary\b/Auxiliary/g
s/\bavaiable\b/available/g
s/\bAVAIABLE\b/AVAILABLE/g
s/\bAvaiable\b/Available/g
s/\bavailabe\b/available/g
s/\bAVAILABE\b/AVAILABLE/g
s/\bAvailabe\b/Available/g
s/\bavailabled\b/available/g
s/\bAVAILABLED\b/AVAILABLE/g
s/\bAvailabled\b/Available/g
s/\bavailablity\b/availability/g
s/\bAVAILABLITY\b/AVAILABILITY/g
s/\bAvailablity\b/Availability/g
s/\bavailale\b/available/g
s/\bAVAILALE\b/AVAILABLE/g
s/\bAvailale\b/Available/g
s/\bavailavility\b/availability/g
s/\bAVAILAVILITY\b/AVAILABILITY/g
s/\bAvailavility\b/Availability/g
s/\bavailble\b/available/g
s/\bAVAILBLE\b/AVAILABLE/g
s/\bAvailble\b/Available/g
s/\bavailiable\b/available/g
s/\bAVAILIABLE\b/AVAILABLE/g
s/\bAvailiable\b/Available/g
s/\bavaliable\b/available/g
s/\bAVALIABLE\b/AVAILABLE/g
s/\bAvaliable\b/Available/g
s/\baviable\b/available/g
s/\bAVIABLE\b/AVAILABLE/g
s/\bAviable\b/Available/g
s/\bavilable\b/available/g
s/\bAVILABLE\b/AVAILABLE/g
s/\bAvilable\b/Available/g
s/\bbackgroud\b/background/g
s/\bBACKGROUD\b/BACKGROUND/g
s/\bBackgroud\b/Background/g
s/\bbackslashs\b/backslashes/g
s/\bBACKSLASHS\b/BACKSLASHES/g
s/\bBackslashs\b/Backslashes/g
s/\bbahavior\b/behavior/g
s/\bBAHAVIOR\b/BEHAVIOR/g
s/\bBahavior\b/Behavior/g
s/\bbaloon\b/balloon/g
s/\bBALOON\b/BALLOON/g
s/\bBaloon\b/Balloon/g
s/\bbaloons\b/balloons/g
s/\bBALOONS\b/BALLOONS/g
s/\bBaloons\b/Balloons/g
s/\bbandwith\b/bandwidth/g
s/\bBANDWITH\b/BANDWIDTH/g
s/\bBandwith\b/Bandwidth/g
s/\bbasicly\b/basically/g
s/\bBASICLY\b/BASICALLY/g
s/\bBasicly\b/Basically/g
s/\bbatery\b/battery/g
s/\bBATERY\b/BATTERY/g
s/\bBatery\b/Battery/g
s/\bbeacause\b/because/g
s/\bBEACAUSE\b/BECAUSE/g
s/\bBeacause\b/Because/g
s/\bbeacuse\b/because/g
s/\bBEACUSE\b/BECAUSE/g
s/\bBeacuse\b/Because/g
s/\bbeause\b/because/g
s/\bBEAUSE\b/BECAUSE/g
s/\bBeause\b/Because/g
s/\bbecomming\b/becoming/g
s/\bBECOMMING\b/BECOMING/g
s/\bBecomming\b/Becoming/g
s/\bbeeing\b/being/g
s/\bBEEING\b/BEING/g
s/\bBeeing\b/Being/g
s/\bbehavoir\b/behavior/g
s/\bBEHAVOIR\b/BEHAVIOR/g
s/\bBehavoir\b/Behavior/g
s/\bbehavoirs\b/behaviors/g
s/\bBEHAVOIRS\b/BEHAVIORS/g
s/\bBehavoirs\b/Behaviors/g
s/\bbellow\b/below/g
s/\bBELLOW\b/BELOW/g
s/\bBellow\b/Below/g
s/\bbenifit\b/benefit/g
s/\bBENIFIT\b/BENEFIT/g
s/\bBenifit\b/Benefit/g
s/\bbetwen\b/between/g
s/\bBETWEN\b/BETWEEN/g
s/\bBetwen\b/Between/g
s/\bbianries\b/binaries/g
s/\bBIANRIES\b/BINARIES/g
s/\bBianries\b/Binaries/g
s/\bbizzare\b/bizarre/g
s/\bBIZZARE\b/BIZARRE/g
s/\bBizzare\b/Bizarre/g
s/\bblindy\b/blindly/g
s/\bBLINDY\b/BLINDLY/g
s/\bBlindy\b/Blindly/g
s/\bboundry\b/boundary/g
s/\bBOUNDRY\b/BOUNDARY/g
s/\bBoundry\b/Boundary/g
s/\bbrige\b/bridge/g
s/\bBRIGE\b/BRIDGE/g
s/\bBrige\b/Bridge/g
s/\bbriges\b/bridges/g
s/\bBRIGES\b/BRIDGES/g
s/\bBriges\b/Bridges/g
s/\bbrighness\b/brightness/g
s/\bBRIGHNESS\b/BRIGHTNESS/g
s/\bBrighness\b/Brightness/g
s/\bbrokeness\b/brokenness/g
s/\bBROKENESS\b/BROKENNESS/g
s/\bBrokeness\b/Brokenness/g
s/\bbrower\b/browser/g
s/\bBROWER\b/BROWSER/g
s/\bBrower\b/Browser/g
s/\bbrowers\b/browsers/g
s/\bBROWERS\b/BROWSERS/g
s/\bBrowers\b/Browsers/g
s/\bbufffer\b/buffer/g
s/\bBUFFFER\b/BUFFER/g
s/\bBufffer\b/Buffer/g
s/\bbufffers\b/buffers/g
s/\bBUFFFERS\b/BUFFERS/g
s/\bBufffers\b/Buffers/g
s/\bbulid\b/build/g
s/\bBULID\b/BUILD/g
s/\bBulid\b/Build/g
s/\bbuliding\b/building/g
s/\bBULIDING\b/BUILDING/g
s/\bBuliding\b/Building/g
s/\bbulids\b/builds/g
s/\bBULIDS\b/BUILDS/g
s/\bBulids\b/Builds/g
s/\bbulit\b/built/g
s/\bBULIT\b/BUILT/g
s/\bBulit\b/Built/g
s/\bcalcualte\b/calculate/g
s/\bCALCUALTE\b/CALCULATE/g
s/\bCalcualte\b/Calculate/g
s/\bcalcualted\b/calculated/g
s/\bCALCUALTED\b/CALCULATED/g
s/\bCalcualted\b/Calculated/g
s/\bcalcualtes\b/calculates/g
s/\bCALCUALTES\b/CALCULATES/g
s/\bCalcualtes\b/Calculates/g
s/\bcalcualting\b/calculating/g
s/\bCALCUALTING\b/CALCULATING/g
s/\bCalcualting\b/Calculating/g
s/\bcalender\b/calendar/g
s/\bCALENDER\b/CALENDAR/g
s/\bCalender\b/Calendar/g
s/\bcalulate\b/calculate/g
s/\bCALULATE\b/CALCULATE/g
s/\bCalulate\b/Calculate/g
s/\bcalulated\b/calculated/g
s/\bCALULATED\b/CALCULATED/g
s/\bCalulated\b/Calculated/g
s/\bcalulates\b/calculates/g
s/\bCALULATES\b/CALCULATES/g
s/\bCalulates\b/Calculates/g
s/\bcalulating\b/calculating/g
s/\bCALULATING\b/CALCULATING/g
s/\bCalulating\b/Calculating/g
s/\bcancelation\b/cancellation/g
s/\bCANCELATION\b/CANCELLATION/g
s/\bCancelation\b/Cancellation/g
s/\bcapabilies\b/capabilities/g
s/\bCAPABILIES\b/CAPABILITIES/g
s/\bCapabilies\b/Capabilities/g
s/\bcapabilites\b/capabilities/g
s/\bCAPABILITES\b/CAPABILITIES/g
s/\bCapabilites\b/Capabilities/g
s/\bcapatibilities\b/capabilities/g
s/\bCAPATIBILITIES\b/CAPABILITIES/g
s/\bCapatibilities\b/Capabilities/g
s/\bcaptial\b/capital/g
s/\bCAPTIAL\b/CAPITAL/g
s/\bCaptial\b/Capital/g
s/\bcarefuly\b/carefully/g
s/\bCAREFULY\b/CAREFULLY/g
s/\bCarefuly\b/Carefully/g
s/\bcariage\b/carriage/g
s/\bCARIAGE\b/CARRIAGE/g
s/\bCariage\b/Carriage/g
s/\bcasue\b/cause/g
s/\bCASUE\b/CAUSE/g
s/\bCasue\b/Cause/g
s/\bcasued\b/caused/g
s/\bCASUED\b/CAUSED/g
s/\bCasued\b/Caused/g
s/\bcasues\b/causes/g
s/\bCASUES\b/CAUSES/g
s/\bCasues\b/Causes/g
s/\bcatched\b/caught/g
s/\bCATCHED\b/CAUGHT/g
s/\bCatched\b/Caught/g
s/\bceate\b/create/g
s/\bCEATE\b/CREATE/g
s/\bCeate\b/Create/g
s/\bceated\b/created/g
s/\bCEATED\b/CREATED/g
s/\bCeated\b/Created/g
s/\bceates\b/creates/g
s/\bCEATES\b/CREATES/g
s/\bCeates\b/Creates/g
s/\bceating\b/creating/g
s/\bCEATING\b/CREATING/g
s/\bCeating\b/Creating/g
s/\bcehck\b/check/g
s/\bCEHCK\b/CHECK/g
s/\bCehck\b/Check/g
s/\bcehcked\b/checked/g
s/\bCEHCKED\b/CHECKED/g
s/\bCehcked\b/Checked/g
s/\bcehcking\b/checking/g
s/\bCEHCKING\b/CHECKING/g
s/\bCehcking\b/Checking/g
s/\bcehcks\b/checks/g
s/\bCEHCKS\b/CHECKS/g
s/\bCehcks\b/Checks/g
s/\bcertficate\b/certificate/g
s/\bCERTFICATE\b/CERTIFICATE/g
s/\bCertficate\b/Certificate/g
s/\bcertficates\b/certificates/g
s/\bCERTFICATES\b/CERTIFICATES/g
s/\bCertficates\b/Certificates/g
s/\bcertian\b/certain/g
s/\bCERTIAN\b/CERTAIN/g
s/\bCertian\b/Certain/g
s/\bcerticate\b/certificate/g
s/\bCERTICATE\b/CERTIFICATE/g
s/\bCerticate\b/Certificate/g
s/\bcerticates\b/certificates/g
s/\bCERTICATES\b/CERTIFICATES/g
s/\bCerticates\b/Certificates/g
s/\bcertifcate\b/certificate/g
s/\bCERTIFCATE\b/CERTIFICATE/g
s/\bCertifcate\b/Certificate/g
s/\bcertifcates\b/certificates/g
s/\bCERTIFCATES\b/CERTIFICATES/g
s/\bCertifcates\b/Certificates/g
s/\bchallange\b/challenge/g
s/\bCHALLANGE\b/CHALLENGE/g
s/\bChallange\b/Challenge/g
s/\bchallanges\b/challenges/g
s/\bCHALLANGES\b/CHALLENGES/g
s/\bChallanges\b/Challenges/g
s/\bchangable\b/changeable/g
s/\bCHANGABLE\b/CHANGEABLE/g
s/\bChangable\b/Changeable/g
s/\bchannnel\b/channel/g
s/\bCHANNNEL\b/CHANNEL/g
s/\bChannnel\b/Channel/g
s/\bchannnels\b/channels/g
s/\bCHANNNELS\b/CHANNELS/g
s/\bChannnels\b/Channels/g
s/\bcharachter\b/character/g
s/\bCHARACHTER\b/CHARACTER/g
s/\bCharachter\b/Character/g
s/\bcharachters\b/characters/g
s/\bCHARACHTERS\b/CHARACTERS/g
s/\bCharachters\b/Characters/g
s/\bcharacted\b/character/g
s/\bCHARACTED\b/CHARACTER/g
s/\bCharacted\b/Character/g
s/\bcharacteds\b/characters/g
s/\bCHARACTEDS\b/CHARACTERS/g
s/\bCharacteds\b/Characters/g
s/\bcharactor\b/character/g
s/\bCHARACTOR\b/CHARACTER/g
s/\bCharactor\b/Character/g
s/\bcharactors\b/characters/g
s/\bCHARACTORS\b/CHARACTERS/g
s/\bCharactors\b/Characters/g
s/\bcharater\b/character/g
s/\bCHARATER\b/CHARACTER/g
s/\bCharater\b/Character/g
s/\bcharaters\b/characters/g
s/\bCHARATERS\b/CHARACTERS/g
s/\bCharaters\b/Characters/g
s/\bcharcter\b/character/g
s/\bCHARCTER\b/CHARACTER/g
s/\bCharcter\b/Character/g
s/\bchcek\b/check/g
s/\bCHCEK\b/CHECK/g
s/\bChcek\b/Check/g
s/\bchceked\b/checked/g
s/\bCHCEKED\b/CHECKED/g
s/\bChceked\b/Checked/g
s/\bchceking\b/checking/g
s/\bCHCEKING\b/CHECKING/g
s/\bChceking\b/Checking/g
s/\bchceks\b/checks/g
s/\bCHCEKS\b/CHECKS/g
s/\bChceks\b/Checks/g
s/\bchecksuming\b/checksumming/g
s/\bCHECKSUMING\b/CHECKSUMMING/g
s/\bChecksuming\b/Checksumming/g
s/\bchildern\b/children/g
s/\bCHILDERN\b/CHILDREN/g
s/\bChildern\b/Children/g
s/\bchilds\b/children/g
s/\bCHILDS\b/CHILDREN/g
s/\bChilds\b/Children/g
s/\bchnage\b/change/g
s/\bCHNAGE\b/CHANGE/g
s/\bChnage\b/Change/g
s/\bchnages\b/changes/g
s/\bCHNAGES\b/CHANGES/g
s/\bChnages\b/Changes/g
s/\bchoise\b/choice/g
s/\bCHOISE\b/CHOICE/g
s/\bChoise\b/Choice/g
s/\bchracter\b/character/g
s/\bCHRACTER\b/CHARACTER/g
s/\bChracter\b/Character/g
s/\bchracters\b/characters/g
s/\bCHRACTERS\b/CHARACTERS/g
s/\bChracters\b/Characters/g
s/\bclasss\b/class/g
s/\bCLASSS\b/CLASS/g
s/\bClasss\b/Class/g
s/\bclassses\b/classes/g
s/\bCLASSSES\b/CLASSES/g
s/\bClassses\b/Classes/g
s/\bclearified\b/clarified/g
s/\bCLEARIFIED\b/CLARIFIED/g
s/\bClearified\b/Clarified/g
s/\bclearifies\b/clarifies/g
s/\bCLEARIFIES\b/CLARIFIES/g
s/\bClearifies\b/Clarifies/g
s/\bclearify\b/clarify/g
s/\bCLEARIFY\b/CLARIFY/g
s/\bClearify\b/Clarify/g
s/\bclearifying\b/clarifying/g
s/\bCLEARIFYING\b/CLARIFYING/g
s/\bClearifying\b/Clarifying/g
s/\bcleint\b/client/g
s/\bCLEINT\b/CLIENT/g
s/\bCleint\b/Client/g
s/\bcleints\b/clients/g
s/\bCLEINTS\b/CLIENTS/g
s/\bCleints\b/Clients/g
s/\bcoefficent\b/coefficient/g
s/\bCOEFFICENT\b/COEFFICIENT/g
s/\bCoefficent\b/Coefficient/g
s/\bcoefficents\b/coefficients/g
s/\bCOEFFICENTS\b/COEFFICIENTS/g
s/\bCoefficents\b/Coefficients/g
s/\bcofigure\b/configure/g
s/\bCOFIGURE\b/CONFIGURE/g
s/\bCofigure\b/Configure/g
s/\bcofigured\b/configured/g
s/\bCOFIGURED\b/CONFIGURED/g
s/\bCofigured\b/Configured/g
s/\bcofigures\b/configures/g
s/\bCOFIGURES\b/CONFIGURES/g
s/\bCofigures\b/Configures/g
s/\bcofiguring\b/configuring/g
s/\bCOFIGURING\b/CONFIGURING/g
s/\bCofiguring\b/Configuring/g
s/\bcollapsable\b/collapsible/g
s/\bCOLLAPSABLE\b/COLLAPSIBLE/g
s/\bCollapsable\b/Collapsible/g
s/\bcollegue\b/colleague/g
s/\bCOLLEGUE\b/COLLEAGUE/g
s/\bCollegue\b/Colleague/g
s/\bcollegues\b/colleagues/g
s/\bCOLLEGUES\b/COLLEAGUES/g
s/\bCollegues\b/Colleagues/g
s/\bcolorfull\b/colorful/g
s/\bCOLORFULL\b/COLORFUL/g
s/\bColorfull\b/Colorful/g
s/\bcomand\b/command/g
s/\bCOMAND\b/COMMAND/g
s/\bComand\b/Command/g
s/\bcoment\b/comment/g
s/\bCOMENT\b/COMMENT/g
s/\bComent\b/Comment/g
s/\bcomented\b/commented/g
s/\bCOMENTED\b/COMMENTED/g
s/\bComented\b/Commented/g
s/\bcomenting\b/commenting/g
s/\bCOMENTING\b/COMMENTING/g
s/\bComenting\b/Commenting/g
s/\bcoments\b/comments/g
s/\bCOMENTS\b/COMMENTS/g
s/\bComents\b/Comments/g
s/\bcomit\b/commit/g
s/\bCOMIT\b/COMMIT/g
s/\bComit\b/Commit/g
s/\bcommad\b/command/g
s/\bCOMMAD\b/COMMAND/g
s/\bCommad\b/Command/g
s/\bcommads\b/commands/g
s/\bCOMMADS\b/COMMANDS/g
s/\bCommads\b/Commands/g
s/\bcommerical\b/commercial/g
s/\bCOMMERICAL\b/COMMERCIAL/g
s/\bCommerical\b/Commercial/g
s/\bcomming\b/coming/g
s/\bCOMMING\b/COMING/g
s/\bComming\b/Coming/g
s/\bcomminucation\b/communication/g
s/\bCOMMINUCATION\b/COMMUNICATION/g
s/\bComminucation\b/Communication/g
s/\bcommiter\b/committer/g
s/\bCOMMITER\b/COMMITTER/g
s/\bCommiter\b/Committer/g
s/\bcommiters\b/committers/g
s/\bCOMMITERS\b/COMMITTERS/g
s/\bCommiters\b/Committers/g
s/\bcommiting\b/committing/g
s/\bCOMMITING\b/COMMITTING/g
s/\bCommiting\b/Committing/g
s/\bcommitt\b/commit/g
s/\bCOMMITT\b/COMMIT/g
s/\bCommitt\b/Commit/g
s/\bcommmand\b/command/g
s/\bCOMMMAND\b/COMMAND/g
s/\bCommmand\b/Command/g
s/\bcommmands\b/commands/g
s/\bCOMMMANDS\b/COMMANDS/g
s/\bCommmands\b/Commands/g
s/\bcommment\b/comment/g
s/\bCOMMMENT\b/COMMENT/g
s/\bCommment\b/Comment/g
s/\bcommmented\b/commented/g
s/\bCOMMMENTED\b/COMMENTED/g
s/\bCommmented\b/Commented/g
s/\bcommmenting\b/commenting/g
s/\bCOMMMENTING\b/COMMENTING/g
s/\bCommmenting\b/Commenting/g
s/\bcommments\b/comments/g
s/\bCOMMMENTS\b/COMMENTS/g
s/\bCommments\b/Comments/g
s/\bcommoditiy\b/commodity/g
s/\bCOMMODITIY\b/COMMODITY/g
s/\bCommoditiy\b/Commodity/g
s/\bcommuncation\b/communication/g
s/\bCOMMUNCATION\b/COMMUNICATION/g
s/\bCommuncation\b/Communication/g
s/\bcompability\b/compatibility/g
s/\bCOMPABILITY\b/COMPATIBILITY/g
s/\bCompability\b/Compatibility/g
s/\bcomparsion\b/comparison/g
s/\bCOMPARSION\b/COMPARISON/g
s/\bComparsion\b/Comparison/g
s/\bcomparsions\b/comparisons/g
s/\bCOMPARSIONS\b/COMPARISONS/g
s/\bComparsions\b/Comparisons/g
s/\bcompatabilty\b/compatibility/g
s/\bCOMPATABILTY\b/COMPATIBILITY/g
s/\bCompatabilty\b/Compatibility/g
s/\bcompatable\b/compatible/g
s/\bCOMPATABLE\b/COMPATIBLE/g
s/\bCompatable\b/Compatible/g
s/\bcompatbility\b/compatibility/g
s/\bCOMPATBILITY\b/COMPATIBILITY/g
s/\bCompatbility\b/Compatibility/g
s/\bcompatiability\b/compatibility/g
s/\bCOMPATIABILITY\b/COMPATIBILITY/g
s/\bCompatiability\b/Compatibility/g
s/\bcompatibiliy\b/compatibility/g
s/\bCOMPATIBILIY\b/COMPATIBILITY/g
s/\bCompatibiliy\b/Compatibility/g
s/\bcompetion\b/completion/g
s/\bCOMPETION\b/COMPLETION/g
s/\bCompetion\b/Completion/g
s/\bcompetions\b/completions/g
s/\bCOMPETIONS\b/COMPLETIONS/g
s/\bCompetions\b/Completions/g
s/\bcompilant\b/compliant/g
s/\bCOMPILANT\b/COMPLIANT/g
s/\bCompilant\b/Compliant/g
s/\bcompleatly\b/completely/g
s/\bCOMPLEATLY\b/COMPLETELY/g
s/\bCompleatly\b/Completely/g
s/\bcompletly\b/completely/g
s/\bCOMPLETLY\b/COMPLETELY/g
s/\bCompletly\b/Completely/g
s/\bcompletness\b/completeness/g
s/\bCOMPLETNESS\b/COMPLETENESS/g
s/\bCompletness\b/Completeness/g
s/\bcomplient\b/compliant/g
s/\bCOMPLIENT\b/COMPLIANT/g
s/\bComplient\b/Compliant/g
s/\bcomplier\b/compiler/g
s/\bCOMPLIER\b/COMPILER/g
s/\bComplier\b/Compiler/g
s/\bcompliers\b/compilers/g
s/\bCOMPLIERS\b/COMPILERS/g
s/\bCompliers\b/Compilers/g
s/\bcomplile\b/compile/g
s/\bCOMPLILE\b/COMPILE/g
s/\bComplile\b/Compile/g
s/\bcompliled\b/compiled/g
s/\bCOMPLILED\b/COMPILED/g
s/\bCompliled\b/Compiled/g
s/\bcompliles\b/compiles/g
s/\bCOMPLILES\b/COMPILES/g
s/\bCompliles\b/Compiles/g
s/\bcompliling\b/compiling/g
s/\bCOMPLILING\b/COMPILING/g
s/\bCompliling\b/Compiling/g
s/\bcompling\b/compiling/g
s/\bCOMPLING\b/COMPILING/g
s/\bCompling\b/Compiling/g
s/\bcompontent\b/component/g
s/\bCOMPONTENT\b/COMPONENT/g
s/\bCompontent\b/Component/g
s/\bcompontents\b/components/g
s/\bCOMPONTENTS\b/COMPONENTS/g
s/\bCompontents\b/Components/g
s/\bcompres\b/compress/g
s/\bCOMPRES\b/COMPRESS/g
s/\bCompres\b/Compress/g
s/\bcompresed\b/compressed/g
s/\bCOMPRESED\b/COMPRESSED/g
s/\bCompresed\b/Compressed/g
s/\bcompreses\b/compresses/g
s/\bCOMPRESES\b/COMPRESSES/g
s/\bCompreses\b/Compresses/g
s/\bcompresing\b/compressing/g
s/\bCOMPRESING\b/COMPRESSING/g
s/\bCompresing\b/Compressing/g
s/\bcompresion\b/compression/g
s/\bCOMPRESION\b/COMPRESSION/g
s/\bCompresion\b/Compression/g
s/\bcomptible\b/compatible/g
s/\bCOMPTIBLE\b/COMPATIBLE/g
s/\bComptible\b/Compatible/g
s/\bcomression\b/compression/g
s/\bCOMRESSION\b/COMPRESSION/g
s/\bComression\b/Compression/g
s/\bconatin\b/contain/g
s/\bCONATIN\b/CONTAIN/g
s/\bConatin\b/Contain/g
s/\bconatined\b/contained/g
s/\bCONATINED\b/CONTAINED/g
s/\bConatined\b/Contained/g
s/\bconatining\b/containing/g
s/\bCONATINING\b/CONTAINING/g
s/\bConatining\b/Containing/g
s/\bconatins\b/contains/g
s/\bCONATINS\b/CONTAINS/g
s/\bConatins\b/Contains/g
s/\bconcatentate\b/concatenate/g
s/\bCONCATENTATE\b/CONCATENATE/g
s/\bConcatentate\b/Concatenate/g
s/\bconcatentated\b/concatenated/g
s/\bCONCATENTATED\b/CONCATENATED/g
s/\bConcatentated\b/Concatenated/g
s/\bconcatentates\b/concatenates/g
s/\bCONCATENTATES\b/CONCATENATES/g
s/\bConcatentates\b/Concatenates/g
s/\bconcatentating\b/concatenating/g
s/\bCONCATENTATING\b/CONCATENATING/g
s/\bConcatentating\b/Concatenating/g
s/\bconcatentation\b/concatenation/g
s/\bCONCATENTATION\b/CONCATENATION/g
s/\bConcatentation\b/Concatenation/g
s/\bconcatentations\b/concatenations/g
s/\bCONCATENTATIONS\b/CONCATENATIONS/g
s/\bConcatentations\b/Concatenations/g
s/\bconcatination\b/concatenation/g
s/\bCONCATINATION\b/CONCATENATION/g
s/\bConcatination\b/Concatenation/g
s/\bconcatinations\b/concatenations/g
s/\bCONCATINATIONS\b/CONCATENATIONS/g
s/\bConcatinations\b/Concatenations/g
s/\bconcensus\b/consensus/g
s/\bCONCENSUS\b/CONSENSUS/g
s/\bConcensus\b/Consensus/g
s/\bconditionaly\b/conditionally/g
s/\bCONDITIONALY\b/CONDITIONALLY/g
s/\bConditionaly\b/Conditionally/g
s/\bconditionnaly\b/conditionally/g
s/\bCONDITIONNALY\b/CONDITIONALLY/g
s/\bConditionnaly\b/Conditionally/g
s/\bconection\b/connection/g
s/\bCONECTION\b/CONNECTION/g
s/\bConection\b/Connection/g
s/\bconections\b/connections/g
s/\bCONECTIONS\b/CONNECTIONS/g
s/\bConections\b/Connections/g
s/\bconent\b/content/g
s/\bCONENT\b/CONTENT/g
s/\bConent\b/Content/g
s/\bconents\b/contents/g
s/\bCONENTS\b/CONTENTS/g
s/\bConents\b/Contents/g
s/\bconfiguation\b/configuration/g
s/\bCONFIGUATION\b/CONFIGURATION/g
s/\bConfiguation\b/Configuration/g
s/\bconfiguations\b/configurations/g
s/\bCONFIGUATIONS\b/CONFIGURATIONS/g
s/\bConfiguations\b/Configurations/g
s/\bconfiguratoin\b/configuration/g
s/\bCONFIGURATOIN\b/CONFIGURATION/g
s/\bConfiguratoin\b/Configuration/g
s/\bconneciton\b/connection/g
s/\bCONNECITON\b/CONNECTION/g
s/\bConneciton\b/Connection/g
s/\bconnecitons\b/connections/g
s/\bCONNECITONS\b/CONNECTIONS/g
s/\bConnecitons\b/Connections/g
s/\bconnectinos\b/connections/g
s/\bCONNECTINOS\b/CONNECTIONS/g
s/\bConnectinos\b/Connections/g
s/\bconnnect\b/connect/g
s/\bCONNNECT\b/CONNECT/g
s/\bConnnect\b/Connect/g
s/\bconnnected\b/connected/g
s/\bCONNNECTED\b/CONNECTED/g
s/\bConnnected\b/Connected/g
s/\bconnnecting\b/connecting/g
s/\bCONNNECTING\b/CONNECTING/g
s/\bConnnecting\b/Connecting/g
s/\bconnnection\b/connection/g
s/\bCONNNECTION\b/CONNECTION/g
s/\bConnnection\b/Connection/g
s/\bconnnections\b/connections/g
s/\bCONNNECTIONS\b/CONNECTIONS/g
s/\bConnnections\b/Connections/g
s/\bconnnects\b/connects/g
s/\bCONNNECTS\b/CONNECTS/g
s/\bConnnects\b/Connects/g
s/\bconsistancy\b/consistency/g
s/\bCONSISTANCY\b/CONSISTENCY/g
s/\bConsistancy\b/Consistency/g
s/\bconstuctor\b/constructor/g
s/\bCONSTUCTOR\b/CONSTRUCTOR/g
s/\bConstuctor\b/Constructor/g
s/\bconstuctors\b/constructors/g
s/\bCONSTUCTORS\b/CONSTRUCTORS/g
s/\bConstuctors\b/Constructors/g
s/\bcontaines\b/contains/g
s/\bCONTAINES\b/CONTAINS/g
s/\bContaines\b/Contains/g
s/\bcontaing\b/containing/g
s/\bCONTAING\b/CONTAINING/g
s/\bContaing\b/Containing/g
s/\bcontaints\b/contains/g
s/\bCONTAINTS\b/CONTAINS/g
s/\bContaints\b/Contains/g
s/\bcontaisn\b/contains/g
s/\bCONTAISN\b/CONTAINS/g
s/\bContaisn\b/Contains/g
s/\bcontan\b/contain/g
s/\bCONTAN\b/CONTAIN/g
s/\bContan\b/Contain/g
s/\bcontaned\b/contained/g
s/\bCONTANED\b/CONTAINED/g
s/\bContaned\b/Contained/g
s/\bcontaning\b/containing/g
s/\bCONTANING\b/CONTAINING/g
s/\bContaning\b/Containing/g
s/\bcontans\b/contains/g
s/\bCONTANS\b/CONTAINS/g
s/\bContans\b/Contains/g
s/\bcontein\b/contain/g
s/\bCONTEIN\b/CONTAIN/g
s/\bContein\b/Contain/g
s/\bconteined\b/contained/g
s/\bCONTEINED\b/CONTAINED/g
s/\bConteined\b/Contained/g
s/\bconteining\b/containing/g
s/\bCONTEINING\b/CONTAINING/g
s/\bConteining\b/Containing/g
s/\bconteins\b/contains/g
s/\bCONTEINS\b/CONTAINS/g
s/\bConteins\b/Contains/g
s/\bcontence\b/contents/g
s/\bCONTENCE\b/CONTENTS/g
s/\bContence\b/Contents/g
s/\bcontinous\b/continuous/g
s/\bCONTINOUS\b/CONTINUOUS/g
s/\bContinous\b/Continuous/g
s/\bcontinously\b/continuously/g
s/\bCONTINOUSLY\b/CONTINUOUSLY/g
s/\bContinously\b/Continuously/g
s/\bcontinueing\b/continuing/g
s/\bCONTINUEING\b/CONTINUING/g
s/\bContinueing\b/Continuing/g
s/\bcontries\b/countries/g
s/\bCONTRIES\b/COUNTRIES/g
s/\bContries\b/Countries/g
s/\bcontroled\b/controlled/g
s/\bCONTROLED\b/CONTROLLED/g
s/\bControled\b/Controlled/g
s/\bcontroler\b/controller/g
s/\bCONTROLER\b/CONTROLLER/g
s/\bControler\b/Controller/g
s/\bcontrolers\b/controllers/g
s/\bCONTROLERS\b/CONTROLLERS/g
s/\bControlers\b/Controllers/g
s/\bcontroll\b/control/g
s/\bCONTROLL\b/CONTROL/g
s/\bControll\b/Control/g
s/\bcontrolls\b/controls/g
s/\bCONTROLLS\b/CONTROLS/g
s/\bControlls\b/Controls/g
s/\bcontructed\b/constructed/g
s/\bCONTRUCTED\b/CONSTRUCTED/g
s/\bContructed\b/Constructed/g
s/\bcontructing\b/constructing/g
s/\bCONTRUCTING\b/CONSTRUCTING/g
s/\bContructing\b/Constructing/g
s/\bcontructors\b/constructors/g
s/\bCONTRUCTORS\b/CONSTRUCTORS/g
s/\bContructors\b/Constructors/g
s/\bcontructs\b/constructs/g
s/\bCONTRUCTS\b/CONSTRUCTS/g
s/\bContructs\b/Constructs/g
s/\bcontry\b/country/g
s/\bCONTRY\b/COUNTRY/g
s/\bContry\b/Country/g
s/\bconverstion\b/conversion/g
s/\bCONVERSTION\b/CONVERSION/g
s/\bConverstion\b/Conversion/g
s/\bconverstions\b/conversions/g
s/\bCONVERSTIONS\b/CONVERSIONS/g
s/\bConverstions\b/Conversions/g
s/\bconvertion\b/conversion/g
s/\bCONVERTION\b/CONVERSION/g
s/\bConvertion\b/Conversion/g
s/\bconvertions\b/conversions/g
s/\bCONVERTIONS\b/CONVERSIONS/g
s/\bConvertions\b/Conversions/g
s/\bconvertor\b/converter/g
s/\bCONVERTOR\b/CONVERTER/g
s/\bConvertor\b/Converter/g
s/\bconvet\b/convert/g
s/\bCONVET\b/CONVERT/g
s/\bConvet\b/Convert/g
s/\bconveted\b/converted/g
s/\bCONVETED\b/CONVERTED/g
s/\bConveted\b/Converted/g
s/\bconveting\b/converting/g
s/\bCONVETING\b/CONVERTING/g
s/\bConveting\b/Converting/g
s/\bconvets\b/converts/g
s/\bCONVETS\b/CONVERTS/g
s/\bConvets\b/Converts/g
s/\bconvinient\b/convenient/g
s/\bCONVINIENT\b/CONVENIENT/g
s/\bConvinient\b/Convenient/g
s/\bcopyrigth\b/copyright/g
s/\bCOPYRIGTH\b/COPYRIGHT/g
s/\bCopyrigth\b/Copyright/g
s/\bcopyrigthed\b/copyrighted/g
s/\bCOPYRIGTHED\b/COPYRIGHTED/g
s/\bCopyrigthed\b/Copyrighted/g
s/\bcopyrigths\b/copyrights/g
s/\bCOPYRIGTHS\b/COPYRIGHTS/g
s/\bCopyrigths\b/Copyrights/g
s/\bcorected\b/corrected/g
s/\bCORECTED\b/CORRECTED/g
s/\bCorected\b/Corrected/g
s/\bcorespond\b/correspond/g
s/\bCORESPOND\b/CORRESPOND/g
s/\bCorespond\b/Correspond/g
s/\bcoresponded\b/corresponded/g
s/\bCORESPONDED\b/CORRESPONDED/g
s/\bCoresponded\b/Corresponded/g
s/\bcorespondence\b/correspondence/g
s/\bCORESPONDENCE\b/CORRESPONDENCE/g
s/\bCorespondence\b/Correspondence/g
s/\bcoresponding\b/corresponding/g
s/\bCORESPONDING\b/CORRESPONDING/g
s/\bCoresponding\b/Corresponding/g
s/\bcoresponds\b/corresponds/g
s/\bCORESPONDS\b/CORRESPONDS/g
s/\bCoresponds\b/Corresponds/g
s/\bcorrectnes\b/correctness/g
s/\bCORRECTNES\b/CORRECTNESS/g
s/\bCorrectnes\b/Correctness/g
s/\bcorreponding\b/corresponding/g
s/\bCORREPONDING\b/CORRESPONDING/g
s/\bCorreponding\b/Corresponding/g
s/\bcorreponds\b/corresponds/g
s/\bCORREPONDS\b/CORRESPONDS/g
s/\bCorreponds\b/Corresponds/g
s/\bcorrespoding\b/corresponding/g
s/\bCORRESPODING\b/CORRESPONDING/g
s/\bCorrespoding\b/Corresponding/g
s/\bcorrespondance\b/correspondence/g
s/\bCORRESPONDANCE\b/CORRESPONDENCE/g
s/\bCorrespondance\b/Correspondence/g
s/\bcorrespondes\b/corresponds/g
s/\bCORRESPONDES\b/CORRESPONDS/g
s/\bCorrespondes\b/Corresponds/g
s/\bcorresponing\b/corresponding/g
s/\bCORRESPONING\b/CORRESPONDING/g
s/\bCorresponing\b/Corresponding/g
s/\bcorresponsing\b/corresponding/g
s/\bCORRESPONSING\b/CORRESPONDING/g
s/\bCorresponsing\b/Corresponding/g
s/\bcorretly\b/correctly/g
s/\bCORRETLY\b/CORRECTLY/g
s/\bCorretly\b/Correctly/g
s/\bcoutner\b/counter/g
s/\bCOUTNER\b/COUNTER/g
s/\bCoutner\b/Counter/g
s/\bcoutners\b/counters/g
s/\bCOUTNERS\b/COUNTERS/g
s/\bCoutners\b/Counters/g
s/\bcoverted\b/converted/g
s/\bCOVERTED\b/CONVERTED/g
s/\bCoverted\b/Converted/g
s/\bcrtical\b/critical/g
s/\bCRTICAL\b/CRITICAL/g
s/\bCrtical\b/Critical/g
s/\bcryptocraphic\b/cryptographic/g
s/\bCRYPTOCRAPHIC\b/CRYPTOGRAPHIC/g
s/\bCryptocraphic\b/Cryptographic/g
s/\bcummulative\b/cumulative/g
s/\bCUMMULATIVE\b/CUMULATIVE/g
s/\bCummulative\b/Cumulative/g
s/\bcurently\b/currently/g
s/\bCURENTLY\b/CURRENTLY/g
s/\bCurently\b/Currently/g
s/\bcymk\b/cmyk/g
s/\bCYMK\b/CMYK/g
s/\bCymk\b/CMYK/g
s/\bdafault\b/default/g
s/\bDAFAULT\b/DEFAULT/g
s/\bDafault\b/Default/g
s/\bdeafault\b/default/g
s/\bDEAFAULT\b/DEFAULT/g
s/\bDeafault\b/Default/g
s/\bdeafult\b/default/g
s/\bDEAFULT\b/DEFAULT/g
s/\bDeafult\b/Default/g
s/\bdeamon\b/daemon/g
s/\bDEAMON\b/DAEMON/g
s/\bDeamon\b/Daemon/g
s/\bdebain\b/debian/g
s/\bDEBAIN\b/DEBIAN/g
s/\bDebain\b/Debian/g
s/\bdebians\b/debian's/g
s/\bDEBIANS\b/DEBIAN'S/g
s/\bDebians\b/Debian's/g
s/\bdebuging\b/debugging/g
s/\bDEBUGING\b/DEBUGGING/g
s/\bDebuging\b/Debugging/g
s/\bdecalare\b/declare/g
s/\bDECALARE\b/DECLARE/g
s/\bDecalare\b/Declare/g
s/\bdecalared\b/declared/g
s/\bDECALARED\b/DECLARED/g
s/\bDecalared\b/Declared/g
s/\bdecalares\b/declares/g
s/\bDECALARES\b/DECLARES/g
s/\bDecalares\b/Declares/g
s/\bdecalaring\b/declaring/g
s/\bDECALARING\b/DECLARING/g
s/\bDecalaring\b/Declaring/g
s/\bdecendant\b/descendant/g
s/\bDECENDANT\b/DESCENDANT/g
s/\bDecendant\b/Descendant/g
s/\bdecendent\b/descendent/g
s/\bDECENDENT\b/DESCENDENT/g
s/\bDecendent\b/Descendent/g
s/\bdeclation\b/declaration/g
s/\bDECLATION\b/DECLARATION/g
s/\bDeclation\b/Declaration/g
s/\bdeclations\b/declarations/g
s/\bDECLATIONS\b/DECLARATIONS/g
s/\bDeclations\b/Declarations/g
s/\bdecompres\b/decompress/g
s/\bDECOMPRES\b/DECOMPRESS/g
s/\bDecompres\b/Decompress/g
s/\bdecompresed\b/decompressed/g
s/\bDECOMPRESED\b/DECOMPRESSED/g
s/\bDecompresed\b/Decompressed/g
s/\bdecompreses\b/decompresses/g
s/\bDECOMPRESES\b/DECOMPRESSES/g
s/\bDecompreses\b/Decompresses/g
s/\bdecompresing\b/decompressing/g
s/\bDECOMPRESING\b/DECOMPRESSING/g
s/\bDecompresing\b/Decompressing/g
s/\bdecribe\b/describe/g
s/\bDECRIBE\b/DESCRIBE/g
s/\bDecribe\b/Describe/g
s/\bdecribed\b/described/g
s/\bDECRIBED\b/DESCRIBED/g
s/\bDecribed\b/Described/g
s/\bdecribes\b/describes/g
s/\bDECRIBES\b/DESCRIBES/g
s/\bDecribes\b/Describes/g
s/\bdecribing\b/describing/g
s/\bDECRIBING\b/DESCRIBING/g
s/\bDecribing\b/Describing/g
s/\bdecription\b/description/g
s/\bDECRIPTION\b/DESCRIPTION/g
s/\bDecription\b/Description/g
s/\bdecriptions\b/descriptions/g
s/\bDECRIPTIONS\b/DESCRIPTIONS/g
s/\bDecriptions\b/Descriptions/g
s/\bdecsriptor\b/descriptor/g
s/\bDECSRIPTOR\b/DESCRIPTOR/g
s/\bDecsriptor\b/Descriptor/g
s/\bdecsriptors\b/descriptors/g
s/\bDECSRIPTORS\b/DESCRIPTORS/g
s/\bDecsriptors\b/Descriptors/g
s/\bdefalt\b/default/g
s/\bDEFALT\b/DEFAULT/g
s/\bDefalt\b/Default/g
s/\bdefautl\b/default/g
s/\bDEFAUTL\b/DEFAULT/g
s/\bDefautl\b/Default/g
s/\bdefinate\b/definite/g
s/\bDEFINATE\b/DEFINITE/g
s/\bDefinate\b/Definite/g
s/\bdefinately\b/definitely/g
s/\bDEFINATELY\b/DEFINITELY/g
s/\bDefinately\b/Definitely/g
s/\bdefinining\b/defining/g
s/\bDEFININING\b/DEFINING/g
s/\bDefinining\b/Defining/g
s/\bdefinitly\b/definitely/g
s/\bDEFINITLY\b/DEFINITELY/g
s/\bDefinitly\b/Definitely/g
s/\bdefintions\b/definitions/g
s/\bDEFINTIONS\b/DEFINITIONS/g
s/\bDefintions\b/Definitions/g
s/\bdefualt\b/default/g
s/\bDEFUALT\b/DEFAULT/g
s/\bDefualt\b/Default/g
s/\bdelare\b/declare/g
s/\bDELARE\b/DECLARE/g
s/\bDelare\b/Declare/g
s/\bdelared\b/declared/g
s/\bDELARED\b/DECLARED/g
s/\bDelared\b/Declared/g
s/\bdelares\b/declares/g
s/\bDELARES\b/DECLARES/g
s/\bDelares\b/Declares/g
s/\bdelaring\b/declaring/g
s/\bDELARING\b/DECLARING/g
s/\bDelaring\b/Declaring/g
s/\bdelemiter\b/delimiter/g
s/\bDELEMITER\b/DELIMITER/g
s/\bDelemiter\b/Delimiter/g
s/\bdelimeters\b/delimiters/g
s/\bDELIMETERS\b/DELIMITERS/g
s/\bDelimeters\b/Delimiters/g
s/\bdemoninator\b/denominator/g
s/\bDEMONINATOR\b/DENOMINATOR/g
s/\bDemoninator\b/Denominator/g
s/\bdemoninators\b/denominators/g
s/\bDEMONINATORS\b/DENOMINATORS/g
s/\bDemoninators\b/Denominators/g
s/\bdemostrate\b/demonstrate/g
s/\bDEMOSTRATE\b/DEMONSTRATE/g
s/\bDemostrate\b/Demonstrate/g
s/\bdemostrated\b/demonstrated/g
s/\bDEMOSTRATED\b/DEMONSTRATED/g
s/\bDemostrated\b/Demonstrated/g
s/\bdemostrates\b/demonstrates/g
s/\bDEMOSTRATES\b/DEMONSTRATES/g
s/\bDemostrates\b/Demonstrates/g
s/\bdemostrating\b/demonstrating/g
s/\bDEMOSTRATING\b/DEMONSTRATING/g
s/\bDemostrating\b/Demonstrating/g
s/\bdepdencies\b/dependencies/g
s/\bDEPDENCIES\b/DEPENDENCIES/g
s/\bDepdencies\b/Dependencies/g
s/\bdepdency\b/dependency/g
s/\bDEPDENCY\b/DEPENDENCY/g
s/\bDepdency\b/Dependency/g
s/\bdepencies\b/dependencies/g
s/\bDEPENCIES\b/DEPENDENCIES/g
s/\bDepencies\b/Dependencies/g
s/\bdepency\b/dependency/g
s/\bDEPENCY\b/DEPENDENCY/g
s/\bDepency\b/Dependency/g
s/\bdependancies\b/dependencies/g
s/\bDEPENDANCIES\b/DEPENDENCIES/g
s/\bDependancies\b/Dependencies/g
s/\bdependancy\b/dependency/g
s/\bDEPENDANCY\b/DEPENDENCY/g
s/\bDependancy\b/Dependency/g
s/\bdependant\b/dependent/g
s/\bDEPENDANT\b/DEPENDENT/g
s/\bDependant\b/Dependent/g
s/\bdependecies\b/dependencies/g
s/\bDEPENDECIES\b/DEPENDENCIES/g
s/\bDependecies\b/Dependencies/g
s/\bdependecy\b/dependency/g
s/\bDEPENDECY\b/DEPENDENCY/g
s/\bDependecy\b/Dependency/g
s/\bdepenencies\b/dependencies/g
s/\bDEPENENCIES\b/DEPENDENCIES/g
s/\bDepenencies\b/Dependencies/g
s/\bdepenency\b/dependency/g
s/\bDEPENENCY\b/DEPENDENCY/g
s/\bDepenency\b/Dependency/g
s/\bdepreacte\b/deprecate/g
s/\bDEPREACTE\b/DEPRECATE/g
s/\bDepreacte\b/Deprecate/g
s/\bdepreacted\b/deprecated/g
s/\bDEPREACTED\b/DEPRECATED/g
s/\bDepreacted\b/Deprecated/g
s/\bdeprectate\b/deprecate/g
s/\bDEPRECTATE\b/DEPRECATE/g
s/\bDeprectate\b/Deprecate/g
s/\bdeprectated\b/deprecated/g
s/\bDEPRECTATED\b/DEPRECATED/g
s/\bDeprectated\b/Deprecated/g
s/\bdeprectates\b/deprecates/g
s/\bDEPRECTATES\b/DEPRECATES/g
s/\bDeprectates\b/Deprecates/g
s/\bdeprectating\b/deprecating/g
s/\bDEPRECTATING\b/DEPRECATING/g
s/\bDeprectating\b/Deprecating/g
s/\bdeprected\b/deprecated/g
s/\bDEPRECTED\b/DEPRECATED/g
s/\bDeprected\b/Deprecated/g
s/\bderefenced\b/dereferenced/g
s/\bDEREFENCED\b/DEREFERENCED/g
s/\bDerefenced\b/Dereferenced/g
s/\bdesactivate\b/deactivate/g
s/\bDESACTIVATE\b/DEACTIVATE/g
s/\bDesactivate\b/Deactivate/g
s/\bdescibe\b/describe/g
s/\bDESCIBE\b/DESCRIBE/g
s/\bDescibe\b/Describe/g
s/\bdescibed\b/described/g
s/\bDESCIBED\b/DESCRIBED/g
s/\bDescibed\b/Described/g
s/\bdescibes\b/describes/g
s/\bDESCIBES\b/DESCRIBES/g
s/\bDescibes\b/Describes/g
s/\bdescibing\b/describing/g
s/\bDESCIBING\b/DESCRIBING/g
s/\bDescibing\b/Describing/g
s/\bdesciptor\b/descriptor/g
s/\bDESCIPTOR\b/DESCRIPTOR/g
s/\bDesciptor\b/Descriptor/g
s/\bdesciptors\b/descriptors/g
s/\bDESCIPTORS\b/DESCRIPTORS/g
s/\bDesciptors\b/Descriptors/g
s/\bdescriptior\b/descriptor/g
s/\bDESCRIPTIOR\b/DESCRIPTOR/g
s/\bDescriptior\b/Descriptor/g
s/\bdescriptiors\b/descriptors/g
s/\bDESCRIPTIORS\b/DESCRIPTORS/g
s/\bDescriptiors\b/Descriptors/g
s/\bdescripton\b/description/g
s/\bDESCRIPTON\b/DESCRIPTION/g
s/\bDescripton\b/Description/g
s/\bdescriptons\b/descriptions/g
s/\bDESCRIPTONS\b/DESCRIPTIONS/g
s/\bDescriptons\b/Descriptions/g
s/\bdescrition\b/description/g
s/\bDESCRITION\b/DESCRIPTION/g
s/\bDescrition\b/Description/g
s/\bdescritpion\b/description/g
s/\bDESCRITPION\b/DESCRIPTION/g
s/\bDescritpion\b/Description/g
s/\bdescritpions\b/descriptions/g
s/\bDESCRITPIONS\b/DESCRIPTIONS/g
s/\bDescritpions\b/Descriptions/g
s/\bdesctiptor\b/descriptor/g
s/\bDESCTIPTOR\b/DESCRIPTOR/g
s/\bDesctiptor\b/Descriptor/g
s/\bdesctiptors\b/descriptors/g
s/\bDESCTIPTORS\b/DESCRIPTORS/g
s/\bDesctiptors\b/Descriptors/g
s/\bdesireable\b/desirable/g
s/\bDESIREABLE\b/DESIRABLE/g
s/\bDesireable\b/Desirable/g
s/\bdesriptor\b/descriptor/g
s/\bDESRIPTOR\b/DESCRIPTOR/g
s/\bDesriptor\b/Descriptor/g
s/\bdesriptors\b/descriptors/g
s/\bDESRIPTORS\b/DESCRIPTORS/g
s/\bDesriptors\b/Descriptors/g
s/\bdetabase\b/database/g
s/\bDETABASE\b/DATABASE/g
s/\bDetabase\b/Database/g
s/\bdetatch\b/detach/g
s/\bDETATCH\b/DETACH/g
s/\bDetatch\b/Detach/g
s/\bdetatched\b/detached/g
s/\bDETATCHED\b/DETACHED/g
s/\bDetatched\b/Detached/g
s/\bdetatches\b/detaches/g
s/\bDETATCHES\b/DETACHES/g
s/\bDetatches\b/Detaches/g
s/\bdetatching\b/detaching/g
s/\bDETATCHING\b/DETACHING/g
s/\bDetatching\b/Detaching/g
s/\bdetemine\b/determine/g
s/\bDETEMINE\b/DETERMINE/g
s/\bDetemine\b/Determine/g
s/\bdetemined\b/determined/g
s/\bDETEMINED\b/DETERMINED/g
s/\bDetemined\b/Determined/g
s/\bdetemines\b/determines/g
s/\bDETEMINES\b/DETERMINES/g
s/\bDetemines\b/Determines/g
s/\bdetemining\b/determining/g
s/\bDETEMINING\b/DETERMINING/g
s/\bDetemining\b/Determining/g
s/\bdeterming\b/determining/g
s/\bDETERMING\b/DETERMINING/g
s/\bDeterming\b/Determining/g
s/\bdeterminstic\b/deterministic/g
s/\bDETERMINSTIC\b/DETERMINISTIC/g
s/\bDeterminstic\b/Deterministic/g
s/\bdeterminstically\b/deterministically/g
s/\bDETERMINSTICALLY\b/DETERMINISTICALLY/g
s/\bDeterminstically\b/Deterministically/g
s/\bdetroy\b/destroy/g
s/\bDETROY\b/DESTROY/g
s/\bDetroy\b/Destroy/g
s/\bdetroyed\b/destroyed/g
s/\bDETROYED\b/DESTROYED/g
s/\bDetroyed\b/Destroyed/g
s/\bdetroying\b/destroying/g
s/\bDETROYING\b/DESTROYING/g
s/\bDetroying\b/Destroying/g
s/\bdetroys\b/destroys/g
s/\bDETROYS\b/DESTROYS/g
s/\bDetroys\b/Destroys/g
s/\bdeveloment\b/development/g
s/\bDEVELOMENT\b/DEVELOPMENT/g
s/\bDeveloment\b/Development/g
s/\bdeveloments\b/developments/g
s/\bDEVELOMENTS\b/DEVELOPMENTS/g
s/\bDeveloments\b/Developments/g
s/\bdevelopement\b/development/g
s/\bDEVELOPEMENT\b/DEVELOPMENT/g
s/\bDevelopement\b/Development/g
s/\bdevelopped\b/developed/g
s/\bDEVELOPPED\b/DEVELOPED/g
s/\bDevelopped\b/Developed/g
s/\bdeveloppement\b/development/g
s/\bDEVELOPPEMENT\b/DEVELOPMENT/g
s/\bDeveloppement\b/Development/g
s/\bdevelopper\b/developer/g
s/\bDEVELOPPER\b/DEVELOPER/g
s/\bDevelopper\b/Developer/g
s/\bdeveloppment\b/development/g
s/\bDEVELOPPMENT\b/DEVELOPMENT/g
s/\bDeveloppment\b/Development/g
s/\bdeveolpment\b/development/g
s/\bDEVEOLPMENT\b/DEVELOPMENT/g
s/\bDeveolpment\b/Development/g
s/\bdevided\b/divided/g
s/\bDEVIDED\b/DIVIDED/g
s/\bDevided\b/Divided/g
s/\bdiable\b/disable/g
s/\bDIABLE\b/DISABLE/g
s/\bDiable\b/Disable/g
s/\bdiabled\b/disabled/g
s/\bDIABLED\b/DISABLED/g
s/\bDiabled\b/Disabled/g
s/\bdiables\b/disables/g
s/\bDIABLES\b/DISABLES/g
s/\bDiables\b/Disables/g
s/\bdiabling\b/disabling/g
s/\bDIABLING\b/DISABLING/g
s/\bDiabling\b/Disabling/g
s/\bdictionnary\b/dictionary/g
s/\bDICTIONNARY\b/DICTIONARY/g
s/\bDictionnary\b/Dictionary/g
s/\bdidnt'\b/didn't/g
s/\bDIDNT'\b/DIDN'T/g
s/\bDidnt'\b/Didn't/g
s/\bdiferent\b/different/g
s/\bDIFERENT\b/DIFFERENT/g
s/\bDiferent\b/Different/g
s/\bdifferents\b/different/g
s/\bDIFFERENTS\b/DIFFERENT/g
s/\bDifferents\b/Different/g
s/\bdiffernet\b/different/g
s/\bDIFFERNET\b/DIFFERENT/g
s/\bDiffernet\b/Different/g
s/\bdiffrent\b/different/g
s/\bDIFFRENT\b/DIFFERENT/g
s/\bDiffrent\b/Different/g
s/\bdifinition\b/definition/g
s/\bDIFINITION\b/DEFINITION/g
s/\bDifinition\b/Definition/g
s/\bdifinitions\b/definitions/g
s/\bDIFINITIONS\b/DEFINITIONS/g
s/\bDifinitions\b/Definitions/g
s/\bdigitial\b/digital/g
s/\bDIGITIAL\b/DIGITAL/g
s/\bDigitial\b/Digital/g
s/\bdiplay\b/display/g
s/\bDIPLAY\b/DISPLAY/g
s/\bDiplay\b/Display/g
s/\bdirectores\b/directories/g
s/\bDIRECTORES\b/DIRECTORIES/g
s/\bDirectores\b/Directories/g
s/\bdirectorys\b/directories/g
s/\bDIRECTORYS\b/DIRECTORIES/g
s/\bDirectorys\b/Directories/g
s/\bdirectries\b/directories/g
s/\bDIRECTRIES\b/DIRECTORIES/g
s/\bDirectries\b/Directories/g
s/\bdirectry\b/directory/g
s/\bDIRECTRY\b/DIRECTORY/g
s/\bDirectry\b/Directory/g
s/\bdirecty\b/directly/g
s/\bDIRECTY\b/DIRECTLY/g
s/\bDirecty\b/Directly/g
s/\bdisapear\b/disappear/g
s/\bDISAPEAR\b/DISAPPEAR/g
s/\bDisapear\b/Disappear/g
s/\bdisapeared\b/disappeared/g
s/\bDISAPEARED\b/DISAPPEARED/g
s/\bDisapeared\b/Disappeared/g
s/\bdisapearing\b/disappearing/g
s/\bDISAPEARING\b/DISAPPEARING/g
s/\bDisapearing\b/Disappearing/g
s/\bdisapears\b/disappears/g
s/\bDISAPEARS\b/DISAPPEARS/g
s/\bDisapears\b/Disappears/g
s/\bdiscernable\b/discernible/g
s/\bDISCERNABLE\b/DISCERNIBLE/g
s/\bDiscernable\b/Discernible/g
s/\bdiscusion\b/discussion/g
s/\bDISCUSION\b/DISCUSSION/g
s/\bDiscusion\b/Discussion/g
s/\bdispath\b/dispatch/g
s/\bDISPATH\b/DISPATCH/g
s/\bDispath\b/Dispatch/g
s/\bdispathed\b/dispatched/g
s/\bDISPATHED\b/DISPATCHED/g
s/\bDispathed\b/Dispatched/g
s/\bdispathes\b/dispatches/g
s/\bDISPATHES\b/DISPATCHES/g
s/\bDispathes\b/Dispatches/g
s/\bdispathing\b/dispatching/g
s/\bDISPATHING\b/DISPATCHING/g
s/\bDispathing\b/Dispatching/g
s/\bdispertion\b/dispersion/g
s/\bDISPERTION\b/DISPERSION/g
s/\bDispertion\b/Dispersion/g
s/\bdissapear\b/disappear/g
s/\bDISSAPEAR\b/DISAPPEAR/g
s/\bDissapear\b/Disappear/g
s/\bdissapeared\b/disappeared/g
s/\bDISSAPEARED\b/DISAPPEARED/g
s/\bDissapeared\b/Disappeared/g
s/\bdissapearing\b/disappearing/g
s/\bDISSAPEARING\b/DISAPPEARING/g
s/\bDissapearing\b/Disappearing/g
s/\bdissapears\b/disappears/g
s/\bDISSAPEARS\b/DISAPPEARS/g
s/\bDissapears\b/Disappears/g
s/\bdistibute\b/distribute/g
s/\bDISTIBUTE\b/DISTRIBUTE/g
s/\bDistibute\b/Distribute/g
s/\bdistibuted\b/distributed/g
s/\bDISTIBUTED\b/DISTRIBUTED/g
s/\bDistibuted\b/Distributed/g
s/\bdistibutes\b/distributes/g
s/\bDISTIBUTES\b/DISTRIBUTES/g
s/\bDistibutes\b/Distributes/g
s/\bdistibuting\b/distributing/g
s/\bDISTIBUTING\b/DISTRIBUTING/g
s/\bDistibuting\b/Distributing/g
s/\bdistibution\b/distribution/g
s/\bDISTIBUTION\b/DISTRIBUTION/g
s/\bDistibution\b/Distribution/g
s/\bdistibutions\b/distributions/g
s/\bDISTIBUTIONS\b/DISTRIBUTIONS/g
s/\bDistibutions\b/Distributions/g
s/\bdistingush\b/distinguish/g
s/\bDISTINGUSH\b/DISTINGUISH/g
s/\bDistingush\b/Distinguish/g
s/\bdistingushed\b/distinguished/g
s/\bDISTINGUSHED\b/DISTINGUISHED/g
s/\bDistingushed\b/Distinguished/g
s/\bdistingushes\b/distinguishes/g
s/\bDISTINGUSHES\b/DISTINGUISHES/g
s/\bDistingushes\b/Distinguishes/g
s/\bdistingushing\b/distinguishing/g
s/\bDISTINGUSHING\b/DISTINGUISHING/g
s/\bDistingushing\b/Distinguishing/g
s/\bdistribtion\b/distribution/g
s/\bDISTRIBTION\b/DISTRIBUTION/g
s/\bDistribtion\b/Distribution/g
s/\bdistribtions\b/distributions/g
s/\bDISTRIBTIONS\b/DISTRIBUTIONS/g
s/\bDistribtions\b/Distributions/g
s/\bdivison\b/division/g
s/\bDIVISON\b/DIVISION/g
s/\bDivison\b/Division/g
s/\bdivisons\b/divisions/g
s/\bDIVISONS\b/DIVISIONS/g
s/\bDivisons\b/Divisions/g
s/\bdocuentation\b/documentation/g
s/\bDOCUENTATION\b/DOCUMENTATION/g
s/\bDocuentation\b/Documentation/g
s/\bdocumantation\b/documentation/g
s/\bDOCUMANTATION\b/DOCUMENTATION/g
s/\bDocumantation\b/Documentation/g
s/\bdocumentaion\b/documentation/g
s/\bDOCUMENTAION\b/DOCUMENTATION/g
s/\bDocumentaion\b/Documentation/g
s/\bdocumention\b/documentation/g
s/\bDOCUMENTION\b/DOCUMENTATION/g
s/\bDocumention\b/Documentation/g
s/\bdocumetation\b/documentation/g
s/\bDOCUMETATION\b/DOCUMENTATION/g
s/\bDocumetation\b/Documentation/g
s/\bdoens't\b/doesn't/g
s/\bDOENS'T\b/DOESN'T/g
s/\bDoens't\b/Doesn't/g
s/\bdoes't\b/doesn't/g
s/\bDOES'T\b/DOESN'T/g
s/\bDoes't\b/Doesn't/g
s/\bdoesen't\b/doesn't/g
s/\bDOESEN'T\b/DOESN'T/g
s/\bDoesen't\b/Doesn't/g
s/\bdoesnt'\b/doesn't/g
s/\bDOESNT'\b/DOESN'T/g
s/\bDoesnt'\b/Doesn't/g
s/\bdoesnt't\b/doesn't/g
s/\bDOESNT'T\b/DOESN'T/g
s/\bDoesnt't\b/Doesn't/g
s/\bdoman\b/domain/g
s/\bDOMAN\b/DOMAIN/g
s/\bDoman\b/Domain/g
s/\bdomans\b/domains/g
s/\bDOMANS\b/DOMAINS/g
s/\bDomans\b/Domains/g
s/\bdont'\b/don't/g
s/\bDONT'\b/DON'T/g
s/\bDont'\b/Don't/g
s/\bdont't\b/don't/g
s/\bDONT'T\b/DON'T/g
s/\bDont't\b/Don't/g
s/\bdonwload\b/download/g
s/\bDONWLOAD\b/DOWNLOAD/g
s/\bDonwload\b/Download/g
s/\bdonwloaded\b/downloaded/g
s/\bDONWLOADED\b/DOWNLOADED/g
s/\bDonwloaded\b/Downloaded/g
s/\bdonwloading\b/downloading/g
s/\bDONWLOADING\b/DOWNLOADING/g
s/\bDonwloading\b/Downloading/g
s/\bdonwloads\b/downloads/g
s/\bDONWLOADS\b/DOWNLOADS/g
s/\bDonwloads\b/Downloads/g
s/\bdosen't\b/doesn't/g
s/\bDOSEN'T\b/DOESN'T/g
s/\bDosen't\b/Doesn't/g
s/\bdownlad\b/download/g
s/\bDOWNLAD\b/DOWNLOAD/g
s/\bDownlad\b/Download/g
s/\bdownlads\b/downloads/g
s/\bDOWNLADS\b/DOWNLOADS/g
s/\bDownlads\b/Downloads/g
s/\bdroppped\b/dropped/g
s/\bDROPPPED\b/DROPPED/g
s/\bDroppped\b/Dropped/g
s/\bdumplicate\b/duplicate/g
s/\bDUMPLICATE\b/DUPLICATE/g
s/\bDumplicate\b/Duplicate/g
s/\bdumplicated\b/duplicated/g
s/\bDUMPLICATED\b/DUPLICATED/g
s/\bDumplicated\b/Duplicated/g
s/\bdumplicates\b/duplicates/g
s/\bDUMPLICATES\b/DUPLICATES/g
s/\bDumplicates\b/Duplicates/g
s/\bdumplicating\b/duplicating/g
s/\bDUMPLICATING\b/DUPLICATING/g
s/\bDumplicating\b/Duplicating/g
s/\bdupliate\b/duplicate/g
s/\bDUPLIATE\b/DUPLICATE/g
s/\bDupliate\b/Duplicate/g
s/\bdupliates\b/duplicates/g
s/\bDUPLIATES\b/DUPLICATES/g
s/\bDupliates\b/Duplicates/g
s/\beasilly\b/easily/g
s/\bEASILLY\b/EASILY/g
s/\bEasilly\b/Easily/g
s/\becspecially\b/especially/g
s/\bECSPECIALLY\b/ESPECIALLY/g
s/\bEcspecially\b/Especially/g
s/\bedditable\b/editable/g
s/\bEDDITABLE\b/EDITABLE/g
s/\bEdditable\b/Editable/g
s/\beditting\b/editing/g
s/\bEDITTING\b/EDITING/g
s/\bEditting\b/Editing/g
s/\beffectly\b/effectively/g
s/\bEFFECTLY\b/EFFECTIVELY/g
s/\bEffectly\b/Effectively/g
s/\befficency\b/efficiency/g
s/\bEFFICENCY\b/EFFICIENCY/g
s/\bEfficency\b/Efficiency/g
s/\befficent\b/efficient/g
s/\bEFFICENT\b/EFFICIENT/g
s/\bEfficent\b/Efficient/g
s/\befficently\b/efficiently/g
s/\bEFFICENTLY\b/EFFICIENTLY/g
s/\bEfficently\b/Efficiently/g
s/\begde\b/edge/g
s/\bEGDE\b/EDGE/g
s/\bEgde\b/Edge/g
s/\begdes\b/edges/g
s/\bEGDES\b/EDGES/g
s/\bEgdes\b/Edges/g
s/\beletronic\b/electronic/g
s/\bELETRONIC\b/ELECTRONIC/g
s/\bEletronic\b/Electronic/g
s/\beligable\b/eligible/g
s/\bELIGABLE\b/ELIGIBLE/g
s/\bEligable\b/Eligible/g
s/\belliminate\b/eliminate/g
s/\bELLIMINATE\b/ELIMINATE/g
s/\bElliminate\b/Eliminate/g
s/\belliminated\b/eliminated/g
s/\bELLIMINATED\b/ELIMINATED/g
s/\bElliminated\b/Eliminated/g
s/\belliminates\b/eliminates/g
s/\bELLIMINATES\b/ELIMINATES/g
s/\bElliminates\b/Eliminates/g
s/\belliminating\b/eliminating/g
s/\bELLIMINATING\b/ELIMINATING/g
s/\bElliminating\b/Eliminating/g
s/\belment\b/element/g
s/\bELMENT\b/ELEMENT/g
s/\bElment\b/Element/g
s/\belments\b/elements/g
s/\bELMENTS\b/ELEMENTS/g
s/\bElments\b/Elements/g
s/\belminate\b/eliminate/g
s/\bELMINATE\b/ELIMINATE/g
s/\bElminate\b/Eliminate/g
s/\belminated\b/eliminated/g
s/\bELMINATED\b/ELIMINATED/g
s/\bElminated\b/Eliminated/g
s/\belminates\b/eliminates/g
s/\bELMINATES\b/ELIMINATES/g
s/\bElminates\b/Eliminates/g
s/\belminating\b/eliminating/g
s/\bELMINATING\b/ELIMINATING/g
s/\bElminating\b/Eliminating/g
s/\bembeddeding\b/embedding/g
s/\bEMBEDDEDING\b/EMBEDDING/g
s/\bEmbeddeding\b/Embedding/g
s/\bemptry\b/empty/g
s/\bEMPTRY\b/EMPTY/g
s/\bEmptry\b/Empty/g
s/\bemtpy\b/empty/g
s/\bEMTPY\b/EMPTY/g
s/\bEmtpy\b/Empty/g
s/\benchanced\b/enhanced/g
s/\bENCHANCED\b/ENHANCED/g
s/\bEnchanced\b/Enhanced/g
s/\benconding\b/encoding/g
s/\bENCONDING\b/ENCODING/g
s/\bEnconding\b/Encoding/g
s/\bencondings\b/encodings/g
s/\bENCONDINGS\b/ENCODINGS/g
s/\bEncondings\b/Encodings/g
s/\bencorporating\b/incorporating/g
s/\bENCORPORATING\b/INCORPORATING/g
s/\bEncorporating\b/Incorporating/g
s/\bencose\b/enclose/g
s/\bENCOSE\b/ENCLOSE/g
s/\bEncose\b/Enclose/g
s/\bencosed\b/enclosed/g
s/\bENCOSED\b/ENCLOSED/g
s/\bEncosed\b/Enclosed/g
s/\bencoses\b/encloses/g
s/\bENCOSES\b/ENCLOSES/g
s/\bEncoses\b/Encloses/g
s/\bencosing\b/enclosing/g
s/\bENCOSING\b/ENCLOSING/g
s/\bEncosing\b/Enclosing/g
s/\bencrytion\b/encryption/g
s/\bENCRYTION\b/ENCRYPTION/g
s/\bEncrytion\b/Encryption/g
s/\bendianes\b/endianness/g
s/\bENDIANES\b/ENDIANNESS/g
s/\bEndianes\b/Endianness/g
s/\bendianess\b/endianness/g
s/\bENDIANESS\b/ENDIANNESS/g
s/\bEndianess\b/Endianness/g
s/\bendiannes\b/endianness/g
s/\bENDIANNES\b/ENDIANNESS/g
s/\bEndiannes\b/Endianness/g
s/\benhaced\b/enhanced/g
s/\bENHACED\b/ENHANCED/g
s/\bEnhaced\b/Enhanced/g
s/\benhancment\b/enhancement/g
s/\bENHANCMENT\b/ENHANCEMENT/g
s/\bEnhancment\b/Enhancement/g
s/\benhancments\b/enhancements/g
s/\bENHANCMENTS\b/ENHANCEMENTS/g
s/\bEnhancments\b/Enhancements/g
s/\benitities\b/entities/g
s/\bENITITIES\b/ENTITIES/g
s/\bEnitities\b/Entities/g
s/\benitity\b/entity/g
s/\bENITITY\b/ENTITY/g
s/\bEnitity\b/Entity/g
s/\benlightnment\b/enlightenment/g
s/\bENLIGHTNMENT\b/ENLIGHTENMENT/g
s/\bEnlightnment\b/Enlightenment/g
s/\benocded\b/encoded/g
s/\bENOCDED\b/ENCODED/g
s/\bEnocded\b/Encoded/g
s/\benrties\b/entries/g
s/\bENRTIES\b/ENTRIES/g
s/\bEnrties\b/Entries/g
s/\benrty\b/entry/g
s/\bENRTY\b/ENTRY/g
s/\bEnrty\b/Entry/g
s/\benterily\b/entirely/g
s/\bENTERILY\b/ENTIRELY/g
s/\bEnterily\b/Entirely/g
s/\bentites\b/entities/g
s/\bENTITES\b/ENTITIES/g
s/\bEntites\b/Entities/g
s/\benvionment\b/environment/g
s/\bENVIONMENT\b/ENVIRONMENT/g
s/\bEnvionment\b/Environment/g
s/\benvireonment\b/environment/g
s/\bENVIREONMENT\b/ENVIRONMENT/g
s/\bEnvireonment\b/Environment/g
s/\benviroiment\b/environment/g
s/\bENVIROIMENT\b/ENVIRONMENT/g
s/\bEnviroiment\b/Environment/g
s/\benviromental\b/environmental/g
s/\bENVIROMENTAL\b/ENVIRONMENTAL/g
s/\bEnviromental\b/Environmental/g
s/\benviromentally\b/environmentally/g
s/\bENVIROMENTALLY\b/ENVIRONMENTALLY/g
s/\bEnviromentally\b/Environmentally/g
s/\benviroments\b/environments/g
s/\bENVIROMENTS\b/ENVIRONMENTS/g
s/\bEnviroments\b/Environments/g
s/\benvironement\b/environment/g
s/\bENVIRONEMENT\b/ENVIRONMENT/g
s/\bEnvironement\b/Environment/g
s/\benvironent\b/environment/g
s/\bENVIRONENT\b/ENVIRONMENT/g
s/\bEnvironent\b/Environment/g
s/\beqivalent\b/equivalent/g
s/\bEQIVALENT\b/EQUIVALENT/g
s/\bEqivalent\b/Equivalent/g
s/\bequiped\b/equipped/g
s/\bEQUIPED\b/EQUIPPED/g
s/\bEquiped\b/Equipped/g
s/\bequivelant\b/equivalent/g
s/\bEQUIVELANT\b/EQUIVALENT/g
s/\bEquivelant\b/Equivalent/g
s/\bequivilant\b/equivalent/g
s/\bEQUIVILANT\b/EQUIVALENT/g
s/\bEquivilant\b/Equivalent/g
s/\bequvalent\b/equivalent/g
s/\bEQUVALENT\b/EQUIVALENT/g
s/\bEquvalent\b/Equivalent/g
s/\beroneous\b/erroneous/g
s/\bERONEOUS\b/ERRONEOUS/g
s/\bEroneous\b/Erroneous/g
s/\beror\b/error/g
s/\bEROR\b/ERROR/g
s/\bEror\b/Error/g
s/\berorr\b/error/g
s/\bERORR\b/ERROR/g
s/\bErorr\b/Error/g
s/\berorrs\b/errors/g
s/\bERORRS\b/ERRORS/g
s/\bErorrs\b/Errors/g
s/\berors\b/errors/g
s/\bERORS\b/ERRORS/g
s/\bErors\b/Errors/g
s/\berroneus\b/erroneous/g
s/\bERRONEUS\b/ERRONEOUS/g
s/\bErroneus\b/Erroneous/g
s/\berroneusly\b/erroneously/g
s/\bERRONEUSLY\b/ERRONEOUSLY/g
s/\bErroneusly\b/Erroneously/g
s/\berronous\b/erroneous/g
s/\bERRONOUS\b/ERRONEOUS/g
s/\bErronous\b/Erroneous/g
s/\berronously\b/erroneously/g
s/\bERRONOUSLY\b/ERRONEOUSLY/g
s/\bErronously\b/Erroneously/g
s/\berrorneous\b/erroneous/g
s/\bERRORNEOUS\b/ERRONEOUS/g
s/\bErrorneous\b/Erroneous/g
s/\berrorneously\b/erroneously/g
s/\bERRORNEOUSLY\b/ERRONEOUSLY/g
s/\bErrorneously\b/Erroneously/g
s/\besential\b/essential/g
s/\bESENTIAL\b/ESSENTIAL/g
s/\bEsential\b/Essential/g
s/\besentially\b/essentially/g
s/\bESENTIALLY\b/ESSENTIALLY/g
s/\bEsentially\b/Essentially/g
s/\bestbalishment\b/establishment/g
s/\bESTBALISHMENT\b/ESTABLISHMENT/g
s/\bEstbalishment\b/Establishment/g
s/\betsablishment\b/establishment/g
s/\bETSABLISHMENT\b/ESTABLISHMENT/g
s/\bEtsablishment\b/Establishment/g
s/\betsbalishment\b/establishment/g
s/\bETSBALISHMENT\b/ESTABLISHMENT/g
s/\bEtsbalishment\b/Establishment/g
s/\bevalutate\b/evaluate/g
s/\bEVALUTATE\b/EVALUATE/g
s/\bEvalutate\b/Evaluate/g
s/\bevalutated\b/evaluated/g
s/\bEVALUTATED\b/EVALUATED/g
s/\bEvalutated\b/Evaluated/g
s/\bevalutates\b/evaluates/g
s/\bEVALUTATES\b/EVALUATES/g
s/\bEvalutates\b/Evaluates/g
s/\bevalutating\b/evaluating/g
s/\bEVALUTATING\b/EVALUATING/g
s/\bEvalutating\b/Evaluating/g
s/\bevalute\b/evaluate/g
s/\bEVALUTE\b/EVALUATE/g
s/\bEvalute\b/Evaluate/g
s/\bevaluted\b/evaluated/g
s/\bEVALUTED\b/EVALUATED/g
s/\bEvaluted\b/Evaluated/g
s/\bevalutes\b/evaluates/g
s/\bEVALUTES\b/EVALUATES/g
s/\bEvalutes\b/Evaluates/g
s/\bevaluting\b/evaluating/g
s/\bEVALUTING\b/EVALUATING/g
s/\bEvaluting\b/Evaluating/g
s/\beverbody\b/everybody/g
s/\bEVERBODY\b/EVERYBODY/g
s/\bEverbody\b/Everybody/g
s/\beverone\b/everyone/g
s/\bEVERONE\b/EVERYONE/g
s/\bEverone\b/Everyone/g
s/\beverthing\b/everything/g
s/\bEVERTHING\b/EVERYTHING/g
s/\bEverthing\b/Everything/g
s/\beverwhere\b/everywhere/g
s/\bEVERWHERE\b/EVERYWHERE/g
s/\bEverwhere\b/Everywhere/g
s/\beveryhing\b/everything/g
s/\bEVERYHING\b/EVERYTHING/g
s/\bEveryhing\b/Everything/g
s/\beverythings\b/everything/g
s/\bEVERYTHINGS\b/EVERYTHING/g
s/\bEverythings\b/Everything/g
s/\bevironment\b/environment/g
s/\bEVIRONMENT\b/ENVIRONMENT/g
s/\bEvironment\b/Environment/g
s/\bevironments\b/environments/g
s/\bEVIRONMENTS\b/ENVIRONMENTS/g
s/\bEvironments\b/Environments/g
s/\bexcact\b/exact/g
s/\bEXCACT\b/EXACT/g
s/\bExcact\b/Exact/g
s/\bexcactly\b/exactly/g
s/\bEXCACTLY\b/EXACTLY/g
s/\bExcactly\b/Exactly/g
s/\bexcecutable\b/executable/g
s/\bEXCECUTABLE\b/EXECUTABLE/g
s/\bExcecutable\b/Executable/g
s/\bexceded\b/exceeded/g
s/\bEXCEDED\b/EXCEEDED/g
s/\bExceded\b/Exceeded/g
s/\bexcellant\b/excellent/g
s/\bEXCELLANT\b/EXCELLENT/g
s/\bExcellant\b/Excellent/g
s/\bexcercised\b/exercised/g
s/\bEXCERCISED\b/EXERCISED/g
s/\bExcercised\b/Exercised/g
s/\bexcercises\b/exercises/g
s/\bEXCERCISES\b/EXERCISES/g
s/\bExcercises\b/Exercises/g
s/\bexcercising\b/exercising/g
s/\bEXCERCISING\b/EXERCISING/g
s/\bExcercising\b/Exercising/g
s/\bexcpect\b/expect/g
s/\bEXCPECT\b/EXPECT/g
s/\bExcpect\b/Expect/g
s/\bexcpected\b/expected/g
s/\bEXCPECTED\b/EXPECTED/g
s/\bExcpected\b/Expected/g
s/\bexcpecting\b/expecting/g
s/\bEXCPECTING\b/EXPECTING/g
s/\bExcpecting\b/Expecting/g
s/\bexcpects\b/expects/g
s/\bEXCPECTS\b/EXPECTS/g
s/\bExcpects\b/Expects/g
s/\bexcutable\b/executable/g
s/\bEXCUTABLE\b/EXECUTABLE/g
s/\bExcutable\b/Executable/g
s/\bexcutables\b/executables/g
s/\bEXCUTABLES\b/EXECUTABLES/g
s/\bExcutables\b/Executables/g
s/\bexcute\b/execute/g
s/\bEXCUTE\b/EXECUTE/g
s/\bExcute\b/Execute/g
s/\bexcuted\b/executed/g
s/\bEXCUTED\b/EXECUTED/g
s/\bExcuted\b/Executed/g
s/\bexcutes\b/executes/g
s/\bEXCUTES\b/EXECUTES/g
s/\bExcutes\b/Executes/g
s/\bexcuting\b/executing/g
s/\bEXCUTING\b/EXECUTING/g
s/\bExcuting\b/Executing/g
s/\bexeception\b/exception/g
s/\bEXECEPTION\b/EXCEPTION/g
s/\bExeception\b/Exception/g
s/\bexeceptions\b/exceptions/g
s/\bEXECEPTIONS\b/EXCEPTIONS/g
s/\bExeceptions\b/Exceptions/g
s/\bexectuable\b/executable/g
s/\bEXECTUABLE\b/EXECUTABLE/g
s/\bExectuable\b/Executable/g
s/\bexectuables\b/executables/g
s/\bEXECTUABLES\b/EXECUTABLES/g
s/\bExectuables\b/Executables/g
s/\bexecuteable\b/executable/g
s/\bEXECUTEABLE\b/EXECUTABLE/g
s/\bExecuteable\b/Executable/g
s/\bexecuteables\b/executables/g
s/\bEXECUTEABLES\b/EXECUTABLES/g
s/\bExecuteables\b/Executables/g
s/\bexension\b/extension/g
s/\bEXENSION\b/EXTENSION/g
s/\bExension\b/Extension/g
s/\bexensions\b/extensions/g
s/\bEXENSIONS\b/EXTENSIONS/g
s/\bExensions\b/Extensions/g
s/\bexept\b/except/g
s/\bEXEPT\b/EXCEPT/g
s/\bExept\b/Except/g
s/\bexeption\b/exception/g
s/\bEXEPTION\b/EXCEPTION/g
s/\bExeption\b/Exception/g
s/\bexeptions\b/exceptions/g
s/\bEXEPTIONS\b/EXCEPTIONS/g
s/\bExeptions\b/Exceptions/g
s/\bexising\b/existing/g
s/\bEXISING\b/EXISTING/g
s/\bExising\b/Existing/g
s/\bexisiting\b/existing/g
s/\bEXISITING\b/EXISTING/g
s/\bExisiting\b/Existing/g
s/\bexlcude\b/exclude/g
s/\bEXLCUDE\b/EXCLUDE/g
s/\bExlcude\b/Exclude/g
s/\bexlcusive\b/exclusive/g
s/\bEXLCUSIVE\b/EXCLUSIVE/g
s/\bExlcusive\b/Exclusive/g
s/\bexlicit\b/explicit/g
s/\bEXLICIT\b/EXPLICIT/g
s/\bExlicit\b/Explicit/g
s/\bexlicitly\b/explicitly/g
s/\bEXLICITLY\b/EXPLICITLY/g
s/\bExlicitly\b/Explicitly/g
s/\bexmaple\b/example/g
s/\bEXMAPLE\b/EXAMPLE/g
s/\bExmaple\b/Example/g
s/\bexpecially\b/especially/g
s/\bEXPECIALLY\b/ESPECIALLY/g
s/\bExpecially\b/Especially/g
s/\bexpectes\b/expects/g
s/\bEXPECTES\b/EXPECTS/g
s/\bExpectes\b/Expects/g
s/\bexplaination\b/explanation/g
s/\bEXPLAINATION\b/EXPLANATION/g
s/\bExplaination\b/Explanation/g
s/\bexplainations\b/explanations/g
s/\bEXPLAINATIONS\b/EXPLANATIONS/g
s/\bExplainations\b/Explanations/g
s/\bexplantion\b/explanation/g
s/\bEXPLANTION\b/EXPLANATION/g
s/\bExplantion\b/Explanation/g
s/\bexplantions\b/explanations/g
s/\bEXPLANTIONS\b/EXPLANATIONS/g
s/\bExplantions\b/Explanations/g
s/\bexplicitily\b/explicitly/g
s/\bEXPLICITILY\b/EXPLICITLY/g
s/\bExplicitily\b/Explicitly/g
s/\bexplit\b/explicit/g
s/\bEXPLIT\b/EXPLICIT/g
s/\bExplit\b/Explicit/g
s/\bexplitly\b/explicitly/g
s/\bEXPLITLY\b/EXPLICITLY/g
s/\bExplitly\b/Explicitly/g
s/\bexpresions\b/expressions/g
s/\bEXPRESIONS\b/EXPRESSIONS/g
s/\bExpresions\b/Expressions/g
s/\bexpresssion\b/expression/g
s/\bEXPRESSSION\b/EXPRESSION/g
s/\bExpresssion\b/Expression/g
s/\bexpresssions\b/expressions/g
s/\bEXPRESSSIONS\b/EXPRESSIONS/g
s/\bExpresssions\b/Expressions/g
s/\bexprimental\b/experimental/g
s/\bEXPRIMENTAL\b/EXPERIMENTAL/g
s/\bExprimental\b/Experimental/g
s/\bextensability\b/extensibility/g
s/\bEXTENSABILITY\b/EXTENSIBILITY/g
s/\bExtensability\b/Extensibility/g
s/\bextenstion\b/extension/g
s/\bEXTENSTION\b/EXTENSION/g
s/\bExtenstion\b/Extension/g
s/\bextenstions\b/extensions/g
s/\bEXTENSTIONS\b/EXTENSIONS/g
s/\bExtenstions\b/Extensions/g
s/\bextesion\b/extension/g
s/\bEXTESION\b/EXTENSION/g
s/\bExtesion\b/Extension/g
s/\bextesions\b/extensions/g
s/\bEXTESIONS\b/EXTENSIONS/g
s/\bExtesions\b/Extensions/g
s/\bextracter\b/extractor/g
s/\bEXTRACTER\b/EXTRACTOR/g
s/\bExtracter\b/Extractor/g
s/\bfaciliate\b/facilitate/g
s/\bFACILIATE\b/FACILITATE/g
s/\bFaciliate\b/Facilitate/g
s/\bfaciliated\b/facilitated/g
s/\bFACILIATED\b/FACILITATED/g
s/\bFaciliated\b/Facilitated/g
s/\bfaciliates\b/facilitates/g
s/\bFACILIATES\b/FACILITATES/g
s/\bFaciliates\b/Facilitates/g
s/\bfaciliating\b/facilitating/g
s/\bFACILIATING\b/FACILITATING/g
s/\bFaciliating\b/Facilitating/g
s/\bfaild\b/failed/g
s/\bFAILD\b/FAILED/g
s/\bFaild\b/Failed/g
s/\bfailue\b/failure/g
s/\bFAILUE\b/FAILURE/g
s/\bFailue\b/Failure/g
s/\bfailuer\b/failure/g
s/\bFAILUER\b/FAILURE/g
s/\bFailuer\b/Failure/g
s/\bfailues\b/failures/g
s/\bFAILUES\b/FAILURES/g
s/\bFailues\b/Failures/g
s/\bfalg\b/flag/g
s/\bFALG\b/FLAG/g
s/\bFalg\b/Flag/g
s/\bfalgs\b/flags/g
s/\bFALGS\b/FLAGS/g
s/\bFalgs\b/Flags/g
s/\bfaliure\b/failure/g
s/\bFALIURE\b/FAILURE/g
s/\bFaliure\b/Failure/g
s/\bfaliures\b/failures/g
s/\bFALIURES\b/FAILURES/g
s/\bFaliures\b/Failures/g
s/\bfamilar\b/familiar/g
s/\bFAMILAR\b/FAMILIAR/g
s/\bFamilar\b/Familiar/g
s/\bfatser\b/faster/g
s/\bFATSER\b/FASTER/g
s/\bFatser\b/Faster/g
s/\bfeasable\b/feasible/g
s/\bFEASABLE\b/FEASIBLE/g
s/\bFeasable\b/Feasible/g
s/\bfeauture\b/feature/g
s/\bFEAUTURE\b/FEATURE/g
s/\bFeauture\b/Feature/g
s/\bfeautures\b/features/g
s/\bFEAUTURES\b/FEATURES/g
s/\bFeautures\b/Features/g
s/\bfetaure\b/feature/g
s/\bFETAURE\b/FEATURE/g
s/\bFetaure\b/Feature/g
s/\bfetaures\b/features/g
s/\bFETAURES\b/FEATURES/g
s/\bFetaures\b/Features/g
s/\bficticious\b/fictitious/g
s/\bFICTICIOUS\b/FICTITIOUS/g
s/\bFicticious\b/Fictitious/g
s/\bfilesytem\b/filesystem/g
s/\bFILESYTEM\b/FILESYSTEM/g
s/\bFilesytem\b/Filesystem/g
s/\bfilesytems\b/filesystems/g
s/\bFILESYTEMS\b/FILESYSTEMS/g
s/\bFilesytems\b/Filesystems/g
s/\bfileystem\b/filesystem/g
s/\bFILEYSTEM\b/FILESYSTEM/g
s/\bFileystem\b/Filesystem/g
s/\bfileystems\b/filesystems/g
s/\bFILEYSTEMS\b/FILESYSTEMS/g
s/\bFileystems\b/Filesystems/g
s/\bfindout\b/find out/g
s/\bFINDOUT\b/FIND OUT/g
s/\bFindout\b/Find out/g
s/\bfitler\b/filter/g
s/\bFITLER\b/FILTER/g
s/\bFitler\b/Filter/g
s/\bfitlers\b/filters/g
s/\bFITLERS\b/FILTERS/g
s/\bFitlers\b/Filters/g
s/\bflie\b/file/g
s/\bFLIE\b/FILE/g
s/\bFlie\b/File/g
s/\bfloting\b/floating/g
s/\bFLOTING\b/FLOATING/g
s/\bFloting\b/Floating/g
s/\bfoget\b/forget/g
s/\bFOGET\b/FORGET/g
s/\bFoget\b/Forget/g
s/\bfogot\b/forgot/g
s/\bFOGOT\b/FORGOT/g
s/\bFogot\b/Forgot/g
s/\bfogotten\b/forgotten/g
s/\bFOGOTTEN\b/FORGOTTEN/g
s/\bFogotten\b/Forgotten/g
s/\bfolloing\b/following/g
s/\bFOLLOING\b/FOLLOWING/g
s/\bFolloing\b/Following/g
s/\bfollwing\b/following/g
s/\bFOLLWING\b/FOLLOWING/g
s/\bFollwing\b/Following/g
s/\bfolowing\b/following/g
s/\bFOLOWING\b/FOLLOWING/g
s/\bFolowing\b/Following/g
s/\bforbiden\b/forbidden/g
s/\bFORBIDEN\b/FORBIDDEN/g
s/\bForbiden\b/Forbidden/g
s/\bforeing\b/foreign/g
s/\bFOREING\b/FOREIGN/g
s/\bForeing\b/Foreign/g
s/\bforground\b/foreground/g
s/\bFORGROUND\b/FOREGROUND/g
s/\bForground\b/Foreground/g
s/\bformated\b/formatted/g
s/\bFORMATED\b/FORMATTED/g
s/\bFormated\b/Formatted/g
s/\bformating\b/formatting/g
s/\bFORMATING\b/FORMATTING/g
s/\bFormating\b/Formatting/g
s/\bforse\b/force/g
s/\bFORSE\b/FORCE/g
s/\bForse\b/Force/g
s/\bforseeable\b/foreseeable/g
s/\bFORSEEABLE\b/FORESEEABLE/g
s/\bForseeable\b/Foreseeable/g
s/\bfortan\b/fortran/g
s/\bFORTAN\b/FORTRAN/g
s/\bFortan\b/Fortran/g
s/\bforunate\b/fortunate/g
s/\bFORUNATE\b/FORTUNATE/g
s/\bForunate\b/Fortunate/g
s/\bforunately\b/fortunately/g
s/\bFORUNATELY\b/FORTUNATELY/g
s/\bForunately\b/Fortunately/g
s/\bforwad\b/forward/g
s/\bFORWAD\b/FORWARD/g
s/\bForwad\b/Forward/g
s/\bforwaded\b/forwarded/g
s/\bFORWADED\b/FORWARDED/g
s/\bForwaded\b/Forwarded/g
s/\bforwading\b/forwarding/g
s/\bFORWADING\b/FORWARDING/g
s/\bForwading\b/Forwarding/g
s/\bforwads\b/forwards/g
s/\bFORWADS\b/FORWARDS/g
s/\bForwads\b/Forwards/g
s/\bforwardig\b/forwarding/g
s/\bFORWARDIG\b/FORWARDING/g
s/\bForwardig\b/Forwarding/g
s/\bfoward\b/forward/g
s/\bFOWARD\b/FORWARD/g
s/\bFoward\b/Forward/g
s/\bfowarded\b/forwarded/g
s/\bFOWARDED\b/FORWARDED/g
s/\bFowarded\b/Forwarded/g
s/\bfowarding\b/forwarding/g
s/\bFOWARDING\b/FORWARDING/g
s/\bFowarding\b/Forwarding/g
s/\bfowards\b/forwards/g
s/\bFOWARDS\b/FORWARDS/g
s/\bFowards\b/Forwards/g
s/\bframwork\b/framework/g
s/\bFRAMWORK\b/FRAMEWORK/g
s/\bFramwork\b/Framework/g
s/\bfreqencies\b/frequencies/g
s/\bFREQENCIES\b/FREQUENCIES/g
s/\bFreqencies\b/Frequencies/g
s/\bfreqency\b/frequency/g
s/\bFREQENCY\b/FREQUENCY/g
s/\bFreqency\b/Frequency/g
s/\bfucntion\b/function/g
s/\bFUCNTION\b/FUNCTION/g
s/\bFucntion\b/Function/g
s/\bfucntions\b/functions/g
s/\bFUCNTIONS\b/FUNCTIONS/g
s/\bFucntions\b/Functions/g
s/\bfuction\b/function/g
s/\bFUCTION\b/FUNCTION/g
s/\bFuction\b/Function/g
s/\bfuctions\b/functions/g
s/\bFUCTIONS\b/FUNCTIONS/g
s/\bFuctions\b/Functions/g
s/\bfullfill\b/fulfill/g
s/\bFULLFILL\b/FULFILL/g
s/\bFullfill\b/Fulfill/g
s/\bfuncion\b/function/g
s/\bFUNCION\b/FUNCTION/g
s/\bFuncion\b/Function/g
s/\bfuncions\b/functions/g
s/\bFUNCIONS\b/FUNCTIONS/g
s/\bFuncions\b/Functions/g
s/\bfunciton\b/function/g
s/\bFUNCITON\b/FUNCTION/g
s/\bFunciton\b/Function/g
s/\bfuncitons\b/functions/g
s/\bFUNCITONS\b/FUNCTIONS/g
s/\bFuncitons\b/Functions/g
s/\bfunctionallity\b/functionality/g
s/\bFUNCTIONALLITY\b/FUNCTIONALITY/g
s/\bFunctionallity\b/Functionality/g
s/\bfunctionaly\b/functionally/g
s/\bFUNCTIONALY\b/FUNCTIONALLY/g
s/\bFunctionaly\b/Functionally/g
s/\bfunctionnality\b/functionality/g
s/\bFUNCTIONNALITY\b/FUNCTIONALITY/g
s/\bFunctionnality\b/Functionality/g
s/\bfunctiosn\b/functions/g
s/\bFUNCTIOSN\b/FUNCTIONS/g
s/\bFunctiosn\b/Functions/g
s/\bfunctonality\b/functionality/g
s/\bFUNCTONALITY\b/FUNCTIONALITY/g
s/\bFunctonality\b/Functionality/g
s/\bfuntions\b/functions/g
s/\bFUNTIONS\b/FUNCTIONS/g
s/\bFuntions\b/Functions/g
s/\bfuthermore\b/furthermore/g
s/\bFUTHERMORE\b/FURTHERMORE/g
s/\bFuthermore\b/Furthermore/g
s/\bgenerater\b/generator/g
s/\bGENERATER\b/GENERATOR/g
s/\bGenerater\b/Generator/g
s/\bgeneraters\b/generators/g
s/\bGENERATERS\b/GENERATORS/g
s/\bGeneraters\b/Generators/g
s/\bgenereate\b/generate/g
s/\bGENEREATE\b/GENERATE/g
s/\bGenereate\b/Generate/g
s/\bgenereated\b/generated/g
s/\bGENEREATED\b/GENERATED/g
s/\bGenereated\b/Generated/g
s/\bgenereates\b/generates/g
s/\bGENEREATES\b/GENERATES/g
s/\bGenereates\b/Generates/g
s/\bgenereating\b/generating/g
s/\bGENEREATING\b/GENERATING/g
s/\bGenereating\b/Generating/g
s/\bgeneriously\b/generously/g
s/\bGENERIOUSLY\b/GENEROUSLY/g
s/\bGeneriously\b/Generously/g
s/\bgenrate\b/generate/g
s/\bGENRATE\b/GENERATE/g
s/\bGenrate\b/Generate/g
s/\bgenrated\b/generated/g
s/\bGENRATED\b/GENERATED/g
s/\bGenrated\b/Generated/g
s/\bgenrates\b/generates/g
s/\bGENRATES\b/GENERATES/g
s/\bGenrates\b/Generates/g
s/\bgenrating\b/generating/g
s/\bGENRATING\b/GENERATING/g
s/\bGenrating\b/Generating/g
s/\bgenreate\b/generate/g
s/\bGENREATE\b/GENERATE/g
s/\bGenreate\b/Generate/g
s/\bgenreated\b/generated/g
s/\bGENREATED\b/GENERATED/g
s/\bGenreated\b/Generated/g
s/\bgenreates\b/generates/g
s/\bGENREATES\b/GENERATES/g
s/\bGenreates\b/Generates/g
s/\bgenreating\b/generating/g
s/\bGENREATING\b/GENERATING/g
s/\bGenreating\b/Generating/g
s/\bgeomtry\b/geometry/g
s/\bGEOMTRY\b/GEOMETRY/g
s/\bGeomtry\b/Geometry/g
s/\bgeting\b/getting/g
s/\bGETING\b/GETTING/g
s/\bGeting\b/Getting/g
s/\bglpyh\b/glyph/g
s/\bGLPYH\b/GLYPH/g
s/\bGlpyh\b/Glyph/g
s/\bglpyhs\b/glyphs/g
s/\bGLPYHS\b/GLYPHS/g
s/\bGlpyhs\b/Glyphs/g
s/\bgoverment\b/government/g
s/\bGOVERMENT\b/GOVERNMENT/g
s/\bGoverment\b/Government/g
s/\bgrabing\b/grabbing/g
s/\bGRABING\b/GRABBING/g
s/\bGrabing\b/Grabbing/g
s/\bgrahical\b/graphical/g
s/\bGRAHICAL\b/GRAPHICAL/g
s/\bGrahical\b/Graphical/g
s/\bgrahpical\b/graphical/g
s/\bGRAHPICAL\b/GRAPHICAL/g
s/\bGrahpical\b/Graphical/g
s/\bgramatically\b/grammatically/g
s/\bGRAMATICALLY\b/GRAMMATICALLY/g
s/\bGramatically\b/Grammatically/g
s/\bgrammer\b/grammar/g
s/\bGRAMMER\b/GRAMMAR/g
s/\bGrammer\b/Grammar/g
s/\bgrammers\b/grammars/g
s/\bGRAMMERS\b/GRAMMARS/g
s/\bGrammers\b/Grammars/g
s/\bgrapic\b/graphic/g
s/\bGRAPIC\b/GRAPHIC/g
s/\bGrapic\b/Graphic/g
s/\bguage\b/gauge/g
s/\bGUAGE\b/GAUGE/g
s/\bGuage\b/Gauge/g
s/\bguarentee\b/guarantee/g
s/\bGUARENTEE\b/GUARANTEE/g
s/\bGuarentee\b/Guarantee/g
s/\bguarenteed\b/guaranteed/g
s/\bGUARENTEED\b/GUARANTEED/g
s/\bGuarenteed\b/Guaranteed/g
s/\bguarenteeing\b/guaranteeing/g
s/\bGUARENTEEING\b/GUARANTEEING/g
s/\bGuarenteeing\b/Guaranteeing/g
s/\bguarentees\b/guarantees/g
s/\bGUARENTEES\b/GUARANTEES/g
s/\bGuarentees\b/Guarantees/g
s/\bguassian\b/gaussian/g
s/\bGUASSIAN\b/GAUSSIAN/g
s/\bGuassian\b/Gaussian/g
s/\bhalfs\b/halves/g
s/\bHALFS\b/HALVES/g
s/\bHalfs\b/Halves/g
s/\bhandfull\b/handful/g
s/\bHANDFULL\b/HANDFUL/g
s/\bHandfull\b/Handful/g
s/\bhanshake\b/handshake/g
s/\bHANSHAKE\b/HANDSHAKE/g
s/\bHanshake\b/Handshake/g
s/\bhanshakes\b/handshakes/g
s/\bHANSHAKES\b/HANDSHAKES/g
s/\bHanshakes\b/Handshakes/g
s/\bhapening\b/happening/g
s/\bHAPENING\b/HAPPENING/g
s/\bHapening\b/Happening/g
s/\bhappend\b/happened/g
s/\bHAPPEND\b/HAPPENED/g
s/\bHappend\b/Happened/g
s/\bhappenned\b/happened/g
s/\bHAPPENNED\b/HAPPENED/g
s/\bHappenned\b/Happened/g
s/\bharcode\b/hardcode/g
s/\bHARCODE\b/HARDCODE/g
s/\bHarcode\b/Hardcode/g
s/\bharcoded\b/hardcoded/g
s/\bHARCODED\b/HARDCODED/g
s/\bHarcoded\b/Hardcoded/g
s/\bharcodes\b/hardcodes/g
s/\bHARCODES\b/HARDCODES/g
s/\bHarcodes\b/Hardcodes/g
s/\bharcoding\b/hardcoding/g
s/\bHARCODING\b/HARDCODING/g
s/\bHarcoding\b/Hardcoding/g
s/\bhavent\b/haven't/g
s/\bHAVENT\b/HAVEN'T/g
s/\bHavent\b/Haven't/g
s/\bheigth\b/height/g
s/\bHEIGTH\b/HEIGHT/g
s/\bHeigth\b/Height/g
s/\bheirarchical\b/hierarchical/g
s/\bHEIRARCHICAL\b/HIERARCHICAL/g
s/\bHeirarchical\b/Hierarchical/g
s/\bheirarchically\b/hierarchically/g
s/\bHEIRARCHICALLY\b/HIERARCHICALLY/g
s/\bHeirarchically\b/Hierarchically/g
s/\bheirarchies\b/hierarchies/g
s/\bHEIRARCHIES\b/HIERARCHIES/g
s/\bHeirarchies\b/Hierarchies/g
s/\bheirarchy\b/hierarchy/g
s/\bHEIRARCHY\b/HIERARCHY/g
s/\bHeirarchy\b/Hierarchy/g
s/\bhelpfull\b/helpful/g
s/\bHELPFULL\b/HELPFUL/g
s/\bHelpfull\b/Helpful/g
s/\bhexidecimal\b/hexadecimal/g
s/\bHEXIDECIMAL\b/HEXADECIMAL/g
s/\bHexidecimal\b/Hexadecimal/g
s/\bhiearchies\b/hierarchies/g
s/\bHIEARCHIES\b/HIERARCHIES/g
s/\bHiearchies\b/Hierarchies/g
s/\bhiearchy\b/hierarchy/g
s/\bHIEARCHY\b/HIERARCHY/g
s/\bHiearchy\b/Hierarchy/g
s/\bhierachy\b/hierarchy/g
s/\bHIERACHY\b/HIERARCHY/g
s/\bHierachy\b/Hierarchy/g
s/\bhierarchie\b/hierarchy/g
s/\bHIERARCHIE\b/HIERARCHY/g
s/\bHierarchie\b/Hierarchy/g
s/\bhighlighing\b/highlighting/g
s/\bHIGHLIGHING\b/HIGHLIGHTING/g
s/\bHighlighing\b/Highlighting/g
s/\bhighlightning\b/highlighting/g
s/\bHIGHLIGHTNING\b/HIGHLIGHTING/g
s/\bHighlightning\b/Highlighting/g
s/\bhiglight\b/highlight/g
s/\bHIGLIGHT\b/HIGHLIGHT/g
s/\bHiglight\b/Highlight/g
s/\bhiglighted\b/highlighted/g
s/\bHIGLIGHTED\b/HIGHLIGHTED/g
s/\bHiglighted\b/Highlighted/g
s/\bhiglighting\b/highlighting/g
s/\bHIGLIGHTING\b/HIGHLIGHTING/g
s/\bHiglighting\b/Highlighting/g
s/\bhiglights\b/highlights/g
s/\bHIGLIGHTS\b/HIGHLIGHTS/g
s/\bHiglights\b/Highlights/g
s/\bhilight\b/highlight/g
s/\bHILIGHT\b/HIGHLIGHT/g
s/\bHilight\b/Highlight/g
s/\bhilighted\b/highlighted/g
s/\bHILIGHTED\b/HIGHLIGHTED/g
s/\bHilighted\b/Highlighted/g
s/\bhilighting\b/highlighting/g
s/\bHILIGHTING\b/HIGHLIGHTING/g
s/\bHilighting\b/Highlighting/g
s/\bhilights\b/highlights/g
s/\bHILIGHTS\b/HIGHLIGHTS/g
s/\bHilights\b/Highlights/g
s/\bhorzontal\b/horizontal/g
s/\bHORZONTAL\b/HORIZONTAL/g
s/\bHorzontal\b/Horizontal/g
s/\bhorzontally\b/horizontally/g
s/\bHORZONTALLY\b/HORIZONTALLY/g
s/\bHorzontally\b/Horizontally/g
s/\bhowerver\b/however/g
s/\bHOWERVER\b/HOWEVER/g
s/\bHowerver\b/However/g
s/\bhowver\b/however/g
s/\bHOWVER\b/HOWEVER/g
s/\bHowver\b/However/g
s/\bhypen\b/hyphen/g
s/\bHYPEN\b/HYPHEN/g
s/\bHypen\b/Hyphen/g
s/\bhypenate\b/hyphenate/g
s/\bHYPENATE\b/HYPHENATE/g
s/\bHypenate\b/Hyphenate/g
s/\bhypenated\b/hyphenated/g
s/\bHYPENATED\b/HYPHENATED/g
s/\bHypenated\b/Hyphenated/g
s/\bhypenates\b/hyphenates/g
s/\bHYPENATES\b/HYPHENATES/g
s/\bHypenates\b/Hyphenates/g
s/\bhypenating\b/hyphenating/g
s/\bHYPENATING\b/HYPHENATING/g
s/\bHypenating\b/Hyphenating/g
s/\bhypenation\b/hyphenation/g
s/\bHYPENATION\b/HYPHENATION/g
s/\bHypenation\b/Hyphenation/g
s/\bhypens\b/hyphens/g
s/\bHYPENS\b/HYPHENS/g
s/\bHypens\b/Hyphens/g
s/\bidentifer\b/identifier/g
s/\bIDENTIFER\b/IDENTIFIER/g
s/\bIdentifer\b/Identifier/g
s/\bidentifers\b/identifiers/g
s/\bIDENTIFERS\b/IDENTIFIERS/g
s/\bIdentifers\b/Identifiers/g
s/\bidicate\b/indicate/g
s/\bIDICATE\b/INDICATE/g
s/\bIdicate\b/Indicate/g
s/\bidicated\b/indicated/g
s/\bIDICATED\b/INDICATED/g
s/\bIdicated\b/Indicated/g
s/\bidicates\b/indicates/g
s/\bIDICATES\b/INDICATES/g
s/\bIdicates\b/Indicates/g
s/\bidicating\b/indicating/g
s/\bIDICATING\b/INDICATING/g
s/\bIdicating\b/Indicating/g
s/\bigore\b/ignore/g
s/\bIGORE\b/IGNORE/g
s/\bIgore\b/Ignore/g
s/\bigored\b/ignored/g
s/\bIGORED\b/IGNORED/g
s/\bIgored\b/Ignored/g
s/\bigores\b/ignores/g
s/\bIGORES\b/IGNORES/g
s/\bIgores\b/Ignores/g
s/\bigoring\b/ignoring/g
s/\bIGORING\b/IGNORING/g
s/\bIgoring\b/Ignoring/g
s/\bimediate\b/immediate/g
s/\bIMEDIATE\b/IMMEDIATE/g
s/\bImediate\b/Immediate/g
s/\bimediately\b/immediately/g
s/\bIMEDIATELY\b/IMMEDIATELY/g
s/\bImediately\b/Immediately/g
s/\bimmeadiately\b/immediately/g
s/\bIMMEADIATELY\b/IMMEDIATELY/g
s/\bImmeadiately\b/Immediately/g
s/\bimmedate\b/immediate/g
s/\bIMMEDATE\b/IMMEDIATE/g
s/\bImmedate\b/Immediate/g
s/\bimmedately\b/immediately/g
s/\bIMMEDATELY\b/IMMEDIATELY/g
s/\bImmedately\b/Immediately/g
s/\bimmediatly\b/immediately/g
s/\bIMMEDIATLY\b/IMMEDIATELY/g
s/\bImmediatly\b/Immediately/g
s/\bimmmediate\b/immediate/g
s/\bIMMMEDIATE\b/IMMEDIATE/g
s/\bImmmediate\b/Immediate/g
s/\bimmmediately\b/immediately/g
s/\bIMMMEDIATELY\b/IMMEDIATELY/g
s/\bImmmediately\b/Immediately/g
s/\bimpementation\b/implementation/g
s/\bIMPEMENTATION\b/IMPLEMENTATION/g
s/\bImpementation\b/Implementation/g
s/\bimpementations\b/implementations/g
s/\bIMPEMENTATIONS\b/IMPLEMENTATIONS/g
s/\bImpementations\b/Implementations/g
s/\bimplemantation\b/implementation/g
s/\bIMPLEMANTATION\b/IMPLEMENTATION/g
s/\bImplemantation\b/Implementation/g
s/\bimplemement\b/implement/g
s/\bIMPLEMEMENT\b/IMPLEMENT/g
s/\bImplemement\b/Implement/g
s/\bimplemementation\b/implementation/g
s/\bIMPLEMEMENTATION\b/IMPLEMENTATION/g
s/\bImplemementation\b/Implementation/g
s/\bimplemementations\b/implementations/g
s/\bIMPLEMEMENTATIONS\b/IMPLEMENTATIONS/g
s/\bImplemementations\b/Implementations/g
s/\bimplememented\b/implemented/g
s/\bIMPLEMEMENTED\b/IMPLEMENTED/g
s/\bImplememented\b/Implemented/g
s/\bimplemementing\b/implementing/g
s/\bIMPLEMEMENTING\b/IMPLEMENTING/g
s/\bImplemementing\b/Implementing/g
s/\bimplemements\b/implements/g
s/\bIMPLEMEMENTS\b/IMPLEMENTS/g
s/\bImplemements\b/Implements/g
s/\bimplemenation\b/implementation/g
s/\bIMPLEMENATION\b/IMPLEMENTATION/g
s/\bImplemenation\b/Implementation/g
s/\bimplemenations\b/implementations/g
s/\bIMPLEMENATIONS\b/IMPLEMENTATIONS/g
s/\bImplemenations\b/Implementations/g
s/\bimplementaion\b/implementation/g
s/\bIMPLEMENTAION\b/IMPLEMENTATION/g
s/\bImplementaion\b/Implementation/g
s/\bimplementaions\b/implementations/g
s/\bIMPLEMENTAIONS\b/IMPLEMENTATIONS/g
s/\bImplementaions\b/Implementations/g
s/\bimplementated\b/implemented/g
s/\bIMPLEMENTATED\b/IMPLEMENTED/g
s/\bImplementated\b/Implemented/g
s/\bimplemention\b/implementation/g
s/\bIMPLEMENTION\b/IMPLEMENTATION/g
s/\bImplemention\b/Implementation/g
s/\bimplemet\b/implement/g
s/\bIMPLEMET\b/IMPLEMENT/g
s/\bImplemet\b/Implement/g
s/\bimplemetation\b/implementation/g
s/\bIMPLEMETATION\b/IMPLEMENTATION/g
s/\bImplemetation\b/Implementation/g
s/\bimplemeted\b/implemented/g
s/\bIMPLEMETED\b/IMPLEMENTED/g
s/\bImplemeted\b/Implemented/g
s/\bimplemeting\b/implementing/g
s/\bIMPLEMETING\b/IMPLEMENTING/g
s/\bImplemeting\b/Implementing/g
s/\bimplemets\b/implements/g
s/\bIMPLEMETS\b/IMPLEMENTS/g
s/\bImplemets\b/Implements/g
s/\bimplemntation\b/implementation/g
s/\bIMPLEMNTATION\b/IMPLEMENTATION/g
s/\bImplemntation\b/Implementation/g
s/\bimplemntations\b/implementations/g
s/\bIMPLEMNTATIONS\b/IMPLEMENTATIONS/g
s/\bImplemntations\b/Implementations/g
s/\bimplicitely\b/implicitly/g
s/\bIMPLICITELY\b/IMPLICITLY/g
s/\bImplicitely\b/Implicitly/g
s/\bimplicity\b/implicitly/g
s/\bIMPLICITY\b/IMPLICITLY/g
s/\bImplicity\b/Implicitly/g
s/\bimplment\b/implement/g
s/\bIMPLMENT\b/IMPLEMENT/g
s/\bImplment\b/Implement/g
s/\bimplmentation\b/implementation/g
s/\bIMPLMENTATION\b/IMPLEMENTATION/g
s/\bImplmentation\b/Implementation/g
s/\bimplmented\b/implemented/g
s/\bIMPLMENTED\b/IMPLEMENTED/g
s/\bImplmented\b/Implemented/g
s/\bimplmenting\b/implementing/g
s/\bIMPLMENTING\b/IMPLEMENTING/g
s/\bImplmenting\b/Implementing/g
s/\bimplments\b/implements/g
s/\bIMPLMENTS\b/IMPLEMENTS/g
s/\bImplments\b/Implements/g
s/\bimprovment\b/improvement/g
s/\bIMPROVMENT\b/IMPROVEMENT/g
s/\bImprovment\b/Improvement/g
s/\bimprovments\b/improvements/g
s/\bIMPROVMENTS\b/IMPROVEMENTS/g
s/\bImprovments\b/Improvements/g
s/\binadvertant\b/inadvertent/g
s/\bINADVERTANT\b/INADVERTENT/g
s/\bInadvertant\b/Inadvertent/g
s/\binadvertantly\b/inadvertently/g
s/\bINADVERTANTLY\b/INADVERTENTLY/g
s/\bInadvertantly\b/Inadvertently/g
s/\binclue\b/include/g
s/\bINCLUE\b/INCLUDE/g
s/\bInclue\b/Include/g
s/\binclued\b/included/g
s/\bINCLUED\b/INCLUDED/g
s/\bInclued\b/Included/g
s/\binclues\b/includes/g
s/\bINCLUES\b/INCLUDES/g
s/\bInclues\b/Includes/g
s/\bincluing\b/including/g
s/\bINCLUING\b/INCLUDING/g
s/\bIncluing\b/Including/g
s/\bincomming\b/incoming/g
s/\bINCOMMING\b/INCOMING/g
s/\bIncomming\b/Incoming/g
s/\bincompatabilities\b/incompatibilities/g
s/\bINCOMPATABILITIES\b/INCOMPATIBILITIES/g
s/\bIncompatabilities\b/Incompatibilities/g
s/\bincompatability\b/incompatibility/g
s/\bINCOMPATABILITY\b/INCOMPATIBILITY/g
s/\bIncompatability\b/Incompatibility/g
s/\bincompatable\b/incompatible/g
s/\bINCOMPATABLE\b/INCOMPATIBLE/g
s/\bIncompatable\b/Incompatible/g
s/\bincompatbility\b/incompatibility/g
s/\bINCOMPATBILITY\b/INCOMPATIBILITY/g
s/\bIncompatbility\b/Incompatibility/g
s/\bincompatiability\b/incompatibility/g
s/\bINCOMPATIABILITY\b/INCOMPATIBILITY/g
s/\bIncompatiability\b/Incompatibility/g
s/\bincomptible\b/incompatible/g
s/\bINCOMPTIBLE\b/INCOMPATIBLE/g
s/\bIncomptible\b/Incompatible/g
s/\binconsistant\b/inconsistent/g
s/\bINCONSISTANT\b/INCONSISTENT/g
s/\bInconsistant\b/Inconsistent/g
s/\bincoporate\b/incorporate/g
s/\bINCOPORATE\b/INCORPORATE/g
s/\bIncoporate\b/Incorporate/g
s/\bincoporated\b/incorporated/g
s/\bINCOPORATED\b/INCORPORATED/g
s/\bIncoporated\b/Incorporated/g
s/\bincoporates\b/incorporates/g
s/\bINCOPORATES\b/INCORPORATES/g
s/\bIncoporates\b/Incorporates/g
s/\bincoporating\b/incorporating/g
s/\bINCOPORATING\b/INCORPORATING/g
s/\bIncoporating\b/Incorporating/g
s/\bincude\b/include/g
s/\bINCUDE\b/INCLUDE/g
s/\bIncude\b/Include/g
s/\bincuded\b/included/g
s/\bINCUDED\b/INCLUDED/g
s/\bIncuded\b/Included/g
s/\bincudes\b/includes/g
s/\bINCUDES\b/INCLUDES/g
s/\bIncudes\b/Includes/g
s/\bincuding\b/including/g
s/\bINCUDING\b/INCLUDING/g
s/\bIncuding\b/Including/g
s/\bincure\b/incur/g
s/\bINCURE\b/INCUR/g
s/\bIncure\b/Incur/g
s/\bindeces\b/indices/g
s/\bINDECES\b/INDICES/g
s/\bIndeces\b/Indices/g
s/\bindempotent\b/idempotent/g
s/\bINDEMPOTENT\b/IDEMPOTENT/g
s/\bIndempotent\b/Idempotent/g
s/\bindendation\b/indentation/g
s/\bINDENDATION\b/INDENTATION/g
s/\bIndendation\b/Indentation/g
s/\bindended\b/intended/g
s/\bINDENDED\b/INTENDED/g
s/\bIndended\b/Intended/g
s/\bindentical\b/identical/g
s/\bINDENTICAL\b/IDENTICAL/g
s/\bIndentical\b/Identical/g
s/\bindepended\b/independent/g
s/\bINDEPENDED\b/INDEPENDENT/g
s/\bIndepended\b/Independent/g
s/\bindepenent\b/independent/g
s/\bINDEPENENT\b/INDEPENDENT/g
s/\bIndepenent\b/Independent/g
s/\bindepenently\b/independently/g
s/\bINDEPENENTLY\b/INDEPENDENTLY/g
s/\bIndepenently\b/Independently/g
s/\bindiate\b/indicate/g
s/\bINDIATE\b/INDICATE/g
s/\bIndiate\b/Indicate/g
s/\bindiated\b/indicated/g
s/\bINDIATED\b/INDICATED/g
s/\bIndiated\b/Indicated/g
s/\bindiates\b/indicates/g
s/\bINDIATES\b/INDICATES/g
s/\bIndiates\b/Indicates/g
s/\bindiating\b/indicating/g
s/\bINDIATING\b/INDICATING/g
s/\bIndiating\b/Indicating/g
s/\bindiciate\b/indicate/g
s/\bINDICIATE\b/INDICATE/g
s/\bIndiciate\b/Indicate/g
s/\bindiciated\b/indicated/g
s/\bINDICIATED\b/INDICATED/g
s/\bIndiciated\b/Indicated/g
s/\bindiciates\b/indicates/g
s/\bINDICIATES\b/INDICATES/g
s/\bIndiciates\b/Indicates/g
s/\bindiciating\b/indicating/g
s/\bINDICIATING\b/INDICATING/g
s/\bIndiciating\b/Indicating/g
s/\bindipendent\b/independent/g
s/\bINDIPENDENT\b/INDEPENDENT/g
s/\bIndipendent\b/Independent/g
s/\bindipendently\b/independently/g
s/\bINDIPENDENTLY\b/INDEPENDENTLY/g
s/\bIndipendently\b/Independently/g
s/\bindivudual\b/individual/g
s/\bINDIVUDUAL\b/INDIVIDUAL/g
s/\bIndivudual\b/Individual/g
s/\bindivudually\b/individually/g
s/\bINDIVUDUALLY\b/INDIVIDUALLY/g
s/\bIndivudually\b/Individually/g
s/\binefficency\b/inefficiency/g
s/\bINEFFICENCY\b/INEFFICIENCY/g
s/\bInefficency\b/Inefficiency/g
s/\binfomation\b/information/g
s/\bINFOMATION\b/INFORMATION/g
s/\bInfomation\b/Information/g
s/\binformatiom\b/information/g
s/\bINFORMATIOM\b/INFORMATION/g
s/\bInformatiom\b/Information/g
s/\binformations\b/information/g
s/\bINFORMATIONS\b/INFORMATION/g
s/\bInformations\b/Information/g
s/\binfromation\b/information/g
s/\bINFROMATION\b/INFORMATION/g
s/\bInfromation\b/Information/g
s/\binital\b/initial/g
s/\bINITAL\b/INITIAL/g
s/\bInital\b/Initial/g
s/\binitalisation\b/initialisation/g
s/\bINITALISATION\b/INITIALISATION/g
s/\bInitalisation\b/Initialisation/g
s/\binitalise\b/initialise/g
s/\bINITALISE\b/INITIALISE/g
s/\bInitalise\b/Initialise/g
s/\binitalised\b/initialised/g
s/\bINITALISED\b/INITIALISED/g
s/\bInitalised\b/Initialised/g
s/\binitalises\b/initialises/g
s/\bINITALISES\b/INITIALISES/g
s/\bInitalises\b/Initialises/g
s/\binitalising\b/initialising/g
s/\bINITALISING\b/INITIALISING/g
s/\bInitalising\b/Initialising/g
s/\binitalization\b/initialization/g
s/\bINITALIZATION\b/INITIALIZATION/g
s/\bInitalization\b/Initialization/g
s/\binitalize\b/initialize/g
s/\bINITALIZE\b/INITIALIZE/g
s/\bInitalize\b/Initialize/g
s/\binitalized\b/initialized/g
s/\bINITALIZED\b/INITIALIZED/g
s/\bInitalized\b/Initialized/g
s/\binitalizes\b/initializes/g
s/\bINITALIZES\b/INITIALIZES/g
s/\bInitalizes\b/Initializes/g
s/\binitalizing\b/initializing/g
s/\bINITALIZING\b/INITIALIZING/g
s/\bInitalizing\b/Initializing/g
s/\binitators\b/initiators/g
s/\bINITATORS\b/INITIATORS/g
s/\bInitators\b/Initiators/g
s/\binitializiation\b/initialization/g
s/\bINITIALIZIATION\b/INITIALIZATION/g
s/\bInitializiation\b/Initialization/g
s/\binitialse\b/initialise/g
s/\bINITIALSE\b/INITIALISE/g
s/\bInitialse\b/Initialise/g
s/\binitialsed\b/initialised/g
s/\bINITIALSED\b/INITIALISED/g
s/\bInitialsed\b/Initialised/g
s/\binitialses\b/initialises/g
s/\bINITIALSES\b/INITIALISES/g
s/\bInitialses\b/Initialises/g
s/\binitialze\b/initialize/g
s/\bINITIALZE\b/INITIALIZE/g
s/\bInitialze\b/Initialize/g
s/\binitialzed\b/initialized/g
s/\bINITIALZED\b/INITIALIZED/g
s/\bInitialzed\b/Initialized/g
s/\binitialzes\b/initializes/g
s/\bINITIALZES\b/INITIALIZES/g
s/\bInitialzes\b/Initializes/g
s/\binitiliase\b/initialise/g
s/\bINITILIASE\b/INITIALISE/g
s/\bInitiliase\b/Initialise/g
s/\binitiliased\b/initialised/g
s/\bINITILIASED\b/INITIALISED/g
s/\bInitiliased\b/Initialised/g
s/\binitiliases\b/initialises/g
s/\bINITILIASES\b/INITIALISES/g
s/\bInitiliases\b/Initialises/g
s/\binitiliasing\b/initialising/g
s/\bINITILIASING\b/INITIALISING/g
s/\bInitiliasing\b/Initialising/g
s/\binitiliaze\b/initialize/g
s/\bINITILIAZE\b/INITIALIZE/g
s/\bInitiliaze\b/Initialize/g
s/\binitiliazed\b/initialized/g
s/\bINITILIAZED\b/INITIALIZED/g
s/\bInitiliazed\b/Initialized/g
s/\binitiliazes\b/initializes/g
s/\bINITILIAZES\b/INITIALIZES/g
s/\bInitiliazes\b/Initializes/g
s/\binitiliazing\b/initializing/g
s/\bINITILIAZING\b/INITIALIZING/g
s/\bInitiliazing\b/Initializing/g
s/\binitilize\b/initialize/g
s/\bINITILIZE\b/INITIALIZE/g
s/\bInitilize\b/Initialize/g
s/\binitilized\b/initialized/g
s/\bINITILIZED\b/INITIALIZED/g
s/\bInitilized\b/Initialized/g
s/\binitilizes\b/initializes/g
s/\bINITILIZES\b/INITIALIZES/g
s/\bInitilizes\b/Initializes/g
s/\binitilizing\b/initializing/g
s/\bINITILIZING\b/INITIALIZING/g
s/\bInitilizing\b/Initializing/g
s/\binlcude\b/include/g
s/\bINLCUDE\b/INCLUDE/g
s/\bInlcude\b/Include/g
s/\binlcuded\b/included/g
s/\bINLCUDED\b/INCLUDED/g
s/\bInlcuded\b/Included/g
s/\binlcudes\b/includes/g
s/\bINLCUDES\b/INCLUDES/g
s/\bInlcudes\b/Includes/g
s/\binlcuding\b/including/g
s/\bINLCUDING\b/INCLUDING/g
s/\bInlcuding\b/Including/g
s/\binofficial\b/unofficial/g
s/\bINOFFICIAL\b/UNOFFICIAL/g
s/\bInofficial\b/Unofficial/g
s/\binproper\b/improper/g
s/\bINPROPER\b/IMPROPER/g
s/\bInproper\b/Improper/g
s/\binproperly\b/improperly/g
s/\bINPROPERLY\b/IMPROPERLY/g
s/\bInproperly\b/Improperly/g
s/\binsensistive\b/insensitive/g
s/\bINSENSISTIVE\b/INSENSITIVE/g
s/\bInsensistive\b/Insensitive/g
s/\binsensistively\b/insensitively/g
s/\bINSENSISTIVELY\b/INSENSITIVELY/g
s/\bInsensistively\b/Insensitively/g
s/\binstanciate\b/instantiate/g
s/\bINSTANCIATE\b/INSTANTIATE/g
s/\bInstanciate\b/Instantiate/g
s/\binstanciated\b/instantiated/g
s/\bINSTANCIATED\b/INSTANTIATED/g
s/\bInstanciated\b/Instantiated/g
s/\binstanciates\b/instantiates/g
s/\bINSTANCIATES\b/INSTANTIATES/g
s/\bInstanciates\b/Instantiates/g
s/\binstanciating\b/instantiating/g
s/\bINSTANCIATING\b/INSTANTIATING/g
s/\bInstanciating\b/Instantiating/g
s/\binstanciation\b/instantiation/g
s/\bINSTANCIATION\b/INSTANTIATION/g
s/\bInstanciation\b/Instantiation/g
s/\binstanciations\b/instantiations/g
s/\bINSTANCIATIONS\b/INSTANTIATIONS/g
s/\bInstanciations\b/Instantiations/g
s/\bintance\b/instance/g
s/\bINTANCE\b/INSTANCE/g
s/\bIntance\b/Instance/g
s/\bintances\b/instances/g
s/\bINTANCES\b/INSTANCES/g
s/\bIntances\b/Instances/g
s/\bintead\b/instead/g
s/\bINTEAD\b/INSTEAD/g
s/\bIntead\b/Instead/g
s/\binteface\b/interface/g
s/\bINTEFACE\b/INTERFACE/g
s/\bInteface\b/Interface/g
s/\bintegreated\b/integrated/g
s/\bINTEGREATED\b/INTEGRATED/g
s/\bIntegreated\b/Integrated/g
s/\bintegrety\b/integrity/g
s/\bINTEGRETY\b/INTEGRITY/g
s/\bIntegrety\b/Integrity/g
s/\bintegrey\b/integrity/g
s/\bINTEGREY\b/INTEGRITY/g
s/\bIntegrey\b/Integrity/g
s/\bintendet\b/intended/g
s/\bINTENDET\b/INTENDED/g
s/\bIntendet\b/Intended/g
s/\bintentially\b/intentionally/g
s/\bINTENTIALLY\b/INTENTIONALLY/g
s/\bIntentially\b/Intentionally/g
s/\bintepret\b/interpret/g
s/\bINTEPRET\b/INTERPRET/g
s/\bIntepret\b/Interpret/g
s/\bintepreted\b/interpreted/g
s/\bINTEPRETED\b/INTERPRETED/g
s/\bIntepreted\b/Interpreted/g
s/\bintepreter\b/interpreter/g
s/\bINTEPRETER\b/INTERPRETER/g
s/\bIntepreter\b/Interpreter/g
s/\bintepreters\b/interpreters/g
s/\bINTEPRETERS\b/INTERPRETERS/g
s/\bIntepreters\b/Interpreters/g
s/\bintepreting\b/interpreting/g
s/\bINTEPRETING\b/INTERPRETING/g
s/\bIntepreting\b/Interpreting/g
s/\binteprets\b/interprets/g
s/\bINTEPRETS\b/INTERPRETS/g
s/\bInteprets\b/Interprets/g
s/\binterace\b/interface/g
s/\bINTERACE\b/INTERFACE/g
s/\bInterace\b/Interface/g
s/\binteraces\b/interfaces/g
s/\bINTERACES\b/INTERFACES/g
s/\bInteraces\b/Interfaces/g
s/\binterator\b/iterator/g
s/\bINTERATOR\b/ITERATOR/g
s/\bInterator\b/Iterator/g
s/\binterators\b/iterators/g
s/\bINTERATORS\b/ITERATORS/g
s/\bInterators\b/Iterators/g
s/\binterchangable\b/interchangeable/g
s/\bINTERCHANGABLE\b/INTERCHANGEABLE/g
s/\bInterchangable\b/Interchangeable/g
s/\binteresect\b/intersect/g
s/\bINTERESECT\b/INTERSECT/g
s/\bInteresect\b/Intersect/g
s/\binteresected\b/intersected/g
s/\bINTERESECTED\b/INTERSECTED/g
s/\bInteresected\b/Intersected/g
s/\binteresecting\b/intersecting/g
s/\bINTERESECTING\b/INTERSECTING/g
s/\bInteresecting\b/Intersecting/g
s/\binteresection\b/intersection/g
s/\bINTERESECTION\b/INTERSECTION/g
s/\bInteresection\b/Intersection/g
s/\binteresections\b/intersections/g
s/\bINTERESECTIONS\b/INTERSECTIONS/g
s/\bInteresections\b/Intersections/g
s/\binteresects\b/intersects/g
s/\bINTERESECTS\b/INTERSECTS/g
s/\bInteresects\b/Intersects/g
s/\binterferred\b/interfered/g
s/\bINTERFERRED\b/INTERFERED/g
s/\bInterferred\b/Interfered/g
s/\binterferring\b/interfering/g
s/\bINTERFERRING\b/INTERFERING/g
s/\bInterferring\b/Interfering/g
s/\binterger\b/integer/g
s/\bINTERGER\b/INTEGER/g
s/\bInterger\b/Integer/g
s/\bintergers\b/integers/g
s/\bINTERGERS\b/INTEGERS/g
s/\bIntergers\b/Integers/g
s/\bintermittant\b/intermittent/g
s/\bINTERMITTANT\b/INTERMITTENT/g
s/\bIntermittant\b/Intermittent/g
s/\binternel\b/internal/g
s/\bINTERNEL\b/INTERNAL/g
s/\bInternel\b/Internal/g
s/\binternels\b/internals/g
s/\bINTERNELS\b/INTERNALS/g
s/\bInternels\b/Internals/g
s/\binterpet\b/interpret/g
s/\bINTERPET\b/INTERPRET/g
s/\bInterpet\b/Interpret/g
s/\binterpeted\b/interpreted/g
s/\bINTERPETED\b/INTERPRETED/g
s/\bInterpeted\b/Interpreted/g
s/\binterpeter\b/interpreter/g
s/\bINTERPETER\b/INTERPRETER/g
s/\bInterpeter\b/Interpreter/g
s/\binterpeters\b/interpreters/g
s/\bINTERPETERS\b/INTERPRETERS/g
s/\bInterpeters\b/Interpreters/g
s/\binterpeting\b/interpreting/g
s/\bINTERPETING\b/INTERPRETING/g
s/\bInterpeting\b/Interpreting/g
s/\binterpets\b/interprets/g
s/\bINTERPETS\b/INTERPRETS/g
s/\bInterpets\b/Interprets/g
s/\binterpretes\b/interprets/g
s/\bINTERPRETES\b/INTERPRETS/g
s/\bInterpretes\b/Interprets/g
s/\binterruped\b/interrupted/g
s/\bINTERRUPED\b/INTERRUPTED/g
s/\bInterruped\b/Interrupted/g
s/\binterupt\b/interrupt/g
s/\bINTERUPT\b/INTERRUPT/g
s/\bInterupt\b/Interrupt/g
s/\binterupted\b/interrupted/g
s/\bINTERUPTED\b/INTERRUPTED/g
s/\bInterupted\b/Interrupted/g
s/\binterupting\b/interrupting/g
s/\bINTERUPTING\b/INTERRUPTING/g
s/\bInterupting\b/Interrupting/g
s/\binterupts\b/interrupts/g
s/\bINTERUPTS\b/INTERRUPTS/g
s/\bInterupts\b/Interrupts/g
s/\bintialisation\b/initialisation/g
s/\bINTIALISATION\b/INITIALISATION/g
s/\bIntialisation\b/Initialisation/g
s/\bintialise\b/initialise/g
s/\bINTIALISE\b/INITIALISE/g
s/\bIntialise\b/Initialise/g
s/\bintialised\b/initialised/g
s/\bINTIALISED\b/INITIALISED/g
s/\bIntialised\b/Initialised/g
s/\bintialises\b/initialises/g
s/\bINTIALISES\b/INITIALISES/g
s/\bIntialises\b/Initialises/g
s/\bintialising\b/initialising/g
s/\bINTIALISING\b/INITIALISING/g
s/\bIntialising\b/Initialising/g
s/\bintialization\b/initialization/g
s/\bINTIALIZATION\b/INITIALIZATION/g
s/\bIntialization\b/Initialization/g
s/\bintialize\b/initialize/g
s/\bINTIALIZE\b/INITIALIZE/g
s/\bIntialize\b/Initialize/g
s/\bintialized\b/initialized/g
s/\bINTIALIZED\b/INITIALIZED/g
s/\bIntialized\b/Initialized/g
s/\bintializes\b/initializes/g
s/\bINTIALIZES\b/INITIALIZES/g
s/\bIntializes\b/Initializes/g
s/\bintializing\b/initializing/g
s/\bINTIALIZING\b/INITIALIZING/g
s/\bIntializing\b/Initializing/g
s/\bintregral\b/integral/g
s/\bINTREGRAL\b/INTEGRAL/g
s/\bIntregral\b/Integral/g
s/\bintruction\b/instruction/g
s/\bINTRUCTION\b/INSTRUCTION/g
s/\bIntruction\b/Instruction/g
s/\bintructions\b/instructions/g
s/\bINTRUCTIONS\b/INSTRUCTIONS/g
s/\bIntructions\b/Instructions/g
s/\bintrument\b/instrument/g
s/\bINTRUMENT\b/INSTRUMENT/g
s/\bIntrument\b/Instrument/g
s/\bintrumented\b/instrumented/g
s/\bINTRUMENTED\b/INSTRUMENTED/g
s/\bIntrumented\b/Instrumented/g
s/\bintrumenting\b/instrumenting/g
s/\bINTRUMENTING\b/INSTRUMENTING/g
s/\bIntrumenting\b/Instrumenting/g
s/\bintruments\b/instruments/g
s/\bINTRUMENTS\b/INSTRUMENTS/g
s/\bIntruments\b/Instruments/g
s/\bintuative\b/intuitive/g
s/\bINTUATIVE\b/INTUITIVE/g
s/\bIntuative\b/Intuitive/g
s/\binvalud\b/invalid/g
s/\bINVALUD\b/INVALID/g
s/\bInvalud\b/Invalid/g
s/\binvarient\b/invariant/g
s/\bINVARIENT\b/INVARIANT/g
s/\bInvarient\b/Invariant/g
s/\binvididual\b/individual/g
s/\bINVIDIDUAL\b/INDIVIDUAL/g
s/\bInvididual\b/Individual/g
s/\binvokation\b/invocation/g
s/\bINVOKATION\b/INVOCATION/g
s/\bInvokation\b/Invocation/g
s/\binvokations\b/invocations/g
s/\bINVOKATIONS\b/INVOCATIONS/g
s/\bInvokations\b/Invocations/g
s/\birrelevent\b/irrelevant/g
s/\bIRRELEVENT\b/IRRELEVANT/g
s/\bIrrelevent\b/Irrelevant/g
s/\bisnt\b/isn't/g
s/\bISNT\b/ISN'T/g
s/\bIsnt\b/Isn't/g
s/\bistead\b/instead/g
s/\bISTEAD\b/INSTEAD/g
s/\bIstead\b/Instead/g
s/\bitialize\b/initialize/g
s/\bITIALIZE\b/INITIALIZE/g
s/\bItialize\b/Initialize/g
s/\bitialized\b/initialized/g
s/\bITIALIZED\b/INITIALIZED/g
s/\bItialized\b/Initialized/g
s/\bitializes\b/initializes/g
s/\bITIALIZES\b/INITIALIZES/g
s/\bItializes\b/Initializes/g
s/\bitializing\b/initializing/g
s/\bITIALIZING\b/INITIALIZING/g
s/\bItializing\b/Initializing/g
s/\bitslef\b/itself/g
s/\bITSLEF\b/ITSELF/g
s/\bItslef\b/Itself/g
s/\bjave\b/java/g
s/\bJAVE\b/JAVA/g
s/\bJave\b/Java/g
s/\bkeywork\b/keyword/g
s/\bKEYWORK\b/KEYWORD/g
s/\bKeywork\b/Keyword/g
s/\blangage\b/language/g
s/\bLANGAGE\b/LANGUAGE/g
s/\bLangage\b/Language/g
s/\blangauage\b/language/g
s/\bLANGAUAGE\b/LANGUAGE/g
s/\bLangauage\b/Language/g
s/\blangauge\b/language/g
s/\bLANGAUGE\b/LANGUAGE/g
s/\bLangauge\b/Language/g
s/\blangauges\b/languages/g
s/\bLANGAUGES\b/LANGUAGES/g
s/\bLangauges\b/Languages/g
s/\blangugage\b/language/g
s/\bLANGUGAGE\b/LANGUAGE/g
s/\bLangugage\b/Language/g
s/\blanguge\b/language/g
s/\bLANGUGE\b/LANGUAGE/g
s/\bLanguge\b/Language/g
s/\blanguges\b/languages/g
s/\bLANGUGES\b/LANGUAGES/g
s/\bLanguges\b/Languages/g
s/\blaod\b/load/g
s/\bLAOD\b/LOAD/g
s/\bLaod\b/Load/g
s/\blaoded\b/loaded/g
s/\bLAODED\b/LOADED/g
s/\bLaoded\b/Loaded/g
s/\blaoding\b/loading/g
s/\bLAODING\b/LOADING/g
s/\bLaoding\b/Loading/g
s/\blaods\b/loads/g
s/\bLAODS\b/LOADS/g
s/\bLaods\b/Loads/g
s/\blauch\b/launch/g
s/\bLAUCH\b/LAUNCH/g
s/\bLauch\b/Launch/g
s/\blauched\b/launched/g
s/\bLAUCHED\b/LAUNCHED/g
s/\bLauched\b/Launched/g
s/\blaucher\b/launcher/g
s/\bLAUCHER\b/LAUNCHER/g
s/\bLaucher\b/Launcher/g
s/\blauches\b/launches/g
s/\bLAUCHES\b/LAUNCHES/g
s/\bLauches\b/Launches/g
s/\blauching\b/launching/g
s/\bLAUCHING\b/LAUNCHING/g
s/\bLauching\b/Launching/g
s/\bleightweight\b/lightweight/g
s/\bLEIGHTWEIGHT\b/LIGHTWEIGHT/g
s/\bLeightweight\b/Lightweight/g
s/\blengh\b/length/g
s/\bLENGH\b/LENGTH/g
s/\bLengh\b/Length/g
s/\blenghs\b/lengths/g
s/\bLENGHS\b/LENGTHS/g
s/\bLenghs\b/Lengths/g
s/\blenghts\b/lengths/g
s/\bLENGHTS\b/LENGTHS/g
s/\bLenghts\b/Lengths/g
s/\blenghty\b/lengthy/g
s/\bLENGHTY\b/LENGTHY/g
s/\bLenghty\b/Lengthy/g
s/\blengthes\b/lengths/g
s/\bLENGTHES\b/LENGTHS/g
s/\bLengthes\b/Lengths/g
s/\blenth\b/length/g
s/\bLENTH\b/LENGTH/g
s/\bLenth\b/Length/g
s/\blesstiff\b/lesstif/g
s/\bLESSTIFF\b/LESSTIF/g
s/\bLesstiff\b/Lesstif/g
s/\blibaries\b/libraries/g
s/\bLIBARIES\b/LIBRARIES/g
s/\bLibaries\b/Libraries/g
s/\blibary\b/library/g
s/\bLIBARY\b/LIBRARY/g
s/\bLibary\b/Library/g
s/\blibrairies\b/libraries/g
s/\bLIBRAIRIES\b/LIBRARIES/g
s/\bLibrairies\b/Libraries/g
s/\blibraris\b/libraries/g
s/\bLIBRARIS\b/LIBRARIES/g
s/\bLibraris\b/Libraries/g
s/\blicenceing\b/licencing/g
s/\bLICENCEING\b/LICENCING/g
s/\bLicenceing\b/Licencing/g
s/\blicese\b/license/g
s/\bLICESE\b/LICENSE/g
s/\bLicese\b/License/g
s/\bligth\b/light/g
s/\bLIGTH\b/LIGHT/g
s/\bLigth\b/Light/g
s/\blikelyhood\b/likelihood/g
s/\bLIKELYHOOD\b/LIKELIHOOD/g
s/\bLikelyhood\b/Likelihood/g
s/\blimted\b/limited/g
s/\bLIMTED\b/LIMITED/g
s/\bLimted\b/Limited/g
s/\blintain\b/lintian/g
s/\bLINTAIN\b/LINTIAN/g
s/\bLintain\b/Lintian/g
s/\bloggging\b/logging/g
s/\bLOGGGING\b/LOGGING/g
s/\bLoggging\b/Logging/g
s/\bloggin\b/login/g
s/\bLOGGIN\b/LOGIN/g
s/\bLoggin\b/Login/g
s/\blogile\b/logfile/g
s/\bLOGILE\b/LOGFILE/g
s/\bLogile\b/Logfile/g
s/\blongers\b/longer/g
s/\bLONGERS\b/LONGER/g
s/\bLongers\b/Longer/g
s/\bloosly\b/loosely/g
s/\bLOOSLY\b/LOOSELY/g
s/\bLoosly\b/Loosely/g
s/\bmachinary\b/machinery/g
s/\bMACHINARY\b/MACHINERY/g
s/\bMachinary\b/Machinery/g
s/\bmaintainance\b/maintenance/g
s/\bMAINTAINANCE\b/MAINTENANCE/g
s/\bMaintainance\b/Maintenance/g
s/\bmaintainence\b/maintenance/g
s/\bMAINTAINENCE\b/MAINTENANCE/g
s/\bMaintainence\b/Maintenance/g
s/\bmaintaing\b/maintaining/g
s/\bMAINTAING\b/MAINTAINING/g
s/\bMaintaing\b/Maintaining/g
s/\bmaintan\b/maintain/g
s/\bMAINTAN\b/MAINTAIN/g
s/\bMaintan\b/Maintain/g
s/\bmakeing\b/making/g
s/\bMAKEING\b/MAKING/g
s/\bMakeing\b/Making/g
s/\bmalplace\b/misplace/g
s/\bMALPLACE\b/MISPLACE/g
s/\bMalplace\b/Misplace/g
s/\bmalplaced\b/misplaced/g
s/\bMALPLACED\b/MISPLACED/g
s/\bMalplaced\b/Misplaced/g
s/\bmamory\b/memory/g
s/\bMAMORY\b/MEMORY/g
s/\bMamory\b/Memory/g
s/\bmanagable\b/manageable/g
s/\bMANAGABLE\b/MANAGEABLE/g
s/\bManagable\b/Manageable/g
s/\bmanagment\b/management/g
s/\bMANAGMENT\b/MANAGEMENT/g
s/\bManagment\b/Management/g
s/\bmanoeuvering\b/maneuvering/g
s/\bMANOEUVERING\b/MANEUVERING/g
s/\bManoeuvering\b/Maneuvering/g
s/\bmantain\b/maintain/g
s/\bMANTAIN\b/MAINTAIN/g
s/\bMantain\b/Maintain/g
s/\bmantained\b/maintained/g
s/\bMANTAINED\b/MAINTAINED/g
s/\bMantained\b/Maintained/g
s/\bmantainer\b/maintainer/g
s/\bMANTAINER\b/MAINTAINER/g
s/\bMantainer\b/Maintainer/g
s/\bmantaining\b/maintaining/g
s/\bMANTAINING\b/MAINTAINING/g
s/\bMantaining\b/Maintaining/g
s/\bmantains\b/maintains/g
s/\bMANTAINS\b/MAINTAINS/g
s/\bMantains\b/Maintains/g
s/\bmanully\b/manually/g
s/\bMANULLY\b/MANUALLY/g
s/\bManully\b/Manually/g
s/\bmatchin\b/matching/g
s/\bMATCHIN\b/MATCHING/g
s/\bMatchin\b/Matching/g
s/\bmatcing\b/matching/g
s/\bMATCING\b/MATCHING/g
s/\bMatcing\b/Matching/g
s/\bmathimatic\b/mathematic/g
s/\bMATHIMATIC\b/MATHEMATIC/g
s/\bMathimatic\b/Mathematic/g
s/\bmathimatical\b/mathematical/g
s/\bMATHIMATICAL\b/MATHEMATICAL/g
s/\bMathimatical\b/Mathematical/g
s/\bmathimatics\b/mathematics/g
s/\bMATHIMATICS\b/MATHEMATICS/g
s/\bMathimatics\b/Mathematics/g
s/\bmaxium\b/maximum/g
s/\bMAXIUM\b/MAXIMUM/g
s/\bMaxium\b/Maximum/g
s/\bmecanism\b/mechanism/g
s/\bMECANISM\b/MECHANISM/g
s/\bMecanism\b/Mechanism/g
s/\bmecanisms\b/mechanisms/g
s/\bMECANISMS\b/MECHANISMS/g
s/\bMecanisms\b/Mechanisms/g
s/\bment\b/meant/g
s/\bMENT\b/MEANT/g
s/\bMent\b/Meant/g
s/\bmentionned\b/mentioned/g
s/\bMENTIONNED\b/MENTIONED/g
s/\bMentionned\b/Mentioned/g
s/\bmesage\b/message/g
s/\bMESAGE\b/MESSAGE/g
s/\bMesage\b/Message/g
s/\bmesages\b/messages/g
s/\bMESAGES\b/MESSAGES/g
s/\bMesages\b/Messages/g
s/\bmessags\b/messages/g
s/\bMESSAGS\b/MESSAGES/g
s/\bMessags\b/Messages/g
s/\bmessge\b/message/g
s/\bMESSGE\b/MESSAGE/g
s/\bMessge\b/Message/g
s/\bmessges\b/messages/g
s/\bMESSGES\b/MESSAGES/g
s/\bMessges\b/Messages/g
s/\bmesssage\b/message/g
s/\bMESSSAGE\b/MESSAGE/g
s/\bMesssage\b/Message/g
s/\bmesssages\b/messages/g
s/\bMESSSAGES\b/MESSAGES/g
s/\bMesssages\b/Messages/g
s/\bmicroprocesspr\b/microprocessor/g
s/\bMICROPROCESSPR\b/MICROPROCESSOR/g
s/\bMicroprocesspr\b/Microprocessor/g
s/\bmilisecond\b/millisecond/g
s/\bMILISECOND\b/MILLISECOND/g
s/\bMilisecond\b/Millisecond/g
s/\bmiliseconds\b/milliseconds/g
s/\bMILISECONDS\b/MILLISECONDS/g
s/\bMiliseconds\b/Milliseconds/g
s/\bmillenium\b/millennium/g
s/\bMILLENIUM\b/MILLENNIUM/g
s/\bMillenium\b/Millennium/g
s/\bmilliseonds\b/milliseconds/g
s/\bMILLISEONDS\b/MILLISECONDS/g
s/\bMilliseonds\b/Milliseconds/g
s/\bmimicing\b/mimicking/g
s/\bMIMICING\b/MIMICKING/g
s/\bMimicing\b/Mimicking/g
s/\bmimick\b/mimic/g
s/\bMIMICK\b/MIMIC/g
s/\bMimick\b/Mimic/g
s/\bmimicks\b/mimics/g
s/\bMIMICKS\b/MIMICS/g
s/\bMimicks\b/Mimics/g
s/\bmininum\b/minimum/g
s/\bMININUM\b/MINIMUM/g
s/\bMininum\b/Minimum/g
s/\bminiscule\b/minuscule/g
s/\bMINISCULE\b/MINUSCULE/g
s/\bMiniscule\b/Minuscule/g
s/\bminumum\b/minimum/g
s/\bMINUMUM\b/MINIMUM/g
s/\bMinumum\b/Minimum/g
s/\bmiscelleneous\b/miscellaneous/g
s/\bMISCELLENEOUS\b/MISCELLANEOUS/g
s/\bMiscelleneous\b/Miscellaneous/g
s/\bmisformed\b/malformed/g
s/\bMISFORMED\b/MALFORMED/g
s/\bMisformed\b/Malformed/g
s/\bmismach\b/mismatch/g
s/\bMISMACH\b/MISMATCH/g
s/\bMismach\b/Mismatch/g
s/\bmismached\b/mismatched/g
s/\bMISMACHED\b/MISMATCHED/g
s/\bMismached\b/Mismatched/g
s/\bmismaches\b/mismatches/g
s/\bMISMACHES\b/MISMATCHES/g
s/\bMismaches\b/Mismatches/g
s/\bmismaching\b/mismatching/g
s/\bMISMACHING\b/MISMATCHING/g
s/\bMismaching\b/Mismatching/g
s/\bmispelled\b/misspelled/g
s/\bMISPELLED\b/MISSPELLED/g
s/\bMispelled\b/Misspelled/g
s/\bmispelt\b/misspelt/g
s/\bMISPELT\b/MISSPELT/g
s/\bMispelt\b/Misspelt/g
s/\bmissconfiguration\b/misconfiguration/g
s/\bMISSCONFIGURATION\b/MISCONFIGURATION/g
s/\bMissconfiguration\b/Misconfiguration/g
s/\bmissconfigure\b/misconfigure/g
s/\bMISSCONFIGURE\b/MISCONFIGURE/g
s/\bMissconfigure\b/Misconfigure/g
s/\bmissconfigured\b/misconfigured/g
s/\bMISSCONFIGURED\b/MISCONFIGURED/g
s/\bMissconfigured\b/Misconfigured/g
s/\bmissconfigures\b/misconfigures/g
s/\bMISSCONFIGURES\b/MISCONFIGURES/g
s/\bMissconfigures\b/Misconfigures/g
s/\bmissconfiguring\b/misconfiguring/g
s/\bMISSCONFIGURING\b/MISCONFIGURING/g
s/\bMissconfiguring\b/Misconfiguring/g
s/\bmissmatch\b/mismatch/g
s/\bMISSMATCH\b/MISMATCH/g
s/\bMissmatch\b/Mismatch/g
s/\bmissmatched\b/mismatched/g
s/\bMISSMATCHED\b/MISMATCHED/g
s/\bMissmatched\b/Mismatched/g
s/\bmissmatches\b/mismatches/g
s/\bMISSMATCHES\b/MISMATCHES/g
s/\bMissmatches\b/Mismatches/g
s/\bmissmatching\b/mismatching/g
s/\bMISSMATCHING\b/MISMATCHING/g
s/\bMissmatching\b/Mismatching/g
s/\bmmnemonic\b/mnemonic/g
s/\bMMNEMONIC\b/MNEMONIC/g
s/\bMmnemonic\b/Mnemonic/g
s/\bmodfied\b/modified/g
s/\bMODFIED\b/MODIFIED/g
s/\bModfied\b/Modified/g
s/\bmodfies\b/modifies/g
s/\bMODFIES\b/MODIFIES/g
s/\bModfies\b/Modifies/g
s/\bmodfy\b/modify/g
s/\bMODFY\b/MODIFY/g
s/\bModfy\b/Modify/g
s/\bmodfying\b/modifying/g
s/\bMODFYING\b/MODIFYING/g
s/\bModfying\b/Modifying/g
s/\bmodifed\b/modified/g
s/\bMODIFED\b/MODIFIED/g
s/\bModifed\b/Modified/g
s/\bmodifing\b/modifying/g
s/\bMODIFING\b/MODIFYING/g
s/\bModifing\b/Modifying/g
s/\bmodulues\b/modules/g
s/\bMODULUES\b/MODULES/g
s/\bModulues\b/Modules/g
s/\bmonochorome\b/monochrome/g
s/\bMONOCHOROME\b/MONOCHROME/g
s/\bMonochorome\b/Monochrome/g
s/\bmonochromo\b/monochrome/g
s/\bMONOCHROMO\b/MONOCHROME/g
s/\bMonochromo\b/Monochrome/g
s/\bmonocrome\b/monochrome/g
s/\bMONOCROME\b/MONOCHROME/g
s/\bMonocrome\b/Monochrome/g
s/\bmorever\b/moreover/g
s/\bMOREVER\b/MOREOVER/g
s/\bMorever\b/Moreover/g
s/\bmroe\b/more/g
s/\bMROE\b/MORE/g
s/\bMroe\b/More/g
s/\bmulitple\b/multiple/g
s/\bMULITPLE\b/MULTIPLE/g
s/\bMulitple\b/Multiple/g
s/\bmulitplied\b/multiplied/g
s/\bMULITPLIED\b/MULTIPLIED/g
s/\bMulitplied\b/Multiplied/g
s/\bmultidimensionnal\b/multidimensional/g
s/\bMULTIDIMENSIONNAL\b/MULTIDIMENSIONAL/g
s/\bMultidimensionnal\b/Multidimensional/g
s/\bmultipled\b/multiplied/g
s/\bMULTIPLED\b/MULTIPLIED/g
s/\bMultipled\b/Multiplied/g
s/\bmultplied\b/multiplied/g
s/\bMULTPLIED\b/MULTIPLIED/g
s/\bMultplied\b/Multiplied/g
s/\bmultplies\b/multiplies/g
s/\bMULTPLIES\b/MULTIPLIES/g
s/\bMultplies\b/Multiplies/g
s/\bmultply\b/multiply/g
s/\bMULTPLY\b/MULTIPLY/g
s/\bMultply\b/Multiply/g
s/\bmultplying\b/multiplying/g
s/\bMULTPLYING\b/MULTIPLYING/g
s/\bMultplying\b/Multiplying/g
s/\bmusn't\b/mustn't/g
s/\bMUSN'T\b/MUSTN'T/g
s/\bMusn't\b/Mustn't/g
s/\bmutiple\b/multiple/g
s/\bMUTIPLE\b/MULTIPLE/g
s/\bMutiple\b/Multiple/g
s/\bmutliple\b/multiple/g
s/\bMUTLIPLE\b/MULTIPLE/g
s/\bMutliple\b/Multiple/g
s/\bnam\b/name/g
s/\bNAM\b/NAME/g
s/\bNam\b/Name/g
s/\bnams\b/names/g
s/\bNAMS\b/NAMES/g
s/\bNams\b/Names/g
s/\bnavagating\b/navigating/g
s/\bNAVAGATING\b/NAVIGATING/g
s/\bNavagating\b/Navigating/g
s/\bnead\b/need/g
s/\bNEAD\b/NEED/g
s/\bNead\b/Need/g
s/\bneccesarily\b/necessarily/g
s/\bNECCESARILY\b/NECESSARILY/g
s/\bNeccesarily\b/Necessarily/g
s/\bneccesary\b/necessary/g
s/\bNECCESARY\b/NECESSARY/g
s/\bNeccesary\b/Necessary/g
s/\bneccessarily\b/necessarily/g
s/\bNECCESSARILY\b/NECESSARILY/g
s/\bNeccessarily\b/Necessarily/g
s/\bneccessary\b/necessary/g
s/\bNECCESSARY\b/NECESSARY/g
s/\bNeccessary\b/Necessary/g
s/\bnecesarily\b/necessarily/g
s/\bNECESARILY\b/NECESSARILY/g
s/\bNecesarily\b/Necessarily/g
s/\bnecesarrily\b/necessarily/g
s/\bNECESARRILY\b/NECESSARILY/g
s/\bNecesarrily\b/Necessarily/g
s/\bnecesarry\b/necessary/g
s/\bNECESARRY\b/NECESSARY/g
s/\bNecesarry\b/Necessary/g
s/\bnecesary\b/necessary/g
s/\bNECESARY\b/NECESSARY/g
s/\bNecesary\b/Necessary/g
s/\bnecessar\b/necessary/g
s/\bNECESSAR\b/NECESSARY/g
s/\bNecessar\b/Necessary/g
s/\bnedded\b/needed/g
s/\bNEDDED\b/NEEDED/g
s/\bNedded\b/Needed/g
s/\bneeed\b/need/g
s/\bNEEED\b/NEED/g
s/\bNeeed\b/Need/g
s/\bneeeded\b/needed/g
s/\bNEEEDED\b/NEEDED/g
s/\bNeeeded\b/Needed/g
s/\bneeeding\b/needing/g
s/\bNEEEDING\b/NEEDING/g
s/\bNeeeding\b/Needing/g
s/\bneeeds\b/needs/g
s/\bNEEEDS\b/NEEDS/g
s/\bNeeeds\b/Needs/g
s/\bnegotation\b/negotiation/g
s/\bNEGOTATION\b/NEGOTIATION/g
s/\bNegotation\b/Negotiation/g
s/\bnescessary\b/necessary/g
s/\bNESCESSARY\b/NECESSARY/g
s/\bNescessary\b/Necessary/g
s/\bnesesarily\b/necessarily/g
s/\bNESESARILY\b/NECESSARILY/g
s/\bNesesarily\b/Necessarily/g
s/\bnessesary\b/necessary/g
s/\bNESSESARY\b/NECESSARY/g
s/\bNessesary\b/Necessary/g
s/\bnessessary\b/necessary/g
s/\bNESSESSARY\b/NECESSARY/g
s/\bNessessary\b/Necessary/g
s/\bnonexistant\b/nonexistent/g
s/\bNONEXISTANT\b/NONEXISTENT/g
s/\bNonexistant\b/Nonexistent/g
s/\bnontheless\b/nonetheless/g
s/\bNONTHELESS\b/NONETHELESS/g
s/\bNontheless\b/Nonetheless/g
s/\bnoone\b/no one/g
s/\bNOONE\b/NO ONE/g
s/\bNoone\b/No one/g
s/\bnormaly\b/normally/g
s/\bNORMALY\b/NORMALLY/g
s/\bNormaly\b/Normally/g
s/\bnoticable\b/noticeable/g
s/\bNOTICABLE\b/NOTICEABLE/g
s/\bNoticable\b/Noticeable/g
s/\bnoticably\b/noticeably/g
s/\bNOTICABLY\b/NOTICEABLY/g
s/\bNoticably\b/Noticeably/g
s/\bnotications\b/notifications/g
s/\bNOTICATIONS\b/NOTIFICATIONS/g
s/\bNotications\b/Notifications/g
s/\bnotifcation\b/notification/g
s/\bNOTIFCATION\b/NOTIFICATION/g
s/\bNotifcation\b/Notification/g
s/\bnotifcations\b/notifications/g
s/\bNOTIFCATIONS\b/NOTIFICATIONS/g
s/\bNotifcations\b/Notifications/g
s/\bnubmer\b/number/g
s/\bNUBMER\b/NUMBER/g
s/\bNubmer\b/Number/g
s/\bnubmers\b/numbers/g
s/\bNUBMERS\b/NUMBERS/g
s/\bNubmers\b/Numbers/g
s/\bnumberal\b/numeral/g
s/\bNUMBERAL\b/NUMERAL/g
s/\bNumberal\b/Numeral/g
s/\bnumberals\b/numerals/g
s/\bNUMBERALS\b/NUMERALS/g
s/\bNumberals\b/Numerals/g
s/\bnumebr\b/number/g
s/\bNUMEBR\b/NUMBER/g
s/\bNumebr\b/Number/g
s/\bnumebrs\b/numbers/g
s/\bNUMEBRS\b/NUMBERS/g
s/\bNumebrs\b/Numbers/g
s/\bo'caml\b/ocaml/g
s/\bO'CAML\b/OCAML/g
s/\bO'caml\b/OCaml/g
s/\bobservered\b/observed/g
s/\bOBSERVERED\b/OBSERVED/g
s/\bObservered\b/Observed/g
s/\bobsure\b/obscure/g
s/\bOBSURE\b/OBSCURE/g
s/\bObsure\b/Obscure/g
s/\boccationally\b/occasionally/g
s/\bOCCATIONALLY\b/OCCASIONALLY/g
s/\bOccationally\b/Occasionally/g
s/\boccurances\b/occurrences/g
s/\bOCCURANCES\b/OCCURRENCES/g
s/\bOccurances\b/Occurrences/g
s/\boccurences\b/occurrences/g
s/\bOCCURENCES\b/OCCURRENCES/g
s/\bOccurences\b/Occurrences/g
s/\boccurrance\b/occurrence/g
s/\bOCCURRANCE\b/OCCURRENCE/g
s/\bOccurrance\b/Occurrence/g
s/\boccurrances\b/occurrences/g
s/\bOCCURRANCES\b/OCCURRENCES/g
s/\bOccurrances\b/Occurrences/g
s/\bocurrence\b/occurrence/g
s/\bOCURRENCE\b/OCCURRENCE/g
s/\bOcurrence\b/Occurrence/g
s/\bocurrences\b/occurrences/g
s/\bOCURRENCES\b/OCCURRENCES/g
s/\bOcurrences\b/Occurrences/g
s/\boffical\b/official/g
s/\bOFFICAL\b/OFFICIAL/g
s/\bOffical\b/Official/g
s/\bofficialy\b/officially/g
s/\bOFFICIALY\b/OFFICIALLY/g
s/\bOfficialy\b/Officially/g
s/\bofthe\b/of the/g
s/\bOFTHE\b/OF THE/g
s/\bOfthe\b/Of the/g
s/\bomitt\b/omit/g
s/\bOMITT\b/OMIT/g
s/\bOmitt\b/Omit/g
s/\bommiting\b/omitting/g
s/\bOMMITING\b/OMITTING/g
s/\bOmmiting\b/Omitting/g
s/\bommitted\b/omitted/g
s/\bOMMITTED\b/OMITTED/g
s/\bOmmitted\b/Omitted/g
s/\bonself\b/oneself/g
s/\bONSELF\b/ONESELF/g
s/\bOnself\b/Oneself/g
s/\bopague\b/opaque/g
s/\bOPAGUE\b/OPAQUE/g
s/\bOpague\b/Opaque/g
s/\bopenened\b/opened/g
s/\bOPENENED\b/OPENED/g
s/\bOpenened\b/Opened/g
s/\bopenned\b/opened/g
s/\bOPENNED\b/OPENED/g
s/\bOpenned\b/Opened/g
s/\bopenning\b/opening/g
s/\bOPENNING\b/OPENING/g
s/\bOpenning\b/Opening/g
s/\bopertaion\b/operation/g
s/\bOPERTAION\b/OPERATION/g
s/\bOpertaion\b/Operation/g
s/\bopertaions\b/operations/g
s/\bOPERTAIONS\b/OPERATIONS/g
s/\bOpertaions\b/Operations/g
s/\bopion\b/option/g
s/\bOPION\b/OPTION/g
s/\bOpion\b/Option/g
s/\bopions\b/options/g
s/\bOPIONS\b/OPTIONS/g
s/\bOpions\b/Options/g
s/\boptinal\b/optional/g
s/\bOPTINAL\b/OPTIONAL/g
s/\bOptinal\b/Optional/g
s/\boptinally\b/optionally/g
s/\bOPTINALLY\b/OPTIONALLY/g
s/\bOptinally\b/Optionally/g
s/\boptionaly\b/optionally/g
s/\bOPTIONALY\b/OPTIONALLY/g
s/\bOptionaly\b/Optionally/g
s/\boptionnal\b/optional/g
s/\bOPTIONNAL\b/OPTIONAL/g
s/\bOptionnal\b/Optional/g
s/\boptmization\b/optimization/g
s/\bOPTMIZATION\b/OPTIMIZATION/g
s/\bOptmization\b/Optimization/g
s/\boptmizations\b/optimizations/g
s/\bOPTMIZATIONS\b/OPTIMIZATIONS/g
s/\bOptmizations\b/Optimizations/g
s/\borderd\b/ordered/g
s/\bORDERD\b/ORDERED/g
s/\bOrderd\b/Ordered/g
s/\borgin\b/origin/g
s/\bORGIN\b/ORIGIN/g
s/\bOrgin\b/Origin/g
s/\borginally\b/originally/g
s/\bORGINALLY\b/ORIGINALLY/g
s/\bOrginally\b/Originally/g
s/\borientatied\b/orientated/g
s/\bORIENTATIED\b/ORIENTATED/g
s/\bOrientatied\b/Orientated/g
s/\borientied\b/oriented/g
s/\bORIENTIED\b/ORIENTED/g
s/\bOrientied\b/Oriented/g
s/\botehr\b/other/g
s/\bOTEHR\b/OTHER/g
s/\bOtehr\b/Other/g
s/\botherwhise\b/otherwise/g
s/\bOTHERWHISE\b/OTHERWISE/g
s/\bOtherwhise\b/Otherwise/g
s/\bothwerwise\b/otherwise/g
s/\bOTHWERWISE\b/OTHERWISE/g
s/\bOthwerwise\b/Otherwise/g
s/\bouptut\b/output/g
s/\bOUPTUT\b/OUTPUT/g
s/\bOuptut\b/Output/g
s/\bouputs\b/outputs/g
s/\bOUPUTS\b/OUTPUTS/g
s/\bOuputs\b/Outputs/g
s/\bouputted\b/outputted/g
s/\bOUPUTTED\b/OUTPUTTED/g
s/\bOuputted\b/Outputted/g
s/\bouputting\b/outputting/g
s/\bOUPUTTING\b/OUTPUTTING/g
s/\bOuputting\b/Outputting/g
s/\boutputing\b/outputting/g
s/\bOUTPUTING\b/OUTPUTTING/g
s/\bOutputing\b/Outputting/g
s/\boutut\b/output/g
s/\bOUTUT\b/OUTPUT/g
s/\bOutut\b/Output/g
s/\boveraall\b/overall/g
s/\bOVERAALL\b/OVERALL/g
s/\bOveraall\b/Overall/g
s/\boveridden\b/overridden/g
s/\bOVERIDDEN\b/OVERRIDDEN/g
s/\bOveridden\b/Overridden/g
s/\boveride\b/override/g
s/\bOVERIDE\b/OVERRIDE/g
s/\bOveride\b/Override/g
s/\boverides\b/overrides/g
s/\bOVERIDES\b/OVERRIDES/g
s/\bOverides\b/Overrides/g
s/\boveriding\b/overriding/g
s/\bOVERIDING\b/OVERRIDING/g
s/\bOveriding\b/Overriding/g
s/\boverridded\b/overridden/g
s/\bOVERRIDDED\b/OVERRIDDEN/g
s/\bOverridded\b/Overridden/g
s/\boverrided\b/overridden/g
s/\bOVERRIDED\b/OVERRIDDEN/g
s/\bOverrided\b/Overridden/g
s/\boverriden\b/overridden/g
s/\bOVERRIDEN\b/OVERRIDDEN/g
s/\bOverriden\b/Overridden/g
s/\boverrridden\b/overridden/g
s/\bOVERRRIDDEN\b/OVERRIDDEN/g
s/\bOverrridden\b/Overridden/g
s/\boverrride\b/override/g
s/\bOVERRRIDE\b/OVERRIDE/g
s/\bOverrride\b/Override/g
s/\boverrriden\b/overridden/g
s/\bOVERRRIDEN\b/OVERRIDDEN/g
s/\bOverrriden\b/Overridden/g
s/\boverrriding\b/overriding/g
s/\bOVERRRIDING\b/OVERRIDING/g
s/\bOverrriding\b/Overriding/g
s/\boverun\b/overrun/g
s/\bOVERUN\b/OVERRUN/g
s/\bOverun\b/Overrun/g
s/\boverwite\b/overwrite/g
s/\bOVERWITE\b/OVERWRITE/g
s/\bOverwite\b/Overwrite/g
s/\boverwites\b/overwrites/g
s/\bOVERWITES\b/OVERWRITES/g
s/\bOverwites\b/Overwrites/g
s/\boverwitten\b/overwritten/g
s/\bOVERWITTEN\b/OVERWRITTEN/g
s/\bOverwitten\b/Overwritten/g
s/\bovverridden\b/overridden/g
s/\bOVVERRIDDEN\b/OVERRIDDEN/g
s/\bOvverridden\b/Overridden/g
s/\bovverride\b/override/g
s/\bOVVERRIDE\b/OVERRIDE/g
s/\bOvverride\b/Override/g
s/\bovverrides\b/overrides/g
s/\bOVVERRIDES\b/OVERRIDES/g
s/\bOvverrides\b/Overrides/g
s/\bovverriding\b/overriding/g
s/\bOVVERRIDING\b/OVERRIDING/g
s/\bOvverriding\b/Overriding/g
s/\bowership\b/ownership/g
s/\bOWERSHIP\b/OWNERSHIP/g
s/\bOwership\b/Ownership/g
s/\bpacakge\b/package/g
s/\bPACAKGE\b/PACKAGE/g
s/\bPacakge\b/Package/g
s/\bpach\b/patch/g
s/\bPACH\b/PATCH/g
s/\bPach\b/Patch/g
s/\bpachage\b/package/g
s/\bPACHAGE\b/PACKAGE/g
s/\bPachage\b/Package/g
s/\bpackacge\b/package/g
s/\bPACKACGE\b/PACKAGE/g
s/\bPackacge\b/Package/g
s/\bpackege\b/package/g
s/\bPACKEGE\b/PACKAGE/g
s/\bPackege\b/Package/g
s/\bpackge\b/package/g
s/\bPACKGE\b/PACKAGE/g
s/\bPackge\b/Package/g
s/\bpackges\b/packages/g
s/\bPACKGES\b/PACKAGES/g
s/\bPackges\b/Packages/g
s/\bpakage\b/package/g
s/\bPAKAGE\b/PACKAGE/g
s/\bPakage\b/Package/g
s/\bpalete\b/palette/g
s/\bPALETE\b/PALETTE/g
s/\bPalete\b/Palette/g
s/\bpallete\b/palette/g
s/\bPALLETE\b/PALETTE/g
s/\bPallete\b/Palette/g
s/\bpallette\b/palette/g
s/\bPALLETTE\b/PALETTE/g
s/\bPallette\b/Palette/g
s/\bpaniced\b/panicked/g
s/\bPANICED\b/PANICKED/g
s/\bPaniced\b/Panicked/g
s/\bpanicing\b/panicking/g
s/\bPANICING\b/PANICKING/g
s/\bPanicing\b/Panicking/g
s/\bparalel\b/parallel/g
s/\bPARALEL\b/PARALLEL/g
s/\bParalel\b/Parallel/g
s/\bparalell\b/parallel/g
s/\bPARALELL\b/PARALLEL/g
s/\bParalell\b/Parallel/g
s/\bparallell\b/parallel/g
s/\bPARALLELL\b/PARALLEL/g
s/\bParallell\b/Parallel/g
s/\bparallization\b/parallelization/g
s/\bPARALLIZATION\b/PARALLELIZATION/g
s/\bParallization\b/Parallelization/g
s/\bparallize\b/parallelize/g
s/\bPARALLIZE\b/PARALLELIZE/g
s/\bParallize\b/Parallelize/g
s/\bparallized\b/parallelized/g
s/\bPARALLIZED\b/PARALLELIZED/g
s/\bParallized\b/Parallelized/g
s/\bparallizes\b/parallelizes/g
s/\bPARALLIZES\b/PARALLELIZES/g
s/\bParallizes\b/Parallelizes/g
s/\bparallizing\b/parallelizing/g
s/\bPARALLIZING\b/PARALLELIZING/g
s/\bParallizing\b/Parallelizing/g
s/\bparamameters\b/parameters/g
s/\bPARAMAMETERS\b/PARAMETERS/g
s/\bParamameters\b/Parameters/g
s/\bparametes\b/parameters/g
s/\bPARAMETES\b/PARAMETERS/g
s/\bParametes\b/Parameters/g
s/\bparametised\b/parametrised/g
s/\bPARAMETISED\b/PARAMETRISED/g
s/\bParametised\b/Parametrised/g
s/\bparamters\b/parameters/g
s/\bPARAMTERS\b/PARAMETERS/g
s/\bParamters\b/Parameters/g
s/\bparantheses\b/parentheses/g
s/\bPARANTHESES\b/PARENTHESES/g
s/\bParantheses\b/Parentheses/g
s/\bparanthesis\b/parenthesis/g
s/\bPARANTHESIS\b/PARENTHESIS/g
s/\bParanthesis\b/Parenthesis/g
s/\bparemeter\b/parameter/g
s/\bPAREMETER\b/PARAMETER/g
s/\bParemeter\b/Parameter/g
s/\bparemeters\b/parameters/g
s/\bPAREMETERS\b/PARAMETERS/g
s/\bParemeters\b/Parameters/g
s/\bparenthesed\b/parenthesized/g
s/\bPARENTHESED\b/PARENTHESIZED/g
s/\bParenthesed\b/Parenthesized/g
s/\bparticularily\b/particularly/g
s/\bPARTICULARILY\b/PARTICULARLY/g
s/\bParticularily\b/Particularly/g
s/\bpartioning\b/partitioning/g
s/\bPARTIONING\b/PARTITIONING/g
s/\bPartioning\b/Partitioning/g
s/\bpased\b/passed/g
s/\bPASED\b/PASSED/g
s/\bPased\b/Passed/g
s/\bpathes\b/paths/g
s/\bPATHES\b/PATHS/g
s/\bPathes\b/Paths/g
s/\bpecularities\b/peculiarities/g
s/\bPECULARITIES\b/PECULIARITIES/g
s/\bPecularities\b/Peculiarities/g
s/\bpecularity\b/peculiarity/g
s/\bPECULARITY\b/PECULIARITY/g
s/\bPecularity\b/Peculiarity/g
s/\bpeformance\b/performance/g
s/\bPEFORMANCE\b/PERFORMANCE/g
s/\bPeformance\b/Performance/g
s/\bpeice\b/piece/g
s/\bPEICE\b/PIECE/g
s/\bPeice\b/Piece/g
s/\bpeices\b/pieces/g
s/\bPEICES\b/PIECES/g
s/\bPeices\b/Pieces/g
s/\bpenalities\b/penalties/g
s/\bPENALITIES\b/PENALTIES/g
s/\bPenalities\b/Penalties/g
s/\bpenality\b/penalty/g
s/\bPENALITY\b/PENALTY/g
s/\bPenality\b/Penalty/g
s/\bpendantic\b/pedantic/g
s/\bPENDANTIC\b/PEDANTIC/g
s/\bPendantic\b/Pedantic/g
s/\bpeprocessor\b/preprocessor/g
s/\bPEPROCESSOR\b/PREPROCESSOR/g
s/\bPeprocessor\b/Preprocessor/g
s/\bperfom\b/perform/g
s/\bPERFOM\b/PERFORM/g
s/\bPerfom\b/Perform/g
s/\bperfomed\b/performed/g
s/\bPERFOMED\b/PERFORMED/g
s/\bPerfomed\b/Performed/g
s/\bperfoming\b/performing/g
s/\bPERFOMING\b/PERFORMING/g
s/\bPerfoming\b/Performing/g
s/\bperfoms\b/performs/g
s/\bPERFOMS\b/PERFORMS/g
s/\bPerfoms\b/Performs/g
s/\bperfrom\b/perform/g
s/\bPERFROM\b/PERFORM/g
s/\bPerfrom\b/Perform/g
s/\bperfromance\b/performance/g
s/\bPERFROMANCE\b/PERFORMANCE/g
s/\bPerfromance\b/Performance/g
s/\bperfromed\b/performed/g
s/\bPERFROMED\b/PERFORMED/g
s/\bPerfromed\b/Performed/g
s/\bperfroming\b/performing/g
s/\bPERFROMING\b/PERFORMING/g
s/\bPerfroming\b/Performing/g
s/\bperfroms\b/performs/g
s/\bPERFROMS\b/PERFORMS/g
s/\bPerfroms\b/Performs/g
s/\bperistent\b/persistent/g
s/\bPERISTENT\b/PERSISTENT/g
s/\bPeristent\b/Persistent/g
s/\bpermanant\b/permanent/g
s/\bPERMANANT\b/PERMANENT/g
s/\bPermanant\b/Permanent/g
s/\bpermanantly\b/permanently/g
s/\bPERMANANTLY\b/PERMANENTLY/g
s/\bPermanantly\b/Permanently/g
s/\bpermision\b/permission/g
s/\bPERMISION\b/PERMISSION/g
s/\bPermision\b/Permission/g
s/\bpermisions\b/permissions/g
s/\bPERMISIONS\b/PERMISSIONS/g
s/\bPermisions\b/Permissions/g
s/\bpermissons\b/permissions/g
s/\bPERMISSONS\b/PERMISSIONS/g
s/\bPermissons\b/Permissions/g
s/\bpermuation\b/permutation/g
s/\bPERMUATION\b/PERMUTATION/g
s/\bPermuation\b/Permutation/g
s/\bpermuations\b/permutations/g
s/\bPERMUATIONS\b/PERMUTATIONS/g
s/\bPermuations\b/Permutations/g
s/\bperoid\b/period/g
s/\bPEROID\b/PERIOD/g
s/\bPeroid\b/Period/g
s/\bperoids\b/periods/g
s/\bPEROIDS\b/PERIODS/g
s/\bPeroids\b/Periods/g
s/\bpersistant\b/persistent/g
s/\bPERSISTANT\b/PERSISTENT/g
s/\bPersistant\b/Persistent/g
s/\bpersonnal\b/personal/g
s/\bPERSONNAL\b/PERSONAL/g
s/\bPersonnal\b/Personal/g
s/\bpervious\b/previous/g
s/\bPERVIOUS\b/PREVIOUS/g
s/\bPervious\b/Previous/g
s/\bperviously\b/previously/g
s/\bPERVIOUSLY\b/PREVIOUSLY/g
s/\bPerviously\b/Previously/g
s/\bpitty\b/pity/g
s/\bPITTY\b/PITY/g
s/\bPitty\b/Pity/g
s/\bplatfrom\b/platform/g
s/\bPLATFROM\b/PLATFORM/g
s/\bPlatfrom\b/Platform/g
s/\bplatfroms\b/platforms/g
s/\bPLATFROMS\b/PLATFORMS/g
s/\bPlatfroms\b/Platforms/g
s/\bplattform\b/platform/g
s/\bPLATTFORM\b/PLATFORM/g
s/\bPlattform\b/Platform/g
s/\bpleaes\b/please/g
s/\bPLEAES\b/PLEASE/g
s/\bPleaes\b/Please/g
s/\bploting\b/plotting/g
s/\bPLOTING\b/PLOTTING/g
s/\bPloting\b/Plotting/g
s/\bpoinnter\b/pointer/g
s/\bPOINNTER\b/POINTER/g
s/\bPoinnter\b/Pointer/g
s/\bpolution\b/pollution/g
s/\bPOLUTION\b/POLLUTION/g
s/\bPolution\b/Pollution/g
s/\bportugese\b/portuguese/g
s/\bPORTUGESE\b/PORTUGUESE/g
s/\bPortugese\b/Portuguese/g
s/\bposible\b/possible/g
s/\bPOSIBLE\b/POSSIBLE/g
s/\bPosible\b/Possible/g
s/\bpositionned\b/positioned/g
s/\bPOSITIONNED\b/POSITIONED/g
s/\bPositionned\b/Positioned/g
s/\bpositve\b/positive/g
s/\bPOSITVE\b/POSITIVE/g
s/\bPositve\b/Positive/g
s/\bpositves\b/positives/g
s/\bPOSITVES\b/POSITIVES/g
s/\bPositves\b/Positives/g
s/\bpossesion\b/possession/g
s/\bPOSSESION\b/POSSESSION/g
s/\bPossesion\b/Possession/g
s/\bpossibe\b/possible/g
s/\bPOSSIBE\b/POSSIBLE/g
s/\bPossibe\b/Possible/g
s/\bpossibilites\b/possibilities/g
s/\bPOSSIBILITES\b/POSSIBILITIES/g
s/\bPossibilites\b/Possibilities/g
s/\bpossibilties\b/possibilities/g
s/\bPOSSIBILTIES\b/POSSIBILITIES/g
s/\bPossibilties\b/Possibilities/g
s/\bpossibilty\b/possibility/g
s/\bPOSSIBILTY\b/POSSIBILITY/g
s/\bPossibilty\b/Possibility/g
s/\bpossiblities\b/possibilities/g
s/\bPOSSIBLITIES\b/POSSIBILITIES/g
s/\bPossiblities\b/Possibilities/g
s/\bpossiblity\b/possibility/g
s/\bPOSSIBLITY\b/POSSIBILITY/g
s/\bPossiblity\b/Possibility/g
s/\bpostgressql\b/postgresql/g
s/\bPOSTGRESSQL\b/POSTGRESQL/g
s/\bPostgressql\b/PostgreSQL/g
s/\bpostion\b/position/g
s/\bPOSTION\b/POSITION/g
s/\bPostion\b/Position/g
s/\bpostions\b/positions/g
s/\bPOSTIONS\b/POSITIONS/g
s/\bPostions\b/Positions/g
s/\bpostives\b/positives/g
s/\bPOSTIVES\b/POSITIVES/g
s/\bPostives\b/Positives/g
s/\bpowerfull\b/powerful/g
s/\bPOWERFULL\b/POWERFUL/g
s/\bPowerfull\b/Powerful/g
s/\bprcess\b/process/g
s/\bPRCESS\b/PROCESS/g
s/\bPrcess\b/Process/g
s/\bprcesses\b/processes/g
s/\bPRCESSES\b/PROCESSES/g
s/\bPrcesses\b/Processes/g
s/\bpreceed\b/precede/g
s/\bPRECEED\b/PRECEDE/g
s/\bPreceed\b/Precede/g
s/\bpreceeded\b/preceded/g
s/\bPRECEEDED\b/PRECEDED/g
s/\bPreceeded\b/Preceded/g
s/\bpreceeding\b/preceding/g
s/\bPRECEEDING\b/PRECEDING/g
s/\bPreceeding\b/Preceding/g
s/\bpreceeds\b/precedes/g
s/\bPRECEEDS\b/PRECEDES/g
s/\bPreceeds\b/Precedes/g
s/\bprecendence\b/precedence/g
s/\bPRECENDENCE\b/PRECEDENCE/g
s/\bPrecendence\b/Precedence/g
s/\bprecison\b/precision/g
s/\bPRECISON\b/PRECISION/g
s/\bPrecison\b/Precision/g
s/\bprecission\b/precision/g
s/\bPRECISSION\b/PRECISION/g
s/\bPrecission\b/Precision/g
s/\bprefered\b/preferred/g
s/\bPREFERED\b/PREFERRED/g
s/\bPrefered\b/Preferred/g
s/\bpreferrable\b/preferable/g
s/\bPREFERRABLE\b/PREFERABLE/g
s/\bPreferrable\b/Preferable/g
s/\bpreferrably\b/preferably/g
s/\bPREFERRABLY\b/PREFERABLY/g
s/\bPreferrably\b/Preferably/g
s/\bprefferable\b/preferable/g
s/\bPREFFERABLE\b/PREFERABLE/g
s/\bPrefferable\b/Preferable/g
s/\bprefferably\b/preferably/g
s/\bPREFFERABLY\b/PREFERABLY/g
s/\bPrefferably\b/Preferably/g
s/\bprepaired\b/prepared/g
s/\bPREPAIRED\b/PREPARED/g
s/\bPrepaired\b/Prepared/g
s/\bprepartion\b/preparation/g
s/\bPREPARTION\b/PREPARATION/g
s/\bPrepartion\b/Preparation/g
s/\bprepartions\b/preparations/g
s/\bPREPARTIONS\b/PREPARATIONS/g
s/\bPrepartions\b/Preparations/g
s/\bprerequsite\b/prerequisite/g
s/\bPREREQUSITE\b/PREREQUISITE/g
s/\bPrerequsite\b/Prerequisite/g
s/\bprerequsites\b/prerequisites/g
s/\bPREREQUSITES\b/PREREQUISITES/g
s/\bPrerequsites\b/Prerequisites/g
s/\bprevously\b/previously/g
s/\bPREVOUSLY\b/PREVIOUSLY/g
s/\bPrevously\b/Previously/g
s/\bpriciple\b/principle/g
s/\bPRICIPLE\b/PRINCIPLE/g
s/\bPriciple\b/Principle/g
s/\bpriciples\b/principles/g
s/\bPRICIPLES\b/PRINCIPLES/g
s/\bPriciples\b/Principles/g
s/\bprimative\b/primitive/g
s/\bPRIMATIVE\b/PRIMITIVE/g
s/\bPrimative\b/Primitive/g
s/\bprincliple\b/principle/g
s/\bPRINCLIPLE\b/PRINCIPLE/g
s/\bPrincliple\b/Principle/g
s/\bpriorty\b/priority/g
s/\bPRIORTY\b/PRIORITY/g
s/\bPriorty\b/Priority/g
s/\bpriveleged\b/privileged/g
s/\bPRIVELEGED\b/PRIVILEGED/g
s/\bPriveleged\b/Privileged/g
s/\bpriviledge\b/privilege/g
s/\bPRIVILEDGE\b/PRIVILEGE/g
s/\bPriviledge\b/Privilege/g
s/\bpriviledges\b/privileges/g
s/\bPRIVILEDGES\b/PRIVILEGES/g
s/\bPriviledges\b/Privileges/g
s/\bprivilige\b/privilege/g
s/\bPRIVILIGE\b/PRIVILEGE/g
s/\bPrivilige\b/Privilege/g
s/\bpriviliges\b/privileges/g
s/\bPRIVILIGES\b/PRIVILEGES/g
s/\bPriviliges\b/Privileges/g
s/\bprobaly\b/probably/g
s/\bPROBALY\b/PROBABLY/g
s/\bProbaly\b/Probably/g
s/\bproblably\b/probably/g
s/\bPROBLABLY\b/PROBABLY/g
s/\bProblably\b/Probably/g
s/\bprocceed\b/proceed/g
s/\bPROCCEED\b/PROCEED/g
s/\bProcceed\b/Proceed/g
s/\bproccesors\b/processors/g
s/\bPROCCESORS\b/PROCESSORS/g
s/\bProccesors\b/Processors/g
s/\bproccess\b/process/g
s/\bPROCCESS\b/PROCESS/g
s/\bProccess\b/Process/g
s/\bproccesses\b/processes/g
s/\bPROCCESSES\b/PROCESSES/g
s/\bProccesses\b/Processes/g
s/\bprocede\b/proceed/g
s/\bPROCEDE\b/PROCEED/g
s/\bProcede\b/Proceed/g
s/\bproceded\b/proceeded/g
s/\bPROCEDED\b/PROCEEDED/g
s/\bProceded\b/Proceeded/g
s/\bprocedes\b/proceeds/g
s/\bPROCEDES\b/PROCEEDS/g
s/\bProcedes\b/Proceeds/g
s/\bproceding\b/proceeding/g
s/\bPROCEDING\b/PROCEEDING/g
s/\bProceding\b/Proceeding/g
s/\bproceeed\b/proceed/g
s/\bPROCEEED\b/PROCEED/g
s/\bProceeed\b/Proceed/g
s/\bproceeeded\b/proceeded/g
s/\bPROCEEEDED\b/PROCEEDED/g
s/\bProceeeded\b/Proceeded/g
s/\bproceeeding\b/proceeding/g
s/\bPROCEEEDING\b/PROCEEDING/g
s/\bProceeeding\b/Proceeding/g
s/\bproceeeds\b/proceeds/g
s/\bPROCEEEDS\b/PROCEEDS/g
s/\bProceeeds\b/Proceeds/g
s/\bproces\b/process/g
s/\bPROCES\b/PROCESS/g
s/\bProces\b/Process/g
s/\bprocesed\b/processed/g
s/\bPROCESED\b/PROCESSED/g
s/\bProcesed\b/Processed/g
s/\bproceses\b/processes/g
s/\bPROCESES\b/PROCESSES/g
s/\bProceses\b/Processes/g
s/\bprocessess\b/processes/g
s/\bPROCESSESS\b/PROCESSES/g
s/\bProcessess\b/Processes/g
s/\bprocessessing\b/processing/g
s/\bPROCESSESSING\b/PROCESSING/g
s/\bProcessessing\b/Processing/g
s/\bprocesspr\b/processor/g
s/\bPROCESSPR\b/PROCESSOR/g
s/\bProcesspr\b/Processor/g
s/\bprocesssing\b/processing/g
s/\bPROCESSSING\b/PROCESSING/g
s/\bProcesssing\b/Processing/g
s/\bproctect\b/protect/g
s/\bPROCTECT\b/PROTECT/g
s/\bProctect\b/Protect/g
s/\bproctected\b/protected/g
s/\bPROCTECTED\b/PROTECTED/g
s/\bProctected\b/Protected/g
s/\bproctecting\b/protecting/g
s/\bPROCTECTING\b/PROTECTING/g
s/\bProctecting\b/Protecting/g
s/\bproctects\b/protects/g
s/\bPROCTECTS\b/PROTECTS/g
s/\bProctects\b/Protects/g
s/\bprocude\b/produce/g
s/\bPROCUDE\b/PRODUCE/g
s/\bProcude\b/Produce/g
s/\bprogams\b/programs/g
s/\bPROGAMS\b/PROGRAMS/g
s/\bProgams\b/Programs/g
s/\bprogess\b/progress/g
s/\bPROGESS\b/PROGRESS/g
s/\bProgess\b/Progress/g
s/\bprogramers\b/programmers/g
s/\bPROGRAMERS\b/PROGRAMMERS/g
s/\bProgramers\b/Programmers/g
s/\bprogramm\b/program/g
s/\bPROGRAMM\b/PROGRAM/g
s/\bProgramm\b/Program/g
s/\bprogramms\b/programs/g
s/\bPROGRAMMS\b/PROGRAMS/g
s/\bProgramms\b/Programs/g
s/\bpromps\b/prompts/g
s/\bPROMPS\b/PROMPTS/g
s/\bPromps\b/Prompts/g
s/\bpronnounced\b/pronounced/g
s/\bPRONNOUNCED\b/PRONOUNCED/g
s/\bPronnounced\b/Pronounced/g
s/\bprononciation\b/pronunciation/g
s/\bPRONONCIATION\b/PRONUNCIATION/g
s/\bPrononciation\b/Pronunciation/g
s/\bpronouce\b/pronounce/g
s/\bPRONOUCE\b/PRONOUNCE/g
s/\bPronouce\b/Pronounce/g
s/\bpronunce\b/pronounce/g
s/\bPRONUNCE\b/PRONOUNCE/g
s/\bPronunce\b/Pronounce/g
s/\bpropery\b/property/g
s/\bPROPERY\b/PROPERTY/g
s/\bPropery\b/Property/g
s/\bpropigate\b/propagate/g
s/\bPROPIGATE\b/PROPAGATE/g
s/\bPropigate\b/Propagate/g
s/\bpropigation\b/propagation/g
s/\bPROPIGATION\b/PROPAGATION/g
s/\bPropigation\b/Propagation/g
s/\bpropogate\b/propagate/g
s/\bPROPOGATE\b/PROPAGATE/g
s/\bPropogate\b/Propagate/g
s/\bpropogated\b/propagated/g
s/\bPROPOGATED\b/PROPAGATED/g
s/\bPropogated\b/Propagated/g
s/\bpropogates\b/propagates/g
s/\bPROPOGATES\b/PROPAGATES/g
s/\bPropogates\b/Propagates/g
s/\bpropogating\b/propagating/g
s/\bPROPOGATING\b/PROPAGATING/g
s/\bPropogating\b/Propagating/g
s/\bprosess\b/process/g
s/\bPROSESS\b/PROCESS/g
s/\bProsess\b/Process/g
s/\bprotable\b/portable/g
s/\bPROTABLE\b/PORTABLE/g
s/\bProtable\b/Portable/g
s/\bprotcol\b/protocol/g
s/\bPROTCOL\b/PROTOCOL/g
s/\bProtcol\b/Protocol/g
s/\bprotecion\b/protection/g
s/\bPROTECION\b/PROTECTION/g
s/\bProtecion\b/Protection/g
s/\bprotocoll\b/protocol/g
s/\bPROTOCOLL\b/PROTOCOL/g
s/\bProtocoll\b/Protocol/g
s/\bpsychadelic\b/psychedelic/g
s/\bPSYCHADELIC\b/PSYCHEDELIC/g
s/\bPsychadelic\b/Psychedelic/g
s/\bqoute\b/quote/g
s/\bQOUTE\b/QUOTE/g
s/\bQoute\b/Quote/g
s/\bqouted\b/quoted/g
s/\bQOUTED\b/QUOTED/g
s/\bQouted\b/Quoted/g
s/\bqoutes\b/quotes/g
s/\bQOUTES\b/QUOTES/g
s/\bQoutes\b/Quotes/g
s/\bqouting\b/quoting/g
s/\bQOUTING\b/QUOTING/g
s/\bQouting\b/Quoting/g
s/\bqueing\b/queueing/g
s/\bQUEING\b/QUEUEING/g
s/\bQueing\b/Queueing/g
s/\bquering\b/querying/g
s/\bQUERING\b/QUERYING/g
s/\bQuering\b/Querying/g
s/\breachs\b/reaches/g
s/\bREACHS\b/REACHES/g
s/\bReachs\b/Reaches/g
s/\breadabilty\b/readability/g
s/\bREADABILTY\b/READABILITY/g
s/\bReadabilty\b/Readability/g
s/\breasearch\b/research/g
s/\bREASEARCH\b/RESEARCH/g
s/\bReasearch\b/Research/g
s/\breasearcher\b/researcher/g
s/\bREASEARCHER\b/RESEARCHER/g
s/\bReasearcher\b/Researcher/g
s/\breasearchers\b/researchers/g
s/\bREASEARCHERS\b/RESEARCHERS/g
s/\bReasearchers\b/Researchers/g
s/\breasonble\b/reasonable/g
s/\bREASONBLE\b/REASONABLE/g
s/\bReasonble\b/Reasonable/g
s/\breasonbly\b/reasonably/g
s/\bREASONBLY\b/REASONABLY/g
s/\bReasonbly\b/Reasonably/g
s/\brebulid\b/rebuild/g
s/\bREBULID\b/REBUILD/g
s/\bRebulid\b/Rebuild/g
s/\brebuliding\b/rebuilding/g
s/\bREBULIDING\b/REBUILDING/g
s/\bRebuliding\b/Rebuilding/g
s/\brebulids\b/rebuilds/g
s/\bREBULIDS\b/REBUILDS/g
s/\bRebulids\b/Rebuilds/g
s/\brebulit\b/rebuilt/g
s/\bREBULIT\b/REBUILT/g
s/\bRebulit\b/Rebuilt/g
s/\breccommend\b/recommend/g
s/\bRECCOMMEND\b/RECOMMEND/g
s/\bReccommend\b/Recommend/g
s/\breccommended\b/recommended/g
s/\bRECCOMMENDED\b/RECOMMENDED/g
s/\bReccommended\b/Recommended/g
s/\breccommending\b/recommending/g
s/\bRECCOMMENDING\b/RECOMMENDING/g
s/\bReccommending\b/Recommending/g
s/\breccommends\b/recommends/g
s/\bRECCOMMENDS\b/RECOMMENDS/g
s/\bReccommends\b/Recommends/g
s/\breceieve\b/receive/g
s/\bRECEIEVE\b/RECEIVE/g
s/\bReceieve\b/Receive/g
s/\breceieved\b/received/g
s/\bRECEIEVED\b/RECEIVED/g
s/\bReceieved\b/Received/g
s/\breceieves\b/receives/g
s/\bRECEIEVES\b/RECEIVES/g
s/\bReceieves\b/Receives/g
s/\breceieving\b/receiving/g
s/\bRECEIEVING\b/RECEIVING/g
s/\bReceieving\b/Receiving/g
s/\brecieved\b/received/g
s/\bRECIEVED\b/RECEIVED/g
s/\bRecieved\b/Received/g
s/\breciever\b/receiver/g
s/\bRECIEVER\b/RECEIVER/g
s/\bReciever\b/Receiver/g
s/\brecieves\b/receives/g
s/\bRECIEVES\b/RECEIVES/g
s/\bRecieves\b/Receives/g
s/\brecieving\b/receiving/g
s/\bRECIEVING\b/RECEIVING/g
s/\bRecieving\b/Receiving/g
s/\brecipies\b/recipes/g
s/\bRECIPIES\b/RECIPES/g
s/\bRecipies\b/Recipes/g
s/\brecogize\b/recognize/g
s/\bRECOGIZE\b/RECOGNIZE/g
s/\bRecogize\b/Recognize/g
s/\brecogized\b/recognized/g
s/\bRECOGIZED\b/RECOGNIZED/g
s/\bRecogized\b/Recognized/g
s/\brecogizes\b/recognizes/g
s/\bRECOGIZES\b/RECOGNIZES/g
s/\bRecogizes\b/Recognizes/g
s/\brecogizing\b/recognizing/g
s/\bRECOGIZING\b/RECOGNIZING/g
s/\bRecogizing\b/Recognizing/g
s/\brecogniced\b/recognised/g
s/\bRECOGNICED\b/RECOGNISED/g
s/\bRecogniced\b/Recognised/g
s/\brecognizeable\b/recognizable/g
s/\bRECOGNIZEABLE\b/RECOGNIZABLE/g
s/\bRecognizeable\b/Recognizable/g
s/\brecommanded\b/recommended/g
s/\bRECOMMANDED\b/RECOMMENDED/g
s/\bRecommanded\b/Recommended/g
s/\brectange\b/rectangle/g
s/\bRECTANGE\b/RECTANGLE/g
s/\bRectange\b/Rectangle/g
s/\brectanges\b/rectangles/g
s/\bRECTANGES\b/RECTANGLES/g
s/\bRectanges\b/Rectangles/g
s/\brecurrance\b/recurrence/g
s/\bRECURRANCE\b/RECURRENCE/g
s/\bRecurrance\b/Recurrence/g
s/\bredefintion\b/redefinition/g
s/\bREDEFINTION\b/REDEFINITION/g
s/\bRedefintion\b/Redefinition/g
s/\bredefintions\b/redefinitions/g
s/\bREDEFINTIONS\b/REDEFINITIONS/g
s/\bRedefintions\b/Redefinitions/g
s/\bredircet\b/redirect/g
s/\bREDIRCET\b/REDIRECT/g
s/\bRedircet\b/Redirect/g
s/\bredirectrion\b/redirection/g
s/\bREDIRECTRION\b/REDIRECTION/g
s/\bRedirectrion\b/Redirection/g
s/\breenable\b/re-enable/g
s/\bREENABLE\b/RE-ENABLE/g
s/\bReenable\b/Re-enable/g
s/\breenabled\b/re-enabled/g
s/\bREENABLED\b/RE-ENABLED/g
s/\bReenabled\b/Re-enabled/g
s/\breencode\b/re-encode/g
s/\bREENCODE\b/RE-ENCODE/g
s/\bReencode\b/Re-encode/g
s/\brefect\b/reflect/g
s/\bREFECT\b/REFLECT/g
s/\bRefect\b/Reflect/g
s/\brefected\b/reflected/g
s/\bREFECTED\b/REFLECTED/g
s/\bRefected\b/Reflected/g
s/\brefecting\b/reflecting/g
s/\bREFECTING\b/REFLECTING/g
s/\bRefecting\b/Reflecting/g
s/\brefects\b/reflects/g
s/\bREFECTS\b/REFLECTS/g
s/\bRefects\b/Reflects/g
s/\brefence\b/reference/g
s/\bREFENCE\b/REFERENCE/g
s/\bRefence\b/Reference/g
s/\brefernce\b/reference/g
s/\bREFERNCE\b/REFERENCE/g
s/\bRefernce\b/Reference/g
s/\brefernced\b/referenced/g
s/\bREFERNCED\b/REFERENCED/g
s/\bRefernced\b/Referenced/g
s/\brefernces\b/references/g
s/\bREFERNCES\b/REFERENCES/g
s/\bRefernces\b/References/g
s/\breferncing\b/referencing/g
s/\bREFERNCING\b/REFERENCING/g
s/\bReferncing\b/Referencing/g
s/\brefrenced\b/referenced/g
s/\bREFRENCED\b/REFERENCED/g
s/\bRefrenced\b/Referenced/g
s/\brefrences\b/references/g
s/\bREFRENCES\b/REFERENCES/g
s/\bRefrences\b/References/g
s/\brefrencing\b/referencing/g
s/\bREFRENCING\b/REFERENCING/g
s/\bRefrencing\b/Referencing/g
s/\bregaring\b/regarding/g
s/\bREGARING\b/REGARDING/g
s/\bRegaring\b/Regarding/g
s/\bregisterd\b/registered/g
s/\bREGISTERD\b/REGISTERED/g
s/\bRegisterd\b/Registered/g
s/\bregistraration\b/registration/g
s/\bREGISTRARATION\b/REGISTRATION/g
s/\bRegistraration\b/Registration/g
s/\bregulamentations\b/regulations/g
s/\bREGULAMENTATIONS\b/REGULATIONS/g
s/\bRegulamentations\b/Regulations/g
s/\bregularily\b/regularly/g
s/\bREGULARILY\b/REGULARLY/g
s/\bRegularily\b/Regularly/g
s/\breimplment\b/reimplement/g
s/\bREIMPLMENT\b/REIMPLEMENT/g
s/\bReimplment\b/Reimplement/g
s/\breimplmentation\b/reimplementation/g
s/\bREIMPLMENTATION\b/REIMPLEMENTATION/g
s/\bReimplmentation\b/Reimplementation/g
s/\breimplmented\b/reimplemented/g
s/\bREIMPLMENTED\b/REIMPLEMENTED/g
s/\bReimplmented\b/Reimplemented/g
s/\breimplmenting\b/reimplementing/g
s/\bREIMPLMENTING\b/REIMPLEMENTING/g
s/\bReimplmenting\b/Reimplementing/g
s/\breimplments\b/reimplements/g
s/\bREIMPLMENTS\b/REIMPLEMENTS/g
s/\bReimplments\b/Reimplements/g
s/\breletive\b/relative/g
s/\bRELETIVE\b/RELATIVE/g
s/\bReletive\b/Relative/g
s/\breletively\b/relatively/g
s/\bRELETIVELY\b/RELATIVELY/g
s/\bReletively\b/Relatively/g
s/\brelevent\b/relevant/g
s/\bRELEVENT\b/RELEVANT/g
s/\bRelevent\b/Relevant/g
s/\bremaing\b/remaining/g
s/\bREMAING\b/REMAINING/g
s/\bRemaing\b/Remaining/g
s/\bremoote\b/remote/g
s/\bREMOOTE\b/REMOTE/g
s/\bRemoote\b/Remote/g
s/\bremoveable\b/removable/g
s/\bREMOVEABLE\b/REMOVABLE/g
s/\bRemoveable\b/Removable/g
s/\brenderering\b/rendering/g
s/\bRENDERERING\b/RENDERING/g
s/\bRenderering\b/Rendering/g
s/\brenegotation\b/renegotiation/g
s/\bRENEGOTATION\b/RENEGOTIATION/g
s/\bRenegotation\b/Renegotiation/g
s/\brepace\b/replace/g
s/\bREPACE\b/REPLACE/g
s/\bRepace\b/Replace/g
s/\brepaced\b/replaced/g
s/\bREPACED\b/REPLACED/g
s/\bRepaced\b/Replaced/g
s/\brepaces\b/replaces/g
s/\bREPACES\b/REPLACES/g
s/\bRepaces\b/Replaces/g
s/\brepacing\b/replacing/g
s/\bREPACING\b/REPLACING/g
s/\bRepacing\b/Replacing/g
s/\brepeatly\b/repeatedly/g
s/\bREPEATLY\b/REPEATEDLY/g
s/\bRepeatly\b/Repeatedly/g
s/\brepective\b/respective/g
s/\bREPECTIVE\b/RESPECTIVE/g
s/\bRepective\b/Respective/g
s/\brepectively\b/respectively/g
s/\bREPECTIVELY\b/RESPECTIVELY/g
s/\bRepectively\b/Respectively/g
s/\breplacable\b/replaceable/g
s/\bREPLACABLE\b/REPLACEABLE/g
s/\bReplacable\b/Replaceable/g
s/\breplacments\b/replacements/g
s/\bREPLACMENTS\b/REPLACEMENTS/g
s/\bReplacments\b/Replacements/g
s/\breplys\b/replies/g
s/\bREPLYS\b/REPLIES/g
s/\bReplys\b/Replies/g
s/\breponse\b/response/g
s/\bREPONSE\b/RESPONSE/g
s/\bReponse\b/Response/g
s/\breponses\b/responses/g
s/\bREPONSES\b/RESPONSES/g
s/\bReponses\b/Responses/g
s/\breproducable\b/reproducible/g
s/\bREPRODUCABLE\b/REPRODUCIBLE/g
s/\bReproducable\b/Reproducible/g
s/\brequiere\b/require/g
s/\bREQUIERE\b/REQUIRE/g
s/\bRequiere\b/Require/g
s/\brequiered\b/required/g
s/\bREQUIERED\b/REQUIRED/g
s/\bRequiered\b/Required/g
s/\brequieres\b/requires/g
s/\bREQUIERES\b/REQUIRES/g
s/\bRequieres\b/Requires/g
s/\brequiering\b/requiring/g
s/\bREQUIERING\b/REQUIRING/g
s/\bRequiering\b/Requiring/g
s/\brequred\b/required/g
s/\bREQURED\b/REQUIRED/g
s/\bRequred\b/Required/g
s/\brequrest\b/request/g
s/\bREQUREST\b/REQUEST/g
s/\bRequrest\b/Request/g
s/\brequrested\b/requested/g
s/\bREQURESTED\b/REQUESTED/g
s/\bRequrested\b/Requested/g
s/\brequresting\b/requesting/g
s/\bREQURESTING\b/REQUESTING/g
s/\bRequresting\b/Requesting/g
s/\brequrests\b/requests/g
s/\bREQURESTS\b/REQUESTS/g
s/\bRequrests\b/Requests/g
s/\brequried\b/required/g
s/\bREQURIED\b/REQUIRED/g
s/\bRequried\b/Required/g
s/\bresemblence\b/resemblance/g
s/\bRESEMBLENCE\b/RESEMBLANCE/g
s/\bResemblence\b/Resemblance/g
s/\breserverd\b/reserved/g
s/\bRESERVERD\b/RESERVED/g
s/\bReserverd\b/Reserved/g
s/\bresizeable\b/resizable/g
s/\bRESIZEABLE\b/RESIZABLE/g
s/\bResizeable\b/Resizable/g
s/\bresouce\b/resource/g
s/\bRESOUCE\b/RESOURCE/g
s/\bResouce\b/Resource/g
s/\bresouces\b/resources/g
s/\bRESOUCES\b/RESOURCES/g
s/\bResouces\b/Resources/g
s/\bresoure\b/resource/g
s/\bRESOURE\b/RESOURCE/g
s/\bResoure\b/Resource/g
s/\bresoures\b/resources/g
s/\bRESOURES\b/RESOURCES/g
s/\bResoures\b/Resources/g
s/\bresponsabilities\b/responsibilities/g
s/\bRESPONSABILITIES\b/RESPONSIBILITIES/g
s/\bResponsabilities\b/Responsibilities/g
s/\bresponsability\b/responsibility/g
s/\bRESPONSABILITY\b/RESPONSIBILITY/g
s/\bResponsability\b/Responsibility/g
s/\bresponsed\b/responded/g
s/\bRESPONSED\b/RESPONDED/g
s/\bResponsed\b/Responded/g
s/\bresponsiblity\b/responsibility/g
s/\bRESPONSIBLITY\b/RESPONSIBILITY/g
s/\bResponsiblity\b/Responsibility/g
s/\bresponsing\b/responding/g
s/\bRESPONSING\b/RESPONDING/g
s/\bResponsing\b/Responding/g
s/\bressize\b/resize/g
s/\bRESSIZE\b/RESIZE/g
s/\bRessize\b/Resize/g
s/\bressource\b/resource/g
s/\bRESSOURCE\b/RESOURCE/g
s/\bRessource\b/Resource/g
s/\bressources\b/resources/g
s/\bRESSOURCES\b/RESOURCES/g
s/\bRessources\b/Resources/g
s/\bresursive\b/recursive/g
s/\bRESURSIVE\b/RECURSIVE/g
s/\bResursive\b/Recursive/g
s/\bresursively\b/recursively/g
s/\bRESURSIVELY\b/RECURSIVELY/g
s/\bResursively\b/Recursively/g
s/\bretore\b/restore/g
s/\bRETORE\b/RESTORE/g
s/\bRetore\b/Restore/g
s/\bretored\b/restored/g
s/\bRETORED\b/RESTORED/g
s/\bRetored\b/Restored/g
s/\bretores\b/restores/g
s/\bRETORES\b/RESTORES/g
s/\bRetores\b/Restores/g
s/\bretoring\b/restoring/g
s/\bRETORING\b/RESTORING/g
s/\bRetoring\b/Restoring/g
s/\bretransmited\b/retransmitted/g
s/\bRETRANSMITED\b/RETRANSMITTED/g
s/\bRetransmited\b/Retransmitted/g
s/\bretreived\b/retrieved/g
s/\bRETREIVED\b/RETRIEVED/g
s/\bRetreived\b/Retrieved/g
s/\bretrive\b/retrieve/g
s/\bRETRIVE\b/RETRIEVE/g
s/\bRetrive\b/Retrieve/g
s/\bretrived\b/retrieved/g
s/\bRETRIVED\b/RETRIEVED/g
s/\bRetrived\b/Retrieved/g
s/\bretrives\b/retrieves/g
s/\bRETRIVES\b/RETRIEVES/g
s/\bRetrives\b/Retrieves/g
s/\bretriving\b/retrieving/g
s/\bRETRIVING\b/RETRIEVING/g
s/\bRetriving\b/Retrieving/g
s/\bretuns\b/returns/g
s/\bRETUNS\b/RETURNS/g
s/\bRetuns\b/Returns/g
s/\bretur\b/return/g
s/\bRETUR\b/RETURN/g
s/\bRetur\b/Return/g
s/\bretured\b/returned/g
s/\bRETURED\b/RETURNED/g
s/\bRetured\b/Returned/g
s/\breturing\b/returning/g
s/\bRETURING\b/RETURNING/g
s/\bReturing\b/Returning/g
s/\breturnes\b/returns/g
s/\bRETURNES\b/RETURNS/g
s/\bReturnes\b/Returns/g
s/\breturs\b/returns/g
s/\bRETURS\b/RETURNS/g
s/\bReturs\b/Returns/g
s/\brewriten\b/rewritten/g
s/\bREWRITEN\b/REWRITTEN/g
s/\bRewriten\b/Rewritten/g
s/\brigth\b/right/g
s/\bRIGTH\b/RIGHT/g
s/\bRigth\b/Right/g
s/\brigths\b/rights/g
s/\bRIGTHS\b/RIGHTS/g
s/\bRigths\b/Rights/g
s/\brmeove\b/remove/g
s/\bRMEOVE\b/REMOVE/g
s/\bRmeove\b/Remove/g
s/\brmeoved\b/removed/g
s/\bRMEOVED\b/REMOVED/g
s/\bRmeoved\b/Removed/g
s/\brmeoves\b/removes/g
s/\bRMEOVES\b/REMOVES/g
s/\bRmeoves\b/Removes/g
s/\brougly\b/roughly/g
s/\bROUGLY\b/ROUGHLY/g
s/\bRougly\b/Roughly/g
s/\brountine\b/routine/g
s/\bROUNTINE\b/ROUTINE/g
s/\bRountine\b/Routine/g
s/\brountines\b/routines/g
s/\bROUNTINES\b/ROUTINES/g
s/\bRountines\b/Routines/g
s/\bruning\b/running/g
s/\bRUNING\b/RUNNING/g
s/\bRuning\b/Running/g
s/\brunned\b/ran/g
s/\bRUNNED\b/RAN/g
s/\bRunned\b/Ran/g
s/\brunnning\b/running/g
s/\bRUNNNING\b/RUNNING/g
s/\bRunnning\b/Running/g
s/\bsacrifying\b/sacrificing/g
s/\bSACRIFYING\b/SACRIFICING/g
s/\bSacrifying\b/Sacrificing/g
s/\bsafly\b/safely/g
s/\bSAFLY\b/SAFELY/g
s/\bSafly\b/Safely/g
s/\bsaftey\b/safety/g
s/\bSAFTEY\b/SAFETY/g
s/\bSaftey\b/Safety/g
s/\bsafty\b/safety/g
s/\bSAFTY\b/SAFETY/g
s/\bSafty\b/Safety/g
s/\bsantize\b/sanitize/g
s/\bSANTIZE\b/SANITIZE/g
s/\bSantize\b/Sanitize/g
s/\bsantized\b/sanitized/g
s/\bSANTIZED\b/SANITIZED/g
s/\bSantized\b/Sanitized/g
s/\bsantizes\b/sanitizes/g
s/\bSANTIZES\b/SANITIZES/g
s/\bSantizes\b/Sanitizes/g
s/\bsantizing\b/sanitizing/g
s/\bSANTIZING\b/SANITIZING/g
s/\bSantizing\b/Sanitizing/g
s/\bsatisfiabilty\b/satisfiability/g
s/\bSATISFIABILTY\b/SATISFIABILITY/g
s/\bSatisfiabilty\b/Satisfiability/g
s/\bsatisified\b/satisfied/g
s/\bSATISIFIED\b/SATISFIED/g
s/\bSatisified\b/Satisfied/g
s/\bsatisifies\b/satisfies/g
s/\bSATISIFIES\b/SATISFIES/g
s/\bSatisifies\b/Satisfies/g
s/\bsatisify\b/satisfy/g
s/\bSATISIFY\b/SATISFY/g
s/\bSatisify\b/Satisfy/g
s/\bsatisifying\b/satisfying/g
s/\bSATISIFYING\b/SATISFYING/g
s/\bSatisifying\b/Satisfying/g
s/\bsavable\b/saveable/g
s/\bSAVABLE\b/SAVEABLE/g
s/\bSavable\b/Saveable/g
s/\bsavely\b/safely/g
s/\bSAVELY\b/SAFELY/g
s/\bSavely\b/Safely/g
s/\bsavety\b/safety/g
s/\bSAVETY\b/SAFETY/g
s/\bSavety\b/Safety/g
s/\bscaned\b/scanned/g
s/\bSCANED\b/SCANNED/g
s/\bScaned\b/Scanned/g
s/\bscaning\b/scanning/g
s/\bSCANING\b/SCANNING/g
s/\bScaning\b/Scanning/g
s/\bseach\b/search/g
s/\bSEACH\b/SEARCH/g
s/\bSeach\b/Search/g
s/\bseached\b/searched/g
s/\bSEACHED\b/SEARCHED/g
s/\bSeached\b/Searched/g
s/\bseaches\b/searches/g
s/\bSEACHES\b/SEARCHES/g
s/\bSeaches\b/Searches/g
s/\bseaching\b/searching/g
s/\bSEACHING\b/SEARCHING/g
s/\bSeaching\b/Searching/g
s/\bsearchs\b/searches/g
s/\bSEARCHS\b/SEARCHES/g
s/\bSearchs\b/Searches/g
s/\bsecund\b/second/g
s/\bSECUND\b/SECOND/g
s/\bSecund\b/Second/g
s/\bsecurty\b/security/g
s/\bSECURTY\b/SECURITY/g
s/\bSecurty\b/Security/g
s/\bsematic\b/semantic/g
s/\bSEMATIC\b/SEMANTIC/g
s/\bSematic\b/Semantic/g
s/\bsematical\b/semantical/g
s/\bSEMATICAL\b/SEMANTICAL/g
s/\bSematical\b/Semantical/g
s/\bsematically\b/semantically/g
s/\bSEMATICALLY\b/SEMANTICALLY/g
s/\bSematically\b/Semantically/g
s/\bsematics\b/semantics/g
s/\bSEMATICS\b/SEMANTICS/g
s/\bSematics\b/Semantics/g
s/\bsempahore\b/semaphore/g
s/\bSEMPAHORE\b/SEMAPHORE/g
s/\bSempahore\b/Semaphore/g
s/\bsempahores\b/semaphores/g
s/\bSEMPAHORES\b/SEMAPHORES/g
s/\bSempahores\b/Semaphores/g
s/\bsensistive\b/insensitive/g
s/\bSENSISTIVE\b/INSENSITIVE/g
s/\bSensistive\b/Insensitive/g
s/\bsensistively\b/insensitively/g
s/\bSENSISTIVELY\b/INSENSITIVELY/g
s/\bSensistively\b/Insensitively/g
s/\bsentance\b/sentence/g
s/\bSENTANCE\b/SENTENCE/g
s/\bSentance\b/Sentence/g
s/\bsentances\b/sentences/g
s/\bSENTANCES\b/SENTENCES/g
s/\bSentances\b/Sentences/g
s/\bsentinal\b/sentinel/g
s/\bSENTINAL\b/SENTINEL/g
s/\bSentinal\b/Sentinel/g
s/\bsentinals\b/sentinels/g
s/\bSENTINALS\b/SENTINELS/g
s/\bSentinals\b/Sentinels/g
s/\bseparatly\b/separately/g
s/\bSEPARATLY\b/SEPARATELY/g
s/\bSeparatly\b/Separately/g
s/\bsepared\b/separated/g
s/\bSEPARED\b/SEPARATED/g
s/\bSepared\b/Separated/g
s/\bseparte\b/separate/g
s/\bSEPARTE\b/SEPARATE/g
s/\bSeparte\b/Separate/g
s/\bseparted\b/separated/g
s/\bSEPARTED\b/SEPARATED/g
s/\bSeparted\b/Separated/g
s/\bsepartes\b/separates/g
s/\bSEPARTES\b/SEPARATES/g
s/\bSepartes\b/Separates/g
s/\bseparting\b/separating/g
s/\bSEPARTING\b/SEPARATING/g
s/\bSeparting\b/Separating/g
s/\bsepcified\b/specified/g
s/\bSEPCIFIED\b/SPECIFIED/g
s/\bSepcified\b/Specified/g
s/\bsepcifies\b/specifies/g
s/\bSEPCIFIES\b/SPECIFIES/g
s/\bSepcifies\b/Specifies/g
s/\bsepcify\b/specify/g
s/\bSEPCIFY\b/SPECIFY/g
s/\bSepcify\b/Specify/g
s/\bsepcifying\b/specifying/g
s/\bSEPCIFYING\b/SPECIFYING/g
s/\bSepcifying\b/Specifying/g
s/\bseperate\b/separate/g
s/\bSEPERATE\b/SEPARATE/g
s/\bSeperate\b/Separate/g
s/\bseperated\b/separated/g
s/\bSEPERATED\b/SEPARATED/g
s/\bSeperated\b/Separated/g
s/\bseperately\b/separately/g
s/\bSEPERATELY\b/SEPARATELY/g
s/\bSeperately\b/Separately/g
s/\bseperates\b/separates/g
s/\bSEPERATES\b/SEPARATES/g
s/\bSeperates\b/Separates/g
s/\bseperating\b/separating/g
s/\bSEPERATING\b/SEPARATING/g
s/\bSeperating\b/Separating/g
s/\bseperatly\b/separately/g
s/\bSEPERATLY\b/SEPARATELY/g
s/\bSeperatly\b/Separately/g
s/\bseperator\b/separator/g
s/\bSEPERATOR\b/SEPARATOR/g
s/\bSeperator\b/Separator/g
s/\bsepperate\b/separate/g
s/\bSEPPERATE\b/SEPARATE/g
s/\bSepperate\b/Separate/g
s/\bseprator\b/separator/g
s/\bSEPRATOR\b/SEPARATOR/g
s/\bSeprator\b/Separator/g
s/\bseprators\b/separators/g
s/\bSEPRATORS\b/SEPARATORS/g
s/\bSeprators\b/Separators/g
s/\bsequencial\b/sequential/g
s/\bSEQUENCIAL\b/SEQUENTIAL/g
s/\bSequencial\b/Sequential/g
s/\bserie\b/series/g
s/\bSERIE\b/SERIES/g
s/\bSerie\b/Series/g
s/\bserivce\b/service/g
s/\bSERIVCE\b/SERVICE/g
s/\bSerivce\b/Service/g
s/\bserivces\b/services/g
s/\bSERIVCES\b/SERVICES/g
s/\bSerivces\b/Services/g
s/\bserveral\b/several/g
s/\bSERVERAL\b/SEVERAL/g
s/\bServeral\b/Several/g
s/\bsesssion\b/session/g
s/\bSESSSION\b/SESSION/g
s/\bSesssion\b/Session/g
s/\bsesssions\b/sessions/g
s/\bSESSSIONS\b/SESSIONS/g
s/\bSesssions\b/Sessions/g
s/\bsetts\b/sets/g
s/\bSETTS\b/SETS/g
s/\bSetts\b/Sets/g
s/\bsettting\b/setting/g
s/\bSETTTING\b/SETTING/g
s/\bSettting\b/Setting/g
s/\bsetttings\b/settings/g
s/\bSETTTINGS\b/SETTINGS/g
s/\bSetttings\b/Settings/g
s/\bshoud\b/should/g
s/\bSHOUD\b/SHOULD/g
s/\bShoud\b/Should/g
s/\bshouldnt\b/shouldn't/g
s/\bSHOULDNT\b/SHOULDN'T/g
s/\bShouldnt\b/Shouldn't/g
s/\bshoule\b/should/g
s/\bSHOULE\b/SHOULD/g
s/\bShoule\b/Should/g
s/\bsignficant\b/significant/g
s/\bSIGNFICANT\b/SIGNIFICANT/g
s/\bSignficant\b/Significant/g
s/\bsignficantly\b/significantly/g
s/\bSIGNFICANTLY\b/SIGNIFICANTLY/g
s/\bSignficantly\b/Significantly/g
s/\bsimilarily\b/similarly/g
s/\bSIMILARILY\b/SIMILARLY/g
s/\bSimilarily\b/Similarly/g
s/\bsimilary\b/similarly/g
s/\bSIMILARY\b/SIMILARLY/g
s/\bSimilary\b/Similarly/g
s/\bsimiliar\b/similar/g
s/\bSIMILIAR\b/SIMILAR/g
s/\bSimiliar\b/Similar/g
s/\bsimiliarly\b/similarly/g
s/\bSIMILIARLY\b/SIMILARLY/g
s/\bSimiliarly\b/Similarly/g
s/\bsimliar\b/similar/g
s/\bSIMLIAR\b/SIMILAR/g
s/\bSimliar\b/Similar/g
s/\bsimmilar\b/similar/g
s/\bSIMMILAR\b/SIMILAR/g
s/\bSimmilar\b/Similar/g
s/\bsimplier\b/simpler/g
s/\bSIMPLIER\b/SIMPLER/g
s/\bSimplier\b/Simpler/g
s/\bsimultanous\b/simultaneous/g
s/\bSIMULTANOUS\b/SIMULTANEOUS/g
s/\bSimultanous\b/Simultaneous/g
s/\bsimultanously\b/simultaneously/g
s/\bSIMULTANOUSLY\b/SIMULTANEOUSLY/g
s/\bSimultanously\b/Simultaneously/g
s/\bsingal\b/signal/g
s/\bSINGAL\b/SIGNAL/g
s/\bSingal\b/Signal/g
s/\bsinged\b/signed/g
s/\bSINGED\b/SIGNED/g
s/\bSinged\b/Signed/g
s/\bsitation\b/situation/g
s/\bSITATION\b/SITUATION/g
s/\bSitation\b/Situation/g
s/\bsitations\b/situations/g
s/\bSITATIONS\b/SITUATIONS/g
s/\bSitations\b/Situations/g
s/\bskiped\b/skipped/g
s/\bSKIPED\b/SKIPPED/g
s/\bSkiped\b/Skipped/g
s/\bskiping\b/skipping/g
s/\bSKIPING\b/SKIPPING/g
s/\bSkiping\b/Skipping/g
s/\bslashs\b/slashes/g
s/\bSLASHS\b/SLASHES/g
s/\bSlashs\b/Slashes/g
s/\bsligth\b/slight/g
s/\bSLIGTH\b/SLIGHT/g
s/\bSligth\b/Slight/g
s/\bsligthly\b/slightly/g
s/\bSLIGTHLY\b/SLIGHTLY/g
s/\bSligthly\b/Slightly/g
s/\bsoftwares\b/software/g
s/\bSOFTWARES\b/SOFTWARE/g
s/\bSoftwares\b/Software/g
s/\bsofware\b/software/g
s/\bSOFWARE\b/SOFTWARE/g
s/\bSofware\b/Software/g
s/\bsomehwere\b/somewhere/g
s/\bSOMEHWERE\b/SOMEWHERE/g
s/\bSomehwere\b/Somewhere/g
s/\bsomes\b/some/g
s/\bSOMES\b/SOME/g
s/\bSomes\b/Some/g
s/\bsometing\b/something/g
s/\bSOMETING\b/SOMETHING/g
s/\bSometing\b/Something/g
s/\bsomthing\b/something/g
s/\bSOMTHING\b/SOMETHING/g
s/\bSomthing\b/Something/g
s/\bsouce\b/source/g
s/\bSOUCE\b/SOURCE/g
s/\bSouce\b/Source/g
s/\bsouces\b/sources/g
s/\bSOUCES\b/SOURCES/g
s/\bSouces\b/Sources/g
s/\bspaw\b/spawn/g
s/\bSPAW\b/SPAWN/g
s/\bSpaw\b/Spawn/g
s/\bspawed\b/spawned/g
s/\bSPAWED\b/SPAWNED/g
s/\bSpawed\b/Spawned/g
s/\bspawing\b/spawning/g
s/\bSPAWING\b/SPAWNING/g
s/\bSpawing\b/Spawning/g
s/\bspaws\b/spawns/g
s/\bSPAWS\b/SPAWNS/g
s/\bSpaws\b/Spawns/g
s/\bspeach\b/speech/g
s/\bSPEACH\b/SPEECH/g
s/\bSpeach\b/Speech/g
s/\bspearator\b/separator/g
s/\bSPEARATOR\b/SEPARATOR/g
s/\bSpearator\b/Separator/g
s/\bspearators\b/separators/g
s/\bSPEARATORS\b/SEPARATORS/g
s/\bSpearators\b/Separators/g
s/\bspecfic\b/specific/g
s/\bSPECFIC\b/SPECIFIC/g
s/\bSpecfic\b/Specific/g
s/\bspecfication\b/specification/g
s/\bSPECFICATION\b/SPECIFICATION/g
s/\bSpecfication\b/Specification/g
s/\bspecfications\b/specifications/g
s/\bSPECFICATIONS\b/SPECIFICATIONS/g
s/\bSpecfications\b/Specifications/g
s/\bspecfied\b/specified/g
s/\bSPECFIED\b/SPECIFIED/g
s/\bSpecfied\b/Specified/g
s/\bspecfies\b/specifies/g
s/\bSPECFIES\b/SPECIFIES/g
s/\bSpecfies\b/Specifies/g
s/\bspecfy\b/specify/g
s/\bSPECFY\b/SPECIFY/g
s/\bSpecfy\b/Specify/g
s/\bspecfying\b/specifying/g
s/\bSPECFYING\b/SPECIFYING/g
s/\bSpecfying\b/Specifying/g
s/\bspeciefied\b/specified/g
s/\bSPECIEFIED\b/SPECIFIED/g
s/\bSpeciefied\b/Specified/g
s/\bspecifc\b/specific/g
s/\bSPECIFC\b/SPECIFIC/g
s/\bSpecifc\b/Specific/g
s/\bspecifed\b/specified/g
s/\bSPECIFED\b/SPECIFIED/g
s/\bSpecifed\b/Specified/g
s/\bspecificatin\b/specification/g
s/\bSPECIFICATIN\b/SPECIFICATION/g
s/\bSpecificatin\b/Specification/g
s/\bspecificaton\b/specification/g
s/\bSPECIFICATON\b/SPECIFICATION/g
s/\bSpecificaton\b/Specification/g
s/\bspecifing\b/specifying/g
s/\bSPECIFING\b/SPECIFYING/g
s/\bSpecifing\b/Specifying/g
s/\bspecifiy\b/specify/g
s/\bSPECIFIY\b/SPECIFY/g
s/\bSpecifiy\b/Specify/g
s/\bspefic\b/specific/g
s/\bSPEFIC\b/SPECIFIC/g
s/\bSpefic\b/Specific/g
s/\bspeficied\b/specified/g
s/\bSPEFICIED\b/SPECIFIED/g
s/\bSpeficied\b/Specified/g
s/\bspeling\b/spelling/g
s/\bSPELING\b/SPELLING/g
s/\bSpeling\b/Spelling/g
s/\bsplitted\b/split/g
s/\bSPLITTED\b/SPLIT/g
s/\bSplitted\b/Split/g
s/\bspport\b/support/g
s/\bSPPORT\b/SUPPORT/g
s/\bSpport\b/Support/g
s/\bspported\b/supported/g
s/\bSPPORTED\b/SUPPORTED/g
s/\bSpported\b/Supported/g
s/\bspporting\b/supporting/g
s/\bSPPORTING\b/SUPPORTING/g
s/\bSpporting\b/Supporting/g
s/\bspports\b/supports/g
s/\bSPPORTS\b/SUPPORTS/g
s/\bSpports\b/Supports/g
s/\bspreaded\b/spread/g
s/\bSPREADED\b/SPREAD/g
s/\bSpreaded\b/Spread/g
s/\bspurios\b/spurious/g
s/\bSPURIOS\b/SPURIOUS/g
s/\bSpurios\b/Spurious/g
s/\bstaically\b/statically/g
s/\bSTAICALLY\b/STATICALLY/g
s/\bStaically\b/Statically/g
s/\bstandardss\b/standards/g
s/\bSTANDARDSS\b/STANDARDS/g
s/\bStandardss\b/Standards/g
s/\bstandart\b/standard/g
s/\bSTANDART\b/STANDARD/g
s/\bStandart\b/Standard/g
s/\bstaticly\b/statically/g
s/\bSTATICLY\b/STATICALLY/g
s/\bStaticly\b/Statically/g
s/\bstatments\b/statements/g
s/\bSTATMENTS\b/STATEMENTS/g
s/\bStatments\b/Statements/g
s/\bstirng\b/string/g
s/\bSTIRNG\b/STRING/g
s/\bStirng\b/String/g
s/\bstirngs\b/strings/g
s/\bSTIRNGS\b/STRINGS/g
s/\bStirngs\b/Strings/g
s/\bstoped\b/stopped/g
s/\bSTOPED\b/STOPPED/g
s/\bStoped\b/Stopped/g
s/\bstoping\b/stopping/g
s/\bSTOPING\b/STOPPING/g
s/\bStoping\b/Stopping/g
s/\bstraigt\b/straight/g
s/\bSTRAIGT\b/STRAIGHT/g
s/\bStraigt\b/Straight/g
s/\bstraigth\b/straight/g
s/\bSTRAIGTH\b/STRAIGHT/g
s/\bStraigth\b/Straight/g
s/\bstrenght\b/strength/g
s/\bSTRENGHT\b/STRENGTH/g
s/\bStrenght\b/Strength/g
s/\bstrenghts\b/strengths/g
s/\bSTRENGHTS\b/STRENGTHS/g
s/\bStrenghts\b/Strengths/g
s/\bstrenth\b/strength/g
s/\bSTRENTH\b/STRENGTH/g
s/\bStrenth\b/Strength/g
s/\bstucture\b/structure/g
s/\bSTUCTURE\b/STRUCTURE/g
s/\bStucture\b/Structure/g
s/\bstuctures\b/structures/g
s/\bSTUCTURES\b/STRUCTURES/g
s/\bStuctures\b/Structures/g
s/\bsubdirectoires\b/subdirectories/g
s/\bSUBDIRECTOIRES\b/SUBDIRECTORIES/g
s/\bSubdirectoires\b/Subdirectories/g
s/\bsubexpresssion\b/subexpression/g
s/\bSUBEXPRESSSION\b/SUBEXPRESSION/g
s/\bSubexpresssion\b/Subexpression/g
s/\bsubexpresssions\b/subexpressions/g
s/\bSUBEXPRESSSIONS\b/SUBEXPRESSIONS/g
s/\bSubexpresssions\b/Subexpressions/g
s/\bsuble\b/subtle/g
s/\bSUBLE\b/SUBTLE/g
s/\bSuble\b/Subtle/g
s/\bsubseqent\b/subsequent/g
s/\bSUBSEQENT\b/SUBSEQUENT/g
s/\bSubseqent\b/Subsequent/g
s/\bsubsequest\b/subsequent/g
s/\bSUBSEQUEST\b/SUBSEQUENT/g
s/\bSubsequest\b/Subsequent/g
s/\bsubstituion\b/substitution/g
s/\bSUBSTITUION\b/SUBSTITUTION/g
s/\bSubstituion\b/Substitution/g
s/\bsubstituions\b/substitutions/g
s/\bSUBSTITUIONS\b/SUBSTITUTIONS/g
s/\bSubstituions\b/Substitutions/g
s/\bsubtitute\b/substitute/g
s/\bSUBTITUTE\b/SUBSTITUTE/g
s/\bSubtitute\b/Substitute/g
s/\bsubtituted\b/substituted/g
s/\bSUBTITUTED\b/SUBSTITUTED/g
s/\bSubtituted\b/Substituted/g
s/\bsubtitutes\b/substitutes/g
s/\bSUBTITUTES\b/SUBSTITUTES/g
s/\bSubtitutes\b/Substitutes/g
s/\bsubtituting\b/substituting/g
s/\bSUBTITUTING\b/SUBSTITUTING/g
s/\bSubtituting\b/Substituting/g
s/\bsubtitution\b/substitution/g
s/\bSUBTITUTION\b/SUBSTITUTION/g
s/\bSubtitution\b/Substitution/g
s/\bsubtitutions\b/substitutions/g
s/\bSUBTITUTIONS\b/SUBSTITUTIONS/g
s/\bSubtitutions\b/Substitutions/g
s/\bsuccede\b/succeed/g
s/\bSUCCEDE\b/SUCCEED/g
s/\bSuccede\b/Succeed/g
s/\bsucceded\b/succeeded/g
s/\bSUCCEDED\b/SUCCEEDED/g
s/\bSucceded\b/Succeeded/g
s/\bsuccedes\b/succeeds/g
s/\bSUCCEDES\b/SUCCEEDS/g
s/\bSuccedes\b/Succeeds/g
s/\bsucceding\b/succeeding/g
s/\bSUCCEDING\b/SUCCEEDING/g
s/\bSucceding\b/Succeeding/g
s/\bsucceedes\b/succeeds/g
s/\bSUCCEEDES\b/SUCCEEDS/g
s/\bSucceedes\b/Succeeds/g
s/\bsuccesfully\b/successfully/g
s/\bSUCCESFULLY\b/SUCCESSFULLY/g
s/\bSuccesfully\b/Successfully/g
s/\bsuccesive\b/successive/g
s/\bSUCCESIVE\b/SUCCESSIVE/g
s/\bSuccesive\b/Successive/g
s/\bsuccessfuly\b/successfully/g
s/\bSUCCESSFULY\b/SUCCESSFULLY/g
s/\bSuccessfuly\b/Successfully/g
s/\bsuccint\b/succinct/g
s/\bSUCCINT\b/SUCCINCT/g
s/\bSuccint\b/Succinct/g
s/\bsuceed\b/succeed/g
s/\bSUCEED\b/SUCCEED/g
s/\bSuceed\b/Succeed/g
s/\bsuceeded\b/succeeded/g
s/\bSUCEEDED\b/SUCCEEDED/g
s/\bSuceeded\b/Succeeded/g
s/\bsuceeding\b/succeeding/g
s/\bSUCEEDING\b/SUCCEEDING/g
s/\bSuceeding\b/Succeeding/g
s/\bsuceeds\b/succeeds/g
s/\bSUCEEDS\b/SUCCEEDS/g
s/\bSuceeds\b/Succeeds/g
s/\bsucesses\b/successes/g
s/\bSUCESSES\b/SUCCESSES/g
s/\bSucesses\b/Successes/g
s/\bsucessfully\b/successfully/g
s/\bSUCESSFULLY\b/SUCCESSFULLY/g
s/\bSucessfully\b/Successfully/g
s/\bsufficent\b/sufficient/g
s/\bSUFFICENT\b/SUFFICIENT/g
s/\bSufficent\b/Sufficient/g
s/\bsufficently\b/sufficiently/g
s/\bSUFFICENTLY\b/SUFFICIENTLY/g
s/\bSufficently\b/Sufficiently/g
s/\bsuperflous\b/superfluous/g
s/\bSUPERFLOUS\b/SUPERFLUOUS/g
s/\bSuperflous\b/Superfluous/g
s/\bsuperseeded\b/superseded/g
s/\bSUPERSEEDED\b/SUPERSEDED/g
s/\bSuperseeded\b/Superseded/g
s/\bsuplied\b/supplied/g
s/\bSUPLIED\b/SUPPLIED/g
s/\bSuplied\b/Supplied/g
s/\bsuport\b/support/g
s/\bSUPORT\b/SUPPORT/g
s/\bSuport\b/Support/g
s/\bsuported\b/supported/g
s/\bSUPORTED\b/SUPPORTED/g
s/\bSuported\b/Supported/g
s/\bsuporting\b/supporting/g
s/\bSUPORTING\b/SUPPORTING/g
s/\bSuporting\b/Supporting/g
s/\bsuports\b/supports/g
s/\bSUPORTS\b/SUPPORTS/g
s/\bSuports\b/Supports/g
s/\bsuppied\b/supplied/g
s/\bSUPPIED\b/SUPPLIED/g
s/\bSuppied\b/Supplied/g
s/\bsuppies\b/supplies/g
s/\bSUPPIES\b/SUPPLIES/g
s/\bSuppies\b/Supplies/g
s/\bsuppored\b/supported/g
s/\bSUPPORED\b/SUPPORTED/g
s/\bSuppored\b/Supported/g
s/\bsupportin\b/supporting/g
s/\bSUPPORTIN\b/SUPPORTING/g
s/\bSupportin\b/Supporting/g
s/\bsuppoted\b/supported/g
s/\bSUPPOTED\b/SUPPORTED/g
s/\bSuppoted\b/Supported/g
s/\bsuppport\b/support/g
s/\bSUPPPORT\b/SUPPORT/g
s/\bSuppport\b/Support/g
s/\bsuppported\b/supported/g
s/\bSUPPPORTED\b/SUPPORTED/g
s/\bSuppported\b/Supported/g
s/\bsuppporting\b/supporting/g
s/\bSUPPPORTING\b/SUPPORTING/g
s/\bSuppporting\b/Supporting/g
s/\bsuppports\b/supports/g
s/\bSUPPPORTS\b/SUPPORTS/g
s/\bSuppports\b/Supports/g
s/\bsuppy\b/supply/g
s/\bSUPPY\b/SUPPLY/g
s/\bSuppy\b/Supply/g
s/\bsuppying\b/supplying/g
s/\bSUPPYING\b/SUPPLYING/g
s/\bSuppying\b/Supplying/g
s/\bsupressed\b/suppressed/g
s/\bSUPRESSED\b/SUPPRESSED/g
s/\bSupressed\b/Suppressed/g
s/\bsupresses\b/suppresses/g
s/\bSUPRESSES\b/SUPPRESSES/g
s/\bSupresses\b/Suppresses/g
s/\bsupressing\b/suppressing/g
s/\bSUPRESSING\b/SUPPRESSING/g
s/\bSupressing\b/Suppressing/g
s/\bsurpress\b/suppress/g
s/\bSURPRESS\b/SUPPRESS/g
s/\bSurpress\b/Suppress/g
s/\bsurpressed\b/suppressed/g
s/\bSURPRESSED\b/SUPPRESSED/g
s/\bSurpressed\b/Suppressed/g
s/\bsurpresses\b/suppresses/g
s/\bSURPRESSES\b/SUPPRESSES/g
s/\bSurpresses\b/Suppresses/g
s/\bsurpressing\b/suppressing/g
s/\bSURPRESSING\b/SUPPRESSING/g
s/\bSurpressing\b/Suppressing/g
s/\bsuspicous\b/suspicious/g
s/\bSUSPICOUS\b/SUSPICIOUS/g
s/\bSuspicous\b/Suspicious/g
s/\bsuspicously\b/suspiciously/g
s/\bSUSPICOUSLY\b/SUSPICIOUSLY/g
s/\bSuspicously\b/Suspiciously/g
s/\bsustitution\b/substitution/g
s/\bSUSTITUTION\b/SUBSTITUTION/g
s/\bSustitution\b/Substitution/g
s/\bsustitutions\b/substitutions/g
s/\bSUSTITUTIONS\b/SUBSTITUTIONS/g
s/\bSustitutions\b/Substitutions/g
s/\bsuuport\b/support/g
s/\bSUUPORT\b/SUPPORT/g
s/\bSuuport\b/Support/g
s/\bsuuported\b/supported/g
s/\bSUUPORTED\b/SUPPORTED/g
s/\bSuuported\b/Supported/g
s/\bsuuporting\b/supporting/g
s/\bSUUPORTING\b/SUPPORTING/g
s/\bSuuporting\b/Supporting/g
s/\bsuuports\b/supports/g
s/\bSUUPORTS\b/SUPPORTS/g
s/\bSuuports\b/Supports/g
s/\bswaping\b/swapping/g
s/\bSWAPING\b/SWAPPING/g
s/\bSwaping\b/Swapping/g
s/\bsynax\b/syntax/g
s/\bSYNAX\b/SYNTAX/g
s/\bSynax\b/Syntax/g
s/\bsynchonized\b/synchronized/g
s/\bSYNCHONIZED\b/SYNCHRONIZED/g
s/\bSynchonized\b/Synchronized/g
s/\bsynchonizes\b/synchronizes/g
s/\bSYNCHONIZES\b/SYNCHRONIZES/g
s/\bSynchonizes\b/Synchronizes/g
s/\bsyncronize\b/synchronize/g
s/\bSYNCRONIZE\b/SYNCHRONIZE/g
s/\bSyncronize\b/Synchronize/g
s/\bsyncronizing\b/synchronizing/g
s/\bSYNCRONIZING\b/SYNCHRONIZING/g
s/\bSyncronizing\b/Synchronizing/g
s/\bsyncronus\b/synchronous/g
s/\bSYNCRONUS\b/SYNCHRONOUS/g
s/\bSyncronus\b/Synchronous/g
s/\bsynopsys\b/synopsis/g
s/\bSYNOPSYS\b/SYNOPSIS/g
s/\bSynopsys\b/Synopsis/g
s/\bsyste\b/system/g
s/\bSYSTE\b/SYSTEM/g
s/\bSyste\b/System/g
s/\bsytem\b/system/g
s/\bSYTEM\b/SYSTEM/g
s/\bSytem\b/System/g
s/\bsytems\b/systems/g
s/\bSYTEMS\b/SYSTEMS/g
s/\bSytems\b/Systems/g
s/\bsythesis\b/synthesis/g
s/\bSYTHESIS\b/SYNTHESIS/g
s/\bSythesis\b/Synthesis/g
s/\btaht\b/that/g
s/\bTAHT\b/THAT/g
s/\bTaht\b/That/g
s/\btargetted\b/targeted/g
s/\bTARGETTED\b/TARGETED/g
s/\bTargetted\b/Targeted/g
s/\btargetting\b/targeting/g
s/\bTARGETTING\b/TARGETING/g
s/\bTargetting\b/Targeting/g
s/\bteh\b/the/g
s/\bTEH\b/THE/g
s/\bTeh\b/The/g
s/\bterminater\b/terminator/g
s/\bTERMINATER\b/TERMINATOR/g
s/\bTerminater\b/Terminator/g
s/\bterminaters\b/terminators/g
s/\bTERMINATERS\b/TERMINATORS/g
s/\bTerminaters\b/Terminators/g
s/\bthats\b/that's/g
s/\bTHATS\b/THAT'S/g
s/\bThats\b/That's/g
s/\btheer\b/there/g
s/\bTHEER\b/THERE/g
s/\bTheer\b/There/g
s/\btheres\b/there's/g
s/\bTHERES\b/THERE'S/g
s/\bTheres\b/There's/g
s/\btherfore\b/therefore/g
s/\bTHERFORE\b/THEREFORE/g
s/\bTherfore\b/Therefore/g
s/\bthie\b/the/g
s/\bTHIE\b/THE/g
s/\bThie\b/The/g
s/\bthier\b/their/g
s/\bTHIER\b/THEIR/g
s/\bThier\b/Their/g
s/\bthreashold\b/threshold/g
s/\bTHREASHOLD\b/THRESHOLD/g
s/\bThreashold\b/Threshold/g
s/\bthreasholds\b/thresholds/g
s/\bTHREASHOLDS\b/THRESHOLDS/g
s/\bThreasholds\b/Thresholds/g
s/\bthrehold\b/threshold/g
s/\bTHREHOLD\b/THRESHOLD/g
s/\bThrehold\b/Threshold/g
s/\bthreshholds\b/thresholds/g
s/\bTHRESHHOLDS\b/THRESHOLDS/g
s/\bThreshholds\b/Thresholds/g
s/\bthrought\b/through/g
s/\bTHROUGHT\b/THROUGH/g
s/\bThrought\b/Through/g
s/\bthses\b/these/g
s/\bTHSES\b/THESE/g
s/\bThses\b/These/g
s/\bthsi\b/this/g
s/\bTHSI\b/THIS/g
s/\bThsi\b/This/g
s/\btigger\b/trigger/g
s/\bTIGGER\b/TRIGGER/g
s/\bTigger\b/Trigger/g
s/\btiggered\b/triggered/g
s/\bTIGGERED\b/TRIGGERED/g
s/\bTiggered\b/Triggered/g
s/\btiggering\b/triggering/g
s/\bTIGGERING\b/TRIGGERING/g
s/\bTiggering\b/Triggering/g
s/\btiggers\b/triggers/g
s/\bTIGGERS\b/TRIGGERS/g
s/\bTiggers\b/Triggers/g
s/\btigth\b/tight/g
s/\bTIGTH\b/TIGHT/g
s/\bTigth\b/Tight/g
s/\btigthen\b/tighten/g
s/\bTIGTHEN\b/TIGHTEN/g
s/\bTigthen\b/Tighten/g
s/\btigthened\b/tightened/g
s/\bTIGTHENED\b/TIGHTENED/g
s/\bTigthened\b/Tightened/g
s/\btigthening\b/tightening/g
s/\bTIGTHENING\b/TIGHTENING/g
s/\bTigthening\b/Tightening/g
s/\btigthens\b/tightens/g
s/\bTIGTHENS\b/TIGHTENS/g
s/\bTigthens\b/Tightens/g
s/\btihs\b/this/g
s/\bTIHS\b/THIS/g
s/\bTihs\b/This/g
s/\btimetamp\b/timestamp/g
s/\bTIMETAMP\b/TIMESTAMP/g
s/\bTimetamp\b/Timestamp/g
s/\btimetamps\b/timestamps/g
s/\bTIMETAMPS\b/TIMESTAMPS/g
s/\bTimetamps\b/Timestamps/g
s/\btimout\b/timeout/g
s/\bTIMOUT\b/TIMEOUT/g
s/\bTimout\b/Timeout/g
s/\btogther\b/together/g
s/\bTOGTHER\b/TOGETHER/g
s/\bTogther\b/Together/g
s/\btouple\b/tuple/g
s/\bTOUPLE\b/TUPLE/g
s/\bTouple\b/Tuple/g
s/\btraditionnal\b/traditional/g
s/\bTRADITIONNAL\b/TRADITIONAL/g
s/\bTraditionnal\b/Traditional/g
s/\btrailling\b/trailing/g
s/\bTRAILLING\b/TRAILING/g
s/\bTrailling\b/Trailing/g
s/\btranfer\b/transfer/g
s/\bTRANFER\b/TRANSFER/g
s/\bTranfer\b/Transfer/g
s/\btranfered\b/transferred/g
s/\bTRANFERED\b/TRANSFERRED/g
s/\bTranfered\b/Transferred/g
s/\btranfering\b/transferring/g
s/\bTRANFERING\b/TRANSFERRING/g
s/\bTranfering\b/Transferring/g
s/\btranfers\b/transfers/g
s/\bTRANFERS\b/TRANSFERS/g
s/\bTranfers\b/Transfers/g
s/\btranform\b/transform/g
s/\bTRANFORM\b/TRANSFORM/g
s/\bTranform\b/Transform/g
s/\btranformation\b/transformation/g
s/\bTRANFORMATION\b/TRANSFORMATION/g
s/\bTranformation\b/Transformation/g
s/\btranformations\b/transformations/g
s/\bTRANFORMATIONS\b/TRANSFORMATIONS/g
s/\bTranformations\b/Transformations/g
s/\btranformed\b/transformed/g
s/\bTRANFORMED\b/TRANSFORMED/g
s/\bTranformed\b/Transformed/g
s/\btranforming\b/transforming/g
s/\bTRANFORMING\b/TRANSFORMING/g
s/\bTranforming\b/Transforming/g
s/\btranforms\b/transforms/g
s/\bTRANFORMS\b/TRANSFORMS/g
s/\bTranforms\b/Transforms/g
s/\btranlation\b/translation/g
s/\bTRANLATION\b/TRANSLATION/g
s/\bTranlation\b/Translation/g
s/\btranlations\b/translations/g
s/\bTRANLATIONS\b/TRANSLATIONS/g
s/\bTranlations\b/Translations/g
s/\btranparent\b/transparent/g
s/\bTRANPARENT\b/TRANSPARENT/g
s/\bTranparent\b/Transparent/g
s/\btranparently\b/transparently/g
s/\bTRANPARENTLY\b/TRANSPARENTLY/g
s/\bTranparently\b/Transparently/g
s/\btransfering\b/transferring/g
s/\bTRANSFERING\b/TRANSFERRING/g
s/\bTransfering\b/Transferring/g
s/\btransistion\b/transition/g
s/\bTRANSISTION\b/TRANSITION/g
s/\bTransistion\b/Transition/g
s/\btransistions\b/transitions/g
s/\bTRANSISTIONS\b/TRANSITIONS/g
s/\bTransistions\b/Transitions/g
s/\btransitionned\b/transitioned/g
s/\bTRANSITIONNED\b/TRANSITIONED/g
s/\bTransitionned\b/Transitioned/g
s/\btransmition\b/transmission/g
s/\bTRANSMITION\b/TRANSMISSION/g
s/\bTransmition\b/Transmission/g
s/\btranstion\b/transition/g
s/\bTRANSTION\b/TRANSITION/g
s/\bTranstion\b/Transition/g
s/\btranstions\b/transitions/g
s/\bTRANSTIONS\b/TRANSITIONS/g
s/\bTranstions\b/Transitions/g
s/\btranstition\b/transition/g
s/\bTRANSTITION\b/TRANSITION/g
s/\bTranstition\b/Transition/g
s/\btranstitions\b/transitions/g
s/\bTRANSTITIONS\b/TRANSITIONS/g
s/\bTranstitions\b/Transitions/g
s/\btrasmission\b/transmission/g
s/\bTRASMISSION\b/TRANSMISSION/g
s/\bTrasmission\b/Transmission/g
s/\btreshold\b/threshold/g
s/\bTRESHOLD\b/THRESHOLD/g
s/\bTreshold\b/Threshold/g
s/\btrigerring\b/triggering/g
s/\bTRIGERRING\b/TRIGGERING/g
s/\bTrigerring\b/Triggering/g
s/\btruely\b/truly/g
s/\bTRUELY\b/TRULY/g
s/\bTruely\b/Truly/g
s/\btupple\b/tuple/g
s/\bTUPPLE\b/TUPLE/g
s/\bTupple\b/Tuple/g
s/\btupples\b/tuples/g
s/\bTUPPLES\b/TUPLES/g
s/\bTupples\b/Tuples/g
s/\btypicaly\b/typically/g
s/\bTYPICALY\b/TYPICALLY/g
s/\bTypicaly\b/Typically/g
s/\btyple\b/tuple/g
s/\bTYPLE\b/TUPLE/g
s/\bTyple\b/Tuple/g
s/\btyples\b/tuples/g
s/\bTYPLES\b/TUPLES/g
s/\bTyples\b/Tuples/g
s/\buesd\b/used/g
s/\bUESD\b/USED/g
s/\bUesd\b/Used/g
s/\buknown\b/unknown/g
s/\bUKNOWN\b/UNKNOWN/g
s/\bUknown\b/Unknown/g
s/\buncoment\b/uncomment/g
s/\bUNCOMENT\b/UNCOMMENT/g
s/\bUncoment\b/Uncomment/g
s/\buncomented\b/uncommented/g
s/\bUNCOMENTED\b/UNCOMMENTED/g
s/\bUncomented\b/Uncommented/g
s/\buncomenting\b/uncommenting/g
s/\bUNCOMENTING\b/UNCOMMENTING/g
s/\bUncomenting\b/Uncommenting/g
s/\buncoments\b/uncomments/g
s/\bUNCOMENTS\b/UNCOMMENTS/g
s/\bUncoments\b/Uncomments/g
s/\buncommment\b/uncomment/g
s/\bUNCOMMMENT\b/UNCOMMENT/g
s/\bUncommment\b/Uncomment/g
s/\buncommmented\b/uncommented/g
s/\bUNCOMMMENTED\b/UNCOMMENTED/g
s/\bUncommmented\b/Uncommented/g
s/\buncommmenting\b/uncommenting/g
s/\bUNCOMMMENTING\b/UNCOMMENTING/g
s/\bUncommmenting\b/Uncommenting/g
s/\buncommments\b/uncomments/g
s/\bUNCOMMMENTS\b/UNCOMMENTS/g
s/\bUncommments\b/Uncomments/g
s/\buncomplete\b/incomplete/g
s/\bUNCOMPLETE\b/INCOMPLETE/g
s/\bUncomplete\b/Incomplete/g
s/\bunconditionaly\b/unconditionally/g
s/\bUNCONDITIONALY\b/UNCONDITIONALLY/g
s/\bUnconditionaly\b/Unconditionally/g
s/\buncoverted\b/unconverted/g
s/\bUNCOVERTED\b/UNCONVERTED/g
s/\bUncoverted\b/Unconverted/g
s/\bunderun\b/underrun/g
s/\bUNDERUN\b/UNDERRUN/g
s/\bUnderun\b/Underrun/g
s/\bunderuns\b/underruns/g
s/\bUNDERUNS\b/UNDERRUNS/g
s/\bUnderuns\b/Underruns/g
s/\bundesireable\b/undesirable/g
s/\bUNDESIREABLE\b/UNDESIRABLE/g
s/\bUndesireable\b/Undesirable/g
s/\bunecessary\b/unnecessary/g
s/\bUNECESSARY\b/UNNECESSARY/g
s/\bUnecessary\b/Unnecessary/g
s/\buneeded\b/unneeded/g
s/\bUNEEDED\b/UNNEEDED/g
s/\bUneeded\b/Unneeded/g
s/\bunexcpected\b/unexpected/g
s/\bUNEXCPECTED\b/UNEXPECTED/g
s/\bUnexcpected\b/Unexpected/g
s/\bunexecpted\b/unexpected/g
s/\bUNEXECPTED\b/UNEXPECTED/g
s/\bUnexecpted\b/Unexpected/g
s/\bunexected\b/unexpected/g
s/\bUNEXECTED\b/UNEXPECTED/g
s/\bUnexected\b/Unexpected/g
s/\bunexepcted\b/unexpected/g
s/\bUNEXEPCTED\b/UNEXPECTED/g
s/\bUnexepcted\b/Unexpected/g
s/\bunfortunatelly\b/unfortunately/g
s/\bUNFORTUNATELLY\b/UNFORTUNATELY/g
s/\bUnfortunatelly\b/Unfortunately/g
s/\bunforunate\b/unfortunate/g
s/\bUNFORUNATE\b/UNFORTUNATE/g
s/\bUnforunate\b/Unfortunate/g
s/\bunforunately\b/unfortunately/g
s/\bUNFORUNATELY\b/UNFORTUNATELY/g
s/\bUnforunately\b/Unfortunately/g
s/\buninitalized\b/uninitialized/g
s/\bUNINITALIZED\b/UNINITIALIZED/g
s/\bUninitalized\b/Uninitialized/g
s/\bunintentially\b/unintentionally/g
s/\bUNINTENTIALLY\b/UNINTENTIONALLY/g
s/\bUnintentially\b/Unintentionally/g
s/\buniqe\b/unique/g
s/\bUNIQE\b/UNIQUE/g
s/\bUniqe\b/Unique/g
s/\bunitialized\b/uninitialized/g
s/\bUNITIALIZED\b/UNINITIALIZED/g
s/\bUnitialized\b/Uninitialized/g
s/\buniverities\b/universities/g
s/\bUNIVERITIES\b/UNIVERSITIES/g
s/\bUniverities\b/Universities/g
s/\buniverity\b/university/g
s/\bUNIVERITY\b/UNIVERSITY/g
s/\bUniverity\b/University/g
s/\bunknonw\b/unknown/g
s/\bUNKNONW\b/UNKNOWN/g
s/\bUnknonw\b/Unknown/g
s/\bunknow\b/unknown/g
s/\bUNKNOW\b/UNKNOWN/g
s/\bUnknow\b/Unknown/g
s/\bunles\b/unless/g
s/\bUNLES\b/UNLESS/g
s/\bUnles\b/Unless/g
s/\bunneccesarily\b/unnecessarily/g
s/\bUNNECCESARILY\b/UNNECESSARILY/g
s/\bUnneccesarily\b/Unnecessarily/g
s/\bunneccesary\b/unnecessary/g
s/\bUNNECCESARY\b/UNNECESSARY/g
s/\bUnneccesary\b/Unnecessary/g
s/\bunneccessarily\b/unnecessarily/g
s/\bUNNECCESSARILY\b/UNNECESSARILY/g
s/\bUnneccessarily\b/Unnecessarily/g
s/\bunneccessary\b/unnecessary/g
s/\bUNNECCESSARY\b/UNNECESSARY/g
s/\bUnneccessary\b/Unnecessary/g
s/\bunnecesarily\b/unnecessarily/g
s/\bUNNECESARILY\b/UNNECESSARILY/g
s/\bUnnecesarily\b/Unnecessarily/g
s/\bunnecesary\b/unnecessary/g
s/\bUNNECESARY\b/UNNECESSARY/g
s/\bUnnecesary\b/Unnecessary/g
s/\bunnedded\b/unneeded/g
s/\bUNNEDDED\b/UNNEEDED/g
s/\bUnnedded\b/Unneeded/g
s/\bunneedingly\b/unnecessarily/g
s/\bUNNEEDINGLY\b/UNNECESSARILY/g
s/\bUnneedingly\b/Unnecessarily/g
s/\bunnesesarily\b/unnecessarily/g
s/\bUNNESESARILY\b/UNNECESSARILY/g
s/\bUnnesesarily\b/Unnecessarily/g
s/\bunnessecary\b/unnecessary/g
s/\bUNNESSECARY\b/UNNECESSARY/g
s/\bUnnessecary\b/Unnecessary/g
s/\bunnessesary\b/unnecessary/g
s/\bUNNESSESARY\b/UNNECESSARY/g
s/\bUnnessesary\b/Unnecessary/g
s/\bunoffical\b/unofficial/g
s/\bUNOFFICAL\b/UNOFFICIAL/g
s/\bUnoffical\b/Unofficial/g
s/\bunorderd\b/unordered/g
s/\bUNORDERD\b/UNORDERED/g
s/\bUnorderd\b/Unordered/g
s/\bunqoute\b/unquote/g
s/\bUNQOUTE\b/UNQUOTE/g
s/\bUnqoute\b/Unquote/g
s/\bunqouted\b/unquoted/g
s/\bUNQOUTED\b/UNQUOTED/g
s/\bUnqouted\b/Unquoted/g
s/\bunqoutes\b/unquotes/g
s/\bUNQOUTES\b/UNQUOTES/g
s/\bUnqoutes\b/Unquotes/g
s/\bunqouting\b/unquoting/g
s/\bUNQOUTING\b/UNQUOTING/g
s/\bUnqouting\b/Unquoting/g
s/\bunrecogized\b/unrecognized/g
s/\bUNRECOGIZED\b/UNRECOGNIZED/g
s/\bUnrecogized\b/Unrecognized/g
s/\bunreconized\b/unrecognized/g
s/\bUNRECONIZED\b/UNRECOGNIZED/g
s/\bUnreconized\b/Unrecognized/g
s/\bunsinged\b/unsigned/g
s/\bUNSINGED\b/UNSIGNED/g
s/\bUnsinged\b/Unsigned/g
s/\bunspported\b/unsupported/g
s/\bUNSPPORTED\b/UNSUPPORTED/g
s/\bUnspported\b/Unsupported/g
s/\bunsual\b/unusual/g
s/\bUNSUAL\b/UNUSUAL/g
s/\bUnsual\b/Unusual/g
s/\bunsued\b/unused/g
s/\bUNSUED\b/UNUSED/g
s/\bUnsued\b/Unused/g
s/\bunsuported\b/unsupported/g
s/\bUNSUPORTED\b/UNSUPPORTED/g
s/\bUnsuported\b/Unsupported/g
s/\buntill\b/until/g
s/\bUNTILL\b/UNTIL/g
s/\bUntill\b/Until/g
s/\bunusal\b/unusual/g
s/\bUNUSAL\b/UNUSUAL/g
s/\bUnusal\b/Unusual/g
s/\bunusally\b/unusually/g
s/\bUNUSALLY\b/UNUSUALLY/g
s/\bUnusally\b/Unusually/g
s/\bunuseful\b/useless/g
s/\bUNUSEFUL\b/USELESS/g
s/\bUnuseful\b/Useless/g
s/\bunusuable\b/unusable/g
s/\bUNUSUABLE\b/UNUSABLE/g
s/\bUnusuable\b/Unusable/g
s/\bunversionned\b/unversioned/g
s/\bUNVERSIONNED\b/UNVERSIONED/g
s/\bUnversionned\b/Unversioned/g
s/\bunversoned\b/unversioned/g
s/\bUNVERSONED\b/UNVERSIONED/g
s/\bUnversoned\b/Unversioned/g
s/\bupate\b/update/g
s/\bUPATE\b/UPDATE/g
s/\bUpate\b/Update/g
s/\bupated\b/updated/g
s/\bUPATED\b/UPDATED/g
s/\bUpated\b/Updated/g
s/\bupates\b/updates/g
s/\bUPATES\b/UPDATES/g
s/\bUpates\b/Updates/g
s/\bupating\b/updating/g
s/\bUPATING\b/UPDATING/g
s/\bUpating\b/Updating/g
s/\bupdateing\b/updating/g
s/\bUPDATEING\b/UPDATING/g
s/\bUpdateing\b/Updating/g
s/\bupsream\b/upstream/g
s/\bUPSREAM\b/UPSTREAM/g
s/\bUpsream\b/Upstream/g
s/\bupsteam\b/upstream/g
s/\bUPSTEAM\b/UPSTREAM/g
s/\bUpsteam\b/Upstream/g
s/\bupstrema\b/upstream/g
s/\bUPSTREMA\b/UPSTREAM/g
s/\bUpstrema\b/Upstream/g
s/\busal\b/usual/g
s/\bUSAL\b/USUAL/g
s/\bUsal\b/Usual/g
s/\busally\b/usually/g
s/\bUSALLY\b/USUALLY/g
s/\bUsally\b/Usually/g
s/\busefule\b/useful/g
s/\bUSEFULE\b/USEFUL/g
s/\bUsefule\b/Useful/g
s/\busege\b/usage/g
s/\bUSEGE\b/USAGE/g
s/\bUsege\b/Usage/g
s/\busera\b/users/g
s/\bUSERA\b/USERS/g
s/\bUsera\b/Users/g
s/\buserful\b/useful/g
s/\bUSERFUL\b/USEFUL/g
s/\bUserful\b/Useful/g
s/\busetnet\b/usenet/g
s/\bUSETNET\b/USENET/g
s/\bUsetnet\b/Usenet/g
s/\busuable\b/usable/g
s/\bUSUABLE\b/USABLE/g
s/\bUsuable\b/Usable/g
s/\busualy\b/usually/g
s/\bUSUALY\b/USUALLY/g
s/\bUsualy\b/Usually/g
s/\butilites\b/utilities/g
s/\bUTILITES\b/UTILITIES/g
s/\bUtilites\b/Utilities/g
s/\butillities\b/utilities/g
s/\bUTILLITIES\b/UTILITIES/g
s/\bUtillities\b/Utilities/g
s/\butilties\b/utilities/g
s/\bUTILTIES\b/UTILITIES/g
s/\bUtilties\b/Utilities/g
s/\butiltity\b/utility/g
s/\bUTILTITY\b/UTILITY/g
s/\bUtiltity\b/Utility/g
s/\butitlty\b/utility/g
s/\bUTITLTY\b/UTILITY/g
s/\bUtitlty\b/Utility/g
s/\butlity\b/utility/g
s/\bUTLITY\b/UTILITY/g
s/\bUtlity\b/Utility/g
s/\bvaiable\b/variable/g
s/\bVAIABLE\b/VARIABLE/g
s/\bVaiable\b/Variable/g
s/\bvaiables\b/variables/g
s/\bVAIABLES\b/VARIABLES/g
s/\bVaiables\b/Variables/g
s/\bvaliding\b/validating/g
s/\bVALIDING\b/VALIDATING/g
s/\bValiding\b/Validating/g
s/\bvarable\b/variable/g
s/\bVARABLE\b/VARIABLE/g
s/\bVarable\b/Variable/g
s/\bvarables\b/variables/g
s/\bVARABLES\b/VARIABLES/g
s/\bVarables\b/Variables/g
s/\bvariabe\b/variable/g
s/\bVARIABE\b/VARIABLE/g
s/\bVariabe\b/Variable/g
s/\bvariabes\b/variables/g
s/\bVARIABES\b/VARIABLES/g
s/\bVariabes\b/Variables/g
s/\bvariantions\b/variations/g
s/\bVARIANTIONS\b/VARIATIONS/g
s/\bVariantions\b/Variations/g
s/\bvaribale\b/variable/g
s/\bVARIBALE\b/VARIABLE/g
s/\bVaribale\b/Variable/g
s/\bvaribales\b/variables/g
s/\bVARIBALES\b/VARIABLES/g
s/\bVaribales\b/Variables/g
s/\bvarient\b/variant/g
s/\bVARIENT\b/VARIANT/g
s/\bVarient\b/Variant/g
s/\bvarity\b/variety/g
s/\bVARITY\b/VARIETY/g
s/\bVarity\b/Variety/g
s/\bvaule\b/value/g
s/\bVAULE\b/VALUE/g
s/\bVaule\b/Value/g
s/\bvauled\b/valued/g
s/\bVAULED\b/VALUED/g
s/\bVauled\b/Valued/g
s/\bvaules\b/values/g
s/\bVAULES\b/VALUES/g
s/\bVaules\b/Values/g
s/\bvauling\b/valuing/g
s/\bVAULING\b/VALUING/g
s/\bVauling\b/Valuing/g
s/\bverbse\b/verbose/g
s/\bVERBSE\b/VERBOSE/g
s/\bVerbse\b/Verbose/g
s/\bverion\b/version/g
s/\bVERION\b/VERSION/g
s/\bVerion\b/Version/g
s/\bverions\b/versions/g
s/\bVERIONS\b/VERSIONS/g
s/\bVerions\b/Versions/g
s/\bverious\b/various/g
s/\bVERIOUS\b/VARIOUS/g
s/\bVerious\b/Various/g
s/\bverison\b/version/g
s/\bVERISON\b/VERSION/g
s/\bVerison\b/Version/g
s/\bverisons\b/versions/g
s/\bVERISONS\b/VERSIONS/g
s/\bVerisons\b/Versions/g
s/\bveritical\b/vertical/g
s/\bVERITICAL\b/VERTICAL/g
s/\bVeritical\b/Vertical/g
s/\bverry\b/very/g
s/\bVERRY\b/VERY/g
s/\bVerry\b/Very/g
s/\bversionned\b/versioned/g
s/\bVERSIONNED\b/VERSIONED/g
s/\bVersionned\b/Versioned/g
s/\bversionning\b/versioning/g
s/\bVERSIONNING\b/VERSIONING/g
s/\bVersionning\b/Versioning/g
s/\bverson\b/version/g
s/\bVERSON\b/VERSION/g
s/\bVerson\b/Version/g
s/\bversoned\b/versioned/g
s/\bVERSONED\b/VERSIONED/g
s/\bVersoned\b/Versioned/g
s/\bversons\b/versions/g
s/\bVERSONS\b/VERSIONS/g
s/\bVersons\b/Versions/g
s/\bvicefersa\b/vice-versa/g
s/\bVICEFERSA\b/VICE-VERSA/g
s/\bVicefersa\b/Vice-versa/g
s/\bvisiters\b/visitors/g
s/\bVISITERS\b/VISITORS/g
s/\bVisiters\b/Visitors/g
s/\bvitual\b/virtual/g
s/\bVITUAL\b/VIRTUAL/g
s/\bVitual\b/Virtual/g
s/\bwan't\b/want/g
s/\bWAN'T\b/WANT/g
s/\bWan't\b/Want/g
s/\bwasnt\b/wasn't/g
s/\bWASNT\b/WASN'T/g
s/\bWasnt\b/Wasn't/g
s/\bweigth\b/weight/g
s/\bWEIGTH\b/WEIGHT/g
s/\bWeigth\b/Weight/g
s/\bweired\b/weird/g
s/\bWEIRED\b/WEIRD/g
s/\bWeired\b/Weird/g
s/\bwhataver\b/whatever/g
s/\bWHATAVER\b/WHATEVER/g
s/\bWhataver\b/Whatever/g
s/\bwhenver\b/whenever/g
s/\bWHENVER\b/WHENEVER/g
s/\bWhenver\b/Whenever/g
s/\bwheras\b/whereas/g
s/\bWHERAS\b/WHEREAS/g
s/\bWheras\b/Whereas/g
s/\bwheter\b/whether/g
s/\bWHETER\b/WHETHER/g
s/\bWheter\b/Whether/g
s/\bwhish\b/wish/g
s/\bWHISH\b/WISH/g
s/\bWhish\b/Wish/g
s/\bwhithout\b/without/g
s/\bWHITHOUT\b/WITHOUT/g
s/\bWhithout\b/Without/g
s/\bwich\b/which/g
s/\bWICH\b/WHICH/g
s/\bWich\b/Which/g
s/\bwidht\b/width/g
s/\bWIDHT\b/WIDTH/g
s/\bWidht\b/Width/g
s/\bwihout\b/without/g
s/\bWIHOUT\b/WITHOUT/g
s/\bWihout\b/Without/g
s/\bwiht\b/with/g
s/\bWIHT\b/WITH/g
s/\bWiht\b/With/g
s/\bwiil\b/will/g
s/\bWIIL\b/WILL/g
s/\bWiil\b/Will/g
s/\bwilcard\b/wildcard/g
s/\bWILCARD\b/WILDCARD/g
s/\bWilcard\b/Wildcard/g
s/\bwilcards\b/wildcards/g
s/\bWILCARDS\b/WILDCARDS/g
s/\bWilcards\b/Wildcards/g
s/\bwithing\b/within/g
s/\bWITHING\b/WITHIN/g
s/\bWithing\b/Within/g
s/\bwitin\b/within/g
s/\bWITIN\b/WITHIN/g
s/\bWitin\b/Within/g
s/\bwnat\b/want/g
s/\bWNAT\b/WANT/g
s/\bWnat\b/Want/g
s/\bwnated\b/wanted/g
s/\bWNATED\b/WANTED/g
s/\bWnated\b/Wanted/g
s/\bwnating\b/wanting/g
s/\bWNATING\b/WANTING/g
s/\bWnating\b/Wanting/g
s/\bwnats\b/wants/g
s/\bWNATS\b/WANTS/g
s/\bWnats\b/Wants/g
s/\bwont\b/won't/g
s/\bWONT\b/WON'T/g
s/\bWont\b/Won't/g
s/\bworkaroung\b/workaround/g
s/\bWORKAROUNG\b/WORKAROUND/g
s/\bWorkaroung\b/Workaround/g
s/\bwriteing\b/writing/g
s/\bWRITEING\b/WRITING/g
s/\bWriteing\b/Writing/g
s/\bwriten\b/written/g
s/\bWRITEN\b/WRITTEN/g
s/\bWriten\b/Written/g
s/\bwritting\b/writing/g
s/\bWRITTING\b/WRITING/g
s/\bWritting\b/Writing/g
s/\bxwindows\b/x/g
s/\bXWINDOWS\b/X/g
s/\bXwindows\b/X/g
s/\byeild\b/yield/g
s/\bYEILD\b/YIELD/g
s/\bYeild\b/Yield/g
s/\byeilded\b/yielded/g
s/\bYEILDED\b/YIELDED/g
s/\bYeilded\b/Yielded/g
s/\byeilding\b/yielding/g
s/\bYEILDING\b/YIELDING/g
s/\bYeilding\b/Yielding/g
s/\byeilds\b/yields/g
s/\bYEILDS\b/YIELDS/g
s/\bYeilds\b/Yields/g
s/\byur\b/your/g
s/\bYUR\b/YOUR/g
s/\bYur\b/Your/g
